.selected-mix-menu[data-v-0bbae480]{background-color:var(--5f861235)}.menu-wrapper :deep(.ant-menu-inline) .ant-menu-item{width:calc(100% - 16px);margin-inline:8px}.menu-wrapper :deep(.ant-menu-submenu-title){width:calc(100% - 16px);margin-inline:8px}.menu-wrapper :deep(.ant-menu-inline-collapsed)>.ant-menu-item{padding-inline:calc(50% - 14px)}.menu-wrapper :deep(.ant-menu-inline-collapsed) .ant-menu-item-icon{vertical-align:-.25em}.menu-wrapper :deep(.ant-menu-inline-collapsed) .ant-menu-submenu-title{padding-inline:calc(50% - 18px)}.select-menu :deep(.ant-menu-inline) .ant-menu-item-selected{background-color:var(--selected-bg-color)}.horizontal-menu :deep(.ant-menu-horizontal) .ant-menu-item{display:flex;align-items:center}.horizontal-menu :deep(.ant-menu-horizontal) .ant-menu-submenu-title{display:flex;align-items:center}.select-menu{--selected-bg-color: var(--ff6d0e9a)}
