import{_ as o}from"./exception-base.vue_vue_type_script_setup_true_lang-BdFCDlQv.js";import{d as n,c as t,o as a}from"./index-BUbJm6vx.js";const m=n({name:"403",__name:"index",setup(c){return(_,s)=>{const e=o;return a(),t(e,{type:"403"})}}});export{m as default};
