import{d as $a,x as vy,a as ls,e4 as wS,e5 as bS,U as Pa,b as cy,o as Er,t as dy,aT as py,$ as Bt,e6 as TS,c as li,w as Pe,f as Ie,e as pa,e7 as CS,bE as DS,h as Nv,bp as AS,I as MS,_ as IS,e8 as LS,bK as PS,e9 as RS,ea as ES,bJ as gy}from"./index-BUbJm6vx.js";import{C as mh,b as yy,c as my,a as kS}from"./index-q5WNHew0.js";const OS=$a({name:"CountTo",__name:"count-to",props:{startValue:{default:0},endValue:{default:2021},duration:{default:1500},autoplay:{type:Boolean,default:!0},decimals:{default:0},prefix:{default:""},suffix:{default:""},separator:{default:","},decimal:{default:"."},useEasing:{type:Boolean,default:!0},transition:{default:"linear"}},setup(r){const t=r,e=vy(t.startValue),n=ls(()=>t.useEasing?wS[t.transition]:void 0),i=bS(e,{disabled:!1,duration:t.duration,transition:n.value}),a=ls(()=>o(i.value));function o(l){const{decimals:u,decimal:f,separator:h,suffix:c,prefix:v}=t;let d=l.toFixed(u);d=String(d);const p=d.split(".");let g=p[0];const y=p.length>1?f+p[1]:"",m=/(\d+)(\d{3})/;if(h)for(;m.test(g);)g=g.replace(m,`$1${h}$2`);return v+g+y+c}async function s(){await py(),e.value=t.endValue}return Pa([()=>t.startValue,()=>t.endValue],()=>{t.autoplay&&s()},{immediate:!0}),(l,u)=>(Er(),cy("span",null,dy(a.value),1))}}),BS={class:"text-16px"},NS={class:"flex justify-between pt-12px"},FS=$a({name:"CardData",__name:"card-data",setup(r){const t=ls(()=>[{key:"visitCount",title:Bt("page.home.visitCount"),value:9725,unit:"",color:{start:"#ec4786",end:"#b955a4"},icon:"ant-design:bar-chart-outlined"},{key:"turnover",title:Bt("page.home.turnover"),value:1026,unit:"$",color:{start:"#865ec0",end:"#5144b4"},icon:"ant-design:money-collect-outlined"},{key:"downloadCount",title:Bt("page.home.downloadCount"),value:970925,unit:"",color:{start:"#56cdf3",end:"#719de3"},icon:"carbon:document-download"},{key:"dealCount",title:Bt("page.home.dealCount"),value:9527,unit:"",color:{start:"#fcbc25",end:"#f68057"},icon:"ant-design:trademark-circle-outlined"}]),[e,n]=TS();function i(a){return`linear-gradient(to bottom right, ${a.start}, ${a.end})`}return(a,o)=>{const s=IS,l=OS,u=my,f=yy,h=mh;return Er(),li(h,{bordered:!1,size:"small",class:"card-wrapper"},{default:Pe(()=>[Ie(Nv(e),null,{default:Pe(({$slots:c,gradientColor:v})=>[pa("div",{class:"rd-8px px-16px pb-4px pt-8px text-white",style:DS({backgroundImage:v})},[(Er(),li(CS(c.default)))],4)]),_:1}),Ie(f,{gutter:[16,16]},{default:Pe(()=>[(Er(!0),cy(MS,null,AS(t.value,c=>(Er(),li(u,{key:c.key,span:24,md:12,lg:6},{default:Pe(()=>[Ie(Nv(n),{"gradient-color":i(c.color),class:"flex-1"},{default:Pe(()=>[pa("h3",BS,dy(c.title),1),pa("div",NS,[Ie(s,{icon:c.icon,class:"text-32px"},null,8,["icon"]),Ie(l,{prefix:c.unit,"start-value":1,"end-value":c.value,class:"text-30px text-white dark:text-dark"},null,8,["prefix","end-value"])])]),_:2},1032,["gradient-color"])]),_:2},1024))),128))]),_:1})]),_:1})}}});/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var Ju=function(r,t){return Ju=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,n){e.__proto__=n}||function(e,n){for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(e[i]=n[i])},Ju(r,t)};function N(r,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");Ju(r,t);function e(){this.constructor=r}r.prototype=t===null?Object.create(t):(e.prototype=t.prototype,new e)}var zS=function(){function r(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return r}(),VS=function(){function r(){this.browser=new zS,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return r}(),J=new VS;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(J.wxa=!0,J.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?J.worker=!0:!J.hasGlobalWindow||"Deno"in window?(J.node=!0,J.svgSupported=!0):GS(navigator.userAgent,J);function GS(r,t){var e=t.browser,n=r.match(/Firefox\/([\d.]+)/),i=r.match(/MSIE\s([\d.]+)/)||r.match(/Trident\/.+?rv:(([\d.]+))/),a=r.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(r);n&&(e.firefox=!0,e.version=n[1]),i&&(e.ie=!0,e.version=i[1]),a&&(e.edge=!0,e.version=a[1],e.newEdge=+a[1].split(".")[0]>18),o&&(e.weChat=!0),t.svgSupported=typeof SVGRect<"u",t.touchEventsSupported="ontouchstart"in window&&!e.ie&&!e.edge,t.pointerEventsSupported="onpointerdown"in window&&(e.edge||e.ie&&+e.version>=11),t.domSupported=typeof document<"u";var s=document.documentElement.style;t.transform3dSupported=(e.ie&&"transition"in s||e.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in s)&&!("OTransition"in s),t.transformSupported=t.transform3dSupported||e.ie&&+e.version>=9}var _h=12,HS="sans-serif",Cn=_h+"px "+HS,WS=20,US=100,YS="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function XS(r){var t={};if(typeof JSON>"u")return t;for(var e=0;e<r.length;e++){var n=String.fromCharCode(e+32),i=(r.charCodeAt(e)-WS)/US;t[n]=i}return t}var ZS=XS(YS),Mi={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:function(){var r,t;return function(e,n){if(!r){var i=Mi.createCanvas();r=i&&i.getContext("2d")}if(r)return t!==n&&(t=r.font=n||Cn),r.measureText(e);e=e||"",n=n||Cn;var a=/((?:\d+)?\.?\d*)px/.exec(n),o=a&&+a[1]||_h,s=0;if(n.indexOf("mono")>=0)s=o*e.length;else for(var l=0;l<e.length;l++){var u=ZS[e[l]];s+=u==null?o:u*o}return{width:s}}}(),loadImage:function(r,t,e){var n=new Image;return n.onload=t,n.onerror=e,n.src=r,n}},_y=zr(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(r,t){return r["[object "+t+"]"]=!0,r},{}),Sy=zr(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(r,t){return r["[object "+t+"Array]"]=!0,r},{}),Ii=Object.prototype.toString,zs=Array.prototype,$S=zs.forEach,qS=zs.filter,Sh=zs.slice,KS=zs.map,Fv=(function(){}).constructor,eo=Fv?Fv.prototype:null,xh="__proto__",QS=2311;function xy(){return QS++}function wh(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];typeof console<"u"&&console.error.apply(console,r)}function tt(r){if(r==null||typeof r!="object")return r;var t=r,e=Ii.call(r);if(e==="[object Array]"){if(!ya(r)){t=[];for(var n=0,i=r.length;n<i;n++)t[n]=tt(r[n])}}else if(Sy[e]){if(!ya(r)){var a=r.constructor;if(a.from)t=a.from(r);else{t=new a(r.length);for(var n=0,i=r.length;n<i;n++)t[n]=r[n]}}}else if(!_y[e]&&!ya(r)&&!_i(r)){t={};for(var o in r)r.hasOwnProperty(o)&&o!==xh&&(t[o]=tt(r[o]))}return t}function nt(r,t,e){if(!Y(t)||!Y(r))return e?tt(t):r;for(var n in t)if(t.hasOwnProperty(n)&&n!==xh){var i=r[n],a=t[n];Y(a)&&Y(i)&&!V(a)&&!V(i)&&!_i(a)&&!_i(i)&&!zv(a)&&!zv(i)&&!ya(a)&&!ya(i)?nt(i,a,e):(e||!(n in r))&&(r[n]=tt(t[n]))}return r}function F(r,t){if(Object.assign)Object.assign(r,t);else for(var e in t)t.hasOwnProperty(e)&&e!==xh&&(r[e]=t[e]);return r}function Q(r,t,e){for(var n=mt(t),i=0,a=n.length;i<a;i++){var o=n[i];r[o]==null&&(r[o]=t[o])}return r}function lt(r,t){if(r){if(r.indexOf)return r.indexOf(t);for(var e=0,n=r.length;e<n;e++)if(r[e]===t)return e}return-1}function JS(r,t){var e=r.prototype;function n(){}n.prototype=t.prototype,r.prototype=new n;for(var i in e)e.hasOwnProperty(i)&&(r.prototype[i]=e[i]);r.prototype.constructor=r,r.superClass=t}function Oe(r,t,e){if(r="prototype"in r?r.prototype:r,t="prototype"in t?t.prototype:t,Object.getOwnPropertyNames)for(var n=Object.getOwnPropertyNames(t),i=0;i<n.length;i++){var a=n[i];a!=="constructor"&&r[a]==null&&(r[a]=t[a])}else Q(r,t)}function Kt(r){return!r||typeof r=="string"?!1:typeof r.length=="number"}function M(r,t,e){if(r&&t)if(r.forEach&&r.forEach===$S)r.forEach(t,e);else if(r.length===+r.length)for(var n=0,i=r.length;n<i;n++)t.call(e,r[n],n,r);else for(var a in r)r.hasOwnProperty(a)&&t.call(e,r[a],a,r)}function H(r,t,e){if(!r)return[];if(!t)return bh(r);if(r.map&&r.map===KS)return r.map(t,e);for(var n=[],i=0,a=r.length;i<a;i++)n.push(t.call(e,r[i],i,r));return n}function zr(r,t,e,n){if(r&&t){for(var i=0,a=r.length;i<a;i++)e=t.call(n,e,r[i],i,r);return e}}function Tt(r,t,e){if(!r)return[];if(!t)return bh(r);if(r.filter&&r.filter===qS)return r.filter(t,e);for(var n=[],i=0,a=r.length;i<a;i++)t.call(e,r[i],i,r)&&n.push(r[i]);return n}function jS(r,t,e){if(r&&t){for(var n=0,i=r.length;n<i;n++)if(t.call(e,r[n],n,r))return r[n]}}function mt(r){if(!r)return[];if(Object.keys)return Object.keys(r);var t=[];for(var e in r)r.hasOwnProperty(e)&&t.push(e);return t}function tx(r,t){for(var e=[],n=2;n<arguments.length;n++)e[n-2]=arguments[n];return function(){return r.apply(t,e.concat(Sh.call(arguments)))}}var dt=eo&&q(eo.bind)?eo.call.bind(eo.bind):tx;function vt(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return function(){return r.apply(this,t.concat(Sh.call(arguments)))}}function V(r){return Array.isArray?Array.isArray(r):Ii.call(r)==="[object Array]"}function q(r){return typeof r=="function"}function W(r){return typeof r=="string"}function ju(r){return Ii.call(r)==="[object String]"}function ct(r){return typeof r=="number"}function Y(r){var t=typeof r;return t==="function"||!!r&&t==="object"}function zv(r){return!!_y[Ii.call(r)]}function oe(r){return!!Sy[Ii.call(r)]}function _i(r){return typeof r=="object"&&typeof r.nodeType=="number"&&typeof r.ownerDocument=="object"}function Vs(r){return r.colorStops!=null}function ex(r){return r.image!=null}function rx(r){return Ii.call(r)==="[object RegExp]"}function us(r){return r!==r}function Si(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];for(var e=0,n=r.length;e<n;e++)if(r[e]!=null)return r[e]}function rt(r,t){return r??t}function ga(r,t,e){return r??t??e}function bh(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return Sh.apply(r,t)}function wy(r){if(typeof r=="number")return[r,r,r,r];var t=r.length;return t===2?[r[0],r[1],r[0],r[1]]:t===3?[r[0],r[1],r[2],r[1]]:r}function je(r,t){if(!r)throw new Error(t)}function Ze(r){return r==null?null:typeof r.trim=="function"?r.trim():r.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var by="__ec_primitive__";function fs(r){r[by]=!0}function ya(r){return r[by]}var nx=function(){function r(){this.data={}}return r.prototype.delete=function(t){var e=this.has(t);return e&&delete this.data[t],e},r.prototype.has=function(t){return this.data.hasOwnProperty(t)},r.prototype.get=function(t){return this.data[t]},r.prototype.set=function(t,e){return this.data[t]=e,this},r.prototype.keys=function(){return mt(this.data)},r.prototype.forEach=function(t){var e=this.data;for(var n in e)e.hasOwnProperty(n)&&t(e[n],n)},r}(),Ty=typeof Map=="function";function ix(){return Ty?new Map:new nx}var ax=function(){function r(t){var e=V(t);this.data=ix();var n=this;t instanceof r?t.each(i):t&&M(t,i);function i(a,o){e?n.set(a,o):n.set(o,a)}}return r.prototype.hasKey=function(t){return this.data.has(t)},r.prototype.get=function(t){return this.data.get(t)},r.prototype.set=function(t,e){return this.data.set(t,e),e},r.prototype.each=function(t,e){this.data.forEach(function(n,i){t.call(e,n,i)})},r.prototype.keys=function(){var t=this.data.keys();return Ty?Array.from(t):t},r.prototype.removeKey=function(t){this.data.delete(t)},r}();function $(r){return new ax(r)}function ox(r,t){for(var e=new r.constructor(r.length+t.length),n=0;n<r.length;n++)e[n]=r[n];for(var i=r.length,n=0;n<t.length;n++)e[n+i]=t[n];return e}function Gs(r,t){var e;if(Object.create)e=Object.create(r);else{var n=function(){};n.prototype=r,e=new n}return t&&F(e,t),e}function Cy(r){var t=r.style;t.webkitUserSelect="none",t.userSelect="none",t.webkitTapHighlightColor="rgba(0,0,0,0)",t["-webkit-touch-callout"]="none"}function tr(r,t){return r.hasOwnProperty(t)}function qt(){}var sx=180/Math.PI;function Li(r,t){return r==null&&(r=0),t==null&&(t=0),[r,t]}function lx(r){return[r[0],r[1]]}function Vv(r,t,e){return r[0]=t[0]+e[0],r[1]=t[1]+e[1],r}function ux(r,t,e){return r[0]=t[0]-e[0],r[1]=t[1]-e[1],r}function fx(r){return Math.sqrt(hx(r))}function hx(r){return r[0]*r[0]+r[1]*r[1]}function bl(r,t,e){return r[0]=t[0]*e,r[1]=t[1]*e,r}function vx(r,t){var e=fx(t);return e===0?(r[0]=0,r[1]=0):(r[0]=t[0]/e,r[1]=t[1]/e),r}function tf(r,t){return Math.sqrt((r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1]))}var ef=tf;function cx(r,t){return(r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1])}var ui=cx;function Xo(r,t,e,n){return r[0]=t[0]+n*(e[0]-t[0]),r[1]=t[1]+n*(e[1]-t[1]),r}function me(r,t,e){var n=t[0],i=t[1];return r[0]=e[0]*n+e[2]*i+e[4],r[1]=e[1]*n+e[3]*i+e[5],r}function ri(r,t,e){return r[0]=Math.min(t[0],e[0]),r[1]=Math.min(t[1],e[1]),r}function ni(r,t,e){return r[0]=Math.max(t[0],e[0]),r[1]=Math.max(t[1],e[1]),r}var Bn=function(){function r(t,e){this.target=t,this.topTarget=e&&e.topTarget}return r}(),dx=function(){function r(t){this.handler=t,t.on("mousedown",this._dragStart,this),t.on("mousemove",this._drag,this),t.on("mouseup",this._dragEnd,this)}return r.prototype._dragStart=function(t){for(var e=t.target;e&&!e.draggable;)e=e.parent||e.__hostTarget;e&&(this._draggingTarget=e,e.dragging=!0,this._x=t.offsetX,this._y=t.offsetY,this.handler.dispatchToElement(new Bn(e,t),"dragstart",t.event))},r.prototype._drag=function(t){var e=this._draggingTarget;if(e){var n=t.offsetX,i=t.offsetY,a=n-this._x,o=i-this._y;this._x=n,this._y=i,e.drift(a,o,t),this.handler.dispatchToElement(new Bn(e,t),"drag",t.event);var s=this.handler.findHover(n,i,e).target,l=this._dropTarget;this._dropTarget=s,e!==s&&(l&&s!==l&&this.handler.dispatchToElement(new Bn(l,t),"dragleave",t.event),s&&s!==l&&this.handler.dispatchToElement(new Bn(s,t),"dragenter",t.event))}},r.prototype._dragEnd=function(t){var e=this._draggingTarget;e&&(e.dragging=!1),this.handler.dispatchToElement(new Bn(e,t),"dragend",t.event),this._dropTarget&&this.handler.dispatchToElement(new Bn(this._dropTarget,t),"drop",t.event),this._draggingTarget=null,this._dropTarget=null},r}(),Be=function(){function r(t){t&&(this._$eventProcessor=t)}return r.prototype.on=function(t,e,n,i){this._$handlers||(this._$handlers={});var a=this._$handlers;if(typeof e=="function"&&(i=n,n=e,e=null),!n||!t)return this;var o=this._$eventProcessor;e!=null&&o&&o.normalizeQuery&&(e=o.normalizeQuery(e)),a[t]||(a[t]=[]);for(var s=0;s<a[t].length;s++)if(a[t][s].h===n)return this;var l={h:n,query:e,ctx:i||this,callAtLast:n.zrEventfulCallAtLast},u=a[t].length-1,f=a[t][u];return f&&f.callAtLast?a[t].splice(u,0,l):a[t].push(l),this},r.prototype.isSilent=function(t){var e=this._$handlers;return!e||!e[t]||!e[t].length},r.prototype.off=function(t,e){var n=this._$handlers;if(!n)return this;if(!t)return this._$handlers={},this;if(e){if(n[t]){for(var i=[],a=0,o=n[t].length;a<o;a++)n[t][a].h!==e&&i.push(n[t][a]);n[t]=i}n[t]&&n[t].length===0&&delete n[t]}else delete n[t];return this},r.prototype.trigger=function(t){for(var e=[],n=1;n<arguments.length;n++)e[n-1]=arguments[n];if(!this._$handlers)return this;var i=this._$handlers[t],a=this._$eventProcessor;if(i)for(var o=e.length,s=i.length,l=0;l<s;l++){var u=i[l];if(!(a&&a.filter&&u.query!=null&&!a.filter(t,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,e[0]);break;case 2:u.h.call(u.ctx,e[0],e[1]);break;default:u.h.apply(u.ctx,e);break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},r.prototype.triggerWithContext=function(t){for(var e=[],n=1;n<arguments.length;n++)e[n-1]=arguments[n];if(!this._$handlers)return this;var i=this._$handlers[t],a=this._$eventProcessor;if(i)for(var o=e.length,s=e[o-1],l=i.length,u=0;u<l;u++){var f=i[u];if(!(a&&a.filter&&f.query!=null&&!a.filter(t,f.query)))switch(o){case 0:f.h.call(s);break;case 1:f.h.call(s,e[0]);break;case 2:f.h.call(s,e[0],e[1]);break;default:f.h.apply(s,e.slice(1,o-1));break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},r}(),px=Math.log(2);function rf(r,t,e,n,i,a){var o=n+"-"+i,s=r.length;if(a.hasOwnProperty(o))return a[o];if(t===1){var l=Math.round(Math.log((1<<s)-1&~i)/px);return r[e][l]}for(var u=n|1<<e,f=e+1;n&1<<f;)f++;for(var h=0,c=0,v=0;c<s;c++){var d=1<<c;d&i||(h+=(v%2?-1:1)*r[e][c]*rf(r,t-1,f,u,i|d,a),v++)}return a[o]=h,h}function Gv(r,t){var e=[[r[0],r[1],1,0,0,0,-t[0]*r[0],-t[0]*r[1]],[0,0,0,r[0],r[1],1,-t[1]*r[0],-t[1]*r[1]],[r[2],r[3],1,0,0,0,-t[2]*r[2],-t[2]*r[3]],[0,0,0,r[2],r[3],1,-t[3]*r[2],-t[3]*r[3]],[r[4],r[5],1,0,0,0,-t[4]*r[4],-t[4]*r[5]],[0,0,0,r[4],r[5],1,-t[5]*r[4],-t[5]*r[5]],[r[6],r[7],1,0,0,0,-t[6]*r[6],-t[6]*r[7]],[0,0,0,r[6],r[7],1,-t[7]*r[6],-t[7]*r[7]]],n={},i=rf(e,8,0,0,0,n);if(i!==0){for(var a=[],o=0;o<8;o++)for(var s=0;s<8;s++)a[s]==null&&(a[s]=0),a[s]+=((o+s)%2?-1:1)*rf(e,7,o===0?1:0,1<<o,1<<s,n)/i*t[o];return function(l,u,f){var h=u*a[6]+f*a[7]+1;l[0]=(u*a[0]+f*a[1]+a[2])/h,l[1]=(u*a[3]+f*a[4]+a[5])/h}}}var Hv="___zrEVENTSAVED",Tl=[];function gx(r,t,e,n,i){return nf(Tl,t,n,i,!0)&&nf(r,e,Tl[0],Tl[1])}function nf(r,t,e,n,i){if(t.getBoundingClientRect&&J.domSupported&&!Dy(t)){var a=t[Hv]||(t[Hv]={}),o=yx(t,a),s=mx(o,a,i);if(s)return s(r,e,n),!0}return!1}function yx(r,t){var e=t.markers;if(e)return e;e=t.markers=[];for(var n=["left","right"],i=["top","bottom"],a=0;a<4;a++){var o=document.createElement("div"),s=o.style,l=a%2,u=(a>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",n[l]+":0",i[u]+":0",n[1-l]+":auto",i[1-u]+":auto",""].join("!important;"),r.appendChild(o),e.push(o)}return e}function mx(r,t,e){for(var n=e?"invTrans":"trans",i=t[n],a=t.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var f=r[u].getBoundingClientRect(),h=2*u,c=f.left,v=f.top;o.push(c,v),l=l&&a&&c===a[h]&&v===a[h+1],s.push(r[u].offsetLeft,r[u].offsetTop)}return l&&i?i:(t.srcCoords=o,t[n]=e?Gv(s,o):Gv(o,s))}function Dy(r){return r.nodeName.toUpperCase()==="CANVAS"}var _x=/([&<>"'])/g,Sx={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function re(r){return r==null?"":(r+"").replace(_x,function(t,e){return Sx[e]})}var xx=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Cl=[],bx=J.browser.firefox&&+J.browser.version.split(".")[0]<39;function af(r,t,e,n){return e=e||{},n?Wv(r,t,e):bx&&t.layerX!=null&&t.layerX!==t.offsetX?(e.zrX=t.layerX,e.zrY=t.layerY):t.offsetX!=null?(e.zrX=t.offsetX,e.zrY=t.offsetY):Wv(r,t,e),e}function Wv(r,t,e){if(J.domSupported&&r.getBoundingClientRect){var n=t.clientX,i=t.clientY;if(Dy(r)){var a=r.getBoundingClientRect();e.zrX=n-a.left,e.zrY=i-a.top;return}else if(nf(Cl,r,n,i)){e.zrX=Cl[0],e.zrY=Cl[1];return}}e.zrX=e.zrY=0}function Th(r){return r||window.event}function ve(r,t,e){if(t=Th(t),t.zrX!=null)return t;var n=t.type,i=n&&n.indexOf("touch")>=0;if(i){var o=n!=="touchend"?t.targetTouches[0]:t.changedTouches[0];o&&af(r,o,t,e)}else{af(r,t,t,e);var a=Tx(t);t.zrDelta=a?a/120:-(t.detail||0)/3}var s=t.button;return t.which==null&&s!==void 0&&xx.test(t.type)&&(t.which=s&1?1:s&2?3:s&4?2:0),t}function Tx(r){var t=r.wheelDelta;if(t)return t;var e=r.deltaX,n=r.deltaY;if(e==null||n==null)return t;var i=Math.abs(n!==0?n:e),a=n>0?-1:n<0?1:e>0?-1:1;return 3*i*a}function of(r,t,e,n){r.addEventListener(t,e,n)}function Cx(r,t,e,n){r.removeEventListener(t,e,n)}var Ay=function(r){r.preventDefault(),r.stopPropagation(),r.cancelBubble=!0},Dx=function(){function r(){this._track=[]}return r.prototype.recognize=function(t,e,n){return this._doTrack(t,e,n),this._recognize(t)},r.prototype.clear=function(){return this._track.length=0,this},r.prototype._doTrack=function(t,e,n){var i=t.touches;if(i){for(var a={points:[],touches:[],target:e,event:t},o=0,s=i.length;o<s;o++){var l=i[o],u=af(n,l,{});a.points.push([u.zrX,u.zrY]),a.touches.push(l)}this._track.push(a)}},r.prototype._recognize=function(t){for(var e in Dl)if(Dl.hasOwnProperty(e)){var n=Dl[e](this._track,t);if(n)return n}},r}();function Uv(r){var t=r[1][0]-r[0][0],e=r[1][1]-r[0][1];return Math.sqrt(t*t+e*e)}function Ax(r){return[(r[0][0]+r[1][0])/2,(r[0][1]+r[1][1])/2]}var Dl={pinch:function(r,t){var e=r.length;if(e){var n=(r[e-1]||{}).points,i=(r[e-2]||{}).points||n;if(i&&i.length>1&&n&&n.length>1){var a=Uv(n)/Uv(i);!isFinite(a)&&(a=1),t.pinchScale=a;var o=Ax(n);return t.pinchX=o[0],t.pinchY=o[1],{type:"pinch",target:r[0].target,event:t}}}}};function fi(){return[1,0,0,1,0,0]}function Ch(r){return r[0]=1,r[1]=0,r[2]=0,r[3]=1,r[4]=0,r[5]=0,r}function Mx(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4],r[5]=t[5],r}function hi(r,t,e){var n=t[0]*e[0]+t[2]*e[1],i=t[1]*e[0]+t[3]*e[1],a=t[0]*e[2]+t[2]*e[3],o=t[1]*e[2]+t[3]*e[3],s=t[0]*e[4]+t[2]*e[5]+t[4],l=t[1]*e[4]+t[3]*e[5]+t[5];return r[0]=n,r[1]=i,r[2]=a,r[3]=o,r[4]=s,r[5]=l,r}function sf(r,t,e){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4]+e[0],r[5]=t[5]+e[1],r}function Dh(r,t,e,n){n===void 0&&(n=[0,0]);var i=t[0],a=t[2],o=t[4],s=t[1],l=t[3],u=t[5],f=Math.sin(e),h=Math.cos(e);return r[0]=i*h+s*f,r[1]=-i*f+s*h,r[2]=a*h+l*f,r[3]=-a*f+h*l,r[4]=h*(o-n[0])+f*(u-n[1])+n[0],r[5]=h*(u-n[1])-f*(o-n[0])+n[1],r}function Ix(r,t,e){var n=e[0],i=e[1];return r[0]=t[0]*n,r[1]=t[1]*i,r[2]=t[2]*n,r[3]=t[3]*i,r[4]=t[4]*n,r[5]=t[5]*i,r}function Hs(r,t){var e=t[0],n=t[2],i=t[4],a=t[1],o=t[3],s=t[5],l=e*o-a*n;return l?(l=1/l,r[0]=o*l,r[1]=-a*l,r[2]=-n*l,r[3]=e*l,r[4]=(n*s-o*i)*l,r[5]=(a*i-e*s)*l,r):null}var X=function(){function r(t,e){this.x=t||0,this.y=e||0}return r.prototype.copy=function(t){return this.x=t.x,this.y=t.y,this},r.prototype.clone=function(){return new r(this.x,this.y)},r.prototype.set=function(t,e){return this.x=t,this.y=e,this},r.prototype.equal=function(t){return t.x===this.x&&t.y===this.y},r.prototype.add=function(t){return this.x+=t.x,this.y+=t.y,this},r.prototype.scale=function(t){this.x*=t,this.y*=t},r.prototype.scaleAndAdd=function(t,e){this.x+=t.x*e,this.y+=t.y*e},r.prototype.sub=function(t){return this.x-=t.x,this.y-=t.y,this},r.prototype.dot=function(t){return this.x*t.x+this.y*t.y},r.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},r.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},r.prototype.normalize=function(){var t=this.len();return this.x/=t,this.y/=t,this},r.prototype.distance=function(t){var e=this.x-t.x,n=this.y-t.y;return Math.sqrt(e*e+n*n)},r.prototype.distanceSquare=function(t){var e=this.x-t.x,n=this.y-t.y;return e*e+n*n},r.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},r.prototype.transform=function(t){if(t){var e=this.x,n=this.y;return this.x=t[0]*e+t[2]*n+t[4],this.y=t[1]*e+t[3]*n+t[5],this}},r.prototype.toArray=function(t){return t[0]=this.x,t[1]=this.y,t},r.prototype.fromArray=function(t){this.x=t[0],this.y=t[1]},r.set=function(t,e,n){t.x=e,t.y=n},r.copy=function(t,e){t.x=e.x,t.y=e.y},r.len=function(t){return Math.sqrt(t.x*t.x+t.y*t.y)},r.lenSquare=function(t){return t.x*t.x+t.y*t.y},r.dot=function(t,e){return t.x*e.x+t.y*e.y},r.add=function(t,e,n){t.x=e.x+n.x,t.y=e.y+n.y},r.sub=function(t,e,n){t.x=e.x-n.x,t.y=e.y-n.y},r.scale=function(t,e,n){t.x=e.x*n,t.y=e.y*n},r.scaleAndAdd=function(t,e,n,i){t.x=e.x+n.x*i,t.y=e.y+n.y*i},r.lerp=function(t,e,n,i){var a=1-i;t.x=a*e.x+i*n.x,t.y=a*e.y+i*n.y},r}(),ro=Math.min,no=Math.max,Zr=new X,$r=new X,qr=new X,Kr=new X,Fi=new X,zi=new X,ut=function(){function r(t,e,n,i){n<0&&(t=t+n,n=-n),i<0&&(e=e+i,i=-i),this.x=t,this.y=e,this.width=n,this.height=i}return r.prototype.union=function(t){var e=ro(t.x,this.x),n=ro(t.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=no(t.x+t.width,this.x+this.width)-e:this.width=t.width,isFinite(this.y)&&isFinite(this.height)?this.height=no(t.y+t.height,this.y+this.height)-n:this.height=t.height,this.x=e,this.y=n},r.prototype.applyTransform=function(t){r.applyTransform(this,this,t)},r.prototype.calculateTransform=function(t){var e=this,n=t.width/e.width,i=t.height/e.height,a=fi();return sf(a,a,[-e.x,-e.y]),Ix(a,a,[n,i]),sf(a,a,[t.x,t.y]),a},r.prototype.intersect=function(t,e){if(!t)return!1;t instanceof r||(t=r.create(t));var n=this,i=n.x,a=n.x+n.width,o=n.y,s=n.y+n.height,l=t.x,u=t.x+t.width,f=t.y,h=t.y+t.height,c=!(a<l||u<i||s<f||h<o);if(e){var v=1/0,d=0,p=Math.abs(a-l),g=Math.abs(u-i),y=Math.abs(s-f),m=Math.abs(h-o),_=Math.min(p,g),S=Math.min(y,m);a<l||u<i?_>d&&(d=_,p<g?X.set(zi,-p,0):X.set(zi,g,0)):_<v&&(v=_,p<g?X.set(Fi,p,0):X.set(Fi,-g,0)),s<f||h<o?S>d&&(d=S,y<m?X.set(zi,0,-y):X.set(zi,0,m)):_<v&&(v=_,y<m?X.set(Fi,0,y):X.set(Fi,0,-m))}return e&&X.copy(e,c?Fi:zi),c},r.prototype.contain=function(t,e){var n=this;return t>=n.x&&t<=n.x+n.width&&e>=n.y&&e<=n.y+n.height},r.prototype.clone=function(){return new r(this.x,this.y,this.width,this.height)},r.prototype.copy=function(t){r.copy(this,t)},r.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},r.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},r.prototype.isZero=function(){return this.width===0||this.height===0},r.create=function(t){return new r(t.x,t.y,t.width,t.height)},r.copy=function(t,e){t.x=e.x,t.y=e.y,t.width=e.width,t.height=e.height},r.applyTransform=function(t,e,n){if(!n){t!==e&&r.copy(t,e);return}if(n[1]<1e-5&&n[1]>-1e-5&&n[2]<1e-5&&n[2]>-1e-5){var i=n[0],a=n[3],o=n[4],s=n[5];t.x=e.x*i+o,t.y=e.y*a+s,t.width=e.width*i,t.height=e.height*a,t.width<0&&(t.x+=t.width,t.width=-t.width),t.height<0&&(t.y+=t.height,t.height=-t.height);return}Zr.x=qr.x=e.x,Zr.y=Kr.y=e.y,$r.x=Kr.x=e.x+e.width,$r.y=qr.y=e.y+e.height,Zr.transform(n),Kr.transform(n),$r.transform(n),qr.transform(n),t.x=ro(Zr.x,$r.x,qr.x,Kr.x),t.y=ro(Zr.y,$r.y,qr.y,Kr.y);var l=no(Zr.x,$r.x,qr.x,Kr.x),u=no(Zr.y,$r.y,qr.y,Kr.y);t.width=l-t.x,t.height=u-t.y},r}(),My="silent";function Lx(r,t,e){return{type:r,event:e,target:t.target,topTarget:t.topTarget,cancelBubble:!1,offsetX:e.zrX,offsetY:e.zrY,gestureEvent:e.gestureEvent,pinchX:e.pinchX,pinchY:e.pinchY,pinchScale:e.pinchScale,wheelDelta:e.zrDelta,zrByTouch:e.zrByTouch,which:e.which,stop:Px}}function Px(){Ay(this.event)}var Rx=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.handler=null,e}return t.prototype.dispose=function(){},t.prototype.setCursor=function(){},t}(Be),Vi=function(){function r(t,e){this.x=t,this.y=e}return r}(),Ex=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],Al=new ut(0,0,0,0),Iy=function(r){N(t,r);function t(e,n,i,a,o){var s=r.call(this)||this;return s._hovered=new Vi(0,0),s.storage=e,s.painter=n,s.painterRoot=a,s._pointerSize=o,i=i||new Rx,s.proxy=null,s.setHandlerProxy(i),s._draggingMgr=new dx(s),s}return t.prototype.setHandlerProxy=function(e){this.proxy&&this.proxy.dispose(),e&&(M(Ex,function(n){e.on&&e.on(n,this[n],this)},this),e.handler=this),this.proxy=e},t.prototype.mousemove=function(e){var n=e.zrX,i=e.zrY,a=Ly(this,n,i),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=a?new Vi(n,i):this.findHover(n,i),u=l.target,f=this.proxy;f.setCursor&&f.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",e),this.dispatchToElement(l,"mousemove",e),u&&u!==s&&this.dispatchToElement(l,"mouseover",e)},t.prototype.mouseout=function(e){var n=e.zrEventControl;n!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",e),n!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:e})},t.prototype.resize=function(){this._hovered=new Vi(0,0)},t.prototype.dispatch=function(e,n){var i=this[e];i&&i.call(this,n)},t.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},t.prototype.setCursorStyle=function(e){var n=this.proxy;n.setCursor&&n.setCursor(e)},t.prototype.dispatchToElement=function(e,n,i){e=e||{};var a=e.target;if(!(a&&a.silent)){for(var o="on"+n,s=Lx(n,e,i);a&&(a[o]&&(s.cancelBubble=!!a[o].call(a,s)),a.trigger(n,s),a=a.__hostTarget?a.__hostTarget:a.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(n,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(n,s)}))}},t.prototype.findHover=function(e,n,i){var a=this.storage.getDisplayList(),o=new Vi(e,n);if(Yv(a,o,e,n,i),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,f=new ut(e-u,n-u,l,l),h=a.length-1;h>=0;h--){var c=a[h];c!==i&&!c.ignore&&!c.ignoreCoarsePointer&&(!c.parent||!c.parent.ignoreCoarsePointer)&&(Al.copy(c.getBoundingRect()),c.transform&&Al.applyTransform(c.transform),Al.intersect(f)&&s.push(c))}if(s.length)for(var v=4,d=Math.PI/12,p=Math.PI*2,g=0;g<u;g+=v)for(var y=0;y<p;y+=d){var m=e+g*Math.cos(y),_=n+g*Math.sin(y);if(Yv(s,o,m,_,i),o.target)return o}}return o},t.prototype.processGesture=function(e,n){this._gestureMgr||(this._gestureMgr=new Dx);var i=this._gestureMgr;n==="start"&&i.clear();var a=i.recognize(e,this.findHover(e.zrX,e.zrY,null).target,this.proxy.dom);if(n==="end"&&i.clear(),a){var o=a.type;e.gestureEvent=o;var s=new Vi;s.target=a.target,this.dispatchToElement(s,o,a.event)}},t}(Be);M(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(r){Iy.prototype[r]=function(t){var e=t.zrX,n=t.zrY,i=Ly(this,e,n),a,o;if((r!=="mouseup"||!i)&&(a=this.findHover(e,n),o=a.target),r==="mousedown")this._downEl=o,this._downPoint=[t.zrX,t.zrY],this._upEl=o;else if(r==="mouseup")this._upEl=o;else if(r==="click"){if(this._downEl!==this._upEl||!this._downPoint||ef(this._downPoint,[t.zrX,t.zrY])>4)return;this._downPoint=null}this.dispatchToElement(a,r,t)}});function kx(r,t,e){if(r[r.rectHover?"rectContain":"contain"](t,e)){for(var n=r,i=void 0,a=!1;n;){if(n.ignoreClip&&(a=!0),!a){var o=n.getClipPath();if(o&&!o.contain(t,e))return!1}n.silent&&(i=!0);var s=n.__hostTarget;n=s||n.parent}return i?My:!0}return!1}function Yv(r,t,e,n,i){for(var a=r.length-1;a>=0;a--){var o=r[a],s=void 0;if(o!==i&&!o.ignore&&(s=kx(o,e,n))&&(!t.topTarget&&(t.topTarget=o),s!==My)){t.target=o;break}}}function Ly(r,t,e){var n=r.painter;return t<0||t>n.getWidth()||e<0||e>n.getHeight()}var Py=32,Gi=7;function Ox(r){for(var t=0;r>=Py;)t|=r&1,r>>=1;return r+t}function Xv(r,t,e,n){var i=t+1;if(i===e)return 1;if(n(r[i++],r[t])<0){for(;i<e&&n(r[i],r[i-1])<0;)i++;Bx(r,t,i)}else for(;i<e&&n(r[i],r[i-1])>=0;)i++;return i-t}function Bx(r,t,e){for(e--;t<e;){var n=r[t];r[t++]=r[e],r[e--]=n}}function Zv(r,t,e,n,i){for(n===t&&n++;n<e;n++){for(var a=r[n],o=t,s=n,l;o<s;)l=o+s>>>1,i(a,r[l])<0?s=l:o=l+1;var u=n-o;switch(u){case 3:r[o+3]=r[o+2];case 2:r[o+2]=r[o+1];case 1:r[o+1]=r[o];break;default:for(;u>0;)r[o+u]=r[o+u-1],u--}r[o]=a}}function Ml(r,t,e,n,i,a){var o=0,s=0,l=1;if(a(r,t[e+i])>0){for(s=n-i;l<s&&a(r,t[e+i+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=i,l+=i}else{for(s=i+1;l<s&&a(r,t[e+i-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=i-l,l=i-u}for(o++;o<l;){var f=o+(l-o>>>1);a(r,t[e+f])>0?o=f+1:l=f}return l}function Il(r,t,e,n,i,a){var o=0,s=0,l=1;if(a(r,t[e+i])<0){for(s=i+1;l<s&&a(r,t[e+i-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=i-l,l=i-u}else{for(s=n-i;l<s&&a(r,t[e+i+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=i,l+=i}for(o++;o<l;){var f=o+(l-o>>>1);a(r,t[e+f])<0?l=f:o=f+1}return l}function Nx(r,t){var e=Gi,n,i,a=0,o=[];n=[],i=[];function s(v,d){n[a]=v,i[a]=d,a+=1}function l(){for(;a>1;){var v=a-2;if(v>=1&&i[v-1]<=i[v]+i[v+1]||v>=2&&i[v-2]<=i[v]+i[v-1])i[v-1]<i[v+1]&&v--;else if(i[v]>i[v+1])break;f(v)}}function u(){for(;a>1;){var v=a-2;v>0&&i[v-1]<i[v+1]&&v--,f(v)}}function f(v){var d=n[v],p=i[v],g=n[v+1],y=i[v+1];i[v]=p+y,v===a-3&&(n[v+1]=n[v+2],i[v+1]=i[v+2]),a--;var m=Il(r[g],r,d,p,0,t);d+=m,p-=m,p!==0&&(y=Ml(r[d+p-1],r,g,y,y-1,t),y!==0&&(p<=y?h(d,p,g,y):c(d,p,g,y)))}function h(v,d,p,g){var y=0;for(y=0;y<d;y++)o[y]=r[v+y];var m=0,_=p,S=v;if(r[S++]=r[_++],--g===0){for(y=0;y<d;y++)r[S+y]=o[m+y];return}if(d===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m];return}for(var w=e,x,b,T;;){x=0,b=0,T=!1;do if(t(r[_],o[m])<0){if(r[S++]=r[_++],b++,x=0,--g===0){T=!0;break}}else if(r[S++]=o[m++],x++,b=0,--d===1){T=!0;break}while((x|b)<w);if(T)break;do{if(x=Il(r[_],o,m,d,0,t),x!==0){for(y=0;y<x;y++)r[S+y]=o[m+y];if(S+=x,m+=x,d-=x,d<=1){T=!0;break}}if(r[S++]=r[_++],--g===0){T=!0;break}if(b=Ml(o[m],r,_,g,0,t),b!==0){for(y=0;y<b;y++)r[S+y]=r[_+y];if(S+=b,_+=b,g-=b,g===0){T=!0;break}}if(r[S++]=o[m++],--d===1){T=!0;break}w--}while(x>=Gi||b>=Gi);if(T)break;w<0&&(w=0),w+=2}if(e=w,e<1&&(e=1),d===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m]}else{if(d===0)throw new Error;for(y=0;y<d;y++)r[S+y]=o[m+y]}}function c(v,d,p,g){var y=0;for(y=0;y<g;y++)o[y]=r[p+y];var m=v+d-1,_=g-1,S=p+g-1,w=0,x=0;if(r[S--]=r[m--],--d===0){for(w=S-(g-1),y=0;y<g;y++)r[w+y]=o[y];return}if(g===1){for(S-=d,m-=d,x=S+1,w=m+1,y=d-1;y>=0;y--)r[x+y]=r[w+y];r[S]=o[_];return}for(var b=e;;){var T=0,C=0,D=!1;do if(t(o[_],r[m])<0){if(r[S--]=r[m--],T++,C=0,--d===0){D=!0;break}}else if(r[S--]=o[_--],C++,T=0,--g===1){D=!0;break}while((T|C)<b);if(D)break;do{if(T=d-Il(o[_],r,v,d,d-1,t),T!==0){for(S-=T,m-=T,d-=T,x=S+1,w=m+1,y=T-1;y>=0;y--)r[x+y]=r[w+y];if(d===0){D=!0;break}}if(r[S--]=o[_--],--g===1){D=!0;break}if(C=g-Ml(r[m],o,0,g,g-1,t),C!==0){for(S-=C,_-=C,g-=C,x=S+1,w=_+1,y=0;y<C;y++)r[x+y]=o[w+y];if(g<=1){D=!0;break}}if(r[S--]=r[m--],--d===0){D=!0;break}b--}while(T>=Gi||C>=Gi);if(D)break;b<0&&(b=0),b+=2}if(e=b,e<1&&(e=1),g===1){for(S-=d,m-=d,x=S+1,w=m+1,y=d-1;y>=0;y--)r[x+y]=r[w+y];r[S]=o[_]}else{if(g===0)throw new Error;for(w=S-(g-1),y=0;y<g;y++)r[w+y]=o[y]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function Zo(r,t,e,n){e||(e=0),n||(n=r.length);var i=n-e;if(!(i<2)){var a=0;if(i<Py){a=Xv(r,e,n,t),Zv(r,e,n,e+a,t);return}var o=Nx(r,t),s=Ox(i);do{if(a=Xv(r,e,n,t),a<s){var l=i;l>s&&(l=s),Zv(r,e,e+l,e+a,t),a=l}o.pushRun(e,a),o.mergeRuns(),i-=a,e+=a}while(i!==0);o.forceMergeRuns()}}var Ke=1,$o=2,sa=4,$v=!1;function Ll(){$v||($v=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function qv(r,t){return r.zlevel===t.zlevel?r.z===t.z?r.z2-t.z2:r.z-t.z:r.zlevel-t.zlevel}var Fx=function(){function r(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=qv}return r.prototype.traverse=function(t,e){for(var n=0;n<this._roots.length;n++)this._roots[n].traverse(t,e)},r.prototype.getDisplayList=function(t,e){e=e||!1;var n=this._displayList;return(t||!n.length)&&this.updateDisplayList(e),n},r.prototype.updateDisplayList=function(t){this._displayListLen=0;for(var e=this._roots,n=this._displayList,i=0,a=e.length;i<a;i++)this._updateAndAddDisplayable(e[i],null,t);n.length=this._displayListLen,Zo(n,qv)},r.prototype._updateAndAddDisplayable=function(t,e,n){if(!(t.ignore&&!n)){t.beforeUpdate(),t.update(),t.afterUpdate();var i=t.getClipPath();if(t.ignoreClip)e=null;else if(i){e?e=e.slice():e=[];for(var a=i,o=t;a;)a.parent=o,a.updateTransform(),e.push(a),o=a,a=a.getClipPath()}if(t.childrenRef){for(var s=t.childrenRef(),l=0;l<s.length;l++){var u=s[l];t.__dirty&&(u.__dirty|=Ke),this._updateAndAddDisplayable(u,e,n)}t.__dirty=0}else{var f=t;e&&e.length?f.__clipPaths=e:f.__clipPaths&&f.__clipPaths.length>0&&(f.__clipPaths=[]),isNaN(f.z)&&(Ll(),f.z=0),isNaN(f.z2)&&(Ll(),f.z2=0),isNaN(f.zlevel)&&(Ll(),f.zlevel=0),this._displayList[this._displayListLen++]=f}var h=t.getDecalElement&&t.getDecalElement();h&&this._updateAndAddDisplayable(h,e,n);var c=t.getTextGuideLine();c&&this._updateAndAddDisplayable(c,e,n);var v=t.getTextContent();v&&this._updateAndAddDisplayable(v,e,n)}},r.prototype.addRoot=function(t){t.__zr&&t.__zr.storage===this||this._roots.push(t)},r.prototype.delRoot=function(t){if(t instanceof Array){for(var e=0,n=t.length;e<n;e++)this.delRoot(t[e]);return}var i=lt(this._roots,t);i>=0&&this._roots.splice(i,1)},r.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},r.prototype.getRoots=function(){return this._roots},r.prototype.dispose=function(){this._displayList=null,this._roots=null},r}(),hs;hs=J.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(r){return setTimeout(r,16)};var ma={linear:function(r){return r},quadraticIn:function(r){return r*r},quadraticOut:function(r){return r*(2-r)},quadraticInOut:function(r){return(r*=2)<1?.5*r*r:-.5*(--r*(r-2)-1)},cubicIn:function(r){return r*r*r},cubicOut:function(r){return--r*r*r+1},cubicInOut:function(r){return(r*=2)<1?.5*r*r*r:.5*((r-=2)*r*r+2)},quarticIn:function(r){return r*r*r*r},quarticOut:function(r){return 1- --r*r*r*r},quarticInOut:function(r){return(r*=2)<1?.5*r*r*r*r:-.5*((r-=2)*r*r*r-2)},quinticIn:function(r){return r*r*r*r*r},quinticOut:function(r){return--r*r*r*r*r+1},quinticInOut:function(r){return(r*=2)<1?.5*r*r*r*r*r:.5*((r-=2)*r*r*r*r+2)},sinusoidalIn:function(r){return 1-Math.cos(r*Math.PI/2)},sinusoidalOut:function(r){return Math.sin(r*Math.PI/2)},sinusoidalInOut:function(r){return .5*(1-Math.cos(Math.PI*r))},exponentialIn:function(r){return r===0?0:Math.pow(1024,r-1)},exponentialOut:function(r){return r===1?1:1-Math.pow(2,-10*r)},exponentialInOut:function(r){return r===0?0:r===1?1:(r*=2)<1?.5*Math.pow(1024,r-1):.5*(-Math.pow(2,-10*(r-1))+2)},circularIn:function(r){return 1-Math.sqrt(1-r*r)},circularOut:function(r){return Math.sqrt(1- --r*r)},circularInOut:function(r){return(r*=2)<1?-.5*(Math.sqrt(1-r*r)-1):.5*(Math.sqrt(1-(r-=2)*r)+1)},elasticIn:function(r){var t,e=.1,n=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=n/4):t=n*Math.asin(1/e)/(2*Math.PI),-(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/n)))},elasticOut:function(r){var t,e=.1,n=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=n/4):t=n*Math.asin(1/e)/(2*Math.PI),e*Math.pow(2,-10*r)*Math.sin((r-t)*(2*Math.PI)/n)+1)},elasticInOut:function(r){var t,e=.1,n=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=n/4):t=n*Math.asin(1/e)/(2*Math.PI),(r*=2)<1?-.5*(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/n)):e*Math.pow(2,-10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/n)*.5+1)},backIn:function(r){var t=1.70158;return r*r*((t+1)*r-t)},backOut:function(r){var t=1.70158;return--r*r*((t+1)*r+t)+1},backInOut:function(r){var t=2.5949095;return(r*=2)<1?.5*(r*r*((t+1)*r-t)):.5*((r-=2)*r*((t+1)*r+t)+2)},bounceIn:function(r){return 1-ma.bounceOut(1-r)},bounceOut:function(r){return r<1/2.75?7.5625*r*r:r<2/2.75?7.5625*(r-=1.5/2.75)*r+.75:r<2.5/2.75?7.5625*(r-=2.25/2.75)*r+.9375:7.5625*(r-=2.625/2.75)*r+.984375},bounceInOut:function(r){return r<.5?ma.bounceIn(r*2)*.5:ma.bounceOut(r*2-1)*.5+.5}},io=Math.pow,Br=Math.sqrt,Ry=1e-8,Ey=1e-4,Kv=Br(3),ao=1/3,Ye=Li(),pe=Li(),vi=Li();function kr(r){return r>-1e-8&&r<Ry}function ky(r){return r>Ry||r<-1e-8}function Et(r,t,e,n,i){var a=1-i;return a*a*(a*r+3*i*t)+i*i*(i*n+3*a*e)}function Qv(r,t,e,n,i){var a=1-i;return 3*(((t-r)*a+2*(e-t)*i)*a+(n-e)*i*i)}function vs(r,t,e,n,i,a){var o=n+3*(t-e)-r,s=3*(e-t*2+r),l=3*(t-r),u=r-i,f=s*s-3*o*l,h=s*l-9*o*u,c=l*l-3*s*u,v=0;if(kr(f)&&kr(h))if(kr(s))a[0]=0;else{var d=-l/s;d>=0&&d<=1&&(a[v++]=d)}else{var p=h*h-4*f*c;if(kr(p)){var g=h/f,d=-s/o+g,y=-g/2;d>=0&&d<=1&&(a[v++]=d),y>=0&&y<=1&&(a[v++]=y)}else if(p>0){var m=Br(p),_=f*s+1.5*o*(-h+m),S=f*s+1.5*o*(-h-m);_<0?_=-io(-_,ao):_=io(_,ao),S<0?S=-io(-S,ao):S=io(S,ao);var d=(-s-(_+S))/(3*o);d>=0&&d<=1&&(a[v++]=d)}else{var w=(2*f*s-3*o*h)/(2*Br(f*f*f)),x=Math.acos(w)/3,b=Br(f),T=Math.cos(x),d=(-s-2*b*T)/(3*o),y=(-s+b*(T+Kv*Math.sin(x)))/(3*o),C=(-s+b*(T-Kv*Math.sin(x)))/(3*o);d>=0&&d<=1&&(a[v++]=d),y>=0&&y<=1&&(a[v++]=y),C>=0&&C<=1&&(a[v++]=C)}}return v}function Oy(r,t,e,n,i){var a=6*e-12*t+6*r,o=9*t+3*n-3*r-9*e,s=3*t-3*r,l=0;if(kr(o)){if(ky(a)){var u=-s/a;u>=0&&u<=1&&(i[l++]=u)}}else{var f=a*a-4*o*s;if(kr(f))i[0]=-a/(2*o);else if(f>0){var h=Br(f),u=(-a+h)/(2*o),c=(-a-h)/(2*o);u>=0&&u<=1&&(i[l++]=u),c>=0&&c<=1&&(i[l++]=c)}}return l}function Vr(r,t,e,n,i,a){var o=(t-r)*i+r,s=(e-t)*i+t,l=(n-e)*i+e,u=(s-o)*i+o,f=(l-s)*i+s,h=(f-u)*i+u;a[0]=r,a[1]=o,a[2]=u,a[3]=h,a[4]=h,a[5]=f,a[6]=l,a[7]=n}function By(r,t,e,n,i,a,o,s,l,u,f){var h,c=.005,v=1/0,d,p,g,y;Ye[0]=l,Ye[1]=u;for(var m=0;m<1;m+=.05)pe[0]=Et(r,e,i,o,m),pe[1]=Et(t,n,a,s,m),g=ui(Ye,pe),g<v&&(h=m,v=g);v=1/0;for(var _=0;_<32&&!(c<Ey);_++)d=h-c,p=h+c,pe[0]=Et(r,e,i,o,d),pe[1]=Et(t,n,a,s,d),g=ui(pe,Ye),d>=0&&g<v?(h=d,v=g):(vi[0]=Et(r,e,i,o,p),vi[1]=Et(t,n,a,s,p),y=ui(vi,Ye),p<=1&&y<v?(h=p,v=y):c*=.5);return f&&(f[0]=Et(r,e,i,o,h),f[1]=Et(t,n,a,s,h)),Br(v)}function zx(r,t,e,n,i,a,o,s,l){for(var u=r,f=t,h=0,c=1/l,v=1;v<=l;v++){var d=v*c,p=Et(r,e,i,o,d),g=Et(t,n,a,s,d),y=p-u,m=g-f;h+=Math.sqrt(y*y+m*m),u=p,f=g}return h}function Gt(r,t,e,n){var i=1-n;return i*(i*r+2*n*t)+n*n*e}function Jv(r,t,e,n){return 2*((1-n)*(t-r)+n*(e-t))}function Vx(r,t,e,n,i){var a=r-2*t+e,o=2*(t-r),s=r-n,l=0;if(kr(a)){if(ky(o)){var u=-s/o;u>=0&&u<=1&&(i[l++]=u)}}else{var f=o*o-4*a*s;if(kr(f)){var u=-o/(2*a);u>=0&&u<=1&&(i[l++]=u)}else if(f>0){var h=Br(f),u=(-o+h)/(2*a),c=(-o-h)/(2*a);u>=0&&u<=1&&(i[l++]=u),c>=0&&c<=1&&(i[l++]=c)}}return l}function Ny(r,t,e){var n=r+e-2*t;return n===0?.5:(r-t)/n}function cs(r,t,e,n,i){var a=(t-r)*n+r,o=(e-t)*n+t,s=(o-a)*n+a;i[0]=r,i[1]=a,i[2]=s,i[3]=s,i[4]=o,i[5]=e}function Fy(r,t,e,n,i,a,o,s,l){var u,f=.005,h=1/0;Ye[0]=o,Ye[1]=s;for(var c=0;c<1;c+=.05){pe[0]=Gt(r,e,i,c),pe[1]=Gt(t,n,a,c);var v=ui(Ye,pe);v<h&&(u=c,h=v)}h=1/0;for(var d=0;d<32&&!(f<Ey);d++){var p=u-f,g=u+f;pe[0]=Gt(r,e,i,p),pe[1]=Gt(t,n,a,p);var v=ui(pe,Ye);if(p>=0&&v<h)u=p,h=v;else{vi[0]=Gt(r,e,i,g),vi[1]=Gt(t,n,a,g);var y=ui(vi,Ye);g<=1&&y<h?(u=g,h=y):f*=.5}}return l&&(l[0]=Gt(r,e,i,u),l[1]=Gt(t,n,a,u)),Br(h)}function Gx(r,t,e,n,i,a,o){for(var s=r,l=t,u=0,f=1/o,h=1;h<=o;h++){var c=h*f,v=Gt(r,e,i,c),d=Gt(t,n,a,c),p=v-s,g=d-l;u+=Math.sqrt(p*p+g*g),s=v,l=d}return u}var Hx=/cubic-bezier\(([0-9,\.e ]+)\)/;function zy(r){var t=r&&Hx.exec(r);if(t){var e=t[1].split(","),n=+Ze(e[0]),i=+Ze(e[1]),a=+Ze(e[2]),o=+Ze(e[3]);if(isNaN(n+i+a+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:vs(0,n,a,1,l,s)&&Et(0,i,o,1,s[0])}}}var Wx=function(){function r(t){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=t.life||1e3,this._delay=t.delay||0,this.loop=t.loop||!1,this.onframe=t.onframe||qt,this.ondestroy=t.ondestroy||qt,this.onrestart=t.onrestart||qt,t.easing&&this.setEasing(t.easing)}return r.prototype.step=function(t,e){if(this._inited||(this._startTime=t+this._delay,this._inited=!0),this._paused){this._pausedTime+=e;return}var n=this._life,i=t-this._startTime-this._pausedTime,a=i/n;a<0&&(a=0),a=Math.min(a,1);var o=this.easingFunc,s=o?o(a):a;if(this.onframe(s),a===1)if(this.loop){var l=i%n;this._startTime=t-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){this._paused=!1},r.prototype.setEasing=function(t){this.easing=t,this.easingFunc=q(t)?t:ma[t]||zy(t)},r}(),Vy=function(){function r(t){this.value=t}return r}(),Ux=function(){function r(){this._len=0}return r.prototype.insert=function(t){var e=new Vy(t);return this.insertEntry(e),e},r.prototype.insertEntry=function(t){this.head?(this.tail.next=t,t.prev=this.tail,t.next=null,this.tail=t):this.head=this.tail=t,this._len++},r.prototype.remove=function(t){var e=t.prev,n=t.next;e?e.next=n:this.head=n,n?n.prev=e:this.tail=e,t.next=t.prev=null,this._len--},r.prototype.len=function(){return this._len},r.prototype.clear=function(){this.head=this.tail=null,this._len=0},r}(),qa=function(){function r(t){this._list=new Ux,this._maxSize=10,this._map={},this._maxSize=t}return r.prototype.put=function(t,e){var n=this._list,i=this._map,a=null;if(i[t]==null){var o=n.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=n.head;n.remove(l),delete i[l.key],a=l.value,this._lastRemovedEntry=l}s?s.value=e:s=new Vy(e),s.key=t,n.insertEntry(s),i[t]=s}return a},r.prototype.get=function(t){var e=this._map[t],n=this._list;if(e!=null)return e!==n.tail&&(n.remove(e),n.insertEntry(e)),e.value},r.prototype.clear=function(){this._list.clear(),this._map={}},r.prototype.len=function(){return this._list.len()},r}(),jv={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function Nr(r){return r=Math.round(r),r<0?0:r>255?255:r}function lf(r){return r<0?0:r>1?1:r}function Pl(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?Nr(parseFloat(t)/100*255):Nr(parseInt(t,10))}function _a(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?lf(parseFloat(t)/100):lf(parseFloat(t))}function Rl(r,t,e){return e<0?e+=1:e>1&&(e-=1),e*6<1?r+(t-r)*e*6:e*2<1?t:e*3<2?r+(t-r)*(2/3-e)*6:r}function oo(r,t,e){return r+(t-r)*e}function he(r,t,e,n,i){return r[0]=t,r[1]=e,r[2]=n,r[3]=i,r}function uf(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r}var Gy=new qa(20),so=null;function Nn(r,t){so&&uf(so,t),so=Gy.put(r,so||t.slice())}function dr(r,t){if(r){t=t||[];var e=Gy.get(r);if(e)return uf(t,e);r=r+"";var n=r.replace(/ /g,"").toLowerCase();if(n in jv)return uf(t,jv[n]),Nn(r,t),t;var i=n.length;if(n.charAt(0)==="#"){if(i===4||i===5){var a=parseInt(n.slice(1,4),16);if(!(a>=0&&a<=4095)){he(t,0,0,0,1);return}return he(t,(a&3840)>>4|(a&3840)>>8,a&240|(a&240)>>4,a&15|(a&15)<<4,i===5?parseInt(n.slice(4),16)/15:1),Nn(r,t),t}else if(i===7||i===9){var a=parseInt(n.slice(1,7),16);if(!(a>=0&&a<=16777215)){he(t,0,0,0,1);return}return he(t,(a&16711680)>>16,(a&65280)>>8,a&255,i===9?parseInt(n.slice(7),16)/255:1),Nn(r,t),t}return}var o=n.indexOf("("),s=n.indexOf(")");if(o!==-1&&s+1===i){var l=n.substr(0,o),u=n.substr(o+1,s-(o+1)).split(","),f=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?he(t,+u[0],+u[1],+u[2],1):he(t,0,0,0,1);f=_a(u.pop());case"rgb":if(u.length>=3)return he(t,Pl(u[0]),Pl(u[1]),Pl(u[2]),u.length===3?f:_a(u[3])),Nn(r,t),t;he(t,0,0,0,1);return;case"hsla":if(u.length!==4){he(t,0,0,0,1);return}return u[3]=_a(u[3]),tc(u,t),Nn(r,t),t;case"hsl":if(u.length!==3){he(t,0,0,0,1);return}return tc(u,t),Nn(r,t),t;default:return}}he(t,0,0,0,1)}}function tc(r,t){var e=(parseFloat(r[0])%360+360)%360/360,n=_a(r[1]),i=_a(r[2]),a=i<=.5?i*(n+1):i+n-i*n,o=i*2-a;return t=t||[],he(t,Nr(Rl(o,a,e+1/3)*255),Nr(Rl(o,a,e)*255),Nr(Rl(o,a,e-1/3)*255),1),r.length===4&&(t[3]=r[3]),t}function ec(r,t){var e=dr(r);if(e){for(var n=0;n<3;n++)e[n]=e[n]*(1-t)|0,e[n]>255?e[n]=255:e[n]<0&&(e[n]=0);return Ws(e,e.length===4?"rgba":"rgb")}}function Yx(r,t,e){if(!(!(t&&t.length)||!(r>=0&&r<=1))){var n=r*(t.length-1),i=Math.floor(n),a=Math.ceil(n),o=dr(t[i]),s=dr(t[a]),l=n-i,u=Ws([Nr(oo(o[0],s[0],l)),Nr(oo(o[1],s[1],l)),Nr(oo(o[2],s[2],l)),lf(oo(o[3],s[3],l))],"rgba");return e?{color:u,leftIndex:i,rightIndex:a,value:n}:u}}function Ws(r,t){if(!(!r||!r.length)){var e=r[0]+","+r[1]+","+r[2];return(t==="rgba"||t==="hsva"||t==="hsla")&&(e+=","+r[3]),t+"("+e+")"}}function ds(r,t){var e=dr(r);return e?(.299*e[0]+.587*e[1]+.114*e[2])*e[3]/255+(1-e[3])*t:0}var rc=new qa(100);function nc(r){if(W(r)){var t=rc.get(r);return t||(t=ec(r,-.1),rc.put(r,t)),t}else if(Vs(r)){var e=F({},r);return e.colorStops=H(r.colorStops,function(n){return{offset:n.offset,color:ec(n.color,-.1)}}),e}return r}function Xx(r){return r.type==="linear"}function Zx(r){return r.type==="radial"}(function(){return J.hasGlobalWindow&&q(window.btoa)?function(r){return window.btoa(unescape(encodeURIComponent(r)))}:typeof Buffer<"u"?function(r){return Buffer.from(r).toString("base64")}:function(r){return null}})();var ff=Array.prototype.slice;function ur(r,t,e){return(t-r)*e+r}function El(r,t,e,n){for(var i=t.length,a=0;a<i;a++)r[a]=ur(t[a],e[a],n);return r}function $x(r,t,e,n){for(var i=t.length,a=i&&t[0].length,o=0;o<i;o++){r[o]||(r[o]=[]);for(var s=0;s<a;s++)r[o][s]=ur(t[o][s],e[o][s],n)}return r}function lo(r,t,e,n){for(var i=t.length,a=0;a<i;a++)r[a]=t[a]+e[a]*n;return r}function ic(r,t,e,n){for(var i=t.length,a=i&&t[0].length,o=0;o<i;o++){r[o]||(r[o]=[]);for(var s=0;s<a;s++)r[o][s]=t[o][s]+e[o][s]*n}return r}function qx(r,t){for(var e=r.length,n=t.length,i=e>n?t:r,a=Math.min(e,n),o=i[a-1]||{color:[0,0,0,0],offset:0},s=a;s<Math.max(e,n);s++)i.push({offset:o.offset,color:o.color.slice()})}function Kx(r,t,e){var n=r,i=t;if(!(!n.push||!i.push)){var a=n.length,o=i.length;if(a!==o){var s=a>o;if(s)n.length=o;else for(var l=a;l<o;l++)n.push(e===1?i[l]:ff.call(i[l]))}for(var u=n[0]&&n[0].length,l=0;l<n.length;l++)if(e===1)isNaN(n[l])&&(n[l]=i[l]);else for(var f=0;f<u;f++)isNaN(n[l][f])&&(n[l][f]=i[l][f])}}function qo(r){if(Kt(r)){var t=r.length;if(Kt(r[0])){for(var e=[],n=0;n<t;n++)e.push(ff.call(r[n]));return e}return ff.call(r)}return r}function Ko(r){return r[0]=Math.floor(r[0])||0,r[1]=Math.floor(r[1])||0,r[2]=Math.floor(r[2])||0,r[3]=r[3]==null?1:r[3],"rgba("+r.join(",")+")"}function Qx(r){return Kt(r&&r[0])?2:1}var uo=0,Qo=1,Hy=2,la=3,hf=4,vf=5,ac=6;function oc(r){return r===hf||r===vf}function fo(r){return r===Qo||r===Hy}var Hi=[0,0,0,0],Jx=function(){function r(t){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=t}return r.prototype.isFinished=function(){return this._finished},r.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},r.prototype.needsAnimate=function(){return this.keyframes.length>=1},r.prototype.getAdditiveTrack=function(){return this._additiveTrack},r.prototype.addKeyframe=function(t,e,n){this._needsSort=!0;var i=this.keyframes,a=i.length,o=!1,s=ac,l=e;if(Kt(e)){var u=Qx(e);s=u,(u===1&&!ct(e[0])||u===2&&!ct(e[0][0]))&&(o=!0)}else if(ct(e)&&!us(e))s=uo;else if(W(e))if(!isNaN(+e))s=uo;else{var f=dr(e);f&&(l=f,s=la)}else if(Vs(e)){var h=F({},l);h.colorStops=H(e.colorStops,function(v){return{offset:v.offset,color:dr(v.color)}}),Xx(e)?s=hf:Zx(e)&&(s=vf),l=h}a===0?this.valType=s:(s!==this.valType||s===ac)&&(o=!0),this.discrete=this.discrete||o;var c={time:t,value:l,rawValue:e,percent:0};return n&&(c.easing=n,c.easingFunc=q(n)?n:ma[n]||zy(n)),i.push(c),c},r.prototype.prepare=function(t,e){var n=this.keyframes;this._needsSort&&n.sort(function(p,g){return p.time-g.time});for(var i=this.valType,a=n.length,o=n[a-1],s=this.discrete,l=fo(i),u=oc(i),f=0;f<a;f++){var h=n[f],c=h.value,v=o.value;h.percent=h.time/t,s||(l&&f!==a-1?Kx(c,v,i):u&&qx(c.colorStops,v.colorStops))}if(!s&&i!==vf&&e&&this.needsAnimate()&&e.needsAnimate()&&i===e.valType&&!e._finished){this._additiveTrack=e;for(var d=n[0].value,f=0;f<a;f++)i===uo?n[f].additiveValue=n[f].value-d:i===la?n[f].additiveValue=lo([],n[f].value,d,-1):fo(i)&&(n[f].additiveValue=i===Qo?lo([],n[f].value,d,-1):ic([],n[f].value,d,-1))}},r.prototype.step=function(t,e){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var n=this._additiveTrack!=null,i=n?"additiveValue":"value",a=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=a===la,f,h=this._lastFr,c=Math.min,v,d;if(s===1)v=d=o[0];else{if(e<0)f=0;else if(e<this._lastFrP){var p=c(h+1,s-1);for(f=p;f>=0&&!(o[f].percent<=e);f--);f=c(f,s-2)}else{for(f=h;f<s&&!(o[f].percent>e);f++);f=c(f-1,s-2)}d=o[f+1],v=o[f]}if(v&&d){this._lastFr=f,this._lastFrP=e;var g=d.percent-v.percent,y=g===0?1:c((e-v.percent)/g,1);d.easingFunc&&(y=d.easingFunc(y));var m=n?this._additiveValue:u?Hi:t[l];if((fo(a)||u)&&!m&&(m=this._additiveValue=[]),this.discrete)t[l]=y<1?v.rawValue:d.rawValue;else if(fo(a))a===Qo?El(m,v[i],d[i],y):$x(m,v[i],d[i],y);else if(oc(a)){var _=v[i],S=d[i],w=a===hf;t[l]={type:w?"linear":"radial",x:ur(_.x,S.x,y),y:ur(_.y,S.y,y),colorStops:H(_.colorStops,function(b,T){var C=S.colorStops[T];return{offset:ur(b.offset,C.offset,y),color:Ko(El([],b.color,C.color,y))}}),global:S.global},w?(t[l].x2=ur(_.x2,S.x2,y),t[l].y2=ur(_.y2,S.y2,y)):t[l].r=ur(_.r,S.r,y)}else if(u)El(m,v[i],d[i],y),n||(t[l]=Ko(m));else{var x=ur(v[i],d[i],y);n?this._additiveValue=x:t[l]=x}n&&this._addToTarget(t)}}},r.prototype._addToTarget=function(t){var e=this.valType,n=this.propName,i=this._additiveValue;e===uo?t[n]=t[n]+i:e===la?(dr(t[n],Hi),lo(Hi,Hi,i,1),t[n]=Ko(Hi)):e===Qo?lo(t[n],t[n],i,1):e===Hy&&ic(t[n],t[n],i,1)},r}(),Ah=function(){function r(t,e,n,i){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=t,this._loop=e,e&&i){wh("Can' use additive animation on looped animation.");return}this._additiveAnimators=i,this._allowDiscrete=n}return r.prototype.getMaxTime=function(){return this._maxTime},r.prototype.getDelay=function(){return this._delay},r.prototype.getLoop=function(){return this._loop},r.prototype.getTarget=function(){return this._target},r.prototype.changeTarget=function(t){this._target=t},r.prototype.when=function(t,e,n){return this.whenWithKeys(t,e,mt(e),n)},r.prototype.whenWithKeys=function(t,e,n,i){for(var a=this._tracks,o=0;o<n.length;o++){var s=n[o],l=a[s];if(!l){l=a[s]=new Jx(s);var u=void 0,f=this._getAdditiveTrack(s);if(f){var h=f.keyframes,c=h[h.length-1];u=c&&c.value,f.valType===la&&u&&(u=Ko(u))}else u=this._target[s];if(u==null)continue;t>0&&l.addKeyframe(0,qo(u),i),this._trackKeys.push(s)}l.addKeyframe(t,qo(e[s]),i)}return this._maxTime=Math.max(this._maxTime,t),this},r.prototype.pause=function(){this._clip.pause(),this._paused=!0},r.prototype.resume=function(){this._clip.resume(),this._paused=!1},r.prototype.isPaused=function(){return!!this._paused},r.prototype.duration=function(t){return this._maxTime=t,this._force=!0,this},r.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var t=this._doneCbs;if(t)for(var e=t.length,n=0;n<e;n++)t[n].call(this)},r.prototype._abortedCallback=function(){this._setTracksFinished();var t=this.animation,e=this._abortedCbs;if(t&&t.removeClip(this._clip),this._clip=null,e)for(var n=0;n<e.length;n++)e[n].call(this)},r.prototype._setTracksFinished=function(){for(var t=this._tracks,e=this._trackKeys,n=0;n<e.length;n++)t[e[n]].setFinished()},r.prototype._getAdditiveTrack=function(t){var e,n=this._additiveAnimators;if(n)for(var i=0;i<n.length;i++){var a=n[i].getTrack(t);a&&(e=a)}return e},r.prototype.start=function(t){if(!(this._started>0)){this._started=1;for(var e=this,n=[],i=this._maxTime||0,a=0;a<this._trackKeys.length;a++){var o=this._trackKeys[a],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,f=u.length;if(s.prepare(i,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var h=u[f-1];h&&(e._target[s.propName]=h.rawValue),s.setFinished()}else n.push(s)}if(n.length||this._force){var c=new Wx({life:i,loop:this._loop,delay:this._delay||0,onframe:function(v){e._started=2;var d=e._additiveAnimators;if(d){for(var p=!1,g=0;g<d.length;g++)if(d[g]._clip){p=!0;break}p||(e._additiveAnimators=null)}for(var g=0;g<n.length;g++)n[g].step(e._target,v);var y=e._onframeCbs;if(y)for(var g=0;g<y.length;g++)y[g](e._target,v)},ondestroy:function(){e._doneCallback()}});this._clip=c,this.animation&&this.animation.addClip(c),t&&c.setEasing(t)}else this._doneCallback();return this}},r.prototype.stop=function(t){if(this._clip){var e=this._clip;t&&e.onframe(1),this._abortedCallback()}},r.prototype.delay=function(t){return this._delay=t,this},r.prototype.during=function(t){return t&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(t)),this},r.prototype.done=function(t){return t&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(t)),this},r.prototype.aborted=function(t){return t&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(t)),this},r.prototype.getClip=function(){return this._clip},r.prototype.getTrack=function(t){return this._tracks[t]},r.prototype.getTracks=function(){var t=this;return H(this._trackKeys,function(e){return t._tracks[e]})},r.prototype.stopTracks=function(t,e){if(!t.length||!this._clip)return!0;for(var n=this._tracks,i=this._trackKeys,a=0;a<t.length;a++){var o=n[t[a]];o&&!o.isFinished()&&(e?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,a=0;a<i.length;a++)if(!n[i[a]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},r.prototype.saveTo=function(t,e,n){if(t){e=e||this._trackKeys;for(var i=0;i<e.length;i++){var a=e[i],o=this._tracks[a];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[n?0:s.length-1];l&&(t[a]=qo(l.rawValue))}}}},r.prototype.__changeFinalValue=function(t,e){e=e||mt(t);for(var n=0;n<e.length;n++){var i=e[n],a=this._tracks[i];if(a){var o=a.keyframes;if(o.length>1){var s=o.pop();a.addKeyframe(s.time,t[i]),a.prepare(this._maxTime,a.getAdditiveTrack())}}}},r}();function ii(){return new Date().getTime()}var jx=function(r){N(t,r);function t(e){var n=r.call(this)||this;return n._running=!1,n._time=0,n._pausedTime=0,n._pauseStart=0,n._paused=!1,e=e||{},n.stage=e.stage||{},n}return t.prototype.addClip=function(e){e.animation&&this.removeClip(e),this._head?(this._tail.next=e,e.prev=this._tail,e.next=null,this._tail=e):this._head=this._tail=e,e.animation=this},t.prototype.addAnimator=function(e){e.animation=this;var n=e.getClip();n&&this.addClip(n)},t.prototype.removeClip=function(e){if(e.animation){var n=e.prev,i=e.next;n?n.next=i:this._head=i,i?i.prev=n:this._tail=n,e.next=e.prev=e.animation=null}},t.prototype.removeAnimator=function(e){var n=e.getClip();n&&this.removeClip(n),e.animation=null},t.prototype.update=function(e){for(var n=ii()-this._pausedTime,i=n-this._time,a=this._head;a;){var o=a.next,s=a.step(n,i);s&&(a.ondestroy(),this.removeClip(a)),a=o}this._time=n,e||(this.trigger("frame",i),this.stage.update&&this.stage.update())},t.prototype._startLoop=function(){var e=this;this._running=!0;function n(){e._running&&(hs(n),!e._paused&&e.update())}hs(n)},t.prototype.start=function(){this._running||(this._time=ii(),this._pausedTime=0,this._startLoop())},t.prototype.stop=function(){this._running=!1},t.prototype.pause=function(){this._paused||(this._pauseStart=ii(),this._paused=!0)},t.prototype.resume=function(){this._paused&&(this._pausedTime+=ii()-this._pauseStart,this._paused=!1)},t.prototype.clear=function(){for(var e=this._head;e;){var n=e.next;e.prev=e.next=e.animation=null,e=n}this._head=this._tail=null},t.prototype.isFinished=function(){return this._head==null},t.prototype.animate=function(e,n){n=n||{},this.start();var i=new Ah(e,n.loop);return this.addAnimator(i),i},t}(Be),tw=300,kl=J.domSupported,Ol=function(){var r=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],t=["touchstart","touchend","touchmove"],e={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},n=H(r,function(i){var a=i.replace("mouse","pointer");return e.hasOwnProperty(a)?a:i});return{mouse:r,touch:t,pointer:n}}(),sc={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},lc=!1;function cf(r){var t=r.pointerType;return t==="pen"||t==="touch"}function ew(r){r.touching=!0,r.touchTimer!=null&&(clearTimeout(r.touchTimer),r.touchTimer=null),r.touchTimer=setTimeout(function(){r.touching=!1,r.touchTimer=null},700)}function Bl(r){r&&(r.zrByTouch=!0)}function rw(r,t){return ve(r.dom,new nw(r,t),!0)}function Wy(r,t){for(var e=t,n=!1;e&&e.nodeType!==9&&!(n=e.domBelongToZr||e!==t&&e===r.painterRoot);)e=e.parentNode;return n}var nw=function(){function r(t,e){this.stopPropagation=qt,this.stopImmediatePropagation=qt,this.preventDefault=qt,this.type=e.type,this.target=this.currentTarget=t.dom,this.pointerType=e.pointerType,this.clientX=e.clientX,this.clientY=e.clientY}return r}(),De={mousedown:function(r){r=ve(this.dom,r),this.__mayPointerCapture=[r.zrX,r.zrY],this.trigger("mousedown",r)},mousemove:function(r){r=ve(this.dom,r);var t=this.__mayPointerCapture;t&&(r.zrX!==t[0]||r.zrY!==t[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",r)},mouseup:function(r){r=ve(this.dom,r),this.__togglePointerCapture(!1),this.trigger("mouseup",r)},mouseout:function(r){r=ve(this.dom,r);var t=r.toElement||r.relatedTarget;Wy(this,t)||(this.__pointerCapturing&&(r.zrEventControl="no_globalout"),this.trigger("mouseout",r))},wheel:function(r){lc=!0,r=ve(this.dom,r),this.trigger("mousewheel",r)},mousewheel:function(r){lc||(r=ve(this.dom,r),this.trigger("mousewheel",r))},touchstart:function(r){r=ve(this.dom,r),Bl(r),this.__lastTouchMoment=new Date,this.handler.processGesture(r,"start"),De.mousemove.call(this,r),De.mousedown.call(this,r)},touchmove:function(r){r=ve(this.dom,r),Bl(r),this.handler.processGesture(r,"change"),De.mousemove.call(this,r)},touchend:function(r){r=ve(this.dom,r),Bl(r),this.handler.processGesture(r,"end"),De.mouseup.call(this,r),+new Date-+this.__lastTouchMoment<tw&&De.click.call(this,r)},pointerdown:function(r){De.mousedown.call(this,r)},pointermove:function(r){cf(r)||De.mousemove.call(this,r)},pointerup:function(r){De.mouseup.call(this,r)},pointerout:function(r){cf(r)||De.mouseout.call(this,r)}};M(["click","dblclick","contextmenu"],function(r){De[r]=function(t){t=ve(this.dom,t),this.trigger(r,t)}});var df={pointermove:function(r){cf(r)||df.mousemove.call(this,r)},pointerup:function(r){df.mouseup.call(this,r)},mousemove:function(r){this.trigger("mousemove",r)},mouseup:function(r){var t=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",r),t&&(r.zrEventControl="only_globalout",this.trigger("mouseout",r))}};function iw(r,t){var e=t.domHandlers;J.pointerEventsSupported?M(Ol.pointer,function(n){Jo(t,n,function(i){e[n].call(r,i)})}):(J.touchEventsSupported&&M(Ol.touch,function(n){Jo(t,n,function(i){e[n].call(r,i),ew(t)})}),M(Ol.mouse,function(n){Jo(t,n,function(i){i=Th(i),t.touching||e[n].call(r,i)})}))}function aw(r,t){J.pointerEventsSupported?M(sc.pointer,e):J.touchEventsSupported||M(sc.mouse,e);function e(n){function i(a){a=Th(a),Wy(r,a.target)||(a=rw(r,a),t.domHandlers[n].call(r,a))}Jo(t,n,i,{capture:!0})}}function Jo(r,t,e,n){r.mounted[t]=e,r.listenerOpts[t]=n,of(r.domTarget,t,e,n)}function Nl(r){var t=r.mounted;for(var e in t)t.hasOwnProperty(e)&&Cx(r.domTarget,e,t[e],r.listenerOpts[e]);r.mounted={}}var uc=function(){function r(t,e){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=t,this.domHandlers=e}return r}(),ow=function(r){N(t,r);function t(e,n){var i=r.call(this)||this;return i.__pointerCapturing=!1,i.dom=e,i.painterRoot=n,i._localHandlerScope=new uc(e,De),kl&&(i._globalHandlerScope=new uc(document,df)),iw(i,i._localHandlerScope),i}return t.prototype.dispose=function(){Nl(this._localHandlerScope),kl&&Nl(this._globalHandlerScope)},t.prototype.setCursor=function(e){this.dom.style&&(this.dom.style.cursor=e||"default")},t.prototype.__togglePointerCapture=function(e){if(this.__mayPointerCapture=null,kl&&+this.__pointerCapturing^+e){this.__pointerCapturing=e;var n=this._globalHandlerScope;e?aw(this,n):Nl(n)}},t}(Be),Uy=1;J.hasGlobalWindow&&(Uy=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var ps=Uy,pf=.4,gf="#333",yf="#ccc",sw="#eee",fc=Ch,lw=5e-5;function Qr(r){return r>lw||r<-5e-5}var Jr=[],Fn=[],Fl=fi(),zl=Math.abs,Ka=function(){function r(){}return r.prototype.getLocalTransform=function(t){return r.getLocalTransform(this,t)},r.prototype.setPosition=function(t){this.x=t[0],this.y=t[1]},r.prototype.setScale=function(t){this.scaleX=t[0],this.scaleY=t[1]},r.prototype.setSkew=function(t){this.skewX=t[0],this.skewY=t[1]},r.prototype.setOrigin=function(t){this.originX=t[0],this.originY=t[1]},r.prototype.needLocalTransform=function(){return Qr(this.rotation)||Qr(this.x)||Qr(this.y)||Qr(this.scaleX-1)||Qr(this.scaleY-1)||Qr(this.skewX)||Qr(this.skewY)},r.prototype.updateTransform=function(){var t=this.parent&&this.parent.transform,e=this.needLocalTransform(),n=this.transform;if(!(e||t)){n&&(fc(n),this.invTransform=null);return}n=n||fi(),e?this.getLocalTransform(n):fc(n),t&&(e?hi(n,t,n):Mx(n,t)),this.transform=n,this._resolveGlobalScaleRatio(n)},r.prototype._resolveGlobalScaleRatio=function(t){var e=this.globalScaleRatio;if(e!=null&&e!==1){this.getGlobalScale(Jr);var n=Jr[0]<0?-1:1,i=Jr[1]<0?-1:1,a=((Jr[0]-n)*e+n)/Jr[0]||0,o=((Jr[1]-i)*e+i)/Jr[1]||0;t[0]*=a,t[1]*=a,t[2]*=o,t[3]*=o}this.invTransform=this.invTransform||fi(),Hs(this.invTransform,t)},r.prototype.getComputedTransform=function(){for(var t=this,e=[];t;)e.push(t),t=t.parent;for(;t=e.pop();)t.updateTransform();return this.transform},r.prototype.setLocalTransform=function(t){if(t){var e=t[0]*t[0]+t[1]*t[1],n=t[2]*t[2]+t[3]*t[3],i=Math.atan2(t[1],t[0]),a=Math.PI/2+i-Math.atan2(t[3],t[2]);n=Math.sqrt(n)*Math.cos(a),e=Math.sqrt(e),this.skewX=a,this.skewY=0,this.rotation=-i,this.x=+t[4],this.y=+t[5],this.scaleX=e,this.scaleY=n,this.originX=0,this.originY=0}},r.prototype.decomposeTransform=function(){if(this.transform){var t=this.parent,e=this.transform;t&&t.transform&&(t.invTransform=t.invTransform||fi(),hi(Fn,t.invTransform,e),e=Fn);var n=this.originX,i=this.originY;(n||i)&&(Fl[4]=n,Fl[5]=i,hi(Fn,e,Fl),Fn[4]-=n,Fn[5]-=i,e=Fn),this.setLocalTransform(e)}},r.prototype.getGlobalScale=function(t){var e=this.transform;return t=t||[],e?(t[0]=Math.sqrt(e[0]*e[0]+e[1]*e[1]),t[1]=Math.sqrt(e[2]*e[2]+e[3]*e[3]),e[0]<0&&(t[0]=-t[0]),e[3]<0&&(t[1]=-t[1]),t):(t[0]=1,t[1]=1,t)},r.prototype.transformCoordToLocal=function(t,e){var n=[t,e],i=this.invTransform;return i&&me(n,n,i),n},r.prototype.transformCoordToGlobal=function(t,e){var n=[t,e],i=this.transform;return i&&me(n,n,i),n},r.prototype.getLineScale=function(){var t=this.transform;return t&&zl(t[0]-1)>1e-10&&zl(t[3]-1)>1e-10?Math.sqrt(zl(t[0]*t[3]-t[2]*t[1])):1},r.prototype.copyTransform=function(t){uw(this,t)},r.getLocalTransform=function(t,e){e=e||[];var n=t.originX||0,i=t.originY||0,a=t.scaleX,o=t.scaleY,s=t.anchorX,l=t.anchorY,u=t.rotation||0,f=t.x,h=t.y,c=t.skewX?Math.tan(t.skewX):0,v=t.skewY?Math.tan(-t.skewY):0;if(n||i||s||l){var d=n+s,p=i+l;e[4]=-d*a-c*p*o,e[5]=-p*o-v*d*a}else e[4]=e[5]=0;return e[0]=a,e[3]=o,e[1]=v*a,e[2]=c*o,u&&Dh(e,e,u),e[4]+=n+f,e[5]+=i+h,e},r.initDefaultProps=function(){var t=r.prototype;t.scaleX=t.scaleY=t.globalScaleRatio=1,t.x=t.y=t.originX=t.originY=t.skewX=t.skewY=t.rotation=t.anchorX=t.anchorY=0}(),r}(),Ra=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function uw(r,t){for(var e=0;e<Ra.length;e++){var n=Ra[e];r[n]=t[n]}}var hc={};function le(r,t){t=t||Cn;var e=hc[t];e||(e=hc[t]=new qa(500));var n=e.get(r);return n==null&&(n=Mi.measureText(r,t).width,e.put(r,n)),n}function vc(r,t,e,n){var i=le(r,t),a=Mh(t),o=ua(0,i,e),s=ti(0,a,n),l=new ut(o,s,i,a);return l}function Us(r,t,e,n){var i=((r||"")+"").split(`
`),a=i.length;if(a===1)return vc(i[0],t,e,n);for(var o=new ut(0,0,0,0),s=0;s<i.length;s++){var l=vc(i[s],t,e,n);s===0?o.copy(l):o.union(l)}return o}function ua(r,t,e){return e==="right"?r-=t:e==="center"&&(r-=t/2),r}function ti(r,t,e){return e==="middle"?r-=t/2:e==="bottom"&&(r-=t),r}function Mh(r){return le("国",r)}function Gr(r,t){return typeof r=="string"?r.lastIndexOf("%")>=0?parseFloat(r)/100*t:parseFloat(r):r}function gs(r,t,e){var n=t.position||"inside",i=t.distance!=null?t.distance:5,a=e.height,o=e.width,s=a/2,l=e.x,u=e.y,f="left",h="top";if(n instanceof Array)l+=Gr(n[0],e.width),u+=Gr(n[1],e.height),f=null,h=null;else switch(n){case"left":l-=i,u+=s,f="right",h="middle";break;case"right":l+=i+o,u+=s,h="middle";break;case"top":l+=o/2,u-=i,f="center",h="bottom";break;case"bottom":l+=o/2,u+=a+i,f="center";break;case"inside":l+=o/2,u+=s,f="center",h="middle";break;case"insideLeft":l+=i,u+=s,h="middle";break;case"insideRight":l+=o-i,u+=s,f="right",h="middle";break;case"insideTop":l+=o/2,u+=i,f="center";break;case"insideBottom":l+=o/2,u+=a-i,f="center",h="bottom";break;case"insideTopLeft":l+=i,u+=i;break;case"insideTopRight":l+=o-i,u+=i,f="right";break;case"insideBottomLeft":l+=i,u+=a-i,h="bottom";break;case"insideBottomRight":l+=o-i,u+=a-i,f="right",h="bottom";break}return r=r||{},r.x=l,r.y=u,r.align=f,r.verticalAlign=h,r}var Vl="__zr_normal__",Gl=Ra.concat(["ignore"]),fw=zr(Ra,function(r,t){return r[t]=!0,r},{ignore:!1}),zn={},hw=new ut(0,0,0,0),Ys=function(){function r(t){this.id=xy(),this.animators=[],this.currentStates=[],this.states={},this._init(t)}return r.prototype._init=function(t){this.attr(t)},r.prototype.drift=function(t,e,n){switch(this.draggable){case"horizontal":e=0;break;case"vertical":t=0;break}var i=this.transform;i||(i=this.transform=[1,0,0,1,0,0]),i[4]+=t,i[5]+=e,this.decomposeTransform(),this.markRedraw()},r.prototype.beforeUpdate=function(){},r.prototype.afterUpdate=function(){},r.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},r.prototype.updateInnerText=function(t){var e=this._textContent;if(e&&(!e.ignore||t)){this.textConfig||(this.textConfig={});var n=this.textConfig,i=n.local,a=e.innerTransformable,o=void 0,s=void 0,l=!1;a.parent=i?this:null;var u=!1;if(a.copyTransform(e),n.position!=null){var f=hw;n.layoutRect?f.copy(n.layoutRect):f.copy(this.getBoundingRect()),i||f.applyTransform(this.transform),this.calculateTextPosition?this.calculateTextPosition(zn,n,f):gs(zn,n,f),a.x=zn.x,a.y=zn.y,o=zn.align,s=zn.verticalAlign;var h=n.origin;if(h&&n.rotation!=null){var c=void 0,v=void 0;h==="center"?(c=f.width*.5,v=f.height*.5):(c=Gr(h[0],f.width),v=Gr(h[1],f.height)),u=!0,a.originX=-a.x+c+(i?0:f.x),a.originY=-a.y+v+(i?0:f.y)}}n.rotation!=null&&(a.rotation=n.rotation);var d=n.offset;d&&(a.x+=d[0],a.y+=d[1],u||(a.originX=-d[0],a.originY=-d[1]));var p=n.inside==null?typeof n.position=="string"&&n.position.indexOf("inside")>=0:n.inside,g=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={}),y=void 0,m=void 0,_=void 0;p&&this.canBeInsideText()?(y=n.insideFill,m=n.insideStroke,(y==null||y==="auto")&&(y=this.getInsideTextFill()),(m==null||m==="auto")&&(m=this.getInsideTextStroke(y),_=!0)):(y=n.outsideFill,m=n.outsideStroke,(y==null||y==="auto")&&(y=this.getOutsideFill()),(m==null||m==="auto")&&(m=this.getOutsideStroke(y),_=!0)),y=y||"#000",(y!==g.fill||m!==g.stroke||_!==g.autoStroke||o!==g.align||s!==g.verticalAlign)&&(l=!0,g.fill=y,g.stroke=m,g.autoStroke=_,g.align=o,g.verticalAlign=s,e.setDefaultTextStyle(g)),e.__dirty|=Ke,l&&e.dirtyStyle(!0)}},r.prototype.canBeInsideText=function(){return!0},r.prototype.getInsideTextFill=function(){return"#fff"},r.prototype.getInsideTextStroke=function(t){return"#000"},r.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?yf:gf},r.prototype.getOutsideStroke=function(t){var e=this.__zr&&this.__zr.getBackgroundColor(),n=typeof e=="string"&&dr(e);n||(n=[255,255,255,1]);for(var i=n[3],a=this.__zr.isDarkMode(),o=0;o<3;o++)n[o]=n[o]*i+(a?0:255)*(1-i);return n[3]=1,Ws(n,"rgba")},r.prototype.traverse=function(t,e){},r.prototype.attrKV=function(t,e){t==="textConfig"?this.setTextConfig(e):t==="textContent"?this.setTextContent(e):t==="clipPath"?this.setClipPath(e):t==="extra"?(this.extra=this.extra||{},F(this.extra,e)):this[t]=e},r.prototype.hide=function(){this.ignore=!0,this.markRedraw()},r.prototype.show=function(){this.ignore=!1,this.markRedraw()},r.prototype.attr=function(t,e){if(typeof t=="string")this.attrKV(t,e);else if(Y(t))for(var n=t,i=mt(n),a=0;a<i.length;a++){var o=i[a];this.attrKV(o,t[o])}return this.markRedraw(),this},r.prototype.saveCurrentToNormalState=function(t){this._innerSaveToNormal(t);for(var e=this._normalState,n=0;n<this.animators.length;n++){var i=this.animators[n],a=i.__fromStateTransition;if(!(i.getLoop()||a&&a!==Vl)){var o=i.targetName,s=o?e[o]:e;i.saveTo(s)}}},r.prototype._innerSaveToNormal=function(t){var e=this._normalState;e||(e=this._normalState={}),t.textConfig&&!e.textConfig&&(e.textConfig=this.textConfig),this._savePrimaryToNormal(t,e,Gl)},r.prototype._savePrimaryToNormal=function(t,e,n){for(var i=0;i<n.length;i++){var a=n[i];t[a]!=null&&!(a in e)&&(e[a]=this[a])}},r.prototype.hasState=function(){return this.currentStates.length>0},r.prototype.getState=function(t){return this.states[t]},r.prototype.ensureState=function(t){var e=this.states;return e[t]||(e[t]={}),e[t]},r.prototype.clearStates=function(t){this.useState(Vl,!1,t)},r.prototype.useState=function(t,e,n,i){var a=t===Vl,o=this.hasState();if(!(!o&&a)){var s=this.currentStates,l=this.stateTransition;if(!(lt(s,t)>=0&&(e||s.length===1))){var u;if(this.stateProxy&&!a&&(u=this.stateProxy(t)),u||(u=this.states&&this.states[t]),!u&&!a){wh("State "+t+" not exists.");return}a||this.saveCurrentToNormalState(u);var f=!!(u&&u.hoverLayer||i);f&&this._toggleHoverLayerFlag(!0),this._applyStateObj(t,u,this._normalState,e,!n&&!this.__inHover&&l&&l.duration>0,l);var h=this._textContent,c=this._textGuide;return h&&h.useState(t,e,n,f),c&&c.useState(t,e,n,f),a?(this.currentStates=[],this._normalState={}):e?this.currentStates.push(t):this.currentStates=[t],this._updateAnimationTargets(),this.markRedraw(),!f&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=-2),u}}},r.prototype.useStates=function(t,e,n){if(!t.length)this.clearStates();else{var i=[],a=this.currentStates,o=t.length,s=o===a.length;if(s){for(var l=0;l<o;l++)if(t[l]!==a[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=t[l],f=void 0;this.stateProxy&&(f=this.stateProxy(u,t)),f||(f=this.states[u]),f&&i.push(f)}var h=i[o-1],c=!!(h&&h.hoverLayer||n);c&&this._toggleHoverLayerFlag(!0);var v=this._mergeStates(i),d=this.stateTransition;this.saveCurrentToNormalState(v),this._applyStateObj(t.join(","),v,this._normalState,!1,!e&&!this.__inHover&&d&&d.duration>0,d);var p=this._textContent,g=this._textGuide;p&&p.useStates(t,e,c),g&&g.useStates(t,e,c),this._updateAnimationTargets(),this.currentStates=t.slice(),this.markRedraw(),!c&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=-2)}},r.prototype.isSilent=function(){for(var t=this.silent,e=this.parent;!t&&e;){if(e.silent){t=!0;break}e=e.parent}return t},r.prototype._updateAnimationTargets=function(){for(var t=0;t<this.animators.length;t++){var e=this.animators[t];e.targetName&&e.changeTarget(this[e.targetName])}},r.prototype.removeState=function(t){var e=lt(this.currentStates,t);if(e>=0){var n=this.currentStates.slice();n.splice(e,1),this.useStates(n)}},r.prototype.replaceState=function(t,e,n){var i=this.currentStates.slice(),a=lt(i,t),o=lt(i,e)>=0;a>=0?o?i.splice(a,1):i[a]=e:n&&!o&&i.push(e),this.useStates(i)},r.prototype.toggleState=function(t,e){e?this.useState(t,!0):this.removeState(t)},r.prototype._mergeStates=function(t){for(var e={},n,i=0;i<t.length;i++){var a=t[i];F(e,a),a.textConfig&&(n=n||{},F(n,a.textConfig))}return n&&(e.textConfig=n),e},r.prototype._applyStateObj=function(t,e,n,i,a,o){var s=!(e&&i);e&&e.textConfig?(this.textConfig=F({},i?this.textConfig:n.textConfig),F(this.textConfig,e.textConfig)):s&&n.textConfig&&(this.textConfig=n.textConfig);for(var l={},u=!1,f=0;f<Gl.length;f++){var h=Gl[f],c=a&&fw[h];e&&e[h]!=null?c?(u=!0,l[h]=e[h]):this[h]=e[h]:s&&n[h]!=null&&(c?(u=!0,l[h]=n[h]):this[h]=n[h])}if(!a)for(var f=0;f<this.animators.length;f++){var v=this.animators[f],d=v.targetName;v.getLoop()||v.__changeFinalValue(d?(e||n)[d]:e||n)}u&&this._transitionState(t,l,o)},r.prototype._attachComponent=function(t){if(!(t.__zr&&!t.__hostTarget)&&t!==this){var e=this.__zr;e&&t.addSelfToZr(e),t.__zr=e,t.__hostTarget=this}},r.prototype._detachComponent=function(t){t.__zr&&t.removeSelfFromZr(t.__zr),t.__zr=null,t.__hostTarget=null},r.prototype.getClipPath=function(){return this._clipPath},r.prototype.setClipPath=function(t){this._clipPath&&this._clipPath!==t&&this.removeClipPath(),this._attachComponent(t),this._clipPath=t,this.markRedraw()},r.prototype.removeClipPath=function(){var t=this._clipPath;t&&(this._detachComponent(t),this._clipPath=null,this.markRedraw())},r.prototype.getTextContent=function(){return this._textContent},r.prototype.setTextContent=function(t){var e=this._textContent;e!==t&&(e&&e!==t&&this.removeTextContent(),t.innerTransformable=new Ka,this._attachComponent(t),this._textContent=t,this.markRedraw())},r.prototype.setTextConfig=function(t){this.textConfig||(this.textConfig={}),F(this.textConfig,t),this.markRedraw()},r.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},r.prototype.removeTextContent=function(){var t=this._textContent;t&&(t.innerTransformable=null,this._detachComponent(t),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},r.prototype.getTextGuideLine=function(){return this._textGuide},r.prototype.setTextGuideLine=function(t){this._textGuide&&this._textGuide!==t&&this.removeTextGuideLine(),this._attachComponent(t),this._textGuide=t,this.markRedraw()},r.prototype.removeTextGuideLine=function(){var t=this._textGuide;t&&(this._detachComponent(t),this._textGuide=null,this.markRedraw())},r.prototype.markRedraw=function(){this.__dirty|=Ke;var t=this.__zr;t&&(this.__inHover?t.refreshHover():t.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},r.prototype.dirty=function(){this.markRedraw()},r.prototype._toggleHoverLayerFlag=function(t){this.__inHover=t;var e=this._textContent,n=this._textGuide;e&&(e.__inHover=t),n&&(n.__inHover=t)},r.prototype.addSelfToZr=function(t){if(this.__zr!==t){this.__zr=t;var e=this.animators;if(e)for(var n=0;n<e.length;n++)t.animation.addAnimator(e[n]);this._clipPath&&this._clipPath.addSelfToZr(t),this._textContent&&this._textContent.addSelfToZr(t),this._textGuide&&this._textGuide.addSelfToZr(t)}},r.prototype.removeSelfFromZr=function(t){if(this.__zr){this.__zr=null;var e=this.animators;if(e)for(var n=0;n<e.length;n++)t.animation.removeAnimator(e[n]);this._clipPath&&this._clipPath.removeSelfFromZr(t),this._textContent&&this._textContent.removeSelfFromZr(t),this._textGuide&&this._textGuide.removeSelfFromZr(t)}},r.prototype.animate=function(t,e,n){var i=t?this[t]:this,a=new Ah(i,e,n);return t&&(a.targetName=t),this.addAnimator(a,t),a},r.prototype.addAnimator=function(t,e){var n=this.__zr,i=this;t.during(function(){i.updateDuringAnimation(e)}).done(function(){var a=i.animators,o=lt(a,t);o>=0&&a.splice(o,1)}),this.animators.push(t),n&&n.animation.addAnimator(t),n&&n.wakeUp()},r.prototype.updateDuringAnimation=function(t){this.markRedraw()},r.prototype.stopAnimation=function(t,e){for(var n=this.animators,i=n.length,a=[],o=0;o<i;o++){var s=n[o];!t||t===s.scope?s.stop(e):a.push(s)}return this.animators=a,this},r.prototype.animateTo=function(t,e,n){Hl(this,t,e,n)},r.prototype.animateFrom=function(t,e,n){Hl(this,t,e,n,!0)},r.prototype._transitionState=function(t,e,n,i){for(var a=Hl(this,e,n,i),o=0;o<a.length;o++)a[o].__fromStateTransition=t},r.prototype.getBoundingRect=function(){return null},r.prototype.getPaintRect=function(){return null},r.initDefaultProps=function(){var t=r.prototype;t.type="element",t.name="",t.ignore=t.silent=t.isGroup=t.draggable=t.dragging=t.ignoreClip=t.__inHover=!1,t.__dirty=Ke;function e(n,i,a,o){Object.defineProperty(t,n,{get:function(){if(!this[i]){var l=this[i]=[];s(this,l)}return this[i]},set:function(l){this[a]=l[0],this[o]=l[1],this[i]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[a]},set:function(f){l[a]=f}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(f){l[o]=f}})}}Object.defineProperty&&(e("position","_legacyPos","x","y"),e("scale","_legacyScale","scaleX","scaleY"),e("origin","_legacyOrigin","originX","originY"))}(),r}();Oe(Ys,Be);Oe(Ys,Ka);function Hl(r,t,e,n,i){e=e||{};var a=[];Yy(r,"",r,t,e,n,a,i);var o=a.length,s=!1,l=e.done,u=e.aborted,f=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},h=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),a.length>0&&e.during&&a[0].during(function(d,p){e.during(p)});for(var c=0;c<a.length;c++){var v=a[c];f&&v.done(f),h&&v.aborted(h),e.force&&v.duration(e.duration),v.start(e.easing)}return a}function Wl(r,t,e){for(var n=0;n<e;n++)r[n]=t[n]}function vw(r){return Kt(r[0])}function cw(r,t,e){if(Kt(t[e]))if(Kt(r[e])||(r[e]=[]),oe(t[e])){var n=t[e].length;r[e].length!==n&&(r[e]=new t[e].constructor(n),Wl(r[e],t[e],n))}else{var i=t[e],a=r[e],o=i.length;if(vw(i))for(var s=i[0].length,l=0;l<o;l++)a[l]?Wl(a[l],i[l],s):a[l]=Array.prototype.slice.call(i[l]);else Wl(a,i,o);a.length=i.length}else r[e]=t[e]}function dw(r,t){return r===t||Kt(r)&&Kt(t)&&pw(r,t)}function pw(r,t){var e=r.length;if(e!==t.length)return!1;for(var n=0;n<e;n++)if(r[n]!==t[n])return!1;return!0}function Yy(r,t,e,n,i,a,o,s){for(var l=mt(n),u=i.duration,f=i.delay,h=i.additive,c=i.setToFinal,v=!Y(a),d=r.animators,p=[],g=0;g<l.length;g++){var y=l[g],m=n[y];if(m!=null&&e[y]!=null&&(v||a[y]))if(Y(m)&&!Kt(m)&&!Vs(m)){if(t){s||(e[y]=m,r.updateDuringAnimation(t));continue}Yy(r,y,e[y],m,i,a&&a[y],o,s)}else p.push(y);else s||(e[y]=m,r.updateDuringAnimation(t),p.push(y))}var _=p.length;if(!h&&_)for(var S=0;S<d.length;S++){var w=d[S];if(w.targetName===t){var x=w.stopTracks(p);if(x){var b=lt(d,w);d.splice(b,1)}}}if(i.force||(p=Tt(p,function(A){return!dw(n[A],e[A])}),_=p.length),_>0||i.force&&!o.length){var T=void 0,C=void 0,D=void 0;if(s){C={},c&&(T={});for(var S=0;S<_;S++){var y=p[S];C[y]=e[y],c?T[y]=n[y]:e[y]=n[y]}}else if(c){D={};for(var S=0;S<_;S++){var y=p[S];D[y]=qo(e[y]),cw(e,n,y)}}var w=new Ah(e,!1,!1,h?Tt(d,function(I){return I.targetName===t}):null);w.targetName=t,i.scope&&(w.scope=i.scope),c&&T&&w.whenWithKeys(0,T,p),D&&w.whenWithKeys(0,D,p),w.whenWithKeys(u??500,s?C:n,p).delay(f||0),r.addAnimator(w,t),o.push(w)}}var yt=function(r){N(t,r);function t(e){var n=r.call(this)||this;return n.isGroup=!0,n._children=[],n.attr(e),n}return t.prototype.childrenRef=function(){return this._children},t.prototype.children=function(){return this._children.slice()},t.prototype.childAt=function(e){return this._children[e]},t.prototype.childOfName=function(e){for(var n=this._children,i=0;i<n.length;i++)if(n[i].name===e)return n[i]},t.prototype.childCount=function(){return this._children.length},t.prototype.add=function(e){return e&&e!==this&&e.parent!==this&&(this._children.push(e),this._doAdd(e)),this},t.prototype.addBefore=function(e,n){if(e&&e!==this&&e.parent!==this&&n&&n.parent===this){var i=this._children,a=i.indexOf(n);a>=0&&(i.splice(a,0,e),this._doAdd(e))}return this},t.prototype.replace=function(e,n){var i=lt(this._children,e);return i>=0&&this.replaceAt(n,i),this},t.prototype.replaceAt=function(e,n){var i=this._children,a=i[n];if(e&&e!==this&&e.parent!==this&&e!==a){i[n]=e,a.parent=null;var o=this.__zr;o&&a.removeSelfFromZr(o),this._doAdd(e)}return this},t.prototype._doAdd=function(e){e.parent&&e.parent.remove(e),e.parent=this;var n=this.__zr;n&&n!==e.__zr&&e.addSelfToZr(n),n&&n.refresh()},t.prototype.remove=function(e){var n=this.__zr,i=this._children,a=lt(i,e);return a<0?this:(i.splice(a,1),e.parent=null,n&&e.removeSelfFromZr(n),n&&n.refresh(),this)},t.prototype.removeAll=function(){for(var e=this._children,n=this.__zr,i=0;i<e.length;i++){var a=e[i];n&&a.removeSelfFromZr(n),a.parent=null}return e.length=0,this},t.prototype.eachChild=function(e,n){for(var i=this._children,a=0;a<i.length;a++){var o=i[a];e.call(n,o,a)}return this},t.prototype.traverse=function(e,n){for(var i=0;i<this._children.length;i++){var a=this._children[i],o=e.call(n,a);a.isGroup&&!o&&a.traverse(e,n)}return this},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var n=0;n<this._children.length;n++){var i=this._children[n];i.addSelfToZr(e)}},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var n=0;n<this._children.length;n++){var i=this._children[n];i.removeSelfFromZr(e)}},t.prototype.getBoundingRect=function(e){for(var n=new ut(0,0,0,0),i=e||this._children,a=[],o=null,s=0;s<i.length;s++){var l=i[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),f=l.getLocalTransform(a);f?(ut.applyTransform(n,u,f),o=o||n.clone(),o.union(n)):(o=o||u.clone(),o.union(u))}}return o||n},t}(Ys);yt.prototype.type="group";/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var jo={},Xy={};function gw(r){delete Xy[r]}function yw(r){if(!r)return!1;if(typeof r=="string")return ds(r,1)<pf;if(r.colorStops){for(var t=r.colorStops,e=0,n=t.length,i=0;i<n;i++)e+=ds(t[i].color,1);return e/=n,e<pf}return!1}var mw=function(){function r(t,e,n){var i=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,n=n||{},this.dom=e,this.id=t;var a=new Fx,o=n.renderer||"canvas";jo[o]||(o=mt(jo)[0]),n.useDirtyRect=n.useDirtyRect==null?!1:n.useDirtyRect;var s=new jo[o](e,a,n,t),l=n.ssr||s.ssrOnly;this.storage=a,this.painter=s;var u=!J.node&&!J.worker&&!l?new ow(s.getViewportRoot(),s.root):null,f=n.useCoarsePointer,h=f==null||f==="auto"?J.touchEventsSupported:!!f,c=44,v;h&&(v=rt(n.pointerSize,c)),this.handler=new Iy(a,s,u,s.root,v),this.animation=new jx({stage:{update:l?null:function(){return i._flush(!0)}}}),l||this.animation.start()}return r.prototype.add=function(t){this._disposed||!t||(this.storage.addRoot(t),t.addSelfToZr(this),this.refresh())},r.prototype.remove=function(t){this._disposed||!t||(this.storage.delRoot(t),t.removeSelfFromZr(this),this.refresh())},r.prototype.configLayer=function(t,e){this._disposed||(this.painter.configLayer&&this.painter.configLayer(t,e),this.refresh())},r.prototype.setBackgroundColor=function(t){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(t),this.refresh(),this._backgroundColor=t,this._darkMode=yw(t))},r.prototype.getBackgroundColor=function(){return this._backgroundColor},r.prototype.setDarkMode=function(t){this._darkMode=t},r.prototype.isDarkMode=function(){return this._darkMode},r.prototype.refreshImmediately=function(t){this._disposed||(t||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},r.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},r.prototype.flush=function(){this._disposed||this._flush(!1)},r.prototype._flush=function(t){var e,n=ii();this._needsRefresh&&(e=!0,this.refreshImmediately(t)),this._needsRefreshHover&&(e=!0,this.refreshHoverImmediately());var i=ii();e?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:i-n})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},r.prototype.setSleepAfterStill=function(t){this._sleepAfterStill=t},r.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},r.prototype.refreshHover=function(){this._needsRefreshHover=!0},r.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},r.prototype.resize=function(t){this._disposed||(t=t||{},this.painter.resize(t.width,t.height),this.handler.resize())},r.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},r.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},r.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},r.prototype.setCursorStyle=function(t){this._disposed||this.handler.setCursorStyle(t)},r.prototype.findHover=function(t,e){if(!this._disposed)return this.handler.findHover(t,e)},r.prototype.on=function(t,e,n){return this._disposed||this.handler.on(t,e,n),this},r.prototype.off=function(t,e){this._disposed||this.handler.off(t,e)},r.prototype.trigger=function(t,e){this._disposed||this.handler.trigger(t,e)},r.prototype.clear=function(){if(!this._disposed){for(var t=this.storage.getRoots(),e=0;e<t.length;e++)t[e]instanceof yt&&t[e].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},r.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,gw(this.id))},r}();function cc(r,t){var e=new mw(xy(),r,t);return Xy[e.id]=e,e}function _w(r,t){jo[r]=t}var Sw=1e-4,Zy=20;function xw(r){return r.replace(/^\s+|\s+$/g,"")}function Zt(r,t,e,n){var i=t[0],a=t[1],o=e[0],s=e[1],l=a-i,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(n)if(l>0){if(r<=i)return o;if(r>=a)return s}else{if(r>=i)return o;if(r<=a)return s}else{if(r===i)return o;if(r===a)return s}return(r-i)/l*u+o}function Z(r,t){switch(r){case"center":case"middle":r="50%";break;case"left":case"top":r="0%";break;case"right":case"bottom":r="100%";break}return W(r)?xw(r).match(/%$/)?parseFloat(r)/100*t:parseFloat(r):r==null?NaN:+r}function Mt(r,t,e){return t==null&&(t=10),t=Math.min(Math.max(0,t),Zy),r=(+r).toFixed(t),e?r:+r}function ww(r){return r.sort(function(t,e){return t-e}),r}function fr(r){if(r=+r,isNaN(r))return 0;if(r>1e-14){for(var t=1,e=0;e<15;e++,t*=10)if(Math.round(r*t)/t===r)return e}return bw(r)}function bw(r){var t=r.toString().toLowerCase(),e=t.indexOf("e"),n=e>0?+t.slice(e+1):0,i=e>0?e:t.length,a=t.indexOf("."),o=a<0?0:i-1-a;return Math.max(0,o-n)}function $y(r,t){var e=Math.log,n=Math.LN10,i=Math.floor(e(r[1]-r[0])/n),a=Math.round(e(Math.abs(t[1]-t[0]))/n),o=Math.min(Math.max(-i+a,0),20);return isFinite(o)?o:20}function Tw(r,t){var e=zr(r,function(v,d){return v+(isNaN(d)?0:d)},0);if(e===0)return[];for(var n=Math.pow(10,t),i=H(r,function(v){return(isNaN(v)?0:v)/e*n*100}),a=n*100,o=H(i,function(v){return Math.floor(v)}),s=zr(o,function(v,d){return v+d},0),l=H(i,function(v,d){return v-o[d]});s<a;){for(var u=Number.NEGATIVE_INFINITY,f=null,h=0,c=l.length;h<c;++h)l[h]>u&&(u=l[h],f=h);++o[f],l[f]=0,++s}return H(o,function(v){return v/n})}function Cw(r,t){var e=Math.max(fr(r),fr(t)),n=r+t;return e>Zy?n:Mt(n,e)}function qy(r){var t=Math.PI*2;return(r%t+t)%t}function ys(r){return r>-1e-4&&r<Sw}var Dw=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function gr(r){if(r instanceof Date)return r;if(W(r)){var t=Dw.exec(r);if(!t)return new Date(NaN);if(t[8]){var e=+t[4]||0;return t[8].toUpperCase()!=="Z"&&(e-=+t[8].slice(0,3)),new Date(Date.UTC(+t[1],+(t[2]||1)-1,+t[3]||1,e,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0))}else return new Date(+t[1],+(t[2]||1)-1,+t[3]||1,+t[4]||0,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0)}else if(r==null)return new Date(NaN);return new Date(Math.round(r))}function Aw(r){return Math.pow(10,Ih(r))}function Ih(r){if(r===0)return 0;var t=Math.floor(Math.log(r)/Math.LN10);return r/Math.pow(10,t)>=10&&t++,t}function Ky(r,t){var e=Ih(r),n=Math.pow(10,e),i=r/n,a;return i<1.5?a=1:i<2.5?a=2:i<4?a=3:i<7?a=5:a=10,r=a*n,e>=-20?+r.toFixed(e<0?-e:0):r}function Hr(r){var t=parseFloat(r);return t==r&&(t!==0||!W(r)||r.indexOf("x")<=0)?t:NaN}function Qy(r){return!isNaN(Hr(r))}function Jy(){return Math.round(Math.random()*9)}function jy(r,t){return t===0?r:jy(t,r%t)}function dc(r,t){return r==null?t:t==null?r:r*t/jy(r,t)}function ft(r){throw new Error(r)}function pc(r,t,e){return(t-r)*e+r}var tm="series\0",em="\0_ec_\0";function It(r){return r instanceof Array?r:r==null?[]:[r]}function mf(r,t,e){if(r){r[t]=r[t]||{},r.emphasis=r.emphasis||{},r.emphasis[t]=r.emphasis[t]||{};for(var n=0,i=e.length;n<i;n++){var a=e[n];!r.emphasis[t].hasOwnProperty(a)&&r[t].hasOwnProperty(a)&&(r.emphasis[t][a]=r[t][a])}}}var gc=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function Qa(r){return Y(r)&&!V(r)&&!(r instanceof Date)?r.value:r}function Mw(r){return Y(r)&&!(r instanceof Array)}function Iw(r,t,e){var n=e==="normalMerge",i=e==="replaceMerge",a=e==="replaceAll";r=r||[],t=(t||[]).slice();var o=$();M(t,function(l,u){if(!Y(l)){t[u]=null;return}});var s=Lw(r,o,e);return(n||i)&&Pw(s,r,o,t),n&&Rw(s,t),n||i?Ew(s,t,i):a&&kw(s,t),Ow(s),s}function Lw(r,t,e){var n=[];if(e==="replaceAll")return n;for(var i=0;i<r.length;i++){var a=r[i];a&&a.id!=null&&t.set(a.id,i),n.push({existing:e==="replaceMerge"||Ea(a)?null:a,newOption:null,keyInfo:null,brandNew:null})}return n}function Pw(r,t,e,n){M(n,function(i,a){if(!(!i||i.id==null)){var o=Sa(i.id),s=e.get(o);if(s!=null){var l=r[s];je(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=i,l.existing=t[s],n[a]=null}}})}function Rw(r,t){M(t,function(e,n){if(!(!e||e.name==null))for(var i=0;i<r.length;i++){var a=r[i].existing;if(!r[i].newOption&&a&&(a.id==null||e.id==null)&&!Ea(e)&&!Ea(a)&&rm("name",a,e)){r[i].newOption=e,t[n]=null;return}}})}function Ew(r,t,e){M(t,function(n){if(n){for(var i,a=0;(i=r[a])&&(i.newOption||Ea(i.existing)||i.existing&&n.id!=null&&!rm("id",n,i.existing));)a++;i?(i.newOption=n,i.brandNew=e):r.push({newOption:n,brandNew:e,existing:null,keyInfo:null}),a++}})}function kw(r,t){M(t,function(e){r.push({newOption:e,brandNew:!0,existing:null,keyInfo:null})})}function Ow(r){var t=$();M(r,function(e){var n=e.existing;n&&t.set(n.id,e)}),M(r,function(e){var n=e.newOption;je(!n||n.id==null||!t.get(n.id)||t.get(n.id)===e,"id duplicates: "+(n&&n.id)),n&&n.id!=null&&t.set(n.id,e),!e.keyInfo&&(e.keyInfo={})}),M(r,function(e,n){var i=e.existing,a=e.newOption,o=e.keyInfo;if(Y(a)){if(o.name=a.name!=null?Sa(a.name):i?i.name:tm+n,i)o.id=Sa(i.id);else if(a.id!=null)o.id=Sa(a.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(t.get(o.id))}t.set(o.id,e)}})}function rm(r,t,e){var n=Qe(t[r],null),i=Qe(e[r],null);return n!=null&&i!=null&&n===i}function Sa(r){return Qe(r,"")}function Qe(r,t){return r==null?t:W(r)?r:ct(r)||ju(r)?r+"":t}function Lh(r){var t=r.name;return!!(t&&t.indexOf(tm))}function Ea(r){return r&&r.id!=null&&Sa(r.id).indexOf(em)===0}function Bw(r){return em+r}function Nw(r,t,e){M(r,function(n){var i=n.newOption;Y(i)&&(n.keyInfo.mainType=t,n.keyInfo.subType=Fw(t,i,n.existing,e))})}function Fw(r,t,e,n){var i=t.type?t.type:e?e.subType:n.determineSubType(r,t);return i}function Dn(r,t){if(t.dataIndexInside!=null)return t.dataIndexInside;if(t.dataIndex!=null)return V(t.dataIndex)?H(t.dataIndex,function(e){return r.indexOfRawIndex(e)}):r.indexOfRawIndex(t.dataIndex);if(t.name!=null)return V(t.name)?H(t.name,function(e){return r.indexOfName(e)}):r.indexOfName(t.name)}function _t(){var r="__ec_inner_"+zw++;return function(t){return t[r]||(t[r]={})}}var zw=Jy();function xa(r,t,e){var n=Ph(t,e),i=n.mainTypeSpecified,a=n.queryOptionMap,o=n.others,s=o,l=e?e.defaultMainType:null;return!i&&l&&a.set(l,{}),a.each(function(u,f){var h=Ja(r,f,u,{useDefault:l===f,enableAll:e&&e.enableAll!=null?e.enableAll:!0,enableNone:e&&e.enableNone!=null?e.enableNone:!0});s[f+"Models"]=h.models,s[f+"Model"]=h.models[0]}),s}function Ph(r,t){var e;if(W(r)){var n={};n[r+"Index"]=0,e=n}else e=r;var i=$(),a={},o=!1;return M(e,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){a[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],f=u[1],h=(u[2]||"").toLowerCase();if(!(!f||!h||t&&t.includeMainTypes&&lt(t.includeMainTypes,f)<0)){o=o||!!f;var c=i.get(f)||i.set(f,{});c[h]=s}}),{mainTypeSpecified:o,queryOptionMap:i,others:a}}var $t={useDefault:!0,enableAll:!1,enableNone:!1},Vw={useDefault:!1,enableAll:!0,enableNone:!0};function Ja(r,t,e,n){n=n||$t;var i=e.index,a=e.id,o=e.name,s={models:null,specified:i!=null||a!=null||o!=null};if(!s.specified){var l=void 0;return s.models=n.useDefault&&(l=r.getComponent(t))?[l]:[],s}return i==="none"||i===!1?(je(n.enableNone,'`"none"` or `false` is not a valid value on index option.'),s.models=[],s):(i==="all"&&(je(n.enableAll,'`"all"` is not a valid value on index option.'),i=a=o=null),s.models=r.queryComponents({mainType:t,index:i,id:a,name:o}),s)}function nm(r,t,e){r.setAttribute?r.setAttribute(t,e):r[t]=e}function Gw(r,t){return r.getAttribute?r.getAttribute(t):r[t]}function Hw(r){return r==="auto"?J.domSupported?"html":"richText":r||"html"}function im(r,t,e,n,i){var a=t==null||t==="auto";if(n==null)return n;if(ct(n)){var o=pc(e||0,n,i);return Mt(o,a?Math.max(fr(e||0),fr(n)):t)}else{if(W(n))return i<1?e:n;for(var s=[],l=e,u=n,f=Math.max(l?l.length:0,u.length),h=0;h<f;++h){var c=r.getDimensionInfo(h);if(c&&c.type==="ordinal")s[h]=(i<1&&l?l:u)[h];else{var v=l&&l[h]?l[h]:0,d=u[h],o=pc(v,d,i);s[h]=Mt(o,a?Math.max(fr(v),fr(d)):t)}}return s}}var Ww=".",jr="___EC__COMPONENT__CONTAINER___",am="___EC__EXTENDED_CLASS___";function $e(r){var t={main:"",sub:""};if(r){var e=r.split(Ww);t.main=e[0]||"",t.sub=e[1]||""}return t}function Uw(r){je(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(r),'componentType "'+r+'" illegal')}function Yw(r){return!!(r&&r[am])}function Rh(r,t){r.$constructor=r,r.extend=function(e){var n=this,i;return Xw(n)?i=function(a){N(o,a);function o(){return a.apply(this,arguments)||this}return o}(n):(i=function(){(e.$constructor||n).apply(this,arguments)},JS(i,this)),F(i.prototype,e),i[am]=!0,i.extend=this.extend,i.superCall=qw,i.superApply=Kw,i.superClass=n,i}}function Xw(r){return q(r)&&/^class\s/.test(Function.prototype.toString.call(r))}function om(r,t){r.extend=t.extend}var Zw=Math.round(Math.random()*10);function $w(r){var t=["__\0is_clz",Zw++].join("_");r.prototype[t]=!0,r.isInstance=function(e){return!!(e&&e[t])}}function qw(r,t){for(var e=[],n=2;n<arguments.length;n++)e[n-2]=arguments[n];return this.superClass.prototype[t].apply(r,e)}function Kw(r,t,e){return this.superClass.prototype[t].apply(r,e)}function Xs(r){var t={};r.registerClass=function(n){var i=n.type||n.prototype.type;if(i){Uw(i),n.prototype.type=i;var a=$e(i);if(!a.sub)t[a.main]=n;else if(a.sub!==jr){var o=e(a);o[a.sub]=n}}return n},r.getClass=function(n,i,a){var o=t[n];if(o&&o[jr]&&(o=i?o[i]:null),a&&!o)throw new Error(i?"Component "+n+"."+(i||"")+" is used but not imported.":n+".type should be specified.");return o},r.getClassesByMainType=function(n){var i=$e(n),a=[],o=t[i.main];return o&&o[jr]?M(o,function(s,l){l!==jr&&a.push(s)}):a.push(o),a},r.hasClass=function(n){var i=$e(n);return!!t[i.main]},r.getAllClassMainTypes=function(){var n=[];return M(t,function(i,a){n.push(a)}),n},r.hasSubTypes=function(n){var i=$e(n),a=t[i.main];return a&&a[jr]};function e(n){var i=t[n.main];return(!i||!i[jr])&&(i=t[n.main]={},i[jr]=!0),i}}function ka(r,t){for(var e=0;e<r.length;e++)r[e][1]||(r[e][1]=r[e][0]);return t=t||!1,function(n,i,a){for(var o={},s=0;s<r.length;s++){var l=r[s][1];if(!(i&&lt(i,l)>=0||a&&lt(a,l)<0)){var u=n.getShallow(l,t);u!=null&&(o[r[s][0]]=u)}}return o}}var Qw=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],Jw=ka(Qw),jw=function(){function r(){}return r.prototype.getAreaStyle=function(t,e){return Jw(this,t,e)},r}(),_f=new qa(50);function tb(r){if(typeof r=="string"){var t=_f.get(r);return t&&t.image}else return r}function sm(r,t,e,n,i){if(r)if(typeof r=="string"){if(t&&t.__zrImageSrc===r||!e)return t;var a=_f.get(r),o={hostEl:e,cb:n,cbPayload:i};return a?(t=a.image,!Zs(t)&&a.pending.push(o)):(t=Mi.loadImage(r,yc,yc),t.__zrImageSrc=r,_f.put(r,t.__cachedImgObj={image:t,pending:[o]})),t}else return r;else return t}function yc(){var r=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var t=0;t<r.pending.length;t++){var e=r.pending[t],n=e.cb;n&&n(this,e.cbPayload),e.hostEl.dirty()}r.pending.length=0}function Zs(r){return r&&r.width&&r.height}var Ul=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function eb(r,t,e,n,i,a){if(!e){r.text="",r.isTruncated=!1;return}var o=(t+"").split(`
`);a=lm(e,n,i,a);for(var s=!1,l={},u=0,f=o.length;u<f;u++)um(l,o[u],a),o[u]=l.textLine,s=s||l.isTruncated;r.text=o.join(`
`),r.isTruncated=s}function lm(r,t,e,n){n=n||{};var i=F({},n);i.font=t,e=rt(e,"..."),i.maxIterations=rt(n.maxIterations,2);var a=i.minChar=rt(n.minChar,0);i.cnCharWidth=le("国",t);var o=i.ascCharWidth=le("a",t);i.placeholder=rt(n.placeholder,"");for(var s=r=Math.max(0,r-1),l=0;l<a&&s>=o;l++)s-=o;var u=le(e,t);return u>s&&(e="",u=0),s=r-u,i.ellipsis=e,i.ellipsisWidth=u,i.contentWidth=s,i.containerWidth=r,i}function um(r,t,e){var n=e.containerWidth,i=e.font,a=e.contentWidth;if(!n){r.textLine="",r.isTruncated=!1;return}var o=le(t,i);if(o<=n){r.textLine=t,r.isTruncated=!1;return}for(var s=0;;s++){if(o<=a||s>=e.maxIterations){t+=e.ellipsis;break}var l=s===0?rb(t,a,e.ascCharWidth,e.cnCharWidth):o>0?Math.floor(t.length*a/o):0;t=t.substr(0,l),o=le(t,i)}t===""&&(t=e.placeholder),r.textLine=t,r.isTruncated=!0}function rb(r,t,e,n){for(var i=0,a=0,o=r.length;a<o&&i<t;a++){var s=r.charCodeAt(a);i+=0<=s&&s<=127?e:n}return a}function nb(r,t){r!=null&&(r+="");var e=t.overflow,n=t.padding,i=t.font,a=e==="truncate",o=Mh(i),s=rt(t.lineHeight,o),l=!!t.backgroundColor,u=t.lineOverflow==="truncate",f=!1,h=t.width,c;h!=null&&(e==="break"||e==="breakAll")?c=r?fm(r,t.font,h,e==="breakAll",0).lines:[]:c=r?r.split(`
`):[];var v=c.length*s,d=rt(t.height,v);if(v>d&&u){var p=Math.floor(d/s);f=f||c.length>p,c=c.slice(0,p)}if(r&&a&&h!=null)for(var g=lm(h,i,t.ellipsis,{minChar:t.truncateMinChar,placeholder:t.placeholder}),y={},m=0;m<c.length;m++)um(y,c[m],g),c[m]=y.textLine,f=f||y.isTruncated;for(var _=d,S=0,m=0;m<c.length;m++)S=Math.max(le(c[m],i),S);h==null&&(h=S);var w=S;return n&&(_+=n[0]+n[2],w+=n[1]+n[3],h+=n[1]+n[3]),l&&(w=h),{lines:c,height:d,outerWidth:w,outerHeight:_,lineHeight:s,calculatedLineHeight:o,contentWidth:S,contentHeight:v,width:h,isTruncated:f}}var ib=function(){function r(){}return r}(),mc=function(){function r(t){this.tokens=[],t&&(this.tokens=t)}return r}(),ab=function(){function r(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[],this.isTruncated=!1}return r}();function ob(r,t){var e=new ab;if(r!=null&&(r+=""),!r)return e;for(var n=t.width,i=t.height,a=t.overflow,o=(a==="break"||a==="breakAll")&&n!=null?{width:n,accumWidth:0,breakAll:a==="breakAll"}:null,s=Ul.lastIndex=0,l;(l=Ul.exec(r))!=null;){var u=l.index;u>s&&Yl(e,r.substring(s,u),t,o),Yl(e,l[2],t,o,l[1]),s=Ul.lastIndex}s<r.length&&Yl(e,r.substring(s,r.length),t,o);var f=[],h=0,c=0,v=t.padding,d=a==="truncate",p=t.lineOverflow==="truncate",g={};function y(z,G,U){z.width=G,z.lineHeight=U,h+=U,c=Math.max(c,G)}t:for(var m=0;m<e.lines.length;m++){for(var _=e.lines[m],S=0,w=0,x=0;x<_.tokens.length;x++){var b=_.tokens[x],T=b.styleName&&t.rich[b.styleName]||{},C=b.textPadding=T.padding,D=C?C[1]+C[3]:0,A=b.font=T.font||t.font;b.contentHeight=Mh(A);var I=rt(T.height,b.contentHeight);if(b.innerHeight=I,C&&(I+=C[0]+C[2]),b.height=I,b.lineHeight=ga(T.lineHeight,t.lineHeight,I),b.align=T&&T.align||t.align,b.verticalAlign=T&&T.verticalAlign||"middle",p&&i!=null&&h+b.lineHeight>i){var L=e.lines.length;x>0?(_.tokens=_.tokens.slice(0,x),y(_,w,S),e.lines=e.lines.slice(0,m+1)):e.lines=e.lines.slice(0,m),e.isTruncated=e.isTruncated||e.lines.length<L;break t}var P=T.width,R=P==null||P==="auto";if(typeof P=="string"&&P.charAt(P.length-1)==="%")b.percentWidth=P,f.push(b),b.contentWidth=le(b.text,A);else{if(R){var E=T.backgroundColor,O=E&&E.image;O&&(O=tb(O),Zs(O)&&(b.width=Math.max(b.width,O.width*I/O.height)))}var k=d&&n!=null?n-w:null;k!=null&&k<b.width?!R||k<D?(b.text="",b.width=b.contentWidth=0):(eb(g,b.text,k-D,A,t.ellipsis,{minChar:t.truncateMinChar}),b.text=g.text,e.isTruncated=e.isTruncated||g.isTruncated,b.width=b.contentWidth=le(b.text,A)):b.contentWidth=le(b.text,A)}b.width+=D,w+=b.width,T&&(S=Math.max(S,b.lineHeight))}y(_,w,S)}e.outerWidth=e.width=rt(n,c),e.outerHeight=e.height=rt(i,h),e.contentHeight=h,e.contentWidth=c,v&&(e.outerWidth+=v[1]+v[3],e.outerHeight+=v[0]+v[2]);for(var m=0;m<f.length;m++){var b=f[m],B=b.percentWidth;b.width=parseInt(B,10)/100*e.width}return e}function Yl(r,t,e,n,i){var a=t==="",o=i&&e.rich[i]||{},s=r.lines,l=o.font||e.font,u=!1,f,h;if(n){var c=o.padding,v=c?c[1]+c[3]:0;if(o.width!=null&&o.width!=="auto"){var d=Gr(o.width,n.width)+v;s.length>0&&d+n.accumWidth>n.width&&(f=t.split(`
`),u=!0),n.accumWidth=d}else{var p=fm(t,l,n.width,n.breakAll,n.accumWidth);n.accumWidth=p.accumWidth+v,h=p.linesWidths,f=p.lines}}else f=t.split(`
`);for(var g=0;g<f.length;g++){var y=f[g],m=new ib;if(m.styleName=i,m.text=y,m.isLineHolder=!y&&!a,typeof o.width=="number"?m.width=o.width:m.width=h?h[g]:le(y,l),!g&&!u){var _=(s[s.length-1]||(s[0]=new mc)).tokens,S=_.length;S===1&&_[0].isLineHolder?_[0]=m:(y||!S||a)&&_.push(m)}else s.push(new mc([m]))}}function sb(r){var t=r.charCodeAt(0);return t>=32&&t<=591||t>=880&&t<=4351||t>=4608&&t<=5119||t>=7680&&t<=8303}var lb=zr(",&?/;] ".split(""),function(r,t){return r[t]=!0,r},{});function ub(r){return sb(r)?!!lb[r]:!0}function fm(r,t,e,n,i){for(var a=[],o=[],s="",l="",u=0,f=0,h=0;h<r.length;h++){var c=r.charAt(h);if(c===`
`){l&&(s+=l,f+=u),a.push(s),o.push(f),s="",l="",u=0,f=0;continue}var v=le(c,t),d=n?!1:!ub(c);if(a.length?f+v>e:i+f+v>e){f?(s||l)&&(d?(s||(s=l,l="",u=0,f=u),a.push(s),o.push(f-u),l+=c,u+=v,s="",f=u):(l&&(s+=l,l="",u=0),a.push(s),o.push(f),s=c,f=v)):d?(a.push(l),o.push(u),l=c,u=v):(a.push(c),o.push(v));continue}f+=v,d?(l+=c,u+=v):(l&&(s+=l,l="",u=0),s+=c)}return!a.length&&!s&&(s=r,l="",u=0),l&&(s+=l),s&&(a.push(s),o.push(f)),a.length===1&&(f+=i),{accumWidth:f,lines:a,linesWidths:o}}var Sf="__zr_style_"+Math.round(Math.random()*10),wn={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},$s={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};wn[Sf]=!0;var _c=["z","z2","invisible"],fb=["invisible"],Pi=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype._init=function(e){for(var n=mt(e),i=0;i<n.length;i++){var a=n[i];a==="style"?this.useStyle(e[a]):r.prototype.attrKV.call(this,a,e[a])}this.style||this.useStyle({})},t.prototype.beforeBrush=function(){},t.prototype.afterBrush=function(){},t.prototype.innerBeforeBrush=function(){},t.prototype.innerAfterBrush=function(){},t.prototype.shouldBePainted=function(e,n,i,a){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&hb(this,e,n)||o&&!o[0]&&!o[3])return!1;if(i&&this.__clipPaths){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(a&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},t.prototype.contain=function(e,n){return this.rectContain(e,n)},t.prototype.traverse=function(e,n){e.call(n,this)},t.prototype.rectContain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect();return a.contain(i[0],i[1])},t.prototype.getPaintRect=function(){var e=this._paintRect;if(!this._paintRect||this.__dirty){var n=this.transform,i=this.getBoundingRect(),a=this.style,o=a.shadowBlur||0,s=a.shadowOffsetX||0,l=a.shadowOffsetY||0;e=this._paintRect||(this._paintRect=new ut(0,0,0,0)),n?ut.applyTransform(e,i,n):e.copy(i),(o||s||l)&&(e.width+=o*2+Math.abs(s),e.height+=o*2+Math.abs(l),e.x=Math.min(e.x,e.x+s-o),e.y=Math.min(e.y,e.y+l-o));var u=this.dirtyRectTolerance;e.isZero()||(e.x=Math.floor(e.x-u),e.y=Math.floor(e.y-u),e.width=Math.ceil(e.width+1+u*2),e.height=Math.ceil(e.height+1+u*2))}return e},t.prototype.setPrevPaintRect=function(e){e?(this._prevPaintRect=this._prevPaintRect||new ut(0,0,0,0),this._prevPaintRect.copy(e)):this._prevPaintRect=null},t.prototype.getPrevPaintRect=function(){return this._prevPaintRect},t.prototype.animateStyle=function(e){return this.animate("style",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():this.markRedraw()},t.prototype.attrKV=function(e,n){e!=="style"?r.prototype.attrKV.call(this,e,n):this.style?this.setStyle(n):this.useStyle(n)},t.prototype.setStyle=function(e,n){return typeof e=="string"?this.style[e]=n:F(this.style,e),this.dirtyStyle(),this},t.prototype.dirtyStyle=function(e){e||this.markRedraw(),this.__dirty|=$o,this._rect&&(this._rect=null)},t.prototype.dirty=function(){this.dirtyStyle()},t.prototype.styleChanged=function(){return!!(this.__dirty&$o)},t.prototype.styleUpdated=function(){this.__dirty&=-3},t.prototype.createStyle=function(e){return Gs(wn,e)},t.prototype.useStyle=function(e){e[Sf]||(e=this.createStyle(e)),this.__inHover?this.__hoverStyle=e:this.style=e,this.dirtyStyle()},t.prototype.isStyleObject=function(e){return e[Sf]},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var n=this._normalState;e.style&&!n.style&&(n.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(e,n,_c)},t.prototype._applyStateObj=function(e,n,i,a,o,s){r.prototype._applyStateObj.call(this,e,n,i,a,o,s);var l=!(n&&a),u;if(n&&n.style?o?a?u=n.style:(u=this._mergeStyle(this.createStyle(),i.style),this._mergeStyle(u,n.style)):(u=this._mergeStyle(this.createStyle(),a?this.style:i.style),this._mergeStyle(u,n.style)):l&&(u=i.style),u)if(o){var f=this.style;if(this.style=this.createStyle(l?{}:f),l)for(var h=mt(f),c=0;c<h.length;c++){var v=h[c];v in u&&(u[v]=u[v],this.style[v]=f[v])}for(var d=mt(u),c=0;c<d.length;c++){var v=d[c];this.style[v]=this.style[v]}this._transitionState(e,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var p=this.__inHover?fb:_c,c=0;c<p.length;c++){var v=p[c];n&&n[v]!=null?this[v]=n[v]:l&&i[v]!=null&&(this[v]=i[v])}},t.prototype._mergeStates=function(e){for(var n=r.prototype._mergeStates.call(this,e),i,a=0;a<e.length;a++){var o=e[a];o.style&&(i=i||{},this._mergeStyle(i,o.style))}return i&&(n.style=i),n},t.prototype._mergeStyle=function(e,n){return F(e,n),e},t.prototype.getAnimationStyleProps=function(){return $s},t.initDefaultProps=function(){var e=t.prototype;e.type="displayable",e.invisible=!1,e.z=0,e.z2=0,e.zlevel=0,e.culling=!1,e.cursor="pointer",e.rectHover=!1,e.incremental=!1,e._rect=null,e.dirtyRectTolerance=0,e.__dirty=Ke|$o}(),t}(Ys),Xl=new ut(0,0,0,0),Zl=new ut(0,0,0,0);function hb(r,t,e){return Xl.copy(r.getBoundingRect()),r.transform&&Xl.applyTransform(r.transform),Zl.width=t,Zl.height=e,!Xl.intersect(Zl)}var ne=Math.min,ie=Math.max,$l=Math.sin,ql=Math.cos,tn=Math.PI*2,ho=Li(),vo=Li(),co=Li();function hm(r,t,e){if(r.length!==0){for(var n=r[0],i=n[0],a=n[0],o=n[1],s=n[1],l=1;l<r.length;l++)n=r[l],i=ne(i,n[0]),a=ie(a,n[0]),o=ne(o,n[1]),s=ie(s,n[1]);t[0]=i,t[1]=o,e[0]=a,e[1]=s}}function Sc(r,t,e,n,i,a){i[0]=ne(r,e),i[1]=ne(t,n),a[0]=ie(r,e),a[1]=ie(t,n)}var xc=[],wc=[];function vb(r,t,e,n,i,a,o,s,l,u){var f=Oy,h=Et,c=f(r,e,i,o,xc);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var v=0;v<c;v++){var d=h(r,e,i,o,xc[v]);l[0]=ne(d,l[0]),u[0]=ie(d,u[0])}c=f(t,n,a,s,wc);for(var v=0;v<c;v++){var p=h(t,n,a,s,wc[v]);l[1]=ne(p,l[1]),u[1]=ie(p,u[1])}l[0]=ne(r,l[0]),u[0]=ie(r,u[0]),l[0]=ne(o,l[0]),u[0]=ie(o,u[0]),l[1]=ne(t,l[1]),u[1]=ie(t,u[1]),l[1]=ne(s,l[1]),u[1]=ie(s,u[1])}function cb(r,t,e,n,i,a,o,s){var l=Ny,u=Gt,f=ie(ne(l(r,e,i),1),0),h=ie(ne(l(t,n,a),1),0),c=u(r,e,i,f),v=u(t,n,a,h);o[0]=ne(r,i,c),o[1]=ne(t,a,v),s[0]=ie(r,i,c),s[1]=ie(t,a,v)}function db(r,t,e,n,i,a,o,s,l){var u=ri,f=ni,h=Math.abs(i-a);if(h%tn<1e-4&&h>1e-4){s[0]=r-e,s[1]=t-n,l[0]=r+e,l[1]=t+n;return}if(ho[0]=ql(i)*e+r,ho[1]=$l(i)*n+t,vo[0]=ql(a)*e+r,vo[1]=$l(a)*n+t,u(s,ho,vo),f(l,ho,vo),i=i%tn,i<0&&(i=i+tn),a=a%tn,a<0&&(a=a+tn),i>a&&!o?a+=tn:i<a&&o&&(i+=tn),o){var c=a;a=i,i=c}for(var v=0;v<a;v+=Math.PI/2)v>i&&(co[0]=ql(v)*e+r,co[1]=$l(v)*n+t,u(s,co,s),f(l,co,l))}var pt={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},en=[],rn=[],Ve=[],xr=[],Ge=[],He=[],Kl=Math.min,Ql=Math.max,nn=Math.cos,an=Math.sin,or=Math.abs,xf=Math.PI,Lr=xf*2,Jl=typeof Float32Array<"u",Wi=[];function jl(r){var t=Math.round(r/xf*1e8)/1e8;return t%2*xf}function Eh(r,t){var e=jl(r[0]);e<0&&(e+=Lr);var n=e-r[0],i=r[1];i+=n,!t&&i-e>=Lr?i=e+Lr:t&&e-i>=Lr?i=e-Lr:!t&&e>i?i=e+(Lr-jl(e-i)):t&&e<i&&(i=e-(Lr-jl(i-e))),r[0]=e,r[1]=i}var yr=function(){function r(t){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,t&&(this._saveData=!1),this._saveData&&(this.data=[])}return r.prototype.increaseVersion=function(){this._version++},r.prototype.getVersion=function(){return this._version},r.prototype.setScale=function(t,e,n){n=n||0,n>0&&(this._ux=or(n/ps/t)||0,this._uy=or(n/ps/e)||0)},r.prototype.setDPR=function(t){this.dpr=t},r.prototype.setContext=function(t){this._ctx=t},r.prototype.getContext=function(){return this._ctx},r.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},r.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},r.prototype.moveTo=function(t,e){return this._drawPendingPt(),this.addData(pt.M,t,e),this._ctx&&this._ctx.moveTo(t,e),this._x0=t,this._y0=e,this._xi=t,this._yi=e,this},r.prototype.lineTo=function(t,e){var n=or(t-this._xi),i=or(e-this._yi),a=n>this._ux||i>this._uy;if(this.addData(pt.L,t,e),this._ctx&&a&&this._ctx.lineTo(t,e),a)this._xi=t,this._yi=e,this._pendingPtDist=0;else{var o=n*n+i*i;o>this._pendingPtDist&&(this._pendingPtX=t,this._pendingPtY=e,this._pendingPtDist=o)}return this},r.prototype.bezierCurveTo=function(t,e,n,i,a,o){return this._drawPendingPt(),this.addData(pt.C,t,e,n,i,a,o),this._ctx&&this._ctx.bezierCurveTo(t,e,n,i,a,o),this._xi=a,this._yi=o,this},r.prototype.quadraticCurveTo=function(t,e,n,i){return this._drawPendingPt(),this.addData(pt.Q,t,e,n,i),this._ctx&&this._ctx.quadraticCurveTo(t,e,n,i),this._xi=n,this._yi=i,this},r.prototype.arc=function(t,e,n,i,a,o){this._drawPendingPt(),Wi[0]=i,Wi[1]=a,Eh(Wi,o),i=Wi[0],a=Wi[1];var s=a-i;return this.addData(pt.A,t,e,n,n,i,s,0,o?0:1),this._ctx&&this._ctx.arc(t,e,n,i,a,o),this._xi=nn(a)*n+t,this._yi=an(a)*n+e,this},r.prototype.arcTo=function(t,e,n,i,a){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(t,e,n,i,a),this},r.prototype.rect=function(t,e,n,i){return this._drawPendingPt(),this._ctx&&this._ctx.rect(t,e,n,i),this.addData(pt.R,t,e,n,i),this},r.prototype.closePath=function(){this._drawPendingPt(),this.addData(pt.Z);var t=this._ctx,e=this._x0,n=this._y0;return t&&t.closePath(),this._xi=e,this._yi=n,this},r.prototype.fill=function(t){t&&t.fill(),this.toStatic()},r.prototype.stroke=function(t){t&&t.stroke(),this.toStatic()},r.prototype.len=function(){return this._len},r.prototype.setData=function(t){var e=t.length;!(this.data&&this.data.length===e)&&Jl&&(this.data=new Float32Array(e));for(var n=0;n<e;n++)this.data[n]=t[n];this._len=e},r.prototype.appendPath=function(t){t instanceof Array||(t=[t]);for(var e=t.length,n=0,i=this._len,a=0;a<e;a++)n+=t[a].len();Jl&&this.data instanceof Float32Array&&(this.data=new Float32Array(i+n));for(var a=0;a<e;a++)for(var o=t[a].data,s=0;s<o.length;s++)this.data[i++]=o[s];this._len=i},r.prototype.addData=function(t,e,n,i,a,o,s,l,u){if(this._saveData){var f=this.data;this._len+arguments.length>f.length&&(this._expandData(),f=this.data);for(var h=0;h<arguments.length;h++)f[this._len++]=arguments[h]}},r.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},r.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var t=[],e=0;e<this._len;e++)t[e]=this.data[e];this.data=t}},r.prototype.toStatic=function(){if(this._saveData){this._drawPendingPt();var t=this.data;t instanceof Array&&(t.length=this._len,Jl&&this._len>11&&(this.data=new Float32Array(t)))}},r.prototype.getBoundingRect=function(){Ve[0]=Ve[1]=Ge[0]=Ge[1]=Number.MAX_VALUE,xr[0]=xr[1]=He[0]=He[1]=-Number.MAX_VALUE;var t=this.data,e=0,n=0,i=0,a=0,o;for(o=0;o<this._len;){var s=t[o++],l=o===1;switch(l&&(e=t[o],n=t[o+1],i=e,a=n),s){case pt.M:e=i=t[o++],n=a=t[o++],Ge[0]=i,Ge[1]=a,He[0]=i,He[1]=a;break;case pt.L:Sc(e,n,t[o],t[o+1],Ge,He),e=t[o++],n=t[o++];break;case pt.C:vb(e,n,t[o++],t[o++],t[o++],t[o++],t[o],t[o+1],Ge,He),e=t[o++],n=t[o++];break;case pt.Q:cb(e,n,t[o++],t[o++],t[o],t[o+1],Ge,He),e=t[o++],n=t[o++];break;case pt.A:var u=t[o++],f=t[o++],h=t[o++],c=t[o++],v=t[o++],d=t[o++]+v;o+=1;var p=!t[o++];l&&(i=nn(v)*h+u,a=an(v)*c+f),db(u,f,h,c,v,d,p,Ge,He),e=nn(d)*h+u,n=an(d)*c+f;break;case pt.R:i=e=t[o++],a=n=t[o++];var g=t[o++],y=t[o++];Sc(i,a,i+g,a+y,Ge,He);break;case pt.Z:e=i,n=a;break}ri(Ve,Ve,Ge),ni(xr,xr,He)}return o===0&&(Ve[0]=Ve[1]=xr[0]=xr[1]=0),new ut(Ve[0],Ve[1],xr[0]-Ve[0],xr[1]-Ve[1])},r.prototype._calculateLength=function(){var t=this.data,e=this._len,n=this._ux,i=this._uy,a=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,f=0,h=0,c=0;c<e;){var v=t[c++],d=c===1;d&&(a=t[c],o=t[c+1],s=a,l=o);var p=-1;switch(v){case pt.M:a=s=t[c++],o=l=t[c++];break;case pt.L:{var g=t[c++],y=t[c++],m=g-a,_=y-o;(or(m)>n||or(_)>i||c===e-1)&&(p=Math.sqrt(m*m+_*_),a=g,o=y);break}case pt.C:{var S=t[c++],w=t[c++],g=t[c++],y=t[c++],x=t[c++],b=t[c++];p=zx(a,o,S,w,g,y,x,b,10),a=x,o=b;break}case pt.Q:{var S=t[c++],w=t[c++],g=t[c++],y=t[c++];p=Gx(a,o,S,w,g,y,10),a=g,o=y;break}case pt.A:var T=t[c++],C=t[c++],D=t[c++],A=t[c++],I=t[c++],L=t[c++],P=L+I;c+=1,d&&(s=nn(I)*D+T,l=an(I)*A+C),p=Ql(D,A)*Kl(Lr,Math.abs(L)),a=nn(P)*D+T,o=an(P)*A+C;break;case pt.R:{s=a=t[c++],l=o=t[c++];var R=t[c++],E=t[c++];p=R*2+E*2;break}case pt.Z:{var m=s-a,_=l-o;p=Math.sqrt(m*m+_*_),a=s,o=l;break}}p>=0&&(u[h++]=p,f+=p)}return this._pathLen=f,f},r.prototype.rebuildPath=function(t,e){var n=this.data,i=this._ux,a=this._uy,o=this._len,s,l,u,f,h,c,v=e<1,d,p,g=0,y=0,m,_=0,S,w;if(!(v&&(this._pathSegLen||this._calculateLength(),d=this._pathSegLen,p=this._pathLen,m=e*p,!m)))t:for(var x=0;x<o;){var b=n[x++],T=x===1;switch(T&&(u=n[x],f=n[x+1],s=u,l=f),b!==pt.L&&_>0&&(t.lineTo(S,w),_=0),b){case pt.M:s=u=n[x++],l=f=n[x++],t.moveTo(u,f);break;case pt.L:{h=n[x++],c=n[x++];var C=or(h-u),D=or(c-f);if(C>i||D>a){if(v){var A=d[y++];if(g+A>m){var I=(m-g)/A;t.lineTo(u*(1-I)+h*I,f*(1-I)+c*I);break t}g+=A}t.lineTo(h,c),u=h,f=c,_=0}else{var L=C*C+D*D;L>_&&(S=h,w=c,_=L)}break}case pt.C:{var P=n[x++],R=n[x++],E=n[x++],O=n[x++],k=n[x++],B=n[x++];if(v){var A=d[y++];if(g+A>m){var I=(m-g)/A;Vr(u,P,E,k,I,en),Vr(f,R,O,B,I,rn),t.bezierCurveTo(en[1],rn[1],en[2],rn[2],en[3],rn[3]);break t}g+=A}t.bezierCurveTo(P,R,E,O,k,B),u=k,f=B;break}case pt.Q:{var P=n[x++],R=n[x++],E=n[x++],O=n[x++];if(v){var A=d[y++];if(g+A>m){var I=(m-g)/A;cs(u,P,E,I,en),cs(f,R,O,I,rn),t.quadraticCurveTo(en[1],rn[1],en[2],rn[2]);break t}g+=A}t.quadraticCurveTo(P,R,E,O),u=E,f=O;break}case pt.A:var z=n[x++],G=n[x++],U=n[x++],j=n[x++],et=n[x++],at=n[x++],Rt=n[x++],jt=!n[x++],Nt=U>j?U:j,Lt=or(U-j)>.001,xt=et+at,K=!1;if(v){var A=d[y++];g+A>m&&(xt=et+at*(m-g)/A,K=!0),g+=A}if(Lt&&t.ellipse?t.ellipse(z,G,U,j,Rt,et,xt,jt):t.arc(z,G,Nt,et,xt,jt),K)break t;T&&(s=nn(et)*U+z,l=an(et)*j+G),u=nn(xt)*U+z,f=an(xt)*j+G;break;case pt.R:s=u=n[x],l=f=n[x+1],h=n[x++],c=n[x++];var ot=n[x++],ze=n[x++];if(v){var A=d[y++];if(g+A>m){var kt=m-g;t.moveTo(h,c),t.lineTo(h+Kl(kt,ot),c),kt-=ot,kt>0&&t.lineTo(h+ot,c+Kl(kt,ze)),kt-=ze,kt>0&&t.lineTo(h+Ql(ot-kt,0),c+ze),kt-=ot,kt>0&&t.lineTo(h,c+Ql(ze-kt,0));break t}g+=A}t.rect(h,c,ot,ze);break;case pt.Z:if(v){var A=d[y++];if(g+A>m){var I=(m-g)/A;t.lineTo(u*(1-I)+s*I,f*(1-I)+l*I);break t}g+=A}t.closePath(),u=s,f=l}}},r.prototype.clone=function(){var t=new r,e=this.data;return t.data=e.slice?e.slice():Array.prototype.slice.call(e),t._len=this._len,t},r.CMD=pt,r.initDefaultProps=function(){var t=r.prototype;t._saveData=!0,t._ux=0,t._uy=0,t._pendingPtDist=0,t._version=0}(),r}();function Vn(r,t,e,n,i,a,o){if(i===0)return!1;var s=i,l=0,u=r;if(o>t+s&&o>n+s||o<t-s&&o<n-s||a>r+s&&a>e+s||a<r-s&&a<e-s)return!1;if(r!==e)l=(t-n)/(r-e),u=(r*n-e*t)/(r-e);else return Math.abs(a-r)<=s/2;var f=l*a-o+u,h=f*f/(l*l+1);return h<=s/2*s/2}function pb(r,t,e,n,i,a,o,s,l,u,f){if(l===0)return!1;var h=l;if(f>t+h&&f>n+h&&f>a+h&&f>s+h||f<t-h&&f<n-h&&f<a-h&&f<s-h||u>r+h&&u>e+h&&u>i+h&&u>o+h||u<r-h&&u<e-h&&u<i-h&&u<o-h)return!1;var c=By(r,t,e,n,i,a,o,s,u,f,null);return c<=h/2}function gb(r,t,e,n,i,a,o,s,l){if(o===0)return!1;var u=o;if(l>t+u&&l>n+u&&l>a+u||l<t-u&&l<n-u&&l<a-u||s>r+u&&s>e+u&&s>i+u||s<r-u&&s<e-u&&s<i-u)return!1;var f=Fy(r,t,e,n,i,a,s,l,null);return f<=u/2}var bc=Math.PI*2;function hr(r){return r%=bc,r<0&&(r+=bc),r}var Ui=Math.PI*2;function yb(r,t,e,n,i,a,o,s,l){if(o===0)return!1;var u=o;s-=r,l-=t;var f=Math.sqrt(s*s+l*l);if(f-u>e||f+u<e)return!1;if(Math.abs(n-i)%Ui<1e-4)return!0;if(a){var h=n;n=hr(i),i=hr(h)}else n=hr(n),i=hr(i);n>i&&(i+=Ui);var c=Math.atan2(l,s);return c<0&&(c+=Ui),c>=n&&c<=i||c+Ui>=n&&c+Ui<=i}function on(r,t,e,n,i,a){if(a>t&&a>n||a<t&&a<n||n===t)return 0;var o=(a-t)/(n-t),s=n<t?1:-1;(o===1||o===0)&&(s=n<t?.5:-.5);var l=o*(e-r)+r;return l===i?1/0:l>i?s:0}var wr=yr.CMD,sn=Math.PI*2,mb=1e-4;function _b(r,t){return Math.abs(r-t)<mb}var Yt=[-1,-1,-1],de=[-1,-1];function Sb(){var r=de[0];de[0]=de[1],de[1]=r}function xb(r,t,e,n,i,a,o,s,l,u){if(u>t&&u>n&&u>a&&u>s||u<t&&u<n&&u<a&&u<s)return 0;var f=vs(t,n,a,s,u,Yt);if(f===0)return 0;for(var h=0,c=-1,v=void 0,d=void 0,p=0;p<f;p++){var g=Yt[p],y=g===0||g===1?.5:1,m=Et(r,e,i,o,g);m<l||(c<0&&(c=Oy(t,n,a,s,de),de[1]<de[0]&&c>1&&Sb(),v=Et(t,n,a,s,de[0]),c>1&&(d=Et(t,n,a,s,de[1]))),c===2?g<de[0]?h+=v<t?y:-y:g<de[1]?h+=d<v?y:-y:h+=s<d?y:-y:g<de[0]?h+=v<t?y:-y:h+=s<v?y:-y)}return h}function wb(r,t,e,n,i,a,o,s){if(s>t&&s>n&&s>a||s<t&&s<n&&s<a)return 0;var l=Vx(t,n,a,s,Yt);if(l===0)return 0;var u=Ny(t,n,a);if(u>=0&&u<=1){for(var f=0,h=Gt(t,n,a,u),c=0;c<l;c++){var v=Yt[c]===0||Yt[c]===1?.5:1,d=Gt(r,e,i,Yt[c]);d<o||(Yt[c]<u?f+=h<t?v:-v:f+=a<h?v:-v)}return f}else{var v=Yt[0]===0||Yt[0]===1?.5:1,d=Gt(r,e,i,Yt[0]);return d<o?0:a<t?v:-v}}function bb(r,t,e,n,i,a,o,s){if(s-=t,s>e||s<-e)return 0;var l=Math.sqrt(e*e-s*s);Yt[0]=-l,Yt[1]=l;var u=Math.abs(n-i);if(u<1e-4)return 0;if(u>=sn-1e-4){n=0,i=sn;var f=a?1:-1;return o>=Yt[0]+r&&o<=Yt[1]+r?f:0}if(n>i){var h=n;n=i,i=h}n<0&&(n+=sn,i+=sn);for(var c=0,v=0;v<2;v++){var d=Yt[v];if(d+r>o){var p=Math.atan2(s,d),f=a?1:-1;p<0&&(p=sn+p),(p>=n&&p<=i||p+sn>=n&&p+sn<=i)&&(p>Math.PI/2&&p<Math.PI*1.5&&(f=-f),c+=f)}}return c}function vm(r,t,e,n,i){for(var a=r.data,o=r.len(),s=0,l=0,u=0,f=0,h=0,c,v,d=0;d<o;){var p=a[d++],g=d===1;switch(p===wr.M&&d>1&&(e||(s+=on(l,u,f,h,n,i))),g&&(l=a[d],u=a[d+1],f=l,h=u),p){case wr.M:f=a[d++],h=a[d++],l=f,u=h;break;case wr.L:if(e){if(Vn(l,u,a[d],a[d+1],t,n,i))return!0}else s+=on(l,u,a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case wr.C:if(e){if(pb(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],t,n,i))return!0}else s+=xb(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case wr.Q:if(e){if(gb(l,u,a[d++],a[d++],a[d],a[d+1],t,n,i))return!0}else s+=wb(l,u,a[d++],a[d++],a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case wr.A:var y=a[d++],m=a[d++],_=a[d++],S=a[d++],w=a[d++],x=a[d++];d+=1;var b=!!(1-a[d++]);c=Math.cos(w)*_+y,v=Math.sin(w)*S+m,g?(f=c,h=v):s+=on(l,u,c,v,n,i);var T=(n-y)*S/_+y;if(e){if(yb(y,m,S,w,w+x,b,t,T,i))return!0}else s+=bb(y,m,S,w,w+x,b,T,i);l=Math.cos(w+x)*_+y,u=Math.sin(w+x)*S+m;break;case wr.R:f=l=a[d++],h=u=a[d++];var C=a[d++],D=a[d++];if(c=f+C,v=h+D,e){if(Vn(f,h,c,h,t,n,i)||Vn(c,h,c,v,t,n,i)||Vn(c,v,f,v,t,n,i)||Vn(f,v,f,h,t,n,i))return!0}else s+=on(c,h,c,v,n,i),s+=on(f,v,f,h,n,i);break;case wr.Z:if(e){if(Vn(l,u,f,h,t,n,i))return!0}else s+=on(l,u,f,h,n,i);l=f,u=h;break}}return!e&&!_b(u,h)&&(s+=on(l,u,f,h,n,i)||0),s!==0}function Tb(r,t,e){return vm(r,0,!1,t,e)}function Cb(r,t,e,n){return vm(r,t,!0,e,n)}var cm=Q({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},wn),Db={style:Q({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},$s.style)},tu=Ra.concat(["invisible","culling","z","z2","zlevel","parent"]),it=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.update=function(){var e=this;r.prototype.update.call(this);var n=this.style;if(n.decal){var i=this._decalEl=this._decalEl||new t;i.buildPath===t.prototype.buildPath&&(i.buildPath=function(l){e.buildPath(l,e.shape)}),i.silent=!0;var a=i.style;for(var o in n)a[o]!==n[o]&&(a[o]=n[o]);a.fill=n.fill?n.decal:null,a.decal=null,a.shadowColor=null,n.strokeFirst&&(a.stroke=null);for(var s=0;s<tu.length;++s)i[tu[s]]=this[tu[s]];i.__dirty|=Ke}else this._decalEl&&(this._decalEl=null)},t.prototype.getDecalElement=function(){return this._decalEl},t.prototype._init=function(e){var n=mt(e);this.shape=this.getDefaultShape();var i=this.getDefaultStyle();i&&this.useStyle(i);for(var a=0;a<n.length;a++){var o=n[a],s=e[o];o==="style"?this.style?F(this.style,s):this.useStyle(s):o==="shape"?F(this.shape,s):r.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},t.prototype.getDefaultStyle=function(){return null},t.prototype.getDefaultShape=function(){return{}},t.prototype.canBeInsideText=function(){return this.hasFill()},t.prototype.getInsideTextFill=function(){var e=this.style.fill;if(e!=="none"){if(W(e)){var n=ds(e,0);return n>.5?gf:n>.2?sw:yf}else if(e)return yf}return gf},t.prototype.getInsideTextStroke=function(e){var n=this.style.fill;if(W(n)){var i=this.__zr,a=!!(i&&i.isDarkMode()),o=ds(e,0)<pf;if(a===o)return n}},t.prototype.buildPath=function(e,n,i){},t.prototype.pathUpdated=function(){this.__dirty&=-5},t.prototype.getUpdatedPathProxy=function(e){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,e),this.path},t.prototype.createPathProxy=function(){this.path=new yr(!1)},t.prototype.hasStroke=function(){var e=this.style,n=e.stroke;return!(n==null||n==="none"||!(e.lineWidth>0))},t.prototype.hasFill=function(){var e=this.style,n=e.fill;return n!=null&&n!=="none"},t.prototype.getBoundingRect=function(){var e=this._rect,n=this.style,i=!e;if(i){var a=!1;this.path||(a=!0,this.createPathProxy());var o=this.path;(a||this.__dirty&sa)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),e=o.getBoundingRect()}if(this._rect=e,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=e.clone());if(this.__dirty||i){s.copy(e);var l=n.strokeNoScale?this.getLineScale():1,u=n.lineWidth;if(!this.hasFill()){var f=this.strokeContainThreshold;u=Math.max(u,f??4)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return e},t.prototype.contain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect(),o=this.style;if(e=i[0],n=i[1],a.contain(e,n)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),Cb(s,l/u,e,n)))return!0}if(this.hasFill())return Tb(s,e,n)}return!1},t.prototype.dirtyShape=function(){this.__dirty|=sa,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},t.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},t.prototype.animateShape=function(e){return this.animate("shape",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():e==="shape"?this.dirtyShape():this.markRedraw()},t.prototype.attrKV=function(e,n){e==="shape"?this.setShape(n):r.prototype.attrKV.call(this,e,n)},t.prototype.setShape=function(e,n){var i=this.shape;return i||(i=this.shape={}),typeof e=="string"?i[e]=n:F(i,e),this.dirtyShape(),this},t.prototype.shapeChanged=function(){return!!(this.__dirty&sa)},t.prototype.createStyle=function(e){return Gs(cm,e)},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var n=this._normalState;e.shape&&!n.shape&&(n.shape=F({},this.shape))},t.prototype._applyStateObj=function(e,n,i,a,o,s){r.prototype._applyStateObj.call(this,e,n,i,a,o,s);var l=!(n&&a),u;if(n&&n.shape?o?a?u=n.shape:(u=F({},i.shape),F(u,n.shape)):(u=F({},a?this.shape:i.shape),F(u,n.shape)):l&&(u=i.shape),u)if(o){this.shape=F({},this.shape);for(var f={},h=mt(u),c=0;c<h.length;c++){var v=h[c];typeof u[v]=="object"?this.shape[v]=u[v]:f[v]=u[v]}this._transitionState(e,{shape:f},s)}else this.shape=u,this.dirtyShape()},t.prototype._mergeStates=function(e){for(var n=r.prototype._mergeStates.call(this,e),i,a=0;a<e.length;a++){var o=e[a];o.shape&&(i=i||{},this._mergeStyle(i,o.shape))}return i&&(n.shape=i),n},t.prototype.getAnimationStyleProps=function(){return Db},t.prototype.isZeroArea=function(){return!1},t.extend=function(e){var n=function(a){N(o,a);function o(s){var l=a.call(this,s)||this;return e.init&&e.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return tt(e.style)},o.prototype.getDefaultShape=function(){return tt(e.shape)},o}(t);for(var i in e)typeof e[i]=="function"&&(n.prototype[i]=e[i]);return n},t.initDefaultProps=function(){var e=t.prototype;e.type="path",e.strokeContainThreshold=5,e.segmentIgnoreThreshold=0,e.subPixelOptimize=!1,e.autoBatch=!1,e.__dirty=Ke|$o|sa}(),t}(Pi),Ab=Q({strokeFirst:!0,font:Cn,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},cm),ms=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.hasStroke=function(){var e=this.style,n=e.stroke;return n!=null&&n!=="none"&&e.lineWidth>0},t.prototype.hasFill=function(){var e=this.style,n=e.fill;return n!=null&&n!=="none"},t.prototype.createStyle=function(e){return Gs(Ab,e)},t.prototype.setBoundingRect=function(e){this._rect=e},t.prototype.getBoundingRect=function(){var e=this.style;if(!this._rect){var n=e.text;n!=null?n+="":n="";var i=Us(n,e.font,e.textAlign,e.textBaseline);if(i.x+=e.x||0,i.y+=e.y||0,this.hasStroke()){var a=e.lineWidth;i.x-=a/2,i.y-=a/2,i.width+=a,i.height+=a}this._rect=i}return this._rect},t.initDefaultProps=function(){var e=t.prototype;e.dirtyRectTolerance=10}(),t}(Pi);ms.prototype.type="tspan";var Mb=Q({x:0,y:0},wn),Ib={style:Q({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},$s.style)};function Lb(r){return!!(r&&typeof r!="string"&&r.width&&r.height)}var Ne=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.createStyle=function(e){return Gs(Mb,e)},t.prototype._getSize=function(e){var n=this.style,i=n[e];if(i!=null)return i;var a=Lb(n.image)?n.image:this.__image;if(!a)return 0;var o=e==="width"?"height":"width",s=n[o];return s==null?a[e]:a[e]/a[o]*s},t.prototype.getWidth=function(){return this._getSize("width")},t.prototype.getHeight=function(){return this._getSize("height")},t.prototype.getAnimationStyleProps=function(){return Ib},t.prototype.getBoundingRect=function(){var e=this.style;return this._rect||(this._rect=new ut(e.x||0,e.y||0,this.getWidth(),this.getHeight())),this._rect},t}(Pi);Ne.prototype.type="image";function Pb(r,t){var e=t.x,n=t.y,i=t.width,a=t.height,o=t.r,s,l,u,f;i<0&&(e=e+i,i=-i),a<0&&(n=n+a,a=-a),typeof o=="number"?s=l=u=f=o:o instanceof Array?o.length===1?s=l=u=f=o[0]:o.length===2?(s=u=o[0],l=f=o[1]):o.length===3?(s=o[0],l=f=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],f=o[3]):s=l=u=f=0;var h;s+l>i&&(h=s+l,s*=i/h,l*=i/h),u+f>i&&(h=u+f,u*=i/h,f*=i/h),l+u>a&&(h=l+u,l*=a/h,u*=a/h),s+f>a&&(h=s+f,s*=a/h,f*=a/h),r.moveTo(e+s,n),r.lineTo(e+i-l,n),l!==0&&r.arc(e+i-l,n+l,l,-Math.PI/2,0),r.lineTo(e+i,n+a-u),u!==0&&r.arc(e+i-u,n+a-u,u,0,Math.PI/2),r.lineTo(e+f,n+a),f!==0&&r.arc(e+f,n+a-f,f,Math.PI/2,Math.PI),r.lineTo(e,n+s),s!==0&&r.arc(e+s,n+s,s,Math.PI,Math.PI*1.5)}var ai=Math.round;function dm(r,t,e){if(t){var n=t.x1,i=t.x2,a=t.y1,o=t.y2;r.x1=n,r.x2=i,r.y1=a,r.y2=o;var s=e&&e.lineWidth;return s&&(ai(n*2)===ai(i*2)&&(r.x1=r.x2=_n(n,s,!0)),ai(a*2)===ai(o*2)&&(r.y1=r.y2=_n(a,s,!0))),r}}function pm(r,t,e){if(t){var n=t.x,i=t.y,a=t.width,o=t.height;r.x=n,r.y=i,r.width=a,r.height=o;var s=e&&e.lineWidth;return s&&(r.x=_n(n,s,!0),r.y=_n(i,s,!0),r.width=Math.max(_n(n+a,s,!1)-r.x,a===0?0:1),r.height=Math.max(_n(i+o,s,!1)-r.y,o===0?0:1)),r}}function _n(r,t,e){if(!t)return r;var n=ai(r*2);return(n+ai(t))%2===0?n/2:(n+(e?1:-1))/2}var Rb=function(){function r(){this.x=0,this.y=0,this.width=0,this.height=0}return r}(),Eb={},St=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Rb},t.prototype.buildPath=function(e,n){var i,a,o,s;if(this.subPixelOptimize){var l=pm(Eb,n,this.style);i=l.x,a=l.y,o=l.width,s=l.height,l.r=n.r,n=l}else i=n.x,a=n.y,o=n.width,s=n.height;n.r?Pb(e,n):e.rect(i,a,o,s)},t.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},t}(it);St.prototype.type="rect";var Tc={fill:"#000"},Cc=2,kb={style:Q({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},$s.style)},Ct=function(r){N(t,r);function t(e){var n=r.call(this)||this;return n.type="text",n._children=[],n._defaultStyle=Tc,n.attr(e),n}return t.prototype.childrenRef=function(){return this._children},t.prototype.update=function(){r.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var e=0;e<this._children.length;e++){var n=this._children[e];n.zlevel=this.zlevel,n.z=this.z,n.z2=this.z2,n.culling=this.culling,n.cursor=this.cursor,n.invisible=this.invisible}},t.prototype.updateTransform=function(){var e=this.innerTransformable;e?(e.updateTransform(),e.transform&&(this.transform=e.transform)):r.prototype.updateTransform.call(this)},t.prototype.getLocalTransform=function(e){var n=this.innerTransformable;return n?n.getLocalTransform(e):r.prototype.getLocalTransform.call(this,e)},t.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),r.prototype.getComputedTransform.call(this)},t.prototype._updateSubTexts=function(){this._childCursor=0,zb(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var n=0;n<this._children.length;n++)this._children[n].__zr=e},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var n=0;n<this._children.length;n++)this._children[n].__zr=null},t.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var e=new ut(0,0,0,0),n=this._children,i=[],a=null,o=0;o<n.length;o++){var s=n[o],l=s.getBoundingRect(),u=s.getLocalTransform(i);u?(e.copy(l),e.applyTransform(u),a=a||e.clone(),a.union(e)):(a=a||l.clone(),a.union(l))}this._rect=a||e}return this._rect},t.prototype.setDefaultTextStyle=function(e){this._defaultStyle=e||Tc},t.prototype.setTextContent=function(e){},t.prototype._mergeStyle=function(e,n){if(!n)return e;var i=n.rich,a=e.rich||i&&{};return F(e,n),i&&a?(this._mergeRich(a,i),e.rich=a):a&&(e.rich=a),e},t.prototype._mergeRich=function(e,n){for(var i=mt(n),a=0;a<i.length;a++){var o=i[a];e[o]=e[o]||{},F(e[o],n[o])}},t.prototype.getAnimationStyleProps=function(){return kb},t.prototype._getOrCreateChild=function(e){var n=this._children[this._childCursor];return(!n||!(n instanceof e))&&(n=new e),this._children[this._childCursor++]=n,n.__zr=this.__zr,n.parent=this,n},t.prototype._updatePlainTexts=function(){var e=this.style,n=e.font||Cn,i=e.padding,a=Rc(e),o=nb(a,e),s=eu(e),l=!!e.backgroundColor,u=o.outerHeight,f=o.outerWidth,h=o.contentWidth,c=o.lines,v=o.lineHeight,d=this._defaultStyle;this.isTruncated=!!o.isTruncated;var p=e.x||0,g=e.y||0,y=e.align||d.align||"left",m=e.verticalAlign||d.verticalAlign||"top",_=p,S=ti(g,o.contentHeight,m);if(s||i){var w=ua(p,f,y),x=ti(g,u,m);s&&this._renderBackground(e,e,w,x,f,u)}S+=v/2,i&&(_=Pc(p,y,i),m==="top"?S+=i[0]:m==="bottom"&&(S-=i[2]));for(var b=0,T=!1,C=Lc("fill"in e?e.fill:(T=!0,d.fill)),D=Ic("stroke"in e?e.stroke:!l&&(!d.autoStroke||T)?(b=Cc,d.stroke):null),A=e.textShadowBlur>0,I=e.width!=null&&(e.overflow==="truncate"||e.overflow==="break"||e.overflow==="breakAll"),L=o.calculatedLineHeight,P=0;P<c.length;P++){var R=this._getOrCreateChild(ms),E=R.createStyle();R.useStyle(E),E.text=c[P],E.x=_,E.y=S,E.textAlign=y,E.textBaseline="middle",E.opacity=e.opacity,E.strokeFirst=!0,A&&(E.shadowBlur=e.textShadowBlur||0,E.shadowColor=e.textShadowColor||"transparent",E.shadowOffsetX=e.textShadowOffsetX||0,E.shadowOffsetY=e.textShadowOffsetY||0),E.stroke=D,E.fill=C,D&&(E.lineWidth=e.lineWidth||b,E.lineDash=e.lineDash,E.lineDashOffset=e.lineDashOffset||0),E.font=n,Ac(E,e),S+=v,I&&R.setBoundingRect(new ut(ua(E.x,h,E.textAlign),ti(E.y,L,E.textBaseline),h,L))}},t.prototype._updateRichTexts=function(){var e=this.style,n=Rc(e),i=ob(n,e),a=i.width,o=i.outerWidth,s=i.outerHeight,l=e.padding,u=e.x||0,f=e.y||0,h=this._defaultStyle,c=e.align||h.align,v=e.verticalAlign||h.verticalAlign;this.isTruncated=!!i.isTruncated;var d=ua(u,o,c),p=ti(f,s,v),g=d,y=p;l&&(g+=l[3],y+=l[0]);var m=g+a;eu(e)&&this._renderBackground(e,e,d,p,o,s);for(var _=!!e.backgroundColor,S=0;S<i.lines.length;S++){for(var w=i.lines[S],x=w.tokens,b=x.length,T=w.lineHeight,C=w.width,D=0,A=g,I=m,L=b-1,P=void 0;D<b&&(P=x[D],!P.align||P.align==="left");)this._placeToken(P,e,T,y,A,"left",_),C-=P.width,A+=P.width,D++;for(;L>=0&&(P=x[L],P.align==="right");)this._placeToken(P,e,T,y,I,"right",_),C-=P.width,I-=P.width,L--;for(A+=(a-(A-g)-(m-I)-C)/2;D<=L;)P=x[D],this._placeToken(P,e,T,y,A+P.width/2,"center",_),A+=P.width,D++;y+=T}},t.prototype._placeToken=function(e,n,i,a,o,s,l){var u=n.rich[e.styleName]||{};u.text=e.text;var f=e.verticalAlign,h=a+i/2;f==="top"?h=a+e.height/2:f==="bottom"&&(h=a+i-e.height/2);var c=!e.isLineHolder&&eu(u);c&&this._renderBackground(u,n,s==="right"?o-e.width:s==="center"?o-e.width/2:o,h-e.height/2,e.width,e.height);var v=!!u.backgroundColor,d=e.textPadding;d&&(o=Pc(o,s,d),h-=e.height/2-d[0]-e.innerHeight/2);var p=this._getOrCreateChild(ms),g=p.createStyle();p.useStyle(g);var y=this._defaultStyle,m=!1,_=0,S=Lc("fill"in u?u.fill:"fill"in n?n.fill:(m=!0,y.fill)),w=Ic("stroke"in u?u.stroke:"stroke"in n?n.stroke:!v&&!l&&(!y.autoStroke||m)?(_=Cc,y.stroke):null),x=u.textShadowBlur>0||n.textShadowBlur>0;g.text=e.text,g.x=o,g.y=h,x&&(g.shadowBlur=u.textShadowBlur||n.textShadowBlur||0,g.shadowColor=u.textShadowColor||n.textShadowColor||"transparent",g.shadowOffsetX=u.textShadowOffsetX||n.textShadowOffsetX||0,g.shadowOffsetY=u.textShadowOffsetY||n.textShadowOffsetY||0),g.textAlign=s,g.textBaseline="middle",g.font=e.font||Cn,g.opacity=ga(u.opacity,n.opacity,1),Ac(g,u),w&&(g.lineWidth=ga(u.lineWidth,n.lineWidth,_),g.lineDash=rt(u.lineDash,n.lineDash),g.lineDashOffset=n.lineDashOffset||0,g.stroke=w),S&&(g.fill=S);var b=e.contentWidth,T=e.contentHeight;p.setBoundingRect(new ut(ua(g.x,b,g.textAlign),ti(g.y,T,g.textBaseline),b,T))},t.prototype._renderBackground=function(e,n,i,a,o,s){var l=e.backgroundColor,u=e.borderWidth,f=e.borderColor,h=l&&l.image,c=l&&!h,v=e.borderRadius,d=this,p,g;if(c||e.lineHeight||u&&f){p=this._getOrCreateChild(St),p.useStyle(p.createStyle()),p.style.fill=null;var y=p.shape;y.x=i,y.y=a,y.width=o,y.height=s,y.r=v,p.dirtyShape()}if(c){var m=p.style;m.fill=l||null,m.fillOpacity=rt(e.fillOpacity,1)}else if(h){g=this._getOrCreateChild(Ne),g.onload=function(){d.dirtyStyle()};var _=g.style;_.image=l.image,_.x=i,_.y=a,_.width=o,_.height=s}if(u&&f){var m=p.style;m.lineWidth=u,m.stroke=f,m.strokeOpacity=rt(e.strokeOpacity,1),m.lineDash=e.borderDash,m.lineDashOffset=e.borderDashOffset||0,p.strokeContainThreshold=0,p.hasFill()&&p.hasStroke()&&(m.strokeFirst=!0,m.lineWidth*=2)}var S=(p||g).style;S.shadowBlur=e.shadowBlur||0,S.shadowColor=e.shadowColor||"transparent",S.shadowOffsetX=e.shadowOffsetX||0,S.shadowOffsetY=e.shadowOffsetY||0,S.opacity=ga(e.opacity,n.opacity,1)},t.makeFont=function(e){var n="";return Fb(e)&&(n=[e.fontStyle,e.fontWeight,Nb(e.fontSize),e.fontFamily||"sans-serif"].join(" ")),n&&Ze(n)||e.textFont||e.font},t}(Pi),Ob={left:!0,right:1,center:1},Bb={top:1,bottom:1,middle:1},Dc=["fontStyle","fontWeight","fontSize","fontFamily"];function Nb(r){return typeof r=="string"&&(r.indexOf("px")!==-1||r.indexOf("rem")!==-1||r.indexOf("em")!==-1)?r:isNaN(+r)?_h+"px":r+"px"}function Ac(r,t){for(var e=0;e<Dc.length;e++){var n=Dc[e],i=t[n];i!=null&&(r[n]=i)}}function Fb(r){return r.fontSize!=null||r.fontFamily||r.fontWeight}function zb(r){return Mc(r),M(r.rich,Mc),r}function Mc(r){if(r){r.font=Ct.makeFont(r);var t=r.align;t==="middle"&&(t="center"),r.align=t==null||Ob[t]?t:"left";var e=r.verticalAlign;e==="center"&&(e="middle"),r.verticalAlign=e==null||Bb[e]?e:"top";var n=r.padding;n&&(r.padding=wy(r.padding))}}function Ic(r,t){return r==null||t<=0||r==="transparent"||r==="none"?null:r.image||r.colorStops?"#000":r}function Lc(r){return r==null||r==="none"?null:r.image||r.colorStops?"#000":r}function Pc(r,t,e){return t==="right"?r-e[1]:t==="center"?r+e[3]/2-e[1]/2:r+e[3]}function Rc(r){var t=r.text;return t!=null&&(t+=""),t}function eu(r){return!!(r.backgroundColor||r.lineHeight||r.borderWidth&&r.borderColor)}var st=_t(),wf=function(r,t,e,n){if(n){var i=st(n);i.dataIndex=e,i.dataType=t,i.seriesIndex=r,i.ssrType="chart",n.type==="group"&&n.traverse(function(a){var o=st(a);o.seriesIndex=r,o.dataIndex=e,o.dataType=t,o.ssrType="chart"})}},Ec=1,kc={},gm=_t(),kh=_t(),Oh=0,qs=1,Ks=2,_e=["emphasis","blur","select"],_s=["normal","emphasis","blur","select"],Vb=10,Gb=9,bn="highlight",ts="downplay",wa="select",es="unselect",ba="toggleSelect";function Gn(r){return r!=null&&r!=="none"}function Qs(r,t,e){r.onHoverStateChange&&(r.hoverState||0)!==e&&r.onHoverStateChange(t),r.hoverState=e}function ym(r){Qs(r,"emphasis",Ks)}function mm(r){r.hoverState===Ks&&Qs(r,"normal",Oh)}function Bh(r){Qs(r,"blur",qs)}function _m(r){r.hoverState===qs&&Qs(r,"normal",Oh)}function Hb(r){r.selected=!0}function Wb(r){r.selected=!1}function Oc(r,t,e){t(r,e)}function _r(r,t,e){Oc(r,t,e),r.isGroup&&r.traverse(function(n){Oc(n,t,e)})}function Bc(r,t){switch(t){case"emphasis":r.hoverState=Ks;break;case"normal":r.hoverState=Oh;break;case"blur":r.hoverState=qs;break;case"select":r.selected=!0}}function Ub(r,t,e,n){for(var i=r.style,a={},o=0;o<t.length;o++){var s=t[o],l=i[s];a[s]=l??(n&&n[s])}for(var o=0;o<r.animators.length;o++){var u=r.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(e)<0&&u.targetName==="style"&&u.saveTo(a,t)}return a}function Yb(r,t,e,n){var i=e&&lt(e,"select")>=0,a=!1;if(r instanceof it){var o=gm(r),s=i&&o.selectFill||o.normalFill,l=i&&o.selectStroke||o.normalStroke;if(Gn(s)||Gn(l)){n=n||{};var u=n.style||{};u.fill==="inherit"?(a=!0,n=F({},n),u=F({},u),u.fill=s):!Gn(u.fill)&&Gn(s)?(a=!0,n=F({},n),u=F({},u),u.fill=nc(s)):!Gn(u.stroke)&&Gn(l)&&(a||(n=F({},n),u=F({},u)),u.stroke=nc(l)),n.style=u}}if(n&&n.z2==null){a||(n=F({},n));var f=r.z2EmphasisLift;n.z2=r.z2+(f??Vb)}return n}function Xb(r,t,e){if(e&&e.z2==null){e=F({},e);var n=r.z2SelectLift;e.z2=r.z2+(n??Gb)}return e}function Zb(r,t,e){var n=lt(r.currentStates,t)>=0,i=r.style.opacity,a=n?null:Ub(r,["opacity"],t,{opacity:1});e=e||{};var o=e.style||{};return o.opacity==null&&(e=F({},e),o=F({opacity:n?i:a.opacity*.1},o),e.style=o),e}function ru(r,t){var e=this.states[r];if(this.style){if(r==="emphasis")return Yb(this,r,t,e);if(r==="blur")return Zb(this,r,e);if(r==="select")return Xb(this,r,e)}return e}function $b(r){r.stateProxy=ru;var t=r.getTextContent(),e=r.getTextGuideLine();t&&(t.stateProxy=ru),e&&(e.stateProxy=ru)}function Nc(r,t){!bm(r,t)&&!r.__highByOuter&&_r(r,ym)}function Fc(r,t){!bm(r,t)&&!r.__highByOuter&&_r(r,mm)}function xi(r,t){r.__highByOuter|=1<<(t||0),_r(r,ym)}function wi(r,t){!(r.__highByOuter&=~(1<<(t||0)))&&_r(r,mm)}function qb(r){_r(r,Bh)}function Sm(r){_r(r,_m)}function xm(r){_r(r,Hb)}function wm(r){_r(r,Wb)}function bm(r,t){return r.__highDownSilentOnTouch&&t.zrByTouch}function Tm(r){var t=r.getModel(),e=[],n=[];t.eachComponent(function(i,a){var o=kh(a),s=i==="series",l=s?r.getViewOfSeriesModel(a):r.getViewOfComponentModel(a);!s&&n.push(l),o.isBlured&&(l.group.traverse(function(u){_m(u)}),s&&e.push(a)),o.isBlured=!1}),M(n,function(i){i&&i.toggleBlurSeries&&i.toggleBlurSeries(e,!1,t)})}function bf(r,t,e,n){var i=n.getModel();e=e||"coordinateSystem";function a(u,f){for(var h=0;h<f.length;h++){var c=u.getItemGraphicEl(f[h]);c&&Sm(c)}}if(r!=null&&!(!t||t==="none")){var o=i.getSeriesByIndex(r),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];i.eachSeries(function(u){var f=o===u,h=u.coordinateSystem;h&&h.master&&(h=h.master);var c=h&&s?h===s:f;if(!(e==="series"&&!f||e==="coordinateSystem"&&!c||t==="series"&&f)){var v=n.getViewOfSeriesModel(u);if(v.group.traverse(function(g){g.__highByOuter&&f&&t==="self"||Bh(g)}),Kt(t))a(u.getData(),t);else if(Y(t))for(var d=mt(t),p=0;p<d.length;p++)a(u.getData(d[p]),t[d[p]]);l.push(u),kh(u).isBlured=!0}}),i.eachComponent(function(u,f){if(u!=="series"){var h=n.getViewOfComponentModel(f);h&&h.toggleBlurSeries&&h.toggleBlurSeries(l,!0,i)}})}}function Tf(r,t,e){if(!(r==null||t==null)){var n=e.getModel().getComponent(r,t);if(n){kh(n).isBlured=!0;var i=e.getViewOfComponentModel(n);!i||!i.focusBlurEnabled||i.group.traverse(function(a){Bh(a)})}}}function Kb(r,t,e){var n=r.seriesIndex,i=r.getData(t.dataType);if(i){var a=Dn(i,t);a=(V(a)?a[0]:a)||0;var o=i.getItemGraphicEl(a);if(!o)for(var s=i.count(),l=0;!o&&l<s;)o=i.getItemGraphicEl(l++);if(o){var u=st(o);bf(n,u.focus,u.blurScope,e)}else{var f=r.get(["emphasis","focus"]),h=r.get(["emphasis","blurScope"]);f!=null&&bf(n,f,h,e)}}}function Nh(r,t,e,n){var i={focusSelf:!1,dispatchers:null};if(r==null||r==="series"||t==null||e==null)return i;var a=n.getModel().getComponent(r,t);if(!a)return i;var o=n.getViewOfComponentModel(a);if(!o||!o.findHighDownDispatchers)return i;for(var s=o.findHighDownDispatchers(e),l,u=0;u<s.length;u++)if(st(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function Qb(r,t,e){var n=st(r),i=Nh(n.componentMainType,n.componentIndex,n.componentHighDownName,e),a=i.dispatchers,o=i.focusSelf;a?(o&&Tf(n.componentMainType,n.componentIndex,e),M(a,function(s){return Nc(s,t)})):(bf(n.seriesIndex,n.focus,n.blurScope,e),n.focus==="self"&&Tf(n.componentMainType,n.componentIndex,e),Nc(r,t))}function Jb(r,t,e){Tm(e);var n=st(r),i=Nh(n.componentMainType,n.componentIndex,n.componentHighDownName,e).dispatchers;i?M(i,function(a){return Fc(a,t)}):Fc(r,t)}function jb(r,t,e){if(Af(t)){var n=t.dataType,i=r.getData(n),a=Dn(i,t);V(a)||(a=[a]),r[t.type===ba?"toggleSelect":t.type===wa?"select":"unselect"](a,n)}}function zc(r){var t=r.getAllData();M(t,function(e){var n=e.data,i=e.type;n.eachItemGraphicEl(function(a,o){r.isSelected(o,i)?xm(a):wm(a)})})}function tT(r){var t=[];return r.eachSeries(function(e){var n=e.getAllData();M(n,function(i){i.data;var a=i.type,o=e.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:e.seriesIndex};a!=null&&(s.dataType=a),t.push(s)}})}),t}function Cf(r,t,e){Cm(r,!0),_r(r,$b),rT(r,t,e)}function eT(r){Cm(r,!1)}function mr(r,t,e,n){n?eT(r):Cf(r,t,e)}function rT(r,t,e){var n=st(r);t!=null?(n.focus=t,n.blurScope=e):n.focus&&(n.focus=null)}var Vc=["emphasis","blur","select"],nT={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function Wr(r,t,e,n){e=e||"itemStyle";for(var i=0;i<Vc.length;i++){var a=Vc[i],o=t.getModel([a,e]),s=r.ensureState(a);s.style=o[nT[e]]()}}function Cm(r,t){var e=t===!1,n=r;r.highDownSilentOnTouch&&(n.__highDownSilentOnTouch=r.highDownSilentOnTouch),(!e||n.__highDownDispatcher)&&(n.__highByOuter=n.__highByOuter||0,n.__highDownDispatcher=!e)}function Df(r){return!!(r&&r.__highDownDispatcher)}function iT(r){var t=kc[r];return t==null&&Ec<=32&&(t=kc[r]=Ec++),t}function Af(r){var t=r.type;return t===wa||t===es||t===ba}function Gc(r){var t=r.type;return t===bn||t===ts}function aT(r){var t=gm(r);t.normalFill=r.style.fill,t.normalStroke=r.style.stroke;var e=r.states.select||{};t.selectFill=e.style&&e.style.fill||null,t.selectStroke=e.style&&e.style.stroke||null}var Hn=yr.CMD,oT=[[],[],[]],Hc=Math.sqrt,sT=Math.atan2;function Dm(r,t){if(t){var e=r.data,n=r.len(),i,a,o,s,l,u,f=Hn.M,h=Hn.C,c=Hn.L,v=Hn.R,d=Hn.A,p=Hn.Q;for(o=0,s=0;o<n;){switch(i=e[o++],s=o,a=0,i){case f:a=1;break;case c:a=1;break;case h:a=3;break;case p:a=2;break;case d:var g=t[4],y=t[5],m=Hc(t[0]*t[0]+t[1]*t[1]),_=Hc(t[2]*t[2]+t[3]*t[3]),S=sT(-t[1]/_,t[0]/m);e[o]*=m,e[o++]+=g,e[o]*=_,e[o++]+=y,e[o++]*=m,e[o++]*=_,e[o++]+=S,e[o++]+=S,o+=2,s=o;break;case v:u[0]=e[o++],u[1]=e[o++],me(u,u,t),e[s++]=u[0],e[s++]=u[1],u[0]+=e[o++],u[1]+=e[o++],me(u,u,t),e[s++]=u[0],e[s++]=u[1]}for(l=0;l<a;l++){var w=oT[l];w[0]=e[o++],w[1]=e[o++],me(w,w,t),e[s++]=w[0],e[s++]=w[1]}}r.increaseVersion()}}var nu=Math.sqrt,po=Math.sin,go=Math.cos,Yi=Math.PI;function Wc(r){return Math.sqrt(r[0]*r[0]+r[1]*r[1])}function Mf(r,t){return(r[0]*t[0]+r[1]*t[1])/(Wc(r)*Wc(t))}function Uc(r,t){return(r[0]*t[1]<r[1]*t[0]?-1:1)*Math.acos(Mf(r,t))}function Yc(r,t,e,n,i,a,o,s,l,u,f){var h=l*(Yi/180),c=go(h)*(r-e)/2+po(h)*(t-n)/2,v=-1*po(h)*(r-e)/2+go(h)*(t-n)/2,d=c*c/(o*o)+v*v/(s*s);d>1&&(o*=nu(d),s*=nu(d));var p=(i===a?-1:1)*nu((o*o*(s*s)-o*o*(v*v)-s*s*(c*c))/(o*o*(v*v)+s*s*(c*c)))||0,g=p*o*v/s,y=p*-s*c/o,m=(r+e)/2+go(h)*g-po(h)*y,_=(t+n)/2+po(h)*g+go(h)*y,S=Uc([1,0],[(c-g)/o,(v-y)/s]),w=[(c-g)/o,(v-y)/s],x=[(-1*c-g)/o,(-1*v-y)/s],b=Uc(w,x);if(Mf(w,x)<=-1&&(b=Yi),Mf(w,x)>=1&&(b=0),b<0){var T=Math.round(b/Yi*1e6)/1e6;b=Yi*2+T%2*Yi}f.addData(u,m,_,o,s,S,b,h,a)}var lT=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,uT=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function fT(r){var t=new yr;if(!r)return t;var e=0,n=0,i=e,a=n,o,s=yr.CMD,l=r.match(lT);if(!l)return t;for(var u=0;u<l.length;u++){for(var f=l[u],h=f.charAt(0),c=void 0,v=f.match(uT)||[],d=v.length,p=0;p<d;p++)v[p]=parseFloat(v[p]);for(var g=0;g<d;){var y=void 0,m=void 0,_=void 0,S=void 0,w=void 0,x=void 0,b=void 0,T=e,C=n,D=void 0,A=void 0;switch(h){case"l":e+=v[g++],n+=v[g++],c=s.L,t.addData(c,e,n);break;case"L":e=v[g++],n=v[g++],c=s.L,t.addData(c,e,n);break;case"m":e+=v[g++],n+=v[g++],c=s.M,t.addData(c,e,n),i=e,a=n,h="l";break;case"M":e=v[g++],n=v[g++],c=s.M,t.addData(c,e,n),i=e,a=n,h="L";break;case"h":e+=v[g++],c=s.L,t.addData(c,e,n);break;case"H":e=v[g++],c=s.L,t.addData(c,e,n);break;case"v":n+=v[g++],c=s.L,t.addData(c,e,n);break;case"V":n=v[g++],c=s.L,t.addData(c,e,n);break;case"C":c=s.C,t.addData(c,v[g++],v[g++],v[g++],v[g++],v[g++],v[g++]),e=v[g-2],n=v[g-1];break;case"c":c=s.C,t.addData(c,v[g++]+e,v[g++]+n,v[g++]+e,v[g++]+n,v[g++]+e,v[g++]+n),e+=v[g-2],n+=v[g-1];break;case"S":y=e,m=n,D=t.len(),A=t.data,o===s.C&&(y+=e-A[D-4],m+=n-A[D-3]),c=s.C,T=v[g++],C=v[g++],e=v[g++],n=v[g++],t.addData(c,y,m,T,C,e,n);break;case"s":y=e,m=n,D=t.len(),A=t.data,o===s.C&&(y+=e-A[D-4],m+=n-A[D-3]),c=s.C,T=e+v[g++],C=n+v[g++],e+=v[g++],n+=v[g++],t.addData(c,y,m,T,C,e,n);break;case"Q":T=v[g++],C=v[g++],e=v[g++],n=v[g++],c=s.Q,t.addData(c,T,C,e,n);break;case"q":T=v[g++]+e,C=v[g++]+n,e+=v[g++],n+=v[g++],c=s.Q,t.addData(c,T,C,e,n);break;case"T":y=e,m=n,D=t.len(),A=t.data,o===s.Q&&(y+=e-A[D-4],m+=n-A[D-3]),e=v[g++],n=v[g++],c=s.Q,t.addData(c,y,m,e,n);break;case"t":y=e,m=n,D=t.len(),A=t.data,o===s.Q&&(y+=e-A[D-4],m+=n-A[D-3]),e+=v[g++],n+=v[g++],c=s.Q,t.addData(c,y,m,e,n);break;case"A":_=v[g++],S=v[g++],w=v[g++],x=v[g++],b=v[g++],T=e,C=n,e=v[g++],n=v[g++],c=s.A,Yc(T,C,e,n,x,b,_,S,w,c,t);break;case"a":_=v[g++],S=v[g++],w=v[g++],x=v[g++],b=v[g++],T=e,C=n,e+=v[g++],n+=v[g++],c=s.A,Yc(T,C,e,n,x,b,_,S,w,c,t);break}}(h==="z"||h==="Z")&&(c=s.Z,t.addData(c),e=i,n=a),o=c}return t.toStatic(),t}var Am=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.applyTransform=function(e){},t}(it);function Mm(r){return r.setData!=null}function Im(r,t){var e=fT(r),n=F({},t);return n.buildPath=function(i){if(Mm(i)){i.setData(e.data);var a=i.getContext();a&&i.rebuildPath(a,1)}else{var a=i;e.rebuildPath(a,1)}},n.applyTransform=function(i){Dm(e,i),this.dirtyShape()},n}function hT(r,t){return new Am(Im(r,t))}function vT(r,t){var e=Im(r,t),n=function(i){N(a,i);function a(o){var s=i.call(this,o)||this;return s.applyTransform=e.applyTransform,s.buildPath=e.buildPath,s}return a}(Am);return n}function cT(r,t){for(var e=[],n=r.length,i=0;i<n;i++){var a=r[i];e.push(a.getUpdatedPathProxy(!0))}var o=new it(t);return o.createPathProxy(),o.buildPath=function(s){if(Mm(s)){s.appendPath(e);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}function Fh(r,t){t=t||{};var e=new it;return r.shape&&e.setShape(r.shape),e.setStyle(r.style),t.bakeTransform?Dm(e.path,r.getComputedTransform()):t.toLocal?e.setLocalTransform(r.getComputedTransform()):e.copyTransform(r),e.buildPath=r.buildPath,e.applyTransform=e.applyTransform,e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel,e}var dT=function(){function r(){this.cx=0,this.cy=0,this.r=0}return r}(),Ri=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new dT},t.prototype.buildPath=function(e,n){e.moveTo(n.cx+n.r,n.cy),e.arc(n.cx,n.cy,n.r,0,Math.PI*2)},t}(it);Ri.prototype.type="circle";var pT=function(){function r(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return r}(),zh=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new pT},t.prototype.buildPath=function(e,n){var i=.5522848,a=n.cx,o=n.cy,s=n.rx,l=n.ry,u=s*i,f=l*i;e.moveTo(a-s,o),e.bezierCurveTo(a-s,o-f,a-u,o-l,a,o-l),e.bezierCurveTo(a+u,o-l,a+s,o-f,a+s,o),e.bezierCurveTo(a+s,o+f,a+u,o+l,a,o+l),e.bezierCurveTo(a-u,o+l,a-s,o+f,a-s,o),e.closePath()},t}(it);zh.prototype.type="ellipse";var Lm=Math.PI,iu=Lm*2,ln=Math.sin,Wn=Math.cos,gT=Math.acos,Ft=Math.atan2,Xc=Math.abs,Ta=Math.sqrt,fa=Math.max,We=Math.min,Ce=1e-4;function yT(r,t,e,n,i,a,o,s){var l=e-r,u=n-t,f=o-i,h=s-a,c=h*l-f*u;if(!(c*c<Ce))return c=(f*(t-a)-h*(r-i))/c,[r+c*l,t+c*u]}function yo(r,t,e,n,i,a,o){var s=r-e,l=t-n,u=(o?a:-a)/Ta(s*s+l*l),f=u*l,h=-u*s,c=r+f,v=t+h,d=e+f,p=n+h,g=(c+d)/2,y=(v+p)/2,m=d-c,_=p-v,S=m*m+_*_,w=i-a,x=c*p-d*v,b=(_<0?-1:1)*Ta(fa(0,w*w*S-x*x)),T=(x*_-m*b)/S,C=(-x*m-_*b)/S,D=(x*_+m*b)/S,A=(-x*m+_*b)/S,I=T-g,L=C-y,P=D-g,R=A-y;return I*I+L*L>P*P+R*R&&(T=D,C=A),{cx:T,cy:C,x0:-f,y0:-h,x1:T*(i/w-1),y1:C*(i/w-1)}}function mT(r){var t;if(V(r)){var e=r.length;if(!e)return r;e===1?t=[r[0],r[0],0,0]:e===2?t=[r[0],r[0],r[1],r[1]]:e===3?t=r.concat(r[2]):t=r}else t=[r,r,r,r];return t}function _T(r,t){var e,n=fa(t.r,0),i=fa(t.r0||0,0),a=n>0,o=i>0;if(!(!a&&!o)){if(a||(n=i,i=0),i>n){var s=n;n=i,i=s}var l=t.startAngle,u=t.endAngle;if(!(isNaN(l)||isNaN(u))){var f=t.cx,h=t.cy,c=!!t.clockwise,v=Xc(u-l),d=v>iu&&v%iu;if(d>Ce&&(v=d),!(n>Ce))r.moveTo(f,h);else if(v>iu-Ce)r.moveTo(f+n*Wn(l),h+n*ln(l)),r.arc(f,h,n,l,u,!c),i>Ce&&(r.moveTo(f+i*Wn(u),h+i*ln(u)),r.arc(f,h,i,u,l,c));else{var p=void 0,g=void 0,y=void 0,m=void 0,_=void 0,S=void 0,w=void 0,x=void 0,b=void 0,T=void 0,C=void 0,D=void 0,A=void 0,I=void 0,L=void 0,P=void 0,R=n*Wn(l),E=n*ln(l),O=i*Wn(u),k=i*ln(u),B=v>Ce;if(B){var z=t.cornerRadius;z&&(e=mT(z),p=e[0],g=e[1],y=e[2],m=e[3]);var G=Xc(n-i)/2;if(_=We(G,y),S=We(G,m),w=We(G,p),x=We(G,g),C=b=fa(_,S),D=T=fa(w,x),(b>Ce||T>Ce)&&(A=n*Wn(u),I=n*ln(u),L=i*Wn(l),P=i*ln(l),v<Lm)){var U=yT(R,E,L,P,A,I,O,k);if(U){var j=R-U[0],et=E-U[1],at=A-U[0],Rt=I-U[1],jt=1/ln(gT((j*at+et*Rt)/(Ta(j*j+et*et)*Ta(at*at+Rt*Rt)))/2),Nt=Ta(U[0]*U[0]+U[1]*U[1]);C=We(b,(n-Nt)/(jt+1)),D=We(T,(i-Nt)/(jt-1))}}}if(!B)r.moveTo(f+R,h+E);else if(C>Ce){var Lt=We(y,C),xt=We(m,C),K=yo(L,P,R,E,n,Lt,c),ot=yo(A,I,O,k,n,xt,c);r.moveTo(f+K.cx+K.x0,h+K.cy+K.y0),C<b&&Lt===xt?r.arc(f+K.cx,h+K.cy,C,Ft(K.y0,K.x0),Ft(ot.y0,ot.x0),!c):(Lt>0&&r.arc(f+K.cx,h+K.cy,Lt,Ft(K.y0,K.x0),Ft(K.y1,K.x1),!c),r.arc(f,h,n,Ft(K.cy+K.y1,K.cx+K.x1),Ft(ot.cy+ot.y1,ot.cx+ot.x1),!c),xt>0&&r.arc(f+ot.cx,h+ot.cy,xt,Ft(ot.y1,ot.x1),Ft(ot.y0,ot.x0),!c))}else r.moveTo(f+R,h+E),r.arc(f,h,n,l,u,!c);if(!(i>Ce)||!B)r.lineTo(f+O,h+k);else if(D>Ce){var Lt=We(p,D),xt=We(g,D),K=yo(O,k,A,I,i,-xt,c),ot=yo(R,E,L,P,i,-Lt,c);r.lineTo(f+K.cx+K.x0,h+K.cy+K.y0),D<T&&Lt===xt?r.arc(f+K.cx,h+K.cy,D,Ft(K.y0,K.x0),Ft(ot.y0,ot.x0),!c):(xt>0&&r.arc(f+K.cx,h+K.cy,xt,Ft(K.y0,K.x0),Ft(K.y1,K.x1),!c),r.arc(f,h,i,Ft(K.cy+K.y1,K.cx+K.x1),Ft(ot.cy+ot.y1,ot.cx+ot.x1),c),Lt>0&&r.arc(f+ot.cx,h+ot.cy,Lt,Ft(ot.y1,ot.x1),Ft(ot.y0,ot.x0),!c))}else r.lineTo(f+O,h+k),r.arc(f,h,i,u,l,c)}r.closePath()}}}var ST=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return r}(),Se=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new ST},t.prototype.buildPath=function(e,n){_T(e,n)},t.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},t}(it);Se.prototype.type="sector";var xT=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return r}(),Js=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new xT},t.prototype.buildPath=function(e,n){var i=n.cx,a=n.cy,o=Math.PI*2;e.moveTo(i+n.r,a),e.arc(i,a,n.r,0,o,!1),e.moveTo(i+n.r0,a),e.arc(i,a,n.r0,0,o,!0)},t}(it);Js.prototype.type="ring";function wT(r,t,e,n){var i=[],a=[],o=[],s=[],l,u,f,h;if(n){f=[1/0,1/0],h=[-1/0,-1/0];for(var c=0,v=r.length;c<v;c++)ri(f,f,r[c]),ni(h,h,r[c]);ri(f,f,n[0]),ni(h,h,n[1])}for(var c=0,v=r.length;c<v;c++){var d=r[c];if(e)l=r[c?c-1:v-1],u=r[(c+1)%v];else if(c===0||c===v-1){i.push(lx(r[c]));continue}else l=r[c-1],u=r[c+1];ux(a,u,l),bl(a,a,t);var p=tf(d,l),g=tf(d,u),y=p+g;y!==0&&(p/=y,g/=y),bl(o,a,-p),bl(s,a,g);var m=Vv([],d,o),_=Vv([],d,s);n&&(ni(m,m,f),ri(m,m,h),ni(_,_,f),ri(_,_,h)),i.push(m),i.push(_)}return e&&i.push(i.shift()),i}function Pm(r,t,e){var n=t.smooth,i=t.points;if(i&&i.length>=2){if(n){var a=wT(i,n,e,t.smoothConstraint);r.moveTo(i[0][0],i[0][1]);for(var o=i.length,s=0;s<(e?o:o-1);s++){var l=a[s*2],u=a[s*2+1],f=i[(s+1)%o];r.bezierCurveTo(l[0],l[1],u[0],u[1],f[0],f[1])}}else{r.moveTo(i[0][0],i[0][1]);for(var s=1,h=i.length;s<h;s++)r.lineTo(i[s][0],i[s][1])}e&&r.closePath()}}var bT=function(){function r(){this.points=null,this.smooth=0,this.smoothConstraint=null}return r}(),Pn=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new bT},t.prototype.buildPath=function(e,n){Pm(e,n,!0)},t}(it);Pn.prototype.type="polygon";var TT=function(){function r(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return r}(),Xr=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new TT},t.prototype.buildPath=function(e,n){Pm(e,n,!1)},t}(it);Xr.prototype.type="polyline";var CT={},DT=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}(),er=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new DT},t.prototype.buildPath=function(e,n){var i,a,o,s;if(this.subPixelOptimize){var l=dm(CT,n,this.style);i=l.x1,a=l.y1,o=l.x2,s=l.y2}else i=n.x1,a=n.y1,o=n.x2,s=n.y2;var u=n.percent;u!==0&&(e.moveTo(i,a),u<1&&(o=i*(1-u)+o*u,s=a*(1-u)+s*u),e.lineTo(o,s))},t.prototype.pointAt=function(e){var n=this.shape;return[n.x1*(1-e)+n.x2*e,n.y1*(1-e)+n.y2*e]},t}(it);er.prototype.type="line";var te=[],AT=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return r}();function Zc(r,t,e){var n=r.cpx2,i=r.cpy2;return n!=null||i!=null?[(e?Qv:Et)(r.x1,r.cpx1,r.cpx2,r.x2,t),(e?Qv:Et)(r.y1,r.cpy1,r.cpy2,r.y2,t)]:[(e?Jv:Gt)(r.x1,r.cpx1,r.x2,t),(e?Jv:Gt)(r.y1,r.cpy1,r.y2,t)]}var Vh=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new AT},t.prototype.buildPath=function(e,n){var i=n.x1,a=n.y1,o=n.x2,s=n.y2,l=n.cpx1,u=n.cpy1,f=n.cpx2,h=n.cpy2,c=n.percent;c!==0&&(e.moveTo(i,a),f==null||h==null?(c<1&&(cs(i,l,o,c,te),l=te[1],o=te[2],cs(a,u,s,c,te),u=te[1],s=te[2]),e.quadraticCurveTo(l,u,o,s)):(c<1&&(Vr(i,l,f,o,c,te),l=te[1],f=te[2],o=te[3],Vr(a,u,h,s,c,te),u=te[1],h=te[2],s=te[3]),e.bezierCurveTo(l,u,f,h,o,s)))},t.prototype.pointAt=function(e){return Zc(this.shape,e,!1)},t.prototype.tangentAt=function(e){var n=Zc(this.shape,e,!0);return vx(n,n)},t}(it);Vh.prototype.type="bezier-curve";var MT=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),js=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new MT},t.prototype.buildPath=function(e,n){var i=n.cx,a=n.cy,o=Math.max(n.r,0),s=n.startAngle,l=n.endAngle,u=n.clockwise,f=Math.cos(s),h=Math.sin(s);e.moveTo(f*o+i,h*o+a),e.arc(i,a,o,s,l,!u)},t}(it);js.prototype.type="arc";var IT=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="compound",e}return t.prototype._updatePathDirty=function(){for(var e=this.shape.paths,n=this.shapeChanged(),i=0;i<e.length;i++)n=n||e[i].shapeChanged();n&&this.dirtyShape()},t.prototype.beforeBrush=function(){this._updatePathDirty();for(var e=this.shape.paths||[],n=this.getGlobalScale(),i=0;i<e.length;i++)e[i].path||e[i].createPathProxy(),e[i].path.setScale(n[0],n[1],e[i].segmentIgnoreThreshold)},t.prototype.buildPath=function(e,n){for(var i=n.paths||[],a=0;a<i.length;a++)i[a].buildPath(e,i[a].shape,!0)},t.prototype.afterBrush=function(){for(var e=this.shape.paths||[],n=0;n<e.length;n++)e[n].pathUpdated()},t.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),it.prototype.getBoundingRect.call(this)},t}(it),Rm=function(){function r(t){this.colorStops=t||[]}return r.prototype.addColorStop=function(t,e){this.colorStops.push({offset:t,color:e})},r}(),Em=function(r){N(t,r);function t(e,n,i,a,o,s){var l=r.call(this,o)||this;return l.x=e??0,l.y=n??0,l.x2=i??1,l.y2=a??0,l.type="linear",l.global=s||!1,l}return t}(Rm),LT=function(r){N(t,r);function t(e,n,i,a,o){var s=r.call(this,a)||this;return s.x=e??.5,s.y=n??.5,s.r=i??.5,s.type="radial",s.global=o||!1,s}return t}(Rm),un=[0,0],fn=[0,0],mo=new X,_o=new X,Ss=function(){function r(t,e){this._corners=[],this._axes=[],this._origin=[0,0];for(var n=0;n<4;n++)this._corners[n]=new X;for(var n=0;n<2;n++)this._axes[n]=new X;t&&this.fromBoundingRect(t,e)}return r.prototype.fromBoundingRect=function(t,e){var n=this._corners,i=this._axes,a=t.x,o=t.y,s=a+t.width,l=o+t.height;if(n[0].set(a,o),n[1].set(s,o),n[2].set(s,l),n[3].set(a,l),e)for(var u=0;u<4;u++)n[u].transform(e);X.sub(i[0],n[1],n[0]),X.sub(i[1],n[3],n[0]),i[0].normalize(),i[1].normalize();for(var u=0;u<2;u++)this._origin[u]=i[u].dot(n[0])},r.prototype.intersect=function(t,e){var n=!0,i=!e;return mo.set(1/0,1/0),_o.set(0,0),!this._intersectCheckOneSide(this,t,mo,_o,i,1)&&(n=!1,i)||!this._intersectCheckOneSide(t,this,mo,_o,i,-1)&&(n=!1,i)||i||X.copy(e,n?mo:_o),n},r.prototype._intersectCheckOneSide=function(t,e,n,i,a,o){for(var s=!0,l=0;l<2;l++){var u=this._axes[l];if(this._getProjMinMaxOnAxis(l,t._corners,un),this._getProjMinMaxOnAxis(l,e._corners,fn),un[1]<fn[0]||un[0]>fn[1]){if(s=!1,a)return s;var f=Math.abs(fn[0]-un[1]),h=Math.abs(un[0]-fn[1]);Math.min(f,h)>i.len()&&(f<h?X.scale(i,u,-f*o):X.scale(i,u,h*o))}else if(n){var f=Math.abs(fn[0]-un[1]),h=Math.abs(un[0]-fn[1]);Math.min(f,h)<n.len()&&(f<h?X.scale(n,u,f*o):X.scale(n,u,-h*o))}}return s},r.prototype._getProjMinMaxOnAxis=function(t,e,n){for(var i=this._axes[t],a=this._origin,o=e[0].dot(i)+a[t],s=o,l=o,u=1;u<e.length;u++){var f=e[u].dot(i)+a[t];s=Math.min(f,s),l=Math.max(f,l)}n[0]=s,n[1]=l},r}(),PT=[],RT=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.notClear=!0,e.incremental=!0,e._displayables=[],e._temporaryDisplayables=[],e._cursor=0,e}return t.prototype.traverse=function(e,n){e.call(n,this)},t.prototype.useStyle=function(){this.style={}},t.prototype.getCursor=function(){return this._cursor},t.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},t.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},t.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},t.prototype.addDisplayable=function(e,n){n?this._temporaryDisplayables.push(e):this._displayables.push(e),this.markRedraw()},t.prototype.addDisplayables=function(e,n){n=n||!1;for(var i=0;i<e.length;i++)this.addDisplayable(e[i],n)},t.prototype.getDisplayables=function(){return this._displayables},t.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},t.prototype.eachPendingDisplayable=function(e){for(var n=this._cursor;n<this._displayables.length;n++)e&&e(this._displayables[n]);for(var n=0;n<this._temporaryDisplayables.length;n++)e&&e(this._temporaryDisplayables[n])},t.prototype.update=function(){this.updateTransform();for(var e=this._cursor;e<this._displayables.length;e++){var n=this._displayables[e];n.parent=this,n.update(),n.parent=null}for(var e=0;e<this._temporaryDisplayables.length;e++){var n=this._temporaryDisplayables[e];n.parent=this,n.update(),n.parent=null}},t.prototype.getBoundingRect=function(){if(!this._rect){for(var e=new ut(1/0,1/0,-1/0,-1/0),n=0;n<this._displayables.length;n++){var i=this._displayables[n],a=i.getBoundingRect().clone();i.needLocalTransform()&&a.applyTransform(i.getLocalTransform(PT)),e.union(a)}this._rect=e}return this._rect},t.prototype.contain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect();if(a.contain(i[0],i[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(e,n))return!0}return!1},t}(Pi),km=_t();function tl(r,t,e,n,i){var a;if(t&&t.ecModel){var o=t.ecModel.getUpdatePayload();a=o&&o.animation}var s=t&&t.isAnimationEnabled(),l=r==="update";if(s){var u=void 0,f=void 0,h=void 0;n?(u=rt(n.duration,200),f=rt(n.easing,"cubicOut"),h=0):(u=t.getShallow(l?"animationDurationUpdate":"animationDuration"),f=t.getShallow(l?"animationEasingUpdate":"animationEasing"),h=t.getShallow(l?"animationDelayUpdate":"animationDelay")),a&&(a.duration!=null&&(u=a.duration),a.easing!=null&&(f=a.easing),a.delay!=null&&(h=a.delay)),q(h)&&(h=h(e,i)),q(u)&&(u=u(e));var c={duration:u||0,delay:h,easing:f};return c}else return null}function Gh(r,t,e,n,i,a,o){var s=!1,l;q(i)?(o=a,a=i,i=null):Y(i)&&(a=i.cb,o=i.during,s=i.isFrom,l=i.removeOpt,i=i.dataIndex);var u=r==="leave";u||t.stopAnimation("leave");var f=tl(r,n,i,u?l||{}:null,n&&n.getAnimationDelayParams?n.getAnimationDelayParams(t,i):null);if(f&&f.duration>0){var h=f.duration,c=f.delay,v=f.easing,d={duration:h,delay:c||0,easing:v,done:a,force:!!a||!!o,setToFinal:!u,scope:r,during:o};s?t.animateFrom(e,d):t.animateTo(e,d)}else t.stopAnimation(),!s&&t.attr(e),o&&o(1),a&&a()}function bt(r,t,e,n,i,a){Gh("update",r,t,e,n,i,a)}function Pt(r,t,e,n,i,a){Gh("enter",r,t,e,n,i,a)}function ci(r){if(!r.__zr)return!0;for(var t=0;t<r.animators.length;t++){var e=r.animators[t];if(e.scope==="leave")return!0}return!1}function Oa(r,t,e,n,i,a){ci(r)||Gh("leave",r,t,e,n,i,a)}function $c(r,t,e,n){r.removeTextContent(),r.removeTextGuideLine(),Oa(r,{style:{opacity:0}},t,e,n)}function xs(r,t,e){function n(){r.parent&&r.parent.remove(r)}r.isGroup?r.traverse(function(i){i.isGroup||$c(i,t,e,n)}):$c(r,t,e,n)}function Ba(r){km(r).oldStyle=r.style}function ET(r){return km(r).oldStyle}var ws=Math.max,bs=Math.min,If={};function kT(r){return it.extend(r)}var OT=vT;function BT(r,t){return OT(r,t)}function Fe(r,t){If[r]=t}function NT(r){if(If.hasOwnProperty(r))return If[r]}function Hh(r,t,e,n){var i=hT(r,t);return e&&(n==="center"&&(e=Bm(e,i.getBoundingRect())),Nm(i,e)),i}function Om(r,t,e){var n=new Ne({style:{image:r,x:t.x,y:t.y,width:t.width,height:t.height},onload:function(i){if(e==="center"){var a={width:i.width,height:i.height};n.setStyle(Bm(t,a))}}});return n}function Bm(r,t){var e=t.width/t.height,n=r.height*e,i;n<=r.width?i=r.height:(n=r.width,i=n/e);var a=r.x+r.width/2,o=r.y+r.height/2;return{x:a-n/2,y:o-i/2,width:n,height:i}}var Lf=cT;function Nm(r,t){if(r.applyTransform){var e=r.getBoundingRect(),n=e.calculateTransform(t);r.applyTransform(n)}}function Na(r,t){return dm(r,r,{lineWidth:t}),r}function FT(r){return pm(r.shape,r.shape,r.style),r}var zT=_n;function Wh(r,t){for(var e=Ch([]);r&&r!==t;)hi(e,r.getLocalTransform(),e),r=r.parent;return e}function Uh(r,t,e){return t&&!Kt(t)&&(t=Ka.getLocalTransform(t)),e&&(t=Hs([],t)),me([],r,t)}function Fm(r,t,e){var n=t[4]===0||t[5]===0||t[0]===0?1:Math.abs(2*t[4]/t[0]),i=t[4]===0||t[5]===0||t[2]===0?1:Math.abs(2*t[4]/t[2]),a=[r==="left"?-n:r==="right"?n:0,r==="top"?-i:r==="bottom"?i:0];return a=Uh(a,t,e),Math.abs(a[0])>Math.abs(a[1])?a[0]>0?"right":"left":a[1]>0?"bottom":"top"}function qc(r){return!r.isGroup}function VT(r){return r.shape!=null}function zm(r,t,e){if(!r||!t)return;function n(o){var s={};return o.traverse(function(l){qc(l)&&l.anid&&(s[l.anid]=l)}),s}function i(o){var s={x:o.x,y:o.y,rotation:o.rotation};return VT(o)&&(s.shape=F({},o.shape)),s}var a=n(r);t.traverse(function(o){if(qc(o)&&o.anid){var s=a[o.anid];if(s){var l=i(o);o.attr(i(s)),bt(o,l,e,st(o).dataIndex)}}})}function Vm(r,t){return H(r,function(e){var n=e[0];n=ws(n,t.x),n=bs(n,t.x+t.width);var i=e[1];return i=ws(i,t.y),i=bs(i,t.y+t.height),[n,i]})}function GT(r,t){var e=ws(r.x,t.x),n=bs(r.x+r.width,t.x+t.width),i=ws(r.y,t.y),a=bs(r.y+r.height,t.y+t.height);if(n>=e&&a>=i)return{x:e,y:i,width:n-e,height:a-i}}function el(r,t,e){var n=F({rectHover:!0},t),i=n.style={strokeNoScale:!0};if(e=e||{x:-1,y:-1,width:2,height:2},r)return r.indexOf("image://")===0?(i.image=r.slice(8),Q(i,e),new Ne(n)):Hh(r.replace("path://",""),n,e,"center")}function HT(r,t,e,n,i){for(var a=0,o=i[i.length-1];a<i.length;a++){var s=i[a];if(Gm(r,t,e,n,s[0],s[1],o[0],o[1]))return!0;o=s}}function Gm(r,t,e,n,i,a,o,s){var l=e-r,u=n-t,f=o-i,h=s-a,c=au(f,h,l,u);if(WT(c))return!1;var v=r-i,d=t-a,p=au(v,d,l,u)/c;if(p<0||p>1)return!1;var g=au(v,d,f,h)/c;return!(g<0||g>1)}function au(r,t,e,n){return r*n-e*t}function WT(r){return r<=1e-6&&r>=-1e-6}function ja(r){var t=r.itemTooltipOption,e=r.componentModel,n=r.itemName,i=W(t)?{formatter:t}:t,a=e.mainType,o=e.componentIndex,s={componentType:a,name:n,$vars:["name"]};s[a+"Index"]=o;var l=r.formatterParamsExtra;l&&M(mt(l),function(f){tr(s,f)||(s[f]=l[f],s.$vars.push(f))});var u=st(r.el);u.componentMainType=a,u.componentIndex=o,u.tooltipConfig={name:n,option:Q({content:n,encodeHTMLContent:!0,formatterParams:s},i)}}function Kc(r,t){var e;r.isGroup&&(e=t(r)),e||r.traverse(t)}function rl(r,t){if(r)if(V(r))for(var e=0;e<r.length;e++)Kc(r[e],t);else Kc(r,t)}Fe("circle",Ri);Fe("ellipse",zh);Fe("sector",Se);Fe("ring",Js);Fe("polygon",Pn);Fe("polyline",Xr);Fe("rect",St);Fe("line",er);Fe("bezierCurve",Vh);Fe("arc",js);const nl=Object.freeze(Object.defineProperty({__proto__:null,Arc:js,BezierCurve:Vh,BoundingRect:ut,Circle:Ri,CompoundPath:IT,Ellipse:zh,Group:yt,Image:Ne,IncrementalDisplayable:RT,Line:er,LinearGradient:Em,OrientedBoundingRect:Ss,Path:it,Point:X,Polygon:Pn,Polyline:Xr,RadialGradient:LT,Rect:St,Ring:Js,Sector:Se,Text:Ct,applyTransform:Uh,clipPointsByRect:Vm,clipRectByRect:GT,createIcon:el,extendPath:BT,extendShape:kT,getShapeClass:NT,getTransform:Wh,groupTransition:zm,initProps:Pt,isElementRemoved:ci,lineLineIntersect:Gm,linePolygonIntersect:HT,makeImage:Om,makePath:Hh,mergePath:Lf,registerShape:Fe,removeElement:Oa,removeElementWithFadeOut:xs,resizePath:Nm,setTooltipConfig:ja,subPixelOptimize:zT,subPixelOptimizeLine:Na,subPixelOptimizeRect:FT,transformDirection:Fm,traverseElements:rl,updateProps:bt},Symbol.toStringTag,{value:"Module"}));var il={};function Hm(r,t){for(var e=0;e<_e.length;e++){var n=_e[e],i=t[n],a=r.ensureState(n);a.style=a.style||{},a.style.text=i}var o=r.currentStates.slice();r.clearStates(!0),r.setStyle({text:t.normal}),r.useStates(o,!0)}function Pf(r,t,e){var n=r.labelFetcher,i=r.labelDataIndex,a=r.labelDimIndex,o=t.normal,s;n&&(s=n.getFormattedLabel(i,"normal",null,a,o&&o.get("formatter"),e!=null?{interpolatedValue:e}:null)),s==null&&(s=q(r.defaultText)?r.defaultText(i,r,e):r.defaultText);for(var l={normal:s},u=0;u<_e.length;u++){var f=_e[u],h=t[f];l[f]=rt(n?n.getFormattedLabel(i,f,null,a,h&&h.get("formatter")):null,s)}return l}function Rn(r,t,e,n){e=e||il;for(var i=r instanceof Ct,a=!1,o=0;o<_s.length;o++){var s=t[_s[o]];if(s&&s.getShallow("show")){a=!0;break}}var l=i?r:r.getTextContent();if(a){i||(l||(l=new Ct,r.setTextContent(l)),r.stateProxy&&(l.stateProxy=r.stateProxy));var u=Pf(e,t),f=t.normal,h=!!f.getShallow("show"),c=ye(f,n&&n.normal,e,!1,!i);c.text=u.normal,i||r.setTextConfig(Qc(f,e,!1));for(var o=0;o<_e.length;o++){var v=_e[o],s=t[v];if(s){var d=l.ensureState(v),p=!!rt(s.getShallow("show"),h);if(p!==h&&(d.ignore=!p),d.style=ye(s,n&&n[v],e,!0,!i),d.style.text=u[v],!i){var g=r.ensureState(v);g.textConfig=Qc(s,e,!0)}}}l.silent=!!f.getShallow("silent"),l.style.x!=null&&(c.x=l.style.x),l.style.y!=null&&(c.y=l.style.y),l.ignore=!h,l.useStyle(c),l.dirty(),e.enableTextSetter&&(Ei(l).setLabelText=function(y){var m=Pf(e,t,y);Hm(l,m)})}else l&&(l.ignore=!0);r.dirty()}function En(r,t){t=t||"label";for(var e={normal:r.getModel(t)},n=0;n<_e.length;n++){var i=_e[n];e[i]=r.getModel([i,t])}return e}function ye(r,t,e,n,i){var a={};return UT(a,r,e,n,i),t&&F(a,t),a}function Qc(r,t,e){t=t||{};var n={},i,a=r.getShallow("rotate"),o=rt(r.getShallow("distance"),e?null:5),s=r.getShallow("offset");return i=r.getShallow("position")||(e?null:"inside"),i==="outside"&&(i=t.defaultOutsidePosition||"top"),i!=null&&(n.position=i),s!=null&&(n.offset=s),a!=null&&(a*=Math.PI/180,n.rotation=a),o!=null&&(n.distance=o),n.outsideFill=r.get("color")==="inherit"?t.inheritColor||null:"auto",n}function UT(r,t,e,n,i){e=e||il;var a=t.ecModel,o=a&&a.option.textStyle,s=YT(t),l;if(s){l={};for(var u in s)if(s.hasOwnProperty(u)){var f=t.getModel(["rich",u]);ed(l[u]={},f,o,e,n,i,!1,!0)}}l&&(r.rich=l);var h=t.get("overflow");h&&(r.overflow=h);var c=t.get("minMargin");c!=null&&(r.margin=c),ed(r,t,o,e,n,i,!0,!1)}function YT(r){for(var t;r&&r!==r.ecModel;){var e=(r.option||il).rich;if(e){t=t||{};for(var n=mt(e),i=0;i<n.length;i++){var a=n[i];t[a]=1}}r=r.parentModel}return t}var Jc=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],jc=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],td=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function ed(r,t,e,n,i,a,o,s){e=!i&&e||il;var l=n&&n.inheritColor,u=t.getShallow("color"),f=t.getShallow("textBorderColor"),h=rt(t.getShallow("opacity"),e.opacity);(u==="inherit"||u==="auto")&&(l?u=l:u=null),(f==="inherit"||f==="auto")&&(l?f=l:f=null),a||(u=u||e.color,f=f||e.textBorderColor),u!=null&&(r.fill=u),f!=null&&(r.stroke=f);var c=rt(t.getShallow("textBorderWidth"),e.textBorderWidth);c!=null&&(r.lineWidth=c);var v=rt(t.getShallow("textBorderType"),e.textBorderType);v!=null&&(r.lineDash=v);var d=rt(t.getShallow("textBorderDashOffset"),e.textBorderDashOffset);d!=null&&(r.lineDashOffset=d),!i&&h==null&&!s&&(h=n&&n.defaultOpacity),h!=null&&(r.opacity=h),!i&&!a&&r.fill==null&&n.inheritColor&&(r.fill=n.inheritColor);for(var p=0;p<Jc.length;p++){var g=Jc[p],y=rt(t.getShallow(g),e[g]);y!=null&&(r[g]=y)}for(var p=0;p<jc.length;p++){var g=jc[p],y=t.getShallow(g);y!=null&&(r[g]=y)}if(r.verticalAlign==null){var m=t.getShallow("baseline");m!=null&&(r.verticalAlign=m)}if(!o||!n.disableBox){for(var p=0;p<td.length;p++){var g=td[p],y=t.getShallow(g);y!=null&&(r[g]=y)}var _=t.getShallow("borderType");_!=null&&(r.borderDash=_),(r.backgroundColor==="auto"||r.backgroundColor==="inherit")&&l&&(r.backgroundColor=l),(r.borderColor==="auto"||r.borderColor==="inherit")&&l&&(r.borderColor=l)}}function Wm(r,t){var e=t&&t.getModel("textStyle");return Ze([r.fontStyle||e&&e.getShallow("fontStyle")||"",r.fontWeight||e&&e.getShallow("fontWeight")||"",(r.fontSize||e&&e.getShallow("fontSize")||12)+"px",r.fontFamily||e&&e.getShallow("fontFamily")||"sans-serif"].join(" "))}var Ei=_t();function Um(r,t,e,n){if(r){var i=Ei(r);i.prevValue=i.value,i.value=e;var a=t.normal;i.valueAnimation=a.get("valueAnimation"),i.valueAnimation&&(i.precision=a.get("precision"),i.defaultInterpolatedText=n,i.statesModels=t)}}function Ym(r,t,e,n,i){var a=Ei(r);if(!a.valueAnimation||a.prevValue===a.value)return;var o=a.defaultInterpolatedText,s=rt(a.interpolatedValue,a.prevValue),l=a.value;function u(f){var h=im(e,a.precision,s,l,f);a.interpolatedValue=f===1?null:h;var c=Pf({labelDataIndex:t,labelFetcher:i,defaultText:o?o(h):h+""},a.statesModels,h);Hm(r,c)}r.percent=0,(a.prevValue==null?Pt:bt)(r,{percent:1},n,t,null,u)}var XT=["textStyle","color"],ou=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],su=new Ct,ZT=function(){function r(){}return r.prototype.getTextColor=function(t){var e=this.ecModel;return this.getShallow("color")||(!t&&e?e.get(XT):null)},r.prototype.getFont=function(){return Wm({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},r.prototype.getTextRect=function(t){for(var e={text:t,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},n=0;n<ou.length;n++)e[ou[n]]=this.getShallow(ou[n]);return su.useStyle(e),su.update(),su.getBoundingRect()},r}(),Xm=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],$T=ka(Xm),qT=function(){function r(){}return r.prototype.getLineStyle=function(t){return $T(this,t)},r}(),Zm=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],KT=ka(Zm),QT=function(){function r(){}return r.prototype.getItemStyle=function(t,e){return KT(this,t,e)},r}(),wt=function(){function r(t,e,n){this.parentModel=e,this.ecModel=n,this.option=t}return r.prototype.init=function(t,e,n){},r.prototype.mergeOption=function(t,e){nt(this.option,t,!0)},r.prototype.get=function(t,e){return t==null?this.option:this._doGet(this.parsePath(t),!e&&this.parentModel)},r.prototype.getShallow=function(t,e){var n=this.option,i=n==null?n:n[t];if(i==null&&!e){var a=this.parentModel;a&&(i=a.getShallow(t))}return i},r.prototype.getModel=function(t,e){var n=t!=null,i=n?this.parsePath(t):null,a=n?this._doGet(i):this.option;return e=e||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(i)),new r(a,e,this.ecModel)},r.prototype.isEmpty=function(){return this.option==null},r.prototype.restoreData=function(){},r.prototype.clone=function(){var t=this.constructor;return new t(tt(this.option))},r.prototype.parsePath=function(t){return typeof t=="string"?t.split("."):t},r.prototype.resolveParentPath=function(t){return t},r.prototype.isAnimationEnabled=function(){if(!J.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},r.prototype._doGet=function(t,e){var n=this.option;if(!t)return n;for(var i=0;i<t.length&&!(t[i]&&(n=n&&typeof n=="object"?n[t[i]]:null,n==null));i++);return n==null&&e&&(n=e._doGet(this.resolveParentPath(t),e.parentModel)),n},r}();Rh(wt);$w(wt);Oe(wt,qT);Oe(wt,QT);Oe(wt,jw);Oe(wt,ZT);var JT=Math.round(Math.random()*10);function to(r){return[r||"",JT++].join("_")}function jT(r){var t={};r.registerSubTypeDefaulter=function(e,n){var i=$e(e);t[i.main]=n},r.determineSubType=function(e,n){var i=n.type;if(!i){var a=$e(e).main;r.hasSubTypes(e)&&t[a]&&(i=t[a](n))}return i}}function tC(r,t){r.topologicalTravel=function(a,o,s,l){if(!a.length)return;var u=e(o),f=u.graph,h=u.noEntryList,c={};for(M(a,function(m){c[m]=!0});h.length;){var v=h.pop(),d=f[v],p=!!c[v];p&&(s.call(l,v,d.originalDeps.slice()),delete c[v]),M(d.successor,p?y:g)}M(c,function(){var m="";throw new Error(m)});function g(m){f[m].entryCount--,f[m].entryCount===0&&h.push(m)}function y(m){c[m]=!0,g(m)}};function e(a){var o={},s=[];return M(a,function(l){var u=n(o,l),f=u.originalDeps=t(l),h=i(f,a);u.entryCount=h.length,u.entryCount===0&&s.push(l),M(h,function(c){lt(u.predecessor,c)<0&&u.predecessor.push(c);var v=n(o,c);lt(v.successor,c)<0&&v.successor.push(l)})}),{graph:o,noEntryList:s}}function n(a,o){return a[o]||(a[o]={predecessor:[],successor:[]}),a[o]}function i(a,o){var s=[];return M(a,function(l){lt(o,l)>=0&&s.push(l)}),s}}function Yh(r,t){return nt(nt({},r,!0),t,!0)}const eC={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},rC={time:{month:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],monthAbbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dayOfWeek:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],dayOfWeekAbbr:["日","一","二","三","四","五","六"]},legend:{selector:{all:"全选",inverse:"反选"}},toolbox:{brush:{title:{rect:"矩形选择",polygon:"圈选",lineX:"横向选择",lineY:"纵向选择",keep:"保持选择",clear:"清除选择"}},dataView:{title:"数据视图",lang:["数据视图","关闭","刷新"]},dataZoom:{title:{zoom:"区域缩放",back:"区域缩放还原"}},magicType:{title:{line:"切换为折线图",bar:"切换为柱状图",stack:"切换为堆叠",tiled:"切换为平铺"}},restore:{title:"还原"},saveAsImage:{title:"保存为图片",lang:["右键另存为图片"]}},series:{typeNames:{pie:"饼图",bar:"柱状图",line:"折线图",scatter:"散点图",effectScatter:"涟漪散点图",radar:"雷达图",tree:"树图",treemap:"矩形树图",boxplot:"箱型图",candlestick:"K线图",k:"K线图",heatmap:"热力图",map:"地图",parallel:"平行坐标图",lines:"线图",graph:"关系图",sankey:"桑基图",funnel:"漏斗图",gauge:"仪表盘图",pictorialBar:"象形柱图",themeRiver:"主题河流图",sunburst:"旭日图",custom:"自定义图表",chart:"图表"}},aria:{general:{withTitle:"这是一个关于“{title}”的图表。",withoutTitle:"这是一个图表，"},series:{single:{prefix:"",withName:"图表类型是{seriesType}，表示{seriesName}。",withoutName:"图表类型是{seriesType}。"},multiple:{prefix:"它由{seriesCount}个图表系列组成。",withName:"第{seriesId}个系列是一个表示{seriesName}的{seriesType}，",withoutName:"第{seriesId}个系列是一个{seriesType}，",separator:{middle:"；",end:"。"}}},data:{allData:"其数据是——",partialData:"其中，前{displayCnt}项是——",withName:"{name}的数据是{value}",withoutName:"{value}",separator:{middle:"，",end:""}}}};var Ts="ZH",Xh="EN",di=Xh,rs={},Zh={},$m=J.domSupported?function(){var r=(document.documentElement.lang||navigator.language||navigator.browserLanguage||di).toUpperCase();return r.indexOf(Ts)>-1?Ts:di}():di;function qm(r,t){r=r.toUpperCase(),Zh[r]=new wt(t),rs[r]=t}function nC(r){if(W(r)){var t=rs[r.toUpperCase()]||{};return r===Ts||r===Xh?tt(t):nt(tt(t),tt(rs[di]),!1)}else return nt(tt(r),tt(rs[di]),!1)}function iC(r){return Zh[r]}function aC(){return Zh[di]}qm(Xh,eC);qm(Ts,rC);var $h=1e3,qh=$h*60,Ca=qh*60,ge=Ca*24,rd=ge*365,ha={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}",none:"{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}"},So="{yyyy}-{MM}-{dd}",nd={year:"{yyyy}",month:"{yyyy}-{MM}",day:So,hour:So+" "+ha.hour,minute:So+" "+ha.minute,second:So+" "+ha.second,millisecond:ha.none},lu=["year","month","day","hour","minute","second","millisecond"],Km=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function br(r,t){return r+="","0000".substr(0,t-r.length)+r}function pi(r){switch(r){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return r}}function oC(r){return r===pi(r)}function sC(r){switch(r){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function al(r,t,e,n){var i=gr(r),a=i[Kh(e)](),o=i[gi(e)]()+1,s=Math.floor((o-1)/3)+1,l=i[ol(e)](),u=i["get"+(e?"UTC":"")+"Day"](),f=i[Fa(e)](),h=(f-1)%12+1,c=i[sl(e)](),v=i[ll(e)](),d=i[ul(e)](),p=f>=12?"pm":"am",g=p.toUpperCase(),y=n instanceof wt?n:iC(n||$m)||aC(),m=y.getModel("time"),_=m.get("month"),S=m.get("monthAbbr"),w=m.get("dayOfWeek"),x=m.get("dayOfWeekAbbr");return(t||"").replace(/{a}/g,p+"").replace(/{A}/g,g+"").replace(/{yyyy}/g,a+"").replace(/{yy}/g,br(a%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,_[o-1]).replace(/{MMM}/g,S[o-1]).replace(/{MM}/g,br(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,br(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,w[u]).replace(/{ee}/g,x[u]).replace(/{e}/g,u+"").replace(/{HH}/g,br(f,2)).replace(/{H}/g,f+"").replace(/{hh}/g,br(h+"",2)).replace(/{h}/g,h+"").replace(/{mm}/g,br(c,2)).replace(/{m}/g,c+"").replace(/{ss}/g,br(v,2)).replace(/{s}/g,v+"").replace(/{SSS}/g,br(d,3)).replace(/{S}/g,d+"")}function lC(r,t,e,n,i){var a=null;if(W(e))a=e;else if(q(e))a=e(r.value,t,{level:r.level});else{var o=F({},ha);if(r.level>0)for(var s=0;s<lu.length;++s)o[lu[s]]="{primary|"+o[lu[s]]+"}";var l=e?e.inherit===!1?e:Q(e,o):o,u=Qm(r.value,i);if(l[u])a=l[u];else if(l.inherit){for(var f=Km.indexOf(u),s=f-1;s>=0;--s)if(l[u]){a=l[u];break}a=a||o.none}if(V(a)){var h=r.level==null?0:r.level>=0?r.level:a.length+r.level;h=Math.min(h,a.length-1),a=a[h]}}return al(new Date(r.value),a,i,n)}function Qm(r,t){var e=gr(r),n=e[gi(t)]()+1,i=e[ol(t)](),a=e[Fa(t)](),o=e[sl(t)](),s=e[ll(t)](),l=e[ul(t)](),u=l===0,f=u&&s===0,h=f&&o===0,c=h&&a===0,v=c&&i===1,d=v&&n===1;return d?"year":v?"month":c?"day":h?"hour":f?"minute":u?"second":"millisecond"}function id(r,t,e){var n=ct(r)?gr(r):r;switch(t=t||Qm(r,e),t){case"year":return n[Kh(e)]();case"half-year":return n[gi(e)]()>=6?1:0;case"quarter":return Math.floor((n[gi(e)]()+1)/4);case"month":return n[gi(e)]();case"day":return n[ol(e)]();case"half-day":return n[Fa(e)]()/24;case"hour":return n[Fa(e)]();case"minute":return n[sl(e)]();case"second":return n[ll(e)]();case"millisecond":return n[ul(e)]()}}function Kh(r){return r?"getUTCFullYear":"getFullYear"}function gi(r){return r?"getUTCMonth":"getMonth"}function ol(r){return r?"getUTCDate":"getDate"}function Fa(r){return r?"getUTCHours":"getHours"}function sl(r){return r?"getUTCMinutes":"getMinutes"}function ll(r){return r?"getUTCSeconds":"getSeconds"}function ul(r){return r?"getUTCMilliseconds":"getMilliseconds"}function uC(r){return r?"setUTCFullYear":"setFullYear"}function Jm(r){return r?"setUTCMonth":"setMonth"}function jm(r){return r?"setUTCDate":"setDate"}function t0(r){return r?"setUTCHours":"setHours"}function e0(r){return r?"setUTCMinutes":"setMinutes"}function r0(r){return r?"setUTCSeconds":"setSeconds"}function n0(r){return r?"setUTCMilliseconds":"setMilliseconds"}function i0(r){if(!Qy(r))return W(r)?r:"-";var t=(r+"").split(".");return t[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(t.length>1?"."+t[1]:"")}function a0(r,t){return r=(r||"").toLowerCase().replace(/-(.)/g,function(e,n){return n.toUpperCase()}),t&&r&&(r=r.charAt(0).toUpperCase()+r.slice(1)),r}var fl=wy;function Rf(r,t,e){var n="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function i(f){return f&&Ze(f)?f:"-"}function a(f){return!!(f!=null&&!isNaN(f)&&isFinite(f))}var o=t==="time",s=r instanceof Date;if(o||s){var l=o?gr(r):r;if(isNaN(+l)){if(s)return"-"}else return al(l,n,e)}if(t==="ordinal")return ju(r)?i(r):ct(r)&&a(r)?r+"":"-";var u=Hr(r);return a(u)?i0(u):ju(r)?i(r):typeof r=="boolean"?r+"":"-"}var ad=["a","b","c","d","e","f","g"],uu=function(r,t){return"{"+r+(t??"")+"}"};function o0(r,t,e){V(t)||(t=[t]);var n=t.length;if(!n)return"";for(var i=t[0].$vars||[],a=0;a<i.length;a++){var o=ad[a];r=r.replace(uu(o),uu(o,0))}for(var s=0;s<n;s++)for(var l=0;l<i.length;l++){var u=t[s][i[l]];r=r.replace(uu(ad[l],s),e?re(u):u)}return r}function fC(r,t){var e=W(r)?{color:r,extraCssText:t}:r||{},n=e.color,i=e.type;t=e.extraCssText;var a=e.renderMode||"html";if(!n)return"";if(a==="html")return i==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+re(n)+";"+(t||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+re(n)+";"+(t||"")+'"></span>';var o=e.markerId||"markerX";return{renderMode:a,content:"{"+o+"|}  ",style:i==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:n}:{width:10,height:10,borderRadius:5,backgroundColor:n}}}function An(r,t){return t=t||"transparent",W(r)?r:Y(r)&&r.colorStops&&(r.colorStops[0]||{}).color||t}function od(r,t){if(t==="_blank"||t==="blank"){var e=window.open();e.opener=null,e.location.href=r}else window.open(r,t)}var ns=M,hC=["left","right","top","bottom","width","height"],xo=[["width","left","right"],["height","top","bottom"]];function Qh(r,t,e,n,i){var a=0,o=0;n==null&&(n=1/0),i==null&&(i=1/0);var s=0;t.eachChild(function(l,u){var f=l.getBoundingRect(),h=t.childAt(u+1),c=h&&h.getBoundingRect(),v,d;if(r==="horizontal"){var p=f.width+(c?-c.x+f.x:0);v=a+p,v>n||l.newline?(a=0,v=p,o+=s+e,s=f.height):s=Math.max(s,f.height)}else{var g=f.height+(c?-c.y+f.y:0);d=o+g,d>i||l.newline?(a+=s+e,o=0,d=g,s=f.width):s=Math.max(s,f.width)}l.newline||(l.x=a,l.y=o,l.markRedraw(),r==="horizontal"?a=v+e:o=d+e)})}var yi=Qh;vt(Qh,"vertical");vt(Qh,"horizontal");function Ur(r,t,e){e=fl(e||0);var n=t.width,i=t.height,a=Z(r.left,n),o=Z(r.top,i),s=Z(r.right,n),l=Z(r.bottom,i),u=Z(r.width,n),f=Z(r.height,i),h=e[2]+e[0],c=e[1]+e[3],v=r.aspect;switch(isNaN(u)&&(u=n-s-c-a),isNaN(f)&&(f=i-l-h-o),v!=null&&(isNaN(u)&&isNaN(f)&&(v>n/i?u=n*.8:f=i*.8),isNaN(u)&&(u=v*f),isNaN(f)&&(f=u/v)),isNaN(a)&&(a=n-s-u-c),isNaN(o)&&(o=i-l-f-h),r.left||r.right){case"center":a=n/2-u/2-e[3];break;case"right":a=n-u-c;break}switch(r.top||r.bottom){case"middle":case"center":o=i/2-f/2-e[0];break;case"bottom":o=i-f-h;break}a=a||0,o=o||0,isNaN(u)&&(u=n-c-a-(s||0)),isNaN(f)&&(f=i-h-o-(l||0));var d=new ut(a+e[3],o+e[0],u,f);return d.margin=e,d}function vC(r,t,e,n,i,a){a=a||r,a.x=r.x,a.y=r.y;var o;if(o=r.getBoundingRect(),r.needLocalTransform()){var s=r.getLocalTransform();o=o.clone(),o.applyTransform(s)}var l=Ur(Q({width:o.width,height:o.height},t),e,n),u=l.x-o.x,f=l.y-o.y;return a.x+=u,a.y+=f,a===r&&r.markRedraw(),!0}function za(r){var t=r.layoutMode||r.constructor.layoutMode;return Y(t)?t:t?{type:t}:null}function bi(r,t,e){var n=e&&e.ignoreSize;!V(n)&&(n=[n,n]);var i=o(xo[0],0),a=o(xo[1],1);u(xo[0],r,i),u(xo[1],r,a);function o(f,h){var c={},v=0,d={},p=0,g=2;if(ns(f,function(_){d[_]=r[_]}),ns(f,function(_){s(t,_)&&(c[_]=d[_]=t[_]),l(c,_)&&v++,l(d,_)&&p++}),n[h])return l(t,f[1])?d[f[2]]=null:l(t,f[2])&&(d[f[1]]=null),d;if(p===g||!v)return d;if(v>=g)return c;for(var y=0;y<f.length;y++){var m=f[y];if(!s(c,m)&&s(r,m)){c[m]=r[m];break}}return c}function s(f,h){return f.hasOwnProperty(h)}function l(f,h){return f[h]!=null&&f[h]!=="auto"}function u(f,h,c){ns(f,function(v){h[v]=c[v]})}}function hl(r){return cC({},r)}function cC(r,t){return t&&r&&ns(hC,function(e){t.hasOwnProperty(e)&&(r[e]=t[e])}),r}var dC=_t(),ht=function(r){N(t,r);function t(e,n,i){var a=r.call(this,e,n,i)||this;return a.uid=to("ec_cpt_model"),a}return t.prototype.init=function(e,n,i){this.mergeDefaultAndTheme(e,i)},t.prototype.mergeDefaultAndTheme=function(e,n){var i=za(this),a=i?hl(e):{},o=n.getTheme();nt(e,o.get(this.mainType)),nt(e,this.getDefaultOption()),i&&bi(e,a,i)},t.prototype.mergeOption=function(e,n){nt(this.option,e,!0);var i=za(this);i&&bi(this.option,e,i)},t.prototype.optionUpdated=function(e,n){},t.prototype.getDefaultOption=function(){var e=this.constructor;if(!Yw(e))return e.defaultOption;var n=dC(this);if(!n.defaultOption){for(var i=[],a=e;a;){var o=a.prototype.defaultOption;o&&i.push(o),a=a.superClass}for(var s={},l=i.length-1;l>=0;l--)s=nt(s,i[l],!0);n.defaultOption=s}return n.defaultOption},t.prototype.getReferringComponents=function(e,n){var i=e+"Index",a=e+"Id";return Ja(this.ecModel,e,{index:this.get(i,!0),id:this.get(a,!0)},n)},t.prototype.getBoxLayoutParams=function(){var e=this;return{left:e.get("left"),top:e.get("top"),right:e.get("right"),bottom:e.get("bottom"),width:e.get("width"),height:e.get("height")}},t.prototype.getZLevelKey=function(){return""},t.prototype.setZLevel=function(e){this.option.zlevel=e},t.protoInitialize=function(){var e=t.prototype;e.type="component",e.id="",e.name="",e.mainType="",e.subType="",e.componentIndex=0}(),t}(wt);om(ht,wt);Xs(ht);jT(ht);tC(ht,pC);function pC(r){var t=[];return M(ht.getClassesByMainType(r),function(e){t=t.concat(e.dependencies||e.prototype.dependencies||[])}),t=H(t,function(e){return $e(e).main}),r!=="dataset"&&lt(t,"dataset")<=0&&t.unshift("dataset"),t}var s0="";typeof navigator<"u"&&(s0=navigator.platform||"");var Un="rgba(0, 0, 0, 0.2)";const gC={darkMode:"auto",colorBy:"series",color:["#5470c6","#91cc75","#fac858","#ee6666","#73c0de","#3ba272","#fc8452","#9a60b4","#ea7ccc"],gradientColor:["#f6efa6","#d88273","#bf444c"],aria:{decal:{decals:[{color:Un,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:Un,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:Un,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:Un,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:Un,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:Un,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:s0.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var l0=$(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),xe="original",Qt="arrayRows",we="objectRows",rr="keyedColumns",Fr="typedArray",u0="unknown",Je="column",ki="row",Ot={Must:1,Might:2,Not:3},f0=_t();function yC(r){f0(r).datasetMap=$()}function mC(r,t,e){var n={},i=Jh(t);if(!i||!r)return n;var a=[],o=[],s=t.ecModel,l=f0(s).datasetMap,u=i.uid+"_"+e.seriesLayoutBy,f,h;r=r.slice(),M(r,function(p,g){var y=Y(p)?p:r[g]={name:p};y.type==="ordinal"&&f==null&&(f=g,h=d(y)),n[y.name]=[]});var c=l.get(u)||l.set(u,{categoryWayDim:h,valueWayDim:0});M(r,function(p,g){var y=p.name,m=d(p);if(f==null){var _=c.valueWayDim;v(n[y],_,m),v(o,_,m),c.valueWayDim+=m}else if(f===g)v(n[y],0,m),v(a,0,m);else{var _=c.categoryWayDim;v(n[y],_,m),v(o,_,m),c.categoryWayDim+=m}});function v(p,g,y){for(var m=0;m<y;m++)p.push(g+m)}function d(p){var g=p.dimsDef;return g?g.length:1}return a.length&&(n.itemName=a),o.length&&(n.seriesName=o),n}function _C(r,t,e){var n={},i=Jh(r);if(!i)return n;var a=t.sourceFormat,o=t.dimensionsDefine,s;(a===we||a===rr)&&M(o,function(f,h){(Y(f)?f.name:f)==="name"&&(s=h)});var l=function(){for(var f={},h={},c=[],v=0,d=Math.min(5,e);v<d;v++){var p=v0(t.data,a,t.seriesLayoutBy,o,t.startIndex,v);c.push(p);var g=p===Ot.Not;if(g&&f.v==null&&v!==s&&(f.v=v),(f.n==null||f.n===f.v||!g&&c[f.n]===Ot.Not)&&(f.n=v),y(f)&&c[f.n]!==Ot.Not)return f;g||(p===Ot.Might&&h.v==null&&v!==s&&(h.v=v),(h.n==null||h.n===h.v)&&(h.n=v))}function y(m){return m.v!=null&&m.n!=null}return y(f)?f:y(h)?h:null}();if(l){n.value=[l.v];var u=s??l.n;n.itemName=[u],n.seriesName=[u]}return n}function Jh(r){var t=r.get("data",!0);if(!t)return Ja(r.ecModel,"dataset",{index:r.get("datasetIndex",!0),id:r.get("datasetId",!0)},$t).models[0]}function SC(r){return!r.get("transform",!0)&&!r.get("fromTransformResult",!0)?[]:Ja(r.ecModel,"dataset",{index:r.get("fromDatasetIndex",!0),id:r.get("fromDatasetId",!0)},$t).models}function h0(r,t){return v0(r.data,r.sourceFormat,r.seriesLayoutBy,r.dimensionsDefine,r.startIndex,t)}function v0(r,t,e,n,i,a){var o,s=5;if(oe(r))return Ot.Not;var l,u;if(n){var f=n[a];Y(f)?(l=f.name,u=f.type):W(f)&&(l=f)}if(u!=null)return u==="ordinal"?Ot.Must:Ot.Not;if(t===Qt){var h=r;if(e===ki){for(var c=h[a],v=0;v<(c||[]).length&&v<s;v++)if((o=S(c[i+v]))!=null)return o}else for(var v=0;v<h.length&&v<s;v++){var d=h[i+v];if(d&&(o=S(d[a]))!=null)return o}}else if(t===we){var p=r;if(!l)return Ot.Not;for(var v=0;v<p.length&&v<s;v++){var g=p[v];if(g&&(o=S(g[l]))!=null)return o}}else if(t===rr){var y=r;if(!l)return Ot.Not;var c=y[l];if(!c||oe(c))return Ot.Not;for(var v=0;v<c.length&&v<s;v++)if((o=S(c[v]))!=null)return o}else if(t===xe)for(var m=r,v=0;v<m.length&&v<s;v++){var g=m[v],_=Qa(g);if(!V(_))return Ot.Not;if((o=S(_[a]))!=null)return o}function S(w){var x=W(w);if(w!=null&&Number.isFinite(Number(w))&&w!=="")return x?Ot.Might:Ot.Not;if(x&&w!=="-")return Ot.Must}return Ot.Not}var Ef=$();function xC(r,t){je(Ef.get(r)==null&&t),Ef.set(r,t)}function wC(r,t,e){var n=Ef.get(t);if(!n)return e;var i=n(r);return i?e.concat(i):e}var sd=_t();_t();var jh=function(){function r(){}return r.prototype.getColorFromPalette=function(t,e,n){var i=It(this.get("color",!0)),a=this.get("colorLayer",!0);return TC(this,sd,i,a,t,e,n)},r.prototype.clearColorPalette=function(){CC(this,sd)},r}();function bC(r,t){for(var e=r.length,n=0;n<e;n++)if(r[n].length>t)return r[n];return r[e-1]}function TC(r,t,e,n,i,a,o){a=a||r;var s=t(a),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(i))return u[i];var f=o==null||!n?e:bC(n,o);if(f=f||e,!(!f||!f.length)){var h=f[l];return i&&(u[i]=h),s.paletteIdx=(l+1)%f.length,h}}function CC(r,t){t(r).paletteIdx=0,t(r).paletteNameMap={}}var wo,Xi,ld,ud="\0_ec_inner",DC=1,tv=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e,n,i,a,o,s){a=a||{},this.option=null,this._theme=new wt(a),this._locale=new wt(o),this._optionManager=s},t.prototype.setOption=function(e,n,i){var a=vd(n);this._optionManager.setOption(e,i,a),this._resetOption(null,a)},t.prototype.resetOption=function(e,n){return this._resetOption(e,vd(n))},t.prototype._resetOption=function(e,n){var i=!1,a=this._optionManager;if(!e||e==="recreate"){var o=a.mountOption(e==="recreate");!this.option||e==="recreate"?ld(this,o):(this.restoreData(),this._mergeOption(o,n)),i=!0}if((e==="timeline"||e==="media")&&this.restoreData(),!e||e==="recreate"||e==="timeline"){var s=a.getTimelineOption(this);s&&(i=!0,this._mergeOption(s,n))}if(!e||e==="recreate"||e==="media"){var l=a.getMediaOption(this);l.length&&M(l,function(u){i=!0,this._mergeOption(u,n)},this)}return i},t.prototype.mergeOption=function(e){this._mergeOption(e,null)},t.prototype._mergeOption=function(e,n){var i=this.option,a=this._componentsMap,o=this._componentsCount,s=[],l=$(),u=n&&n.replaceMergeMainTypeMap;yC(this),M(e,function(h,c){h!=null&&(ht.hasClass(c)?c&&(s.push(c),l.set(c,!0)):i[c]=i[c]==null?tt(h):nt(i[c],h,!0))}),u&&u.each(function(h,c){ht.hasClass(c)&&!l.get(c)&&(s.push(c),l.set(c,!0))}),ht.topologicalTravel(s,ht.getAllClassMainTypes(),f,this);function f(h){var c=wC(this,h,It(e[h])),v=a.get(h),d=v?u&&u.get(h)?"replaceMerge":"normalMerge":"replaceAll",p=Iw(v,c,d);Nw(p,h,ht),i[h]=null,a.set(h,null),o.set(h,0);var g=[],y=[],m=0,_;M(p,function(S,w){var x=S.existing,b=S.newOption;if(!b)x&&(x.mergeOption({},this),x.optionUpdated({},!1));else{var T=h==="series",C=ht.getClass(h,S.keyInfo.subType,!T);if(!C)return;if(h==="tooltip"){if(_)return;_=!0}if(x&&x.constructor===C)x.name=S.keyInfo.name,x.mergeOption(b,this),x.optionUpdated(b,!1);else{var D=F({componentIndex:w},S.keyInfo);x=new C(b,this,this,D),F(x,D),S.brandNew&&(x.__requireNewView=!0),x.init(b,this,this),x.optionUpdated(null,!0)}}x?(g.push(x.option),y.push(x),m++):(g.push(void 0),y.push(void 0))},this),i[h]=g,a.set(h,y),o.set(h,m),h==="series"&&wo(this)}this._seriesIndices||wo(this)},t.prototype.getOption=function(){var e=tt(this.option);return M(e,function(n,i){if(ht.hasClass(i)){for(var a=It(n),o=a.length,s=!1,l=o-1;l>=0;l--)a[l]&&!Ea(a[l])?s=!0:(a[l]=null,!s&&o--);a.length=o,e[i]=a}}),delete e[ud],e},t.prototype.getTheme=function(){return this._theme},t.prototype.getLocaleModel=function(){return this._locale},t.prototype.setUpdatePayload=function(e){this._payload=e},t.prototype.getUpdatePayload=function(){return this._payload},t.prototype.getComponent=function(e,n){var i=this._componentsMap.get(e);if(i){var a=i[n||0];if(a)return a;if(n==null){for(var o=0;o<i.length;o++)if(i[o])return i[o]}}},t.prototype.queryComponents=function(e){var n=e.mainType;if(!n)return[];var i=e.index,a=e.id,o=e.name,s=this._componentsMap.get(n);if(!s||!s.length)return[];var l;return i!=null?(l=[],M(It(i),function(u){s[u]&&l.push(s[u])})):a!=null?l=fd("id",a,s):o!=null?l=fd("name",o,s):l=Tt(s,function(u){return!!u}),hd(l,e)},t.prototype.findComponents=function(e){var n=e.query,i=e.mainType,a=s(n),o=a?this.queryComponents(a):Tt(this._componentsMap.get(i),function(u){return!!u});return l(hd(o,e));function s(u){var f=i+"Index",h=i+"Id",c=i+"Name";return u&&(u[f]!=null||u[h]!=null||u[c]!=null)?{mainType:i,index:u[f],id:u[h],name:u[c]}:null}function l(u){return e.filter?Tt(u,e.filter):u}},t.prototype.eachComponent=function(e,n,i){var a=this._componentsMap;if(q(e)){var o=n,s=e;a.each(function(h,c){for(var v=0;h&&v<h.length;v++){var d=h[v];d&&s.call(o,c,d,d.componentIndex)}})}else for(var l=W(e)?a.get(e):Y(e)?this.findComponents(e):null,u=0;l&&u<l.length;u++){var f=l[u];f&&n.call(i,f,f.componentIndex)}},t.prototype.getSeriesByName=function(e){var n=Qe(e,null);return Tt(this._componentsMap.get("series"),function(i){return!!i&&n!=null&&i.name===n})},t.prototype.getSeriesByIndex=function(e){return this._componentsMap.get("series")[e]},t.prototype.getSeriesByType=function(e){return Tt(this._componentsMap.get("series"),function(n){return!!n&&n.subType===e})},t.prototype.getSeries=function(){return Tt(this._componentsMap.get("series"),function(e){return!!e})},t.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},t.prototype.eachSeries=function(e,n){Xi(this),M(this._seriesIndices,function(i){var a=this._componentsMap.get("series")[i];e.call(n,a,i)},this)},t.prototype.eachRawSeries=function(e,n){M(this._componentsMap.get("series"),function(i){i&&e.call(n,i,i.componentIndex)})},t.prototype.eachSeriesByType=function(e,n,i){Xi(this),M(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];o.subType===e&&n.call(i,o,a)},this)},t.prototype.eachRawSeriesByType=function(e,n,i){return M(this.getSeriesByType(e),n,i)},t.prototype.isSeriesFiltered=function(e){return Xi(this),this._seriesIndicesMap.get(e.componentIndex)==null},t.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},t.prototype.filterSeries=function(e,n){Xi(this);var i=[];M(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];e.call(n,o,a)&&i.push(a)},this),this._seriesIndices=i,this._seriesIndicesMap=$(i)},t.prototype.restoreData=function(e){wo(this);var n=this._componentsMap,i=[];n.each(function(a,o){ht.hasClass(o)&&i.push(o)}),ht.topologicalTravel(i,ht.getAllClassMainTypes(),function(a){M(n.get(a),function(o){o&&(a!=="series"||!AC(o,e))&&o.restoreData()})})},t.internalField=function(){wo=function(e){var n=e._seriesIndices=[];M(e._componentsMap.get("series"),function(i){i&&n.push(i.componentIndex)}),e._seriesIndicesMap=$(n)},Xi=function(e){},ld=function(e,n){e.option={},e.option[ud]=DC,e._componentsMap=$({series:[]}),e._componentsCount=$();var i=n.aria;Y(i)&&i.enabled==null&&(i.enabled=!0),MC(n,e._theme.option),nt(n,gC,!1),e._mergeOption(n,null)}}(),t}(wt);function AC(r,t){if(t){var e=t.seriesIndex,n=t.seriesId,i=t.seriesName;return e!=null&&r.componentIndex!==e||n!=null&&r.id!==n||i!=null&&r.name!==i}}function MC(r,t){var e=r.color&&!r.colorLayer;M(t,function(n,i){i==="colorLayer"&&e||ht.hasClass(i)||(typeof n=="object"?r[i]=r[i]?nt(r[i],n,!1):tt(n):r[i]==null&&(r[i]=n))})}function fd(r,t,e){if(V(t)){var n=$();return M(t,function(a){if(a!=null){var o=Qe(a,null);o!=null&&n.set(a,!0)}}),Tt(e,function(a){return a&&n.get(a[r])})}else{var i=Qe(t,null);return Tt(e,function(a){return a&&i!=null&&a[r]===i})}}function hd(r,t){return t.hasOwnProperty("subType")?Tt(r,function(e){return e&&e.subType===t.subType}):r}function vd(r){var t=$();return r&&M(It(r.replaceMerge),function(e){t.set(e,!0)}),{replaceMergeMainTypeMap:t}}Oe(tv,jh);var IC=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],c0=function(){function r(t){M(IC,function(e){this[e]=dt(t[e],t)},this)}return r}(),fu={},ev=function(){function r(){this._coordinateSystems=[]}return r.prototype.create=function(t,e){var n=[];M(fu,function(i,a){var o=i.create(t,e);n=n.concat(o||[])}),this._coordinateSystems=n},r.prototype.update=function(t,e){M(this._coordinateSystems,function(n){n.update&&n.update(t,e)})},r.prototype.getCoordinateSystems=function(){return this._coordinateSystems.slice()},r.register=function(t,e){fu[t]=e},r.get=function(t){return fu[t]},r}(),LC=/^(min|max)?(.+)$/,PC=function(){function r(t){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=t}return r.prototype.setOption=function(t,e,n){t&&(M(It(t.series),function(o){o&&o.data&&oe(o.data)&&fs(o.data)}),M(It(t.dataset),function(o){o&&o.source&&oe(o.source)&&fs(o.source)})),t=tt(t);var i=this._optionBackup,a=RC(t,e,!i);this._newBaseOption=a.baseOption,i?(a.timelineOptions.length&&(i.timelineOptions=a.timelineOptions),a.mediaList.length&&(i.mediaList=a.mediaList),a.mediaDefault&&(i.mediaDefault=a.mediaDefault)):this._optionBackup=a},r.prototype.mountOption=function(t){var e=this._optionBackup;return this._timelineOptions=e.timelineOptions,this._mediaList=e.mediaList,this._mediaDefault=e.mediaDefault,this._currentMediaIndices=[],tt(t?e.baseOption:this._newBaseOption)},r.prototype.getTimelineOption=function(t){var e,n=this._timelineOptions;if(n.length){var i=t.getComponent("timeline");i&&(e=tt(n[i.getCurrentIndex()]))}return e},r.prototype.getMediaOption=function(t){var e=this._api.getWidth(),n=this._api.getHeight(),i=this._mediaList,a=this._mediaDefault,o=[],s=[];if(!i.length&&!a)return s;for(var l=0,u=i.length;l<u;l++)EC(i[l].query,e,n)&&o.push(l);return!o.length&&a&&(o=[-1]),o.length&&!OC(o,this._currentMediaIndices)&&(s=H(o,function(f){return tt(f===-1?a.option:i[f].option)})),this._currentMediaIndices=o,s},r}();function RC(r,t,e){var n=[],i,a,o=r.baseOption,s=r.timeline,l=r.options,u=r.media,f=!!r.media,h=!!(l||s||o&&o.timeline);o?(a=o,a.timeline||(a.timeline=s)):((h||f)&&(r.options=r.media=null),a=r),f&&V(u)&&M(u,function(v){v&&v.option&&(v.query?n.push(v):i||(i=v))}),c(a),M(l,function(v){return c(v)}),M(n,function(v){return c(v.option)});function c(v){M(t,function(d){d(v,e)})}return{baseOption:a,timelineOptions:l||[],mediaDefault:i,mediaList:n}}function EC(r,t,e){var n={width:t,height:e,aspectratio:t/e},i=!0;return M(r,function(a,o){var s=o.match(LC);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();kC(n[u],a,l)||(i=!1)}}),i}function kC(r,t,e){return e==="min"?r>=t:e==="max"?r<=t:r===t}function OC(r,t){return r.join(",")===t.join(",")}var be=M,Va=Y,cd=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function hu(r){var t=r&&r.itemStyle;if(t)for(var e=0,n=cd.length;e<n;e++){var i=cd[e],a=t.normal,o=t.emphasis;a&&a[i]&&(r[i]=r[i]||{},r[i].normal?nt(r[i].normal,a[i]):r[i].normal=a[i],a[i]=null),o&&o[i]&&(r[i]=r[i]||{},r[i].emphasis?nt(r[i].emphasis,o[i]):r[i].emphasis=o[i],o[i]=null)}}function Ht(r,t,e){if(r&&r[t]&&(r[t].normal||r[t].emphasis)){var n=r[t].normal,i=r[t].emphasis;n&&(e?(r[t].normal=r[t].emphasis=null,Q(r[t],n)):r[t]=n),i&&(r.emphasis=r.emphasis||{},r.emphasis[t]=i,i.focus&&(r.emphasis.focus=i.focus),i.blurScope&&(r.emphasis.blurScope=i.blurScope))}}function va(r){Ht(r,"itemStyle"),Ht(r,"lineStyle"),Ht(r,"areaStyle"),Ht(r,"label"),Ht(r,"labelLine"),Ht(r,"upperLabel"),Ht(r,"edgeLabel")}function At(r,t){var e=Va(r)&&r[t],n=Va(e)&&e.textStyle;if(n)for(var i=0,a=gc.length;i<a;i++){var o=gc[i];n.hasOwnProperty(o)&&(e[o]=n[o])}}function ce(r){r&&(va(r),At(r,"label"),r.emphasis&&At(r.emphasis,"label"))}function BC(r){if(Va(r)){hu(r),va(r),At(r,"label"),At(r,"upperLabel"),At(r,"edgeLabel"),r.emphasis&&(At(r.emphasis,"label"),At(r.emphasis,"upperLabel"),At(r.emphasis,"edgeLabel"));var t=r.markPoint;t&&(hu(t),ce(t));var e=r.markLine;e&&(hu(e),ce(e));var n=r.markArea;n&&ce(n);var i=r.data;if(r.type==="graph"){i=i||r.nodes;var a=r.links||r.edges;if(a&&!oe(a))for(var o=0;o<a.length;o++)ce(a[o]);M(r.categories,function(u){va(u)})}if(i&&!oe(i))for(var o=0;o<i.length;o++)ce(i[o]);if(t=r.markPoint,t&&t.data)for(var s=t.data,o=0;o<s.length;o++)ce(s[o]);if(e=r.markLine,e&&e.data)for(var l=e.data,o=0;o<l.length;o++)V(l[o])?(ce(l[o][0]),ce(l[o][1])):ce(l[o]);r.type==="gauge"?(At(r,"axisLabel"),At(r,"title"),At(r,"detail")):r.type==="treemap"?(Ht(r.breadcrumb,"itemStyle"),M(r.levels,function(u){va(u)})):r.type==="tree"&&va(r.leaves)}}function sr(r){return V(r)?r:r?[r]:[]}function dd(r){return(V(r)?r[0]:r)||{}}function NC(r,t){be(sr(r.series),function(n){Va(n)&&BC(n)});var e=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];t&&e.push("valueAxis","categoryAxis","logAxis","timeAxis"),be(e,function(n){be(sr(r[n]),function(i){i&&(At(i,"axisLabel"),At(i.axisPointer,"label"))})}),be(sr(r.parallel),function(n){var i=n&&n.parallelAxisDefault;At(i,"axisLabel"),At(i&&i.axisPointer,"label")}),be(sr(r.calendar),function(n){Ht(n,"itemStyle"),At(n,"dayLabel"),At(n,"monthLabel"),At(n,"yearLabel")}),be(sr(r.radar),function(n){At(n,"name"),n.name&&n.axisName==null&&(n.axisName=n.name,delete n.name),n.nameGap!=null&&n.axisNameGap==null&&(n.axisNameGap=n.nameGap,delete n.nameGap)}),be(sr(r.geo),function(n){Va(n)&&(ce(n),be(sr(n.regions),function(i){ce(i)}))}),be(sr(r.timeline),function(n){ce(n),Ht(n,"label"),Ht(n,"itemStyle"),Ht(n,"controlStyle",!0);var i=n.data;V(i)&&M(i,function(a){Y(a)&&(Ht(a,"label"),Ht(a,"itemStyle"))})}),be(sr(r.toolbox),function(n){Ht(n,"iconStyle"),be(n.feature,function(i){Ht(i,"iconStyle")})}),At(dd(r.axisPointer),"label"),At(dd(r.tooltip).axisPointer,"label")}function FC(r,t){for(var e=t.split(","),n=r,i=0;i<e.length&&(n=n&&n[e[i]],n!=null);i++);return n}function zC(r,t,e,n){for(var i=t.split(","),a=r,o,s=0;s<i.length-1;s++)o=i[s],a[o]==null&&(a[o]={}),a=a[o];a[i[s]]==null&&(a[i[s]]=e)}function pd(r){r&&M(VC,function(t){t[0]in r&&!(t[1]in r)&&(r[t[1]]=r[t[0]])})}var VC=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],GC=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],vu=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function Zi(r){var t=r&&r.itemStyle;if(t)for(var e=0;e<vu.length;e++){var n=vu[e][1],i=vu[e][0];t[n]!=null&&(t[i]=t[n])}}function gd(r){r&&r.alignTo==="edge"&&r.margin!=null&&r.edgeDistance==null&&(r.edgeDistance=r.margin)}function yd(r){r&&r.downplay&&!r.blur&&(r.blur=r.downplay)}function HC(r){r&&r.focusNodeAdjacency!=null&&(r.emphasis=r.emphasis||{},r.emphasis.focus==null&&(r.emphasis.focus="adjacency"))}function d0(r,t){if(r)for(var e=0;e<r.length;e++)t(r[e]),r[e]&&d0(r[e].children,t)}function p0(r,t){NC(r,t),r.series=It(r.series),M(r.series,function(e){if(Y(e)){var n=e.type;if(n==="line")e.clipOverflow!=null&&(e.clip=e.clipOverflow);else if(n==="pie"||n==="gauge"){e.clockWise!=null&&(e.clockwise=e.clockWise),gd(e.label);var i=e.data;if(i&&!oe(i))for(var a=0;a<i.length;a++)gd(i[a]);e.hoverOffset!=null&&(e.emphasis=e.emphasis||{},(e.emphasis.scaleSize=null)&&(e.emphasis.scaleSize=e.hoverOffset))}else if(n==="gauge"){var o=FC(e,"pointer.color");o!=null&&zC(e,"itemStyle.color",o)}else if(n==="bar"){Zi(e),Zi(e.backgroundStyle),Zi(e.emphasis);var i=e.data;if(i&&!oe(i))for(var a=0;a<i.length;a++)typeof i[a]=="object"&&(Zi(i[a]),Zi(i[a]&&i[a].emphasis))}else if(n==="sunburst"){var s=e.highlightPolicy;s&&(e.emphasis=e.emphasis||{},e.emphasis.focus||(e.emphasis.focus=s)),yd(e),d0(e.data,yd)}else n==="graph"||n==="sankey"?HC(e):n==="map"&&(e.mapType&&!e.map&&(e.map=e.mapType),e.mapLocation&&Q(e,e.mapLocation));e.hoverAnimation!=null&&(e.emphasis=e.emphasis||{},e.emphasis&&e.emphasis.scale==null&&(e.emphasis.scale=e.hoverAnimation)),pd(e)}}),r.dataRange&&(r.visualMap=r.dataRange),M(GC,function(e){var n=r[e];n&&(V(n)||(n=[n]),M(n,function(i){pd(i)}))})}function WC(r){var t=$();r.eachSeries(function(e){var n=e.get("stack");if(n){var i=t.get(n)||t.set(n,[]),a=e.getData(),o={stackResultDimension:a.getCalculationInfo("stackResultDimension"),stackedOverDimension:a.getCalculationInfo("stackedOverDimension"),stackedDimension:a.getCalculationInfo("stackedDimension"),stackedByDimension:a.getCalculationInfo("stackedByDimension"),isStackedByIndex:a.getCalculationInfo("isStackedByIndex"),data:a,seriesModel:e};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;i.length&&a.setCalculationInfo("stackedOnSeries",i[i.length-1].seriesModel),i.push(o)}}),t.each(UC)}function UC(r){M(r,function(t,e){var n=[],i=[NaN,NaN],a=[t.stackResultDimension,t.stackedOverDimension],o=t.data,s=t.isStackedByIndex,l=t.seriesModel.get("stackStrategy")||"samesign";o.modify(a,function(u,f,h){var c=o.get(t.stackedDimension,h);if(isNaN(c))return i;var v,d;s?d=o.getRawIndex(h):v=o.get(t.stackedByDimension,h);for(var p=NaN,g=e-1;g>=0;g--){var y=r[g];if(s||(d=y.data.rawIndexOf(y.stackedByDimension,v)),d>=0){var m=y.data.getByRawIndex(y.stackResultDimension,d);if(l==="all"||l==="positive"&&m>0||l==="negative"&&m<0||l==="samesign"&&c>=0&&m>0||l==="samesign"&&c<=0&&m<0){c=Cw(c,m),p=m;break}}}return n[0]=c,n[1]=p,n})})}var vl=function(){function r(t){this.data=t.data||(t.sourceFormat===rr?{}:[]),this.sourceFormat=t.sourceFormat||u0,this.seriesLayoutBy=t.seriesLayoutBy||Je,this.startIndex=t.startIndex||0,this.dimensionsDetectedCount=t.dimensionsDetectedCount,this.metaRawOption=t.metaRawOption;var e=this.dimensionsDefine=t.dimensionsDefine;if(e)for(var n=0;n<e.length;n++){var i=e[n];i.type==null&&h0(this,n)===Ot.Must&&(i.type="ordinal")}}return r}();function rv(r){return r instanceof vl}function kf(r,t,e){e=e||y0(r);var n=t.seriesLayoutBy,i=XC(r,e,n,t.sourceHeader,t.dimensions),a=new vl({data:r,sourceFormat:e,seriesLayoutBy:n,dimensionsDefine:i.dimensionsDefine,startIndex:i.startIndex,dimensionsDetectedCount:i.dimensionsDetectedCount,metaRawOption:tt(t)});return a}function g0(r){return new vl({data:r,sourceFormat:oe(r)?Fr:xe})}function YC(r){return new vl({data:r.data,sourceFormat:r.sourceFormat,seriesLayoutBy:r.seriesLayoutBy,dimensionsDefine:tt(r.dimensionsDefine),startIndex:r.startIndex,dimensionsDetectedCount:r.dimensionsDetectedCount})}function y0(r){var t=u0;if(oe(r))t=Fr;else if(V(r)){r.length===0&&(t=Qt);for(var e=0,n=r.length;e<n;e++){var i=r[e];if(i!=null){if(V(i)||oe(i)){t=Qt;break}else if(Y(i)){t=we;break}}}}else if(Y(r)){for(var a in r)if(tr(r,a)&&Kt(r[a])){t=rr;break}}return t}function XC(r,t,e,n,i){var a,o;if(!r)return{dimensionsDefine:md(i),startIndex:o,dimensionsDetectedCount:a};if(t===Qt){var s=r;n==="auto"||n==null?_d(function(u){u!=null&&u!=="-"&&(W(u)?o==null&&(o=1):o=0)},e,s,10):o=ct(n)?n:n?1:0,!i&&o===1&&(i=[],_d(function(u,f){i[f]=u!=null?u+"":""},e,s,1/0)),a=i?i.length:e===ki?s.length:s[0]?s[0].length:null}else if(t===we)i||(i=ZC(r));else if(t===rr)i||(i=[],M(r,function(u,f){i.push(f)}));else if(t===xe){var l=Qa(r[0]);a=V(l)&&l.length||1}return{startIndex:o,dimensionsDefine:md(i),dimensionsDetectedCount:a}}function ZC(r){for(var t=0,e;t<r.length&&!(e=r[t++]););if(e)return mt(e)}function md(r){if(r){var t=$();return H(r,function(e,n){e=Y(e)?e:{name:e};var i={name:e.name,displayName:e.displayName,type:e.type};if(i.name==null)return i;i.name+="",i.displayName==null&&(i.displayName=i.name);var a=t.get(i.name);return a?i.name+="-"+a.count++:t.set(i.name,{count:1}),i})}}function _d(r,t,e,n){if(t===ki)for(var i=0;i<e.length&&i<n;i++)r(e[i]?e[i][0]:null,i);else for(var a=e[0]||[],i=0;i<a.length&&i<n;i++)r(a[i],i)}function m0(r){var t=r.sourceFormat;return t===we||t===rr}var hn,vn,cn,Sd,xd,_0=function(){function r(t,e){var n=rv(t)?t:g0(t);this._source=n;var i=this._data=n.data;n.sourceFormat===Fr&&(this._offset=0,this._dimSize=e,this._data=i),xd(this,i,n)}return r.prototype.getSource=function(){return this._source},r.prototype.count=function(){return 0},r.prototype.getItem=function(t,e){},r.prototype.appendData=function(t){},r.prototype.clean=function(){},r.protoInitialize=function(){var t=r.prototype;t.pure=!1,t.persistent=!0}(),r.internalField=function(){var t;xd=function(o,s,l){var u=l.sourceFormat,f=l.seriesLayoutBy,h=l.startIndex,c=l.dimensionsDefine,v=Sd[nv(u,f)];if(F(o,v),u===Fr)o.getItem=e,o.count=i,o.fillStorage=n;else{var d=S0(u,f);o.getItem=dt(d,null,s,h,c);var p=x0(u,f);o.count=dt(p,null,s,h,c)}};var e=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,f=u*o,h=0;h<u;h++)s[h]=l[f+h];return s},n=function(o,s,l,u){for(var f=this._data,h=this._dimSize,c=0;c<h;c++){for(var v=u[c],d=v[0]==null?1/0:v[0],p=v[1]==null?-1/0:v[1],g=s-o,y=l[c],m=0;m<g;m++){var _=f[m*h+c];y[o+m]=_,_<d&&(d=_),_>p&&(p=_)}v[0]=d,v[1]=p}},i=function(){return this._data?this._data.length/this._dimSize:0};Sd=(t={},t[Qt+"_"+Je]={pure:!0,appendData:a},t[Qt+"_"+ki]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},t[we]={pure:!0,appendData:a},t[rr]={pure:!0,appendData:function(o){var s=this._data;M(o,function(l,u){for(var f=s[u]||(s[u]=[]),h=0;h<(l||[]).length;h++)f.push(l[h])})}},t[xe]={appendData:a},t[Fr]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},t);function a(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}}(),r}(),wd=function(r,t,e,n){return r[n]},$C=(hn={},hn[Qt+"_"+Je]=function(r,t,e,n){return r[n+t]},hn[Qt+"_"+ki]=function(r,t,e,n,i){n+=t;for(var a=i||[],o=r,s=0;s<o.length;s++){var l=o[s];a[s]=l?l[n]:null}return a},hn[we]=wd,hn[rr]=function(r,t,e,n,i){for(var a=i||[],o=0;o<e.length;o++){var s=e[o].name,l=r[s];a[o]=l?l[n]:null}return a},hn[xe]=wd,hn);function S0(r,t){var e=$C[nv(r,t)];return e}var bd=function(r,t,e){return r.length},qC=(vn={},vn[Qt+"_"+Je]=function(r,t,e){return Math.max(0,r.length-t)},vn[Qt+"_"+ki]=function(r,t,e){var n=r[0];return n?Math.max(0,n.length-t):0},vn[we]=bd,vn[rr]=function(r,t,e){var n=e[0].name,i=r[n];return i?i.length:0},vn[xe]=bd,vn);function x0(r,t){var e=qC[nv(r,t)];return e}var cu=function(r,t,e){return r[t]},KC=(cn={},cn[Qt]=cu,cn[we]=function(r,t,e){return r[e]},cn[rr]=cu,cn[xe]=function(r,t,e){var n=Qa(r);return n instanceof Array?n[t]:n},cn[Fr]=cu,cn);function w0(r){var t=KC[r];return t}function nv(r,t){return r===Qt?r+"_"+t:r}function Ti(r,t,e){if(r){var n=r.getRawDataItem(t);if(n!=null){var i=r.getStore(),a=i.getSource().sourceFormat;if(e!=null){var o=r.getDimensionIndex(e),s=i.getDimensionProperty(o);return w0(a)(n,o,s)}else{var l=n;return a===xe&&(l=Qa(n)),l}}}}var QC=/\{@(.+?)\}/g,JC=function(){function r(){}return r.prototype.getDataParams=function(t,e){var n=this.getData(e),i=this.getRawValue(t,e),a=n.getRawIndex(t),o=n.getName(t),s=n.getRawDataItem(t),l=n.getItemVisual(t,"style"),u=l&&l[n.getItemVisual(t,"drawType")||"fill"],f=l&&l.stroke,h=this.mainType,c=h==="series",v=n.userOutput&&n.userOutput.get();return{componentType:h,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:c?this.subType:null,seriesIndex:this.seriesIndex,seriesId:c?this.id:null,seriesName:c?this.name:null,name:o,dataIndex:a,data:s,dataType:e,value:i,color:u,borderColor:f,dimensionNames:v?v.fullDimensions:null,encode:v?v.encode:null,$vars:["seriesName","name","value"]}},r.prototype.getFormattedLabel=function(t,e,n,i,a,o){e=e||"normal";var s=this.getData(n),l=this.getDataParams(t,n);if(o&&(l.value=o.interpolatedValue),i!=null&&V(l.value)&&(l.value=l.value[i]),!a){var u=s.getItemModel(t);a=u.get(e==="normal"?["label","formatter"]:[e,"label","formatter"])}if(q(a))return l.status=e,l.dimensionIndex=i,a(l);if(W(a)){var f=o0(a,l);return f.replace(QC,function(h,c){var v=c.length,d=c;d.charAt(0)==="["&&d.charAt(v-1)==="]"&&(d=+d.slice(1,v-1));var p=Ti(s,t,d);if(o&&V(o.interpolatedValue)){var g=s.getDimensionIndex(d);g>=0&&(p=o.interpolatedValue[g])}return p!=null?p+"":""})}},r.prototype.getRawValue=function(t,e){return Ti(this.getData(e),t)},r.prototype.formatTooltip=function(t,e,n){},r}();function Td(r){var t,e;return Y(r)?r.type&&(e=r):t=r,{text:t,frag:e}}function Da(r){return new jC(r)}var jC=function(){function r(t){t=t||{},this._reset=t.reset,this._plan=t.plan,this._count=t.count,this._onDirty=t.onDirty,this._dirty=!0}return r.prototype.perform=function(t){var e=this._upstream,n=t&&t.skip;if(this._dirty&&e){var i=this.context;i.data=i.outputData=e.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var a;this._plan&&!n&&(a=this._plan(this.context));var o=f(this._modBy),s=this._modDataCount||0,l=f(t&&t.modBy),u=t&&t.modDataCount||0;(o!==l||s!==u)&&(a="reset");function f(m){return!(m>=1)&&(m=1),m}var h;(this._dirty||a==="reset")&&(this._dirty=!1,h=this._doReset(n)),this._modBy=l,this._modDataCount=u;var c=t&&t.step;if(e?this._dueEnd=e._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var v=this._dueIndex,d=Math.min(c!=null?this._dueIndex+c:1/0,this._dueEnd);if(!n&&(h||v<d)){var p=this._progress;if(V(p))for(var g=0;g<p.length;g++)this._doProgress(p[g],v,d,l,u);else this._doProgress(p,v,d,l,u)}this._dueIndex=d;var y=this._settedOutputEnd!=null?this._settedOutputEnd:d;this._outputDueEnd=y}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},r.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},r.prototype._doProgress=function(t,e,n,i,a){Cd.reset(e,n,i,a),this._callingProgress=t,this._callingProgress({start:e,end:n,count:n-e,next:Cd.next},this.context)},r.prototype._doReset=function(t){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var e,n;!t&&this._reset&&(e=this._reset(this.context),e&&e.progress&&(n=e.forceFirstProgress,e=e.progress),V(e)&&!e.length&&(e=null)),this._progress=e,this._modBy=this._modDataCount=null;var i=this._downstream;return i&&i.dirty(),n},r.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},r.prototype.pipe=function(t){(this._downstream!==t||this._dirty)&&(this._downstream=t,t._upstream=this,t.dirty())},r.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},r.prototype.getUpstream=function(){return this._upstream},r.prototype.getDownstream=function(){return this._downstream},r.prototype.setOutputEnd=function(t){this._outputDueEnd=this._settedOutputEnd=t},r}(),Cd=function(){var r,t,e,n,i,a={reset:function(l,u,f,h){t=l,r=u,e=f,n=h,i=Math.ceil(n/e),a.next=e>1&&n>0?s:o}};return a;function o(){return t<r?t++:null}function s(){var l=t%i*e+Math.ceil(t/i),u=t>=r?null:l<n?l:t;return t++,u}}();function is(r,t){var e=t&&t.type;return e==="ordinal"?r:(e==="time"&&!ct(r)&&r!=null&&r!=="-"&&(r=+gr(r)),r==null||r===""?NaN:Number(r))}var tD=$({number:function(r){return parseFloat(r)},time:function(r){return+gr(r)},trim:function(r){return W(r)?Ze(r):r}});function b0(r){return tD.get(r)}var T0={lt:function(r,t){return r<t},lte:function(r,t){return r<=t},gt:function(r,t){return r>t},gte:function(r,t){return r>=t}},eD=function(){function r(t,e){if(!ct(e)){var n="";ft(n)}this._opFn=T0[t],this._rvalFloat=Hr(e)}return r.prototype.evaluate=function(t){return ct(t)?this._opFn(t,this._rvalFloat):this._opFn(Hr(t),this._rvalFloat)},r}(),C0=function(){function r(t,e){var n=t==="desc";this._resultLT=n?1:-1,e==null&&(e=n?"min":"max"),this._incomparable=e==="min"?-1/0:1/0}return r.prototype.evaluate=function(t,e){var n=ct(t)?t:Hr(t),i=ct(e)?e:Hr(e),a=isNaN(n),o=isNaN(i);if(a&&(n=this._incomparable),o&&(i=this._incomparable),a&&o){var s=W(t),l=W(e);s&&(n=l?t:0),l&&(i=s?e:0)}return n<i?this._resultLT:n>i?-this._resultLT:0},r}(),rD=function(){function r(t,e){this._rval=e,this._isEQ=t,this._rvalTypeof=typeof e,this._rvalFloat=Hr(e)}return r.prototype.evaluate=function(t){var e=t===this._rval;if(!e){var n=typeof t;n!==this._rvalTypeof&&(n==="number"||this._rvalTypeof==="number")&&(e=Hr(t)===this._rvalFloat)}return this._isEQ?e:!e},r}();function nD(r,t){return r==="eq"||r==="ne"?new rD(r==="eq",t):tr(T0,r)?new eD(r,t):null}var iD=function(){function r(){}return r.prototype.getRawData=function(){throw new Error("not supported")},r.prototype.getRawDataItem=function(t){throw new Error("not supported")},r.prototype.cloneRawData=function(){},r.prototype.getDimensionInfo=function(t){},r.prototype.cloneAllDimensionInfo=function(){},r.prototype.count=function(){},r.prototype.retrieveValue=function(t,e){},r.prototype.retrieveValueFromItem=function(t,e){},r.prototype.convertValue=function(t,e){return is(t,e)},r}();function aD(r,t){var e=new iD,n=r.data,i=e.sourceFormat=r.sourceFormat,a=r.startIndex,o="";r.seriesLayoutBy!==Je&&ft(o);var s=[],l={},u=r.dimensionsDefine;if(u)M(u,function(p,g){var y=p.name,m={index:g,name:y,displayName:p.displayName};if(s.push(m),y!=null){var _="";tr(l,y)&&ft(_),l[y]=m}});else for(var f=0;f<r.dimensionsDetectedCount;f++)s.push({index:f});var h=S0(i,Je);t.__isBuiltIn&&(e.getRawDataItem=function(p){return h(n,a,s,p)},e.getRawData=dt(oD,null,r)),e.cloneRawData=dt(sD,null,r);var c=x0(i,Je);e.count=dt(c,null,n,a,s);var v=w0(i);e.retrieveValue=function(p,g){var y=h(n,a,s,p);return d(y,g)};var d=e.retrieveValueFromItem=function(p,g){if(p!=null){var y=s[g];if(y)return v(p,g,y.name)}};return e.getDimensionInfo=dt(lD,null,s,l),e.cloneAllDimensionInfo=dt(uD,null,s),e}function oD(r){var t=r.sourceFormat;if(!iv(t)){var e="";ft(e)}return r.data}function sD(r){var t=r.sourceFormat,e=r.data;if(!iv(t)){var n="";ft(n)}if(t===Qt){for(var i=[],a=0,o=e.length;a<o;a++)i.push(e[a].slice());return i}else if(t===we){for(var i=[],a=0,o=e.length;a<o;a++)i.push(F({},e[a]));return i}}function lD(r,t,e){if(e!=null){if(ct(e)||!isNaN(e)&&!tr(t,e))return r[e];if(tr(t,e))return t[e]}}function uD(r){return tt(r)}var D0=$();function fD(r){r=tt(r);var t=r.type,e="";t||ft(e);var n=t.split(":");n.length!==2&&ft(e);var i=!1;n[0]==="echarts"&&(t=n[1],i=!0),r.__isBuiltIn=i,D0.set(t,r)}function hD(r,t,e){var n=It(r),i=n.length,a="";i||ft(a);for(var o=0,s=i;o<s;o++){var l=n[o];t=vD(l,t),o!==s-1&&(t.length=Math.max(t.length,1))}return t}function vD(r,t,e,n){var i="";t.length||ft(i),Y(r)||ft(i);var a=r.type,o=D0.get(a);o||ft(i);var s=H(t,function(u){return aD(u,o)}),l=It(o.transform({upstream:s[0],upstreamList:s,config:tt(r.config)}));return H(l,function(u,f){var h="";Y(u)||ft(h),u.data||ft(h);var c=y0(u.data);iv(c)||ft(h);var v,d=t[0];if(d&&f===0&&!u.dimensions){var p=d.startIndex;p&&(u.data=d.data.slice(0,p).concat(u.data)),v={seriesLayoutBy:Je,sourceHeader:p,dimensions:d.metaRawOption.dimensions}}else v={seriesLayoutBy:Je,sourceHeader:0,dimensions:u.dimensions};return kf(u.data,v,null)})}function iv(r){return r===Qt||r===we}var cl="undefined",cD=typeof Uint32Array===cl?Array:Uint32Array,dD=typeof Uint16Array===cl?Array:Uint16Array,A0=typeof Int32Array===cl?Array:Int32Array,Dd=typeof Float64Array===cl?Array:Float64Array,M0={float:Dd,int:A0,ordinal:Array,number:Array,time:Dd},du;function Yn(r){return r>65535?cD:dD}function Xn(){return[1/0,-1/0]}function pD(r){var t=r.constructor;return t===Array?r.slice():new t(r)}function Ad(r,t,e,n,i){var a=M0[e||"float"];if(i){var o=r[t],s=o&&o.length;if(s!==n){for(var l=new a(n),u=0;u<s;u++)l[u]=o[u];r[t]=l}}else r[t]=new a(n)}var Of=function(){function r(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=$()}return r.prototype.initData=function(t,e,n){this._provider=t,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var i=t.getSource(),a=this.defaultDimValueGetter=du[i.sourceFormat];this._dimValueGetter=n||a,this._rawExtent=[],m0(i),this._dimensions=H(e,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,t.count())},r.prototype.getProvider=function(){return this._provider},r.prototype.getSource=function(){return this._provider.getSource()},r.prototype.ensureCalculationDimension=function(t,e){var n=this._calcDimNameToIdx,i=this._dimensions,a=n.get(t);if(a!=null){if(i[a].type===e)return a}else a=i.length;return i[a]={type:e},n.set(t,a),this._chunks[a]=new M0[e||"float"](this._rawCount),this._rawExtent[a]=Xn(),a},r.prototype.collectOrdinalMeta=function(t,e){var n=this._chunks[t],i=this._dimensions[t],a=this._rawExtent,o=i.ordinalOffset||0,s=n.length;o===0&&(a[t]=Xn());for(var l=a[t],u=o;u<s;u++){var f=n[u]=e.parseAndCollect(n[u]);isNaN(f)||(l[0]=Math.min(f,l[0]),l[1]=Math.max(f,l[1]))}i.ordinalMeta=e,i.ordinalOffset=s,i.type="ordinal"},r.prototype.getOrdinalMeta=function(t){var e=this._dimensions[t],n=e.ordinalMeta;return n},r.prototype.getDimensionProperty=function(t){var e=this._dimensions[t];return e&&e.property},r.prototype.appendData=function(t){var e=this._provider,n=this.count();e.appendData(t);var i=e.count();return e.persistent||(i+=n),n<i&&this._initDataFromProvider(n,i,!0),[n,i]},r.prototype.appendValues=function(t,e){for(var n=this._chunks,i=this._dimensions,a=i.length,o=this._rawExtent,s=this.count(),l=s+Math.max(t.length,e||0),u=0;u<a;u++){var f=i[u];Ad(n,u,f.type,l,!0)}for(var h=[],c=s;c<l;c++)for(var v=c-s,d=0;d<a;d++){var f=i[d],p=du.arrayRows.call(this,t[v]||h,f.property,v,d);n[d][c]=p;var g=o[d];p<g[0]&&(g[0]=p),p>g[1]&&(g[1]=p)}return this._rawCount=this._count=l,{start:s,end:l}},r.prototype._initDataFromProvider=function(t,e,n){for(var i=this._provider,a=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=H(o,function(m){return m.property}),f=0;f<s;f++){var h=o[f];l[f]||(l[f]=Xn()),Ad(a,f,h.type,e,n)}if(i.fillStorage)i.fillStorage(t,e,a,l);else for(var c=[],v=t;v<e;v++){c=i.getItem(v,c);for(var d=0;d<s;d++){var p=a[d],g=this._dimValueGetter(c,u[d],v,d);p[v]=g;var y=l[d];g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}!i.persistent&&i.clean&&i.clean(),this._rawCount=this._count=e,this._extent=[]},r.prototype.count=function(){return this._count},r.prototype.get=function(t,e){if(!(e>=0&&e<this._count))return NaN;var n=this._chunks[t];return n?n[this.getRawIndex(e)]:NaN},r.prototype.getValues=function(t,e){var n=[],i=[];if(e==null){e=t,t=[];for(var a=0;a<this._dimensions.length;a++)i.push(a)}else i=t;for(var a=0,o=i.length;a<o;a++)n.push(this.get(i[a],e));return n},r.prototype.getByRawIndex=function(t,e){if(!(e>=0&&e<this._rawCount))return NaN;var n=this._chunks[t];return n?n[e]:NaN},r.prototype.getSum=function(t){var e=this._chunks[t],n=0;if(e)for(var i=0,a=this.count();i<a;i++){var o=this.get(t,i);isNaN(o)||(n+=o)}return n},r.prototype.getMedian=function(t){var e=[];this.each([t],function(a){isNaN(a)||e.push(a)});var n=e.sort(function(a,o){return a-o}),i=this.count();return i===0?0:i%2===1?n[(i-1)/2]:(n[i/2]+n[i/2-1])/2},r.prototype.indexOfRawIndex=function(t){if(t>=this._rawCount||t<0)return-1;if(!this._indices)return t;var e=this._indices,n=e[t];if(n!=null&&n<this._count&&n===t)return t;for(var i=0,a=this._count-1;i<=a;){var o=(i+a)/2|0;if(e[o]<t)i=o+1;else if(e[o]>t)a=o-1;else return o}return-1},r.prototype.indicesOfNearest=function(t,e,n){var i=this._chunks,a=i[t],o=[];if(!a)return o;n==null&&(n=1/0);for(var s=1/0,l=-1,u=0,f=0,h=this.count();f<h;f++){var c=this.getRawIndex(f),v=e-a[c],d=Math.abs(v);d<=n&&((d<s||d===s&&v>=0&&l<0)&&(s=d,l=v,u=0),v===l&&(o[u++]=f))}return o.length=u,o},r.prototype.getIndices=function(){var t,e=this._indices;if(e){var n=e.constructor,i=this._count;if(n===Array){t=new n(i);for(var a=0;a<i;a++)t[a]=e[a]}else t=new n(e.buffer,0,i)}else{var n=Yn(this._rawCount);t=new n(this.count());for(var a=0;a<t.length;a++)t[a]=a}return t},r.prototype.filter=function(t,e){if(!this._count)return this;for(var n=this.clone(),i=n.count(),a=Yn(n._rawCount),o=new a(i),s=[],l=t.length,u=0,f=t[0],h=n._chunks,c=0;c<i;c++){var v=void 0,d=n.getRawIndex(c);if(l===0)v=e(c);else if(l===1){var p=h[f][d];v=e(p,c)}else{for(var g=0;g<l;g++)s[g]=h[t[g]][d];s[g]=c,v=e.apply(null,s)}v&&(o[u++]=d)}return u<i&&(n._indices=o),n._count=u,n._extent=[],n._updateGetRawIdx(),n},r.prototype.selectRange=function(t){var e=this.clone(),n=e._count;if(!n)return this;var i=mt(t),a=i.length;if(!a)return this;var o=e.count(),s=Yn(e._rawCount),l=new s(o),u=0,f=i[0],h=t[f][0],c=t[f][1],v=e._chunks,d=!1;if(!e._indices){var p=0;if(a===1){for(var g=v[i[0]],y=0;y<n;y++){var m=g[y];(m>=h&&m<=c||isNaN(m))&&(l[u++]=p),p++}d=!0}else if(a===2){for(var g=v[i[0]],_=v[i[1]],S=t[i[1]][0],w=t[i[1]][1],y=0;y<n;y++){var m=g[y],x=_[y];(m>=h&&m<=c||isNaN(m))&&(x>=S&&x<=w||isNaN(x))&&(l[u++]=p),p++}d=!0}}if(!d)if(a===1)for(var y=0;y<o;y++){var b=e.getRawIndex(y),m=v[i[0]][b];(m>=h&&m<=c||isNaN(m))&&(l[u++]=b)}else for(var y=0;y<o;y++){for(var T=!0,b=e.getRawIndex(y),C=0;C<a;C++){var D=i[C],m=v[D][b];(m<t[D][0]||m>t[D][1])&&(T=!1)}T&&(l[u++]=e.getRawIndex(y))}return u<o&&(e._indices=l),e._count=u,e._extent=[],e._updateGetRawIdx(),e},r.prototype.map=function(t,e){var n=this.clone(t);return this._updateDims(n,t,e),n},r.prototype.modify=function(t,e){this._updateDims(this,t,e)},r.prototype._updateDims=function(t,e,n){for(var i=t._chunks,a=[],o=e.length,s=t.count(),l=[],u=t._rawExtent,f=0;f<e.length;f++)u[e[f]]=Xn();for(var h=0;h<s;h++){for(var c=t.getRawIndex(h),v=0;v<o;v++)l[v]=i[e[v]][c];l[o]=h;var d=n&&n.apply(null,l);if(d!=null){typeof d!="object"&&(a[0]=d,d=a);for(var f=0;f<d.length;f++){var p=e[f],g=d[f],y=u[p],m=i[p];m&&(m[c]=g),g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}}},r.prototype.lttbDownSample=function(t,e){var n=this.clone([t],!0),i=n._chunks,a=i[t],o=this.count(),s=0,l=Math.floor(1/e),u=this.getRawIndex(0),f,h,c,v=new(Yn(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));v[s++]=u;for(var d=1;d<o-1;d+=l){for(var p=Math.min(d+l,o-1),g=Math.min(d+l*2,o),y=(g+p)/2,m=0,_=p;_<g;_++){var S=this.getRawIndex(_),w=a[S];isNaN(w)||(m+=w)}m/=g-p;var x=d,b=Math.min(d+l,o),T=d-1,C=a[u];f=-1,c=x;for(var D=-1,A=0,_=x;_<b;_++){var S=this.getRawIndex(_),w=a[S];if(isNaN(w)){A++,D<0&&(D=S);continue}h=Math.abs((T-y)*(w-C)-(T-_)*(m-C)),h>f&&(f=h,c=S)}A>0&&A<b-x&&(v[s++]=Math.min(D,c),c=Math.max(D,c)),v[s++]=c,u=c}return v[s++]=this.getRawIndex(o-1),n._count=s,n._indices=v,n.getRawIndex=this._getRawIdx,n},r.prototype.minmaxDownSample=function(t,e){for(var n=this.clone([t],!0),i=n._chunks,a=Math.floor(1/e),o=i[t],s=this.count(),l=new(Yn(this._rawCount))(Math.ceil(s/a)*2),u=0,f=0;f<s;f+=a){var h=f,c=o[this.getRawIndex(h)],v=f,d=o[this.getRawIndex(v)],p=a;f+a>s&&(p=s-f);for(var g=0;g<p;g++){var y=this.getRawIndex(f+g),m=o[y];m<c&&(c=m,h=f+g),m>d&&(d=m,v=f+g)}var _=this.getRawIndex(h),S=this.getRawIndex(v);h<v?(l[u++]=_,l[u++]=S):(l[u++]=S,l[u++]=_)}return n._count=u,n._indices=l,n._updateGetRawIdx(),n},r.prototype.downSample=function(t,e,n,i){for(var a=this.clone([t],!0),o=a._chunks,s=[],l=Math.floor(1/e),u=o[t],f=this.count(),h=a._rawExtent[t]=Xn(),c=new(Yn(this._rawCount))(Math.ceil(f/l)),v=0,d=0;d<f;d+=l){l>f-d&&(l=f-d,s.length=l);for(var p=0;p<l;p++){var g=this.getRawIndex(d+p);s[p]=u[g]}var y=n(s),m=this.getRawIndex(Math.min(d+i(s,y)||0,f-1));u[m]=y,y<h[0]&&(h[0]=y),y>h[1]&&(h[1]=y),c[v++]=m}return a._count=v,a._indices=c,a._updateGetRawIdx(),a},r.prototype.each=function(t,e){if(this._count)for(var n=t.length,i=this._chunks,a=0,o=this.count();a<o;a++){var s=this.getRawIndex(a);switch(n){case 0:e(a);break;case 1:e(i[t[0]][s],a);break;case 2:e(i[t[0]][s],i[t[1]][s],a);break;default:for(var l=0,u=[];l<n;l++)u[l]=i[t[l]][s];u[l]=a,e.apply(null,u)}}},r.prototype.getDataExtent=function(t){var e=this._chunks[t],n=Xn();if(!e)return n;var i=this.count(),a=!this._indices,o;if(a)return this._rawExtent[t].slice();if(o=this._extent[t],o)return o.slice();o=n;for(var s=o[0],l=o[1],u=0;u<i;u++){var f=this.getRawIndex(u),h=e[f];h<s&&(s=h),h>l&&(l=h)}return o=[s,l],this._extent[t]=o,o},r.prototype.getRawDataItem=function(t){var e=this.getRawIndex(t);if(this._provider.persistent)return this._provider.getItem(e);for(var n=[],i=this._chunks,a=0;a<i.length;a++)n.push(i[a][e]);return n},r.prototype.clone=function(t,e){var n=new r,i=this._chunks,a=t&&zr(t,function(s,l){return s[l]=!0,s},{});if(a)for(var o=0;o<i.length;o++)n._chunks[o]=a[o]?pD(i[o]):i[o];else n._chunks=i;return this._copyCommonProps(n),e||(n._indices=this._cloneIndices()),n._updateGetRawIdx(),n},r.prototype._copyCommonProps=function(t){t._count=this._count,t._rawCount=this._rawCount,t._provider=this._provider,t._dimensions=this._dimensions,t._extent=tt(this._extent),t._rawExtent=tt(this._rawExtent)},r.prototype._cloneIndices=function(){if(this._indices){var t=this._indices.constructor,e=void 0;if(t===Array){var n=this._indices.length;e=new t(n);for(var i=0;i<n;i++)e[i]=this._indices[i]}else e=new t(this._indices);return e}return null},r.prototype._getRawIdxIdentity=function(t){return t},r.prototype._getRawIdx=function(t){return t<this._count&&t>=0?this._indices[t]:-1},r.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},r.internalField=function(){function t(e,n,i,a){return is(e[a],this._dimensions[a])}du={arrayRows:t,objectRows:function(e,n,i,a){return is(e[n],this._dimensions[a])},keyedColumns:t,original:function(e,n,i,a){var o=e&&(e.value==null?e:e.value);return is(o instanceof Array?o[a]:o,this._dimensions[a])},typedArray:function(e,n,i,a){return e[a]}}}(),r}(),I0=function(){function r(t){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=t}return r.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},r.prototype._setLocalSource=function(t,e){this._sourceList=t,this._upstreamSignList=e,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},r.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},r.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},r.prototype._createSource=function(){this._setLocalSource([],[]);var t=this._sourceHost,e=this._getUpstreamSourceManagers(),n=!!e.length,i,a;if(bo(t)){var o=t,s=void 0,l=void 0,u=void 0;if(n){var f=e[0];f.prepareSource(),u=f.getSource(),s=u.data,l=u.sourceFormat,a=[f._getVersionSign()]}else s=o.get("data",!0),l=oe(s)?Fr:xe,a=[];var h=this._getSourceMetaRawOption()||{},c=u&&u.metaRawOption||{},v=rt(h.seriesLayoutBy,c.seriesLayoutBy)||null,d=rt(h.sourceHeader,c.sourceHeader),p=rt(h.dimensions,c.dimensions),g=v!==c.seriesLayoutBy||!!d!=!!c.sourceHeader||p;i=g?[kf(s,{seriesLayoutBy:v,sourceHeader:d,dimensions:p},l)]:[]}else{var y=t;if(n){var m=this._applyTransform(e);i=m.sourceList,a=m.upstreamSignList}else{var _=y.get("source",!0);i=[kf(_,this._getSourceMetaRawOption(),null)],a=[]}}this._setLocalSource(i,a)},r.prototype._applyTransform=function(t){var e=this._sourceHost,n=e.get("transform",!0),i=e.get("fromTransformResult",!0);if(i!=null){var a="";t.length!==1&&Id(a)}var o,s=[],l=[];return M(t,function(u){u.prepareSource();var f=u.getSource(i||0),h="";i!=null&&!f&&Id(h),s.push(f),l.push(u._getVersionSign())}),n?o=hD(n,s,{datasetIndex:e.componentIndex}):i!=null&&(o=[YC(s[0])]),{sourceList:o,upstreamSignList:l}},r.prototype._isDirty=function(){if(this._dirty)return!0;for(var t=this._getUpstreamSourceManagers(),e=0;e<t.length;e++){var n=t[e];if(n._isDirty()||this._upstreamSignList[e]!==n._getVersionSign())return!0}},r.prototype.getSource=function(t){t=t||0;var e=this._sourceList[t];if(!e){var n=this._getUpstreamSourceManagers();return n[0]&&n[0].getSource(t)}return e},r.prototype.getSharedDataStore=function(t){var e=t.makeStoreSchema();return this._innerGetDataStore(e.dimensions,t.source,e.hash)},r.prototype._innerGetDataStore=function(t,e,n){var i=0,a=this._storeList,o=a[i];o||(o=a[i]={});var s=o[n];if(!s){var l=this._getUpstreamSourceManagers()[0];bo(this._sourceHost)&&l?s=l._innerGetDataStore(t,e,n):(s=new Of,s.initData(new _0(e,t.length),t)),o[n]=s}return s},r.prototype._getUpstreamSourceManagers=function(){var t=this._sourceHost;if(bo(t)){var e=Jh(t);return e?[e.getSourceManager()]:[]}else return H(SC(t),function(n){return n.getSourceManager()})},r.prototype._getSourceMetaRawOption=function(){var t=this._sourceHost,e,n,i;if(bo(t))e=t.get("seriesLayoutBy",!0),n=t.get("sourceHeader",!0),i=t.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var a=t;e=a.get("seriesLayoutBy",!0),n=a.get("sourceHeader",!0),i=a.get("dimensions",!0)}return{seriesLayoutBy:e,sourceHeader:n,dimensions:i}},r}();function Md(r){var t=r.option.transform;t&&fs(r.option.transform)}function bo(r){return r.mainType==="series"}function Id(r){throw new Error(r)}var gD="line-height:1";function L0(r){var t=r.lineHeight;return t==null?gD:"line-height:"+re(t+"")+"px"}function P0(r,t){var e=r.color||"#6e7079",n=r.fontSize||12,i=r.fontWeight||"400",a=r.color||"#464646",o=r.fontSize||14,s=r.fontWeight||"900";return t==="html"?{nameStyle:"font-size:"+re(n+"")+"px;color:"+re(e)+";font-weight:"+re(i+""),valueStyle:"font-size:"+re(o+"")+"px;color:"+re(a)+";font-weight:"+re(s+"")}:{nameStyle:{fontSize:n,fill:e,fontWeight:i},valueStyle:{fontSize:o,fill:a,fontWeight:s}}}var yD=[0,10,20,30],mD=["",`
`,`

`,`


`];function Mn(r,t){return t.type=r,t}function Bf(r){return r.type==="section"}function R0(r){return Bf(r)?_D:SD}function E0(r){if(Bf(r)){var t=0,e=r.blocks.length,n=e>1||e>0&&!r.noHeader;return M(r.blocks,function(i){var a=E0(i);a>=t&&(t=a+ +(n&&(!a||Bf(i)&&!i.noHeader)))}),t}return 0}function _D(r,t,e,n){var i=t.noHeader,a=xD(E0(t)),o=[],s=t.blocks||[];je(!s||V(s)),s=s||[];var l=r.orderMode;if(t.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(tr(u,l)){var f=new C0(u[l],null);s.sort(function(p,g){return f.evaluate(p.sortParam,g.sortParam)})}else l==="seriesDesc"&&s.reverse()}M(s,function(p,g){var y=t.valueFormatter,m=R0(p)(y?F(F({},r),{valueFormatter:y}):r,p,g>0?a.html:0,n);m!=null&&o.push(m)});var h=r.renderMode==="richText"?o.join(a.richText):Nf(n,o.join(""),i?e:a.html);if(i)return h;var c=Rf(t.header,"ordinal",r.useUTC),v=P0(n,r.renderMode).nameStyle,d=L0(n);return r.renderMode==="richText"?k0(r,c,v)+a.richText+h:Nf(n,'<div style="'+v+";"+d+';">'+re(c)+"</div>"+h,e)}function SD(r,t,e,n){var i=r.renderMode,a=t.noName,o=t.noValue,s=!t.markerType,l=t.name,u=r.useUTC,f=t.valueFormatter||r.valueFormatter||function(S){return S=V(S)?S:[S],H(S,function(w,x){return Rf(w,V(v)?v[x]:v,u)})};if(!(a&&o)){var h=s?"":r.markupStyleCreator.makeTooltipMarker(t.markerType,t.markerColor||"#333",i),c=a?"":Rf(l,"ordinal",u),v=t.valueType,d=o?[]:f(t.value,t.dataIndex),p=!s||!a,g=!s&&a,y=P0(n,i),m=y.nameStyle,_=y.valueStyle;return i==="richText"?(s?"":h)+(a?"":k0(r,c,m))+(o?"":TD(r,d,p,g,_)):Nf(n,(s?"":h)+(a?"":wD(c,!s,m))+(o?"":bD(d,p,g,_)),e)}}function Ld(r,t,e,n,i,a){if(r){var o=R0(r),s={useUTC:i,renderMode:e,orderMode:n,markupStyleCreator:t,valueFormatter:r.valueFormatter};return o(s,r,0,a)}}function xD(r){return{html:yD[r],richText:mD[r]}}function Nf(r,t,e){var n='<div style="clear:both"></div>',i="margin: "+e+"px 0 0",a=L0(r);return'<div style="'+i+";"+a+';">'+t+n+"</div>"}function wD(r,t,e){var n=t?"margin-left:2px":"";return'<span style="'+e+";"+n+'">'+re(r)+"</span>"}function bD(r,t,e,n){var i=e?"10px":"20px",a=t?"float:right;margin-left:"+i:"";return r=V(r)?r:[r],'<span style="'+a+";"+n+'">'+H(r,function(o){return re(o)}).join("&nbsp;&nbsp;")+"</span>"}function k0(r,t,e){return r.markupStyleCreator.wrapRichTextStyle(t,e)}function TD(r,t,e,n,i){var a=[i],o=n?10:20;return e&&a.push({padding:[0,0,0,o],align:"right"}),r.markupStyleCreator.wrapRichTextStyle(V(t)?t.join("  "):t,a)}function O0(r,t){var e=r.getData().getItemVisual(t,"style"),n=e[r.visualDrawType];return An(n)}function B0(r,t){var e=r.get("padding");return e??(t==="richText"?[8,10]:10)}var pu=function(){function r(){this.richTextStyles={},this._nextStyleNameId=Jy()}return r.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},r.prototype.makeTooltipMarker=function(t,e,n){var i=n==="richText"?this._generateStyleName():null,a=fC({color:e,type:t,renderMode:n,markerId:i});return W(a)?a:(this.richTextStyles[i]=a.style,a.content)},r.prototype.wrapRichTextStyle=function(t,e){var n={};V(e)?M(e,function(a){return F(n,a)}):F(n,e);var i=this._generateStyleName();return this.richTextStyles[i]=n,"{"+i+"|"+t+"}"},r}();function CD(r){var t=r.series,e=r.dataIndex,n=r.multipleSeries,i=t.getData(),a=i.mapDimensionsAll("defaultedTooltip"),o=a.length,s=t.getRawValue(e),l=V(s),u=O0(t,e),f,h,c,v;if(o>1||l&&!o){var d=DD(s,t,e,a,u);f=d.inlineValues,h=d.inlineValueTypes,c=d.blocks,v=d.inlineValues[0]}else if(o){var p=i.getDimensionInfo(a[0]);v=f=Ti(i,e,a[0]),h=p.type}else v=f=l?s[0]:s;var g=Lh(t),y=g&&t.name||"",m=i.getName(e),_=n?y:m;return Mn("section",{header:y,noHeader:n||!g,sortParam:v,blocks:[Mn("nameValue",{markerType:"item",markerColor:u,name:_,noName:!Ze(_),value:f,valueType:h,dataIndex:e})].concat(c||[])})}function DD(r,t,e,n,i){var a=t.getData(),o=zr(r,function(h,c,v){var d=a.getDimensionInfo(v);return h=h||d&&d.tooltip!==!1&&d.displayName!=null},!1),s=[],l=[],u=[];n.length?M(n,function(h){f(Ti(a,e,h),h)}):M(r,f);function f(h,c){var v=a.getDimensionInfo(c);!v||v.otherDims.tooltip===!1||(o?u.push(Mn("nameValue",{markerType:"subItem",markerColor:i,name:v.displayName,value:h,valueType:v.type})):(s.push(h),l.push(v.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var Tr=_t();function To(r,t){return r.getName(t)||r.getId(t)}var as="__universalTransitionEnabled",se=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e._selectedDataIndicesMap={},e}return t.prototype.init=function(e,n,i){this.seriesIndex=this.componentIndex,this.dataTask=Da({count:MD,reset:ID}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(e,i);var a=Tr(this).sourceManager=new I0(this);a.prepareSource();var o=this.getInitialData(e,i);Rd(o,this),this.dataTask.context.data=o,Tr(this).dataBeforeProcessed=o,Pd(this),this._initSelectedMapFromData(o)},t.prototype.mergeDefaultAndTheme=function(e,n){var i=za(this),a=i?hl(e):{},o=this.subType;ht.hasClass(o)&&(o+="Series"),nt(e,n.getTheme().get(this.subType)),nt(e,this.getDefaultOption()),mf(e,"label",["show"]),this.fillDataTextStyle(e.data),i&&bi(e,a,i)},t.prototype.mergeOption=function(e,n){e=nt(this.option,e,!0),this.fillDataTextStyle(e.data);var i=za(this);i&&bi(this.option,e,i);var a=Tr(this).sourceManager;a.dirty(),a.prepareSource();var o=this.getInitialData(e,n);Rd(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,Tr(this).dataBeforeProcessed=o,Pd(this),this._initSelectedMapFromData(o)},t.prototype.fillDataTextStyle=function(e){if(e&&!oe(e))for(var n=["show"],i=0;i<e.length;i++)e[i]&&e[i].label&&mf(e[i],"label",n)},t.prototype.getInitialData=function(e,n){},t.prototype.appendData=function(e){var n=this.getRawData();n.appendData(e.data)},t.prototype.getData=function(e){var n=Ff(this);if(n){var i=n.context.data;return e==null||!i.getLinkedData?i:i.getLinkedData(e)}else return Tr(this).data},t.prototype.getAllData=function(){var e=this.getData();return e&&e.getLinkedDataAll?e.getLinkedDataAll():[{data:e}]},t.prototype.setData=function(e){var n=Ff(this);if(n){var i=n.context;i.outputData=e,n!==this.dataTask&&(i.data=e)}Tr(this).data=e},t.prototype.getEncode=function(){var e=this.get("encode",!0);if(e)return $(e)},t.prototype.getSourceManager=function(){return Tr(this).sourceManager},t.prototype.getSource=function(){return this.getSourceManager().getSource()},t.prototype.getRawData=function(){return Tr(this).dataBeforeProcessed},t.prototype.getColorBy=function(){var e=this.get("colorBy");return e||"series"},t.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},t.prototype.getBaseAxis=function(){var e=this.coordinateSystem;return e&&e.getBaseAxis&&e.getBaseAxis()},t.prototype.formatTooltip=function(e,n,i){return CD({series:this,dataIndex:e,multipleSeries:n})},t.prototype.isAnimationEnabled=function(){var e=this.ecModel;if(J.node&&!(e&&e.ssr))return!1;var n=this.getShallow("animation");return n&&this.getData().count()>this.getShallow("animationThreshold")&&(n=!1),!!n},t.prototype.restoreData=function(){this.dataTask.dirty()},t.prototype.getColorFromPalette=function(e,n,i){var a=this.ecModel,o=jh.prototype.getColorFromPalette.call(this,e,n,i);return o||(o=a.getColorFromPalette(e,n,i)),o},t.prototype.coordDimToDataDim=function(e){return this.getRawData().mapDimensionsAll(e)},t.prototype.getProgressive=function(){return this.get("progressive")},t.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},t.prototype.select=function(e,n){this._innerSelect(this.getData(n),e)},t.prototype.unselect=function(e,n){var i=this.option.selectedMap;if(i){var a=this.option.selectedMode,o=this.getData(n);if(a==="series"||i==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<e.length;s++){var l=e[s],u=To(o,l);i[u]=!1,this._selectedDataIndicesMap[u]=-1}}},t.prototype.toggleSelect=function(e,n){for(var i=[],a=0;a<e.length;a++)i[0]=e[a],this.isSelected(e[a],n)?this.unselect(i,n):this.select(i,n)},t.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var e=this._selectedDataIndicesMap,n=mt(e),i=[],a=0;a<n.length;a++){var o=e[n[a]];o>=0&&i.push(o)}return i},t.prototype.isSelected=function(e,n){var i=this.option.selectedMap;if(!i)return!1;var a=this.getData(n);return(i==="all"||i[To(a,e)])&&!a.getItemModel(e).get(["select","disabled"])},t.prototype.isUniversalTransitionEnabled=function(){if(this[as])return!0;var e=this.option.universalTransition;return e?e===!0?!0:e&&e.enabled:!1},t.prototype._innerSelect=function(e,n){var i,a,o=this.option,s=o.selectedMode,l=n.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){Y(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,f=0;f<l;f++){var h=n[f],c=To(e,h);u[c]=!0,this._selectedDataIndicesMap[c]=e.getRawIndex(h)}}else if(s==="single"||s===!0){var v=n[l-1],c=To(e,v);o.selectedMap=(i={},i[c]=!0,i),this._selectedDataIndicesMap=(a={},a[c]=e.getRawIndex(v),a)}}},t.prototype._initSelectedMapFromData=function(e){if(!this.option.selectedMap){var n=[];e.hasItemOption&&e.each(function(i){var a=e.getRawDataItem(i);a&&a.selected&&n.push(i)}),n.length>0&&this._innerSelect(e,n)}},t.registerClass=function(e){return ht.registerClass(e)},t.protoInitialize=function(){var e=t.prototype;e.type="series.__base__",e.seriesIndex=0,e.ignoreStyleOnData=!1,e.hasSymbolVisual=!1,e.defaultSymbol="circle",e.visualStyleAccessPath="itemStyle",e.visualDrawType="fill"}(),t}(ht);Oe(se,JC);Oe(se,jh);om(se,ht);function Pd(r){var t=r.name;Lh(r)||(r.name=AD(r)||t)}function AD(r){var t=r.getRawData(),e=t.mapDimensionsAll("seriesName"),n=[];return M(e,function(i){var a=t.getDimensionInfo(i);a.displayName&&n.push(a.displayName)}),n.join(" ")}function MD(r){return r.model.getRawData().count()}function ID(r){var t=r.model;return t.setData(t.getRawData().cloneShallow()),LD}function LD(r,t){t.outputData&&r.end>t.outputData.count()&&t.model.getRawData().cloneShallow(t.outputData)}function Rd(r,t){M(ox(r.CHANGABLE_METHODS,r.DOWNSAMPLE_METHODS),function(e){r.wrapMethod(e,vt(PD,t))})}function PD(r,t){var e=Ff(r);return e&&e.setOutputEnd((t||this).count()),t}function Ff(r){var t=(r.ecModel||{}).scheduler,e=t&&t.getPipeline(r.uid);if(e){var n=e.currentTask;if(n){var i=n.agentStubMap;i&&(n=i.get(r.uid))}return n}}var Jt=function(){function r(){this.group=new yt,this.uid=to("viewComponent")}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,n,i){},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,n,i){},r.prototype.updateLayout=function(t,e,n,i){},r.prototype.updateVisual=function(t,e,n,i){},r.prototype.toggleBlurSeries=function(t,e,n){},r.prototype.eachRendered=function(t){var e=this.group;e&&e.traverse(t)},r}();Rh(Jt);Xs(Jt);function av(){var r=_t();return function(t){var e=r(t),n=t.pipelineContext,i=!!e.large,a=!!e.progressiveRender,o=e.large=!!(n&&n.large),s=e.progressiveRender=!!(n&&n.progressiveRender);return(i!==o||a!==s)&&"reset"}}var N0=_t(),RD=av(),Wt=function(){function r(){this.group=new yt,this.uid=to("viewChart"),this.renderTask=Da({plan:ED,reset:kD}),this.renderTask.context={view:this}}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,n,i){},r.prototype.highlight=function(t,e,n,i){var a=t.getData(i&&i.dataType);a&&kd(a,i,"emphasis")},r.prototype.downplay=function(t,e,n,i){var a=t.getData(i&&i.dataType);a&&kd(a,i,"normal")},r.prototype.remove=function(t,e){this.group.removeAll()},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,n,i){this.render(t,e,n,i)},r.prototype.updateLayout=function(t,e,n,i){this.render(t,e,n,i)},r.prototype.updateVisual=function(t,e,n,i){this.render(t,e,n,i)},r.prototype.eachRendered=function(t){rl(this.group,t)},r.markUpdateMethod=function(t,e){N0(t).updateMethod=e},r.protoInitialize=function(){var t=r.prototype;t.type="chart"}(),r}();function Ed(r,t,e){r&&Df(r)&&(t==="emphasis"?xi:wi)(r,e)}function kd(r,t,e){var n=Dn(r,t),i=t&&t.highlightKey!=null?iT(t.highlightKey):null;n!=null?M(It(n),function(a){Ed(r.getItemGraphicEl(a),e,i)}):r.eachItemGraphicEl(function(a){Ed(a,e,i)})}Rh(Wt);Xs(Wt);function ED(r){return RD(r.model)}function kD(r){var t=r.model,e=r.ecModel,n=r.api,i=r.payload,a=t.pipelineContext.progressiveRender,o=r.view,s=i&&N0(i).updateMethod,l=a?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](t,e,n,i),OD[l]}var OD={incrementalPrepareRender:{progress:function(r,t){t.view.incrementalRender(r,t.model,t.ecModel,t.api,t.payload)}},render:{forceFirstProgress:!0,progress:function(r,t){t.view.render(t.model,t.ecModel,t.api,t.payload)}}},Cs="\0__throttleOriginMethod",Od="\0__throttleRate",Bd="\0__throttleType";function ov(r,t,e){var n,i=0,a=0,o=null,s,l,u,f;t=t||0;function h(){a=new Date().getTime(),o=null,r.apply(l,u||[])}var c=function(){for(var v=[],d=0;d<arguments.length;d++)v[d]=arguments[d];n=new Date().getTime(),l=this,u=v;var p=f||t,g=f||e;f=null,s=n-(g?i:a)-p,clearTimeout(o),g?o=setTimeout(h,p):s>=0?h():o=setTimeout(h,-s),i=n};return c.clear=function(){o&&(clearTimeout(o),o=null)},c.debounceNextCall=function(v){f=v},c}function F0(r,t,e,n){var i=r[t];if(i){var a=i[Cs]||i,o=i[Bd],s=i[Od];if(s!==e||o!==n){if(e==null)return r[t]=a;i=r[t]=ov(a,e,n==="debounce"),i[Cs]=a,i[Bd]=n,i[Od]=e}return i}}function zf(r,t){var e=r[t];e&&e[Cs]&&(e.clear&&e.clear(),r[t]=e[Cs])}var Nd=_t(),Fd={itemStyle:ka(Zm,!0),lineStyle:ka(Xm,!0)},BD={lineStyle:"stroke",itemStyle:"fill"};function z0(r,t){var e=r.visualStyleMapper||Fd[t];return e||(console.warn("Unknown style type '"+t+"'."),Fd.itemStyle)}function V0(r,t){var e=r.visualDrawType||BD[t];return e||(console.warn("Unknown style type '"+t+"'."),"fill")}var ND={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData(),n=r.visualStyleAccessPath||"itemStyle",i=r.getModel(n),a=z0(r,n),o=a(i),s=i.getShallow("decal");s&&(e.setVisual("decal",s),s.dirty=!0);var l=V0(r,n),u=o[l],f=q(u)?u:null,h=o.fill==="auto"||o.stroke==="auto";if(!o[l]||f||h){var c=r.getColorFromPalette(r.name,null,t.getSeriesCount());o[l]||(o[l]=c,e.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||q(o.fill)?c:o.fill,o.stroke=o.stroke==="auto"||q(o.stroke)?c:o.stroke}if(e.setVisual("style",o),e.setVisual("drawType",l),!t.isSeriesFiltered(r)&&f)return e.setVisual("colorFromPalette",!1),{dataEach:function(v,d){var p=r.getDataParams(d),g=F({},o);g[l]=f(p),v.setItemVisual(d,"style",g)}}}},$i=new wt,FD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!(r.ignoreStyleOnData||t.isSeriesFiltered(r))){var e=r.getData(),n=r.visualStyleAccessPath||"itemStyle",i=z0(r,n),a=e.getVisual("drawType");return{dataEach:e.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[n]){$i.option=l[n];var u=i($i),f=o.ensureUniqueItemVisual(s,"style");F(f,u),$i.option.decal&&(o.setItemVisual(s,"decal",$i.option.decal),$i.option.decal.dirty=!0),a in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},zD={performRawSeries:!0,overallReset:function(r){var t=$();r.eachSeries(function(e){var n=e.getColorBy();if(!e.isColorBySeries()){var i=e.type+"-"+n,a=t.get(i);a||(a={},t.set(i,a)),Nd(e).scope=a}}),r.eachSeries(function(e){if(!(e.isColorBySeries()||r.isSeriesFiltered(e))){var n=e.getRawData(),i={},a=e.getData(),o=Nd(e).scope,s=e.visualStyleAccessPath||"itemStyle",l=V0(e,s);a.each(function(u){var f=a.getRawIndex(u);i[f]=u}),n.each(function(u){var f=i[u],h=a.getItemVisual(f,"colorFromPalette");if(h){var c=a.ensureUniqueItemVisual(f,"style"),v=n.getName(u)||u+"",d=n.count();c[l]=e.getColorFromPalette(v,o,d)}})}})}},Co=Math.PI;function VD(r,t){t=t||{},Q(t,{text:"loading",textColor:"#000",fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255, 255, 255, 0.8)",showSpinner:!0,color:"#5470c6",spinnerRadius:10,lineWidth:5,zlevel:0});var e=new yt,n=new St({style:{fill:t.maskColor},zlevel:t.zlevel,z:1e4});e.add(n);var i=new Ct({style:{text:t.text,fill:t.textColor,fontSize:t.fontSize,fontWeight:t.fontWeight,fontStyle:t.fontStyle,fontFamily:t.fontFamily},zlevel:t.zlevel,z:10001}),a=new St({style:{fill:"none"},textContent:i,textConfig:{position:"right",distance:10},zlevel:t.zlevel,z:10001});e.add(a);var o;return t.showSpinner&&(o=new js({shape:{startAngle:-Co/2,endAngle:-Co/2+.1,r:t.spinnerRadius},style:{stroke:t.color,lineCap:"round",lineWidth:t.lineWidth},zlevel:t.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:Co*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:Co*3/2}).delay(300).start("circularInOut"),e.add(o)),e.resize=function(){var s=i.getBoundingRect().width,l=t.showSpinner?t.spinnerRadius:0,u=(r.getWidth()-l*2-(t.showSpinner&&s?10:0)-s)/2-(t.showSpinner&&s?0:5+s/2)+(t.showSpinner?0:s/2)+(s?0:l),f=r.getHeight()/2;t.showSpinner&&o.setShape({cx:u,cy:f}),a.setShape({x:u-l,y:f-l,width:l*2,height:l*2}),n.setShape({x:0,y:0,width:r.getWidth(),height:r.getHeight()})},e.resize(),e}var G0=function(){function r(t,e,n,i){this._stageTaskMap=$(),this.ecInstance=t,this.api=e,n=this._dataProcessorHandlers=n.slice(),i=this._visualHandlers=i.slice(),this._allHandlers=n.concat(i)}return r.prototype.restoreData=function(t,e){t.restoreData(e),this._stageTaskMap.each(function(n){var i=n.overallTask;i&&i.dirty()})},r.prototype.getPerformArgs=function(t,e){if(t.__pipeline){var n=this._pipelineMap.get(t.__pipeline.id),i=n.context,a=!e&&n.progressiveEnabled&&(!i||i.progressiveRender)&&t.__idxInPipeline>n.blockIndex,o=a?n.step:null,s=i&&i.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},r.prototype.getPipeline=function(t){return this._pipelineMap.get(t)},r.prototype.updateStreamModes=function(t,e){var n=this._pipelineMap.get(t.uid),i=t.getData(),a=i.count(),o=n.progressiveEnabled&&e.incrementalPrepareRender&&a>=n.threshold,s=t.get("large")&&a>=t.get("largeThreshold"),l=t.get("progressiveChunkMode")==="mod"?a:null;t.pipelineContext=n.context={progressiveRender:o,modDataCount:l,large:s}},r.prototype.restorePipelines=function(t){var e=this,n=e._pipelineMap=$();t.eachSeries(function(i){var a=i.getProgressive(),o=i.uid;n.set(o,{id:o,head:null,tail:null,threshold:i.getProgressiveThreshold(),progressiveEnabled:a&&!(i.preventIncremental&&i.preventIncremental()),blockIndex:-1,step:Math.round(a||700),count:0}),e._pipe(i,i.dataTask)})},r.prototype.prepareStageTasks=function(){var t=this._stageTaskMap,e=this.api.getModel(),n=this.api;M(this._allHandlers,function(i){var a=t.get(i.uid)||t.set(i.uid,{}),o="";je(!(i.reset&&i.overallReset),o),i.reset&&this._createSeriesStageTask(i,a,e,n),i.overallReset&&this._createOverallStageTask(i,a,e,n)},this)},r.prototype.prepareView=function(t,e,n,i){var a=t.renderTask,o=a.context;o.model=e,o.ecModel=n,o.api=i,a.__block=!t.incrementalPrepareRender,this._pipe(e,a)},r.prototype.performDataProcessorTasks=function(t,e){this._performStageTasks(this._dataProcessorHandlers,t,e,{block:!0})},r.prototype.performVisualTasks=function(t,e,n){this._performStageTasks(this._visualHandlers,t,e,n)},r.prototype._performStageTasks=function(t,e,n,i){i=i||{};var a=!1,o=this;M(t,function(l,u){if(!(i.visualType&&i.visualType!==l.visualType)){var f=o._stageTaskMap.get(l.uid),h=f.seriesTaskMap,c=f.overallTask;if(c){var v,d=c.agentStubMap;d.each(function(g){s(i,g)&&(g.dirty(),v=!0)}),v&&c.dirty(),o.updatePayload(c,n);var p=o.getPerformArgs(c,i.block);d.each(function(g){g.perform(p)}),c.perform(p)&&(a=!0)}else h&&h.each(function(g,y){s(i,g)&&g.dirty();var m=o.getPerformArgs(g,i.block);m.skip=!l.performRawSeries&&e.isSeriesFiltered(g.context.model),o.updatePayload(g,n),g.perform(m)&&(a=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=a||this.unfinished},r.prototype.performSeriesTasks=function(t){var e;t.eachSeries(function(n){e=n.dataTask.perform()||e}),this.unfinished=e||this.unfinished},r.prototype.plan=function(){this._pipelineMap.each(function(t){var e=t.tail;do{if(e.__block){t.blockIndex=e.__idxInPipeline;break}e=e.getUpstream()}while(e)})},r.prototype.updatePayload=function(t,e){e!=="remain"&&(t.context.payload=e)},r.prototype._createSeriesStageTask=function(t,e,n,i){var a=this,o=e.seriesTaskMap,s=e.seriesTaskMap=$(),l=t.seriesType,u=t.getTargetSeries;t.createOnAllSeries?n.eachRawSeries(f):l?n.eachRawSeriesByType(l,f):u&&u(n,i).each(f);function f(h){var c=h.uid,v=s.set(c,o&&o.get(c)||Da({plan:YD,reset:XD,count:$D}));v.context={model:h,ecModel:n,api:i,useClearVisual:t.isVisual&&!t.isLayout,plan:t.plan,reset:t.reset,scheduler:a},a._pipe(h,v)}},r.prototype._createOverallStageTask=function(t,e,n,i){var a=this,o=e.overallTask=e.overallTask||Da({reset:GD});o.context={ecModel:n,api:i,overallReset:t.overallReset,scheduler:a};var s=o.agentStubMap,l=o.agentStubMap=$(),u=t.seriesType,f=t.getTargetSeries,h=!0,c=!1,v="";je(!t.createOnAllSeries,v),u?n.eachRawSeriesByType(u,d):f?f(n,i).each(d):(h=!1,M(n.getSeries(),d));function d(p){var g=p.uid,y=l.set(g,s&&s.get(g)||(c=!0,Da({reset:HD,onDirty:UD})));y.context={model:p,overallProgress:h},y.agent=o,y.__block=h,a._pipe(p,y)}c&&o.dirty()},r.prototype._pipe=function(t,e){var n=t.uid,i=this._pipelineMap.get(n);!i.head&&(i.head=e),i.tail&&i.tail.pipe(e),i.tail=e,e.__idxInPipeline=i.count++,e.__pipeline=i},r.wrapStageHandler=function(t,e){return q(t)&&(t={overallReset:t,seriesType:qD(t)}),t.uid=to("stageHandler"),e&&(t.visualType=e),t},r}();function GD(r){r.overallReset(r.ecModel,r.api,r.payload)}function HD(r){return r.overallProgress&&WD}function WD(){this.agent.dirty(),this.getDownstream().dirty()}function UD(){this.agent&&this.agent.dirty()}function YD(r){return r.plan?r.plan(r.model,r.ecModel,r.api,r.payload):null}function XD(r){r.useClearVisual&&r.data.clearAllVisual();var t=r.resetDefines=It(r.reset(r.model,r.ecModel,r.api,r.payload));return t.length>1?H(t,function(e,n){return H0(n)}):ZD}var ZD=H0(0);function H0(r){return function(t,e){var n=e.data,i=e.resetDefines[r];if(i&&i.dataEach)for(var a=t.start;a<t.end;a++)i.dataEach(n,a);else i&&i.progress&&i.progress(t,n)}}function $D(r){return r.data.count()}function qD(r){Ds=null;try{r(Ga,W0)}catch{}return Ds}var Ga={},W0={},Ds;U0(Ga,tv);U0(W0,c0);Ga.eachSeriesByType=Ga.eachRawSeriesByType=function(r){Ds=r};Ga.eachComponent=function(r){r.mainType==="series"&&r.subType&&(Ds=r.subType)};function U0(r,t){for(var e in t.prototype)r[e]=qt}var zd=["#37A2DA","#32C5E9","#67E0E3","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#E062AE","#E690D1","#e7bcf3","#9d96f5","#8378EA","#96BFFF"];const KD={color:zd,colorLayer:[["#37A2DA","#ffd85c","#fd7b5f"],["#37A2DA","#67E0E3","#FFDB5C","#ff9f7f","#E062AE","#9d96f5"],["#37A2DA","#32C5E9","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#e7bcf3","#8378EA","#96BFFF"],zd]};var Vt="#B9B8CE",Vd="#100C2A",Do=function(){return{axisLine:{lineStyle:{color:Vt}},splitLine:{lineStyle:{color:"#484753"}},splitArea:{areaStyle:{color:["rgba(255,255,255,0.02)","rgba(255,255,255,0.05)"]}},minorSplitLine:{lineStyle:{color:"#20203B"}}}},Gd=["#4992ff","#7cffb2","#fddd60","#ff6e76","#58d9f9","#05c091","#ff8a45","#8d48e3","#dd79ff"],Y0={darkMode:!0,color:Gd,backgroundColor:Vd,axisPointer:{lineStyle:{color:"#817f91"},crossStyle:{color:"#817f91"},label:{color:"#fff"}},legend:{textStyle:{color:Vt},pageTextStyle:{color:Vt}},textStyle:{color:Vt},title:{textStyle:{color:"#EEF1FA"},subtextStyle:{color:"#B9B8CE"}},toolbox:{iconStyle:{borderColor:Vt}},dataZoom:{borderColor:"#71708A",textStyle:{color:Vt},brushStyle:{color:"rgba(135,163,206,0.3)"},handleStyle:{color:"#353450",borderColor:"#C5CBE3"},moveHandleStyle:{color:"#B0B6C3",opacity:.3},fillerColor:"rgba(135,163,206,0.2)",emphasis:{handleStyle:{borderColor:"#91B7F2",color:"#4D587D"},moveHandleStyle:{color:"#636D9A",opacity:.7}},dataBackground:{lineStyle:{color:"#71708A",width:1},areaStyle:{color:"#71708A"}},selectedDataBackground:{lineStyle:{color:"#87A3CE"},areaStyle:{color:"#87A3CE"}}},visualMap:{textStyle:{color:Vt}},timeline:{lineStyle:{color:Vt},label:{color:Vt},controlStyle:{color:Vt,borderColor:Vt}},calendar:{itemStyle:{color:Vd},dayLabel:{color:Vt},monthLabel:{color:Vt},yearLabel:{color:Vt}},timeAxis:Do(),logAxis:Do(),valueAxis:Do(),categoryAxis:Do(),line:{symbol:"circle"},graph:{color:Gd},gauge:{title:{color:Vt},axisLine:{lineStyle:{color:[[1,"rgba(207,212,219,0.2)"]]}},axisLabel:{color:Vt},detail:{color:"#EEF1FA"}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}}};Y0.categoryAxis.splitLine.show=!1;var QD=function(){function r(){}return r.prototype.normalizeQuery=function(t){var e={},n={},i={};if(W(t)){var a=$e(t);e.mainType=a.main||null,e.subType=a.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};M(t,function(l,u){for(var f=!1,h=0;h<o.length;h++){var c=o[h],v=u.lastIndexOf(c);if(v>0&&v===u.length-c.length){var d=u.slice(0,v);d!=="data"&&(e.mainType=d,e[c.toLowerCase()]=l,f=!0)}}s.hasOwnProperty(u)&&(n[u]=l,f=!0),f||(i[u]=l)})}return{cptQuery:e,dataQuery:n,otherQuery:i}},r.prototype.filter=function(t,e){var n=this.eventInfo;if(!n)return!0;var i=n.targetEl,a=n.packedEvent,o=n.model,s=n.view;if(!o||!s)return!0;var l=e.cptQuery,u=e.dataQuery;return f(l,o,"mainType")&&f(l,o,"subType")&&f(l,o,"index","componentIndex")&&f(l,o,"name")&&f(l,o,"id")&&f(u,a,"name")&&f(u,a,"dataIndex")&&f(u,a,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(t,e.otherQuery,i,a));function f(h,c,v,d){return h[v]==null||c[d||v]===h[v]}},r.prototype.afterTrigger=function(){this.eventInfo=null},r}(),Vf=["symbol","symbolSize","symbolRotate","symbolOffset"],Hd=Vf.concat(["symbolKeepAspect"]),JD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData();if(r.legendIcon&&e.setVisual("legendIcon",r.legendIcon),!r.hasSymbolVisual)return;for(var n={},i={},a=!1,o=0;o<Vf.length;o++){var s=Vf[o],l=r.get(s);q(l)?(a=!0,i[s]=l):n[s]=l}if(n.symbol=n.symbol||r.defaultSymbol,e.setVisual(F({legendIcon:r.legendIcon||n.symbol,symbolKeepAspect:r.get("symbolKeepAspect")},n)),t.isSeriesFiltered(r))return;var u=mt(i);function f(h,c){for(var v=r.getRawValue(c),d=r.getDataParams(c),p=0;p<u.length;p++){var g=u[p];h.setItemVisual(c,g,i[g](v,d))}}return{dataEach:a?f:null}}},jD={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!r.hasSymbolVisual||t.isSeriesFiltered(r))return;var e=r.getData();function n(i,a){for(var o=i.getItemModel(a),s=0;s<Hd.length;s++){var l=Hd[s],u=o.getShallow(l,!0);u!=null&&i.setItemVisual(a,l,u)}}return{dataEach:e.hasItemOption?n:null}}};function tA(r,t,e){switch(e){case"color":var n=r.getItemVisual(t,"style");return n[r.getVisual("drawType")];case"opacity":return r.getItemVisual(t,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getItemVisual(t,e)}}function eA(r,t){switch(t){case"color":var e=r.getVisual("style");return e[r.getVisual("drawType")];case"opacity":return r.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getVisual(t)}}function rA(r,t){function e(n,i){var a=[];return n.eachComponent({mainType:"series",subType:r,query:i},function(o){a.push(o.seriesIndex)}),a}M([[r+"ToggleSelect","toggleSelect"],[r+"Select","select"],[r+"UnSelect","unselect"]],function(n){t(n[0],function(i,a,o){i=F({},i),o.dispatchAction(F(i,{type:n[1],seriesIndex:e(a,i)}))})})}function Zn(r,t,e,n,i){var a=r+t;e.isSilent(a)||n.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=i.selected,f=0;f<u.length;f++)if(u[f].seriesIndex===s){var h=o.getData(),c=Dn(h,i.fromActionPayload);e.trigger(a,{type:a,seriesId:o.id,name:V(c)?h.getName(c[0]):h.getName(c),selected:W(l)?l:F({},l)})}})}function nA(r,t,e){r.on("selectchanged",function(n){var i=e.getModel();n.isFromClick?(Zn("map","selectchanged",t,i,n),Zn("pie","selectchanged",t,i,n)):n.fromAction==="select"?(Zn("map","selected",t,i,n),Zn("pie","selected",t,i,n)):n.fromAction==="unselect"&&(Zn("map","unselected",t,i,n),Zn("pie","unselected",t,i,n))})}function ca(r,t,e){for(var n;r&&!(t(r)&&(n=r,e));)r=r.__hostTarget||r.parent;return n}var iA=Math.round(Math.random()*9),aA=typeof Object.defineProperty=="function",oA=function(){function r(){this._id="__ec_inner_"+iA++}return r.prototype.get=function(t){return this._guard(t)[this._id]},r.prototype.set=function(t,e){var n=this._guard(t);return aA?Object.defineProperty(n,this._id,{value:e,enumerable:!1,configurable:!0}):n[this._id]=e,this},r.prototype.delete=function(t){return this.has(t)?(delete this._guard(t)[this._id],!0):!1},r.prototype.has=function(t){return!!this._guard(t)[this._id]},r.prototype._guard=function(t){if(t!==Object(t))throw TypeError("Value of WeakMap is not a non-null object.");return t},r}(),sA=it.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,n=t.cy,i=t.width/2,a=t.height/2;r.moveTo(e,n-a),r.lineTo(e+i,n+a),r.lineTo(e-i,n+a),r.closePath()}}),lA=it.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,n=t.cy,i=t.width/2,a=t.height/2;r.moveTo(e,n-a),r.lineTo(e+i,n),r.lineTo(e,n+a),r.lineTo(e-i,n),r.closePath()}}),uA=it.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.x,n=t.y,i=t.width/5*3,a=Math.max(i,t.height),o=i/2,s=o*o/(a-o),l=n-a+o+s,u=Math.asin(s/o),f=Math.cos(u)*o,h=Math.sin(u),c=Math.cos(u),v=o*.6,d=o*.7;r.moveTo(e-f,l+s),r.arc(e,l,o,Math.PI-u,Math.PI*2+u),r.bezierCurveTo(e+f-h*v,l+s+c*v,e,n-d,e,n),r.bezierCurveTo(e,n-d,e-f+h*v,l+s+c*v,e-f,l+s),r.closePath()}}),fA=it.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.height,n=t.width,i=t.x,a=t.y,o=n/3*2;r.moveTo(i,a),r.lineTo(i+o,a+e),r.lineTo(i,a+e/4*3),r.lineTo(i-o,a+e),r.lineTo(i,a),r.closePath()}}),hA={line:er,rect:St,roundRect:St,square:St,circle:Ri,diamond:lA,pin:uA,arrow:fA,triangle:sA},vA={line:function(r,t,e,n,i){i.x1=r,i.y1=t+n/2,i.x2=r+e,i.y2=t+n/2},rect:function(r,t,e,n,i){i.x=r,i.y=t,i.width=e,i.height=n},roundRect:function(r,t,e,n,i){i.x=r,i.y=t,i.width=e,i.height=n,i.r=Math.min(e,n)/4},square:function(r,t,e,n,i){var a=Math.min(e,n);i.x=r,i.y=t,i.width=a,i.height=a},circle:function(r,t,e,n,i){i.cx=r+e/2,i.cy=t+n/2,i.r=Math.min(e,n)/2},diamond:function(r,t,e,n,i){i.cx=r+e/2,i.cy=t+n/2,i.width=e,i.height=n},pin:function(r,t,e,n,i){i.x=r+e/2,i.y=t+n/2,i.width=e,i.height=n},arrow:function(r,t,e,n,i){i.x=r+e/2,i.y=t+n/2,i.width=e,i.height=n},triangle:function(r,t,e,n,i){i.cx=r+e/2,i.cy=t+n/2,i.width=e,i.height=n}},Gf={};M(hA,function(r,t){Gf[t]=new r});var cA=it.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(r,t,e){var n=gs(r,t,e),i=this.shape;return i&&i.symbolType==="pin"&&t.position==="inside"&&(n.y=e.y+e.height*.4),n},buildPath:function(r,t,e){var n=t.symbolType;if(n!=="none"){var i=Gf[n];i||(n="rect",i=Gf[n]),vA[n](t.x,t.y,t.width,t.height,i.shape),i.buildPath(r,i.shape,e)}}});function dA(r,t){if(this.type!=="image"){var e=this.style;this.__isEmptyBrush?(e.stroke=r,e.fill=t||"#fff",e.lineWidth=2):this.shape.symbolType==="line"?e.stroke=r:e.fill=r,this.markRedraw()}}function Ee(r,t,e,n,i,a,o){var s=r.indexOf("empty")===0;s&&(r=r.substr(5,1).toLowerCase()+r.substr(6));var l;return r.indexOf("image://")===0?l=Om(r.slice(8),new ut(t,e,n,i),o?"center":"cover"):r.indexOf("path://")===0?l=Hh(r.slice(7),{},new ut(t,e,n,i),o?"center":"cover"):l=new cA({shape:{symbolType:r,x:t,y:e,width:n,height:i}}),l.__isEmptyBrush=s,l.setColor=dA,a&&l.setColor(a),l}function X0(r){return V(r)||(r=[+r,+r]),[r[0]||0,r[1]||0]}function sv(r,t){if(r!=null)return V(r)||(r=[r,r]),[Z(r[0],t[0])||0,Z(rt(r[1],r[0]),t[1])||0]}function Sn(r){return isFinite(r)}function pA(r,t,e){var n=t.x==null?0:t.x,i=t.x2==null?1:t.x2,a=t.y==null?0:t.y,o=t.y2==null?0:t.y2;t.global||(n=n*e.width+e.x,i=i*e.width+e.x,a=a*e.height+e.y,o=o*e.height+e.y),n=Sn(n)?n:0,i=Sn(i)?i:1,a=Sn(a)?a:0,o=Sn(o)?o:0;var s=r.createLinearGradient(n,a,i,o);return s}function gA(r,t,e){var n=e.width,i=e.height,a=Math.min(n,i),o=t.x==null?.5:t.x,s=t.y==null?.5:t.y,l=t.r==null?.5:t.r;t.global||(o=o*n+e.x,s=s*i+e.y,l=l*a),o=Sn(o)?o:.5,s=Sn(s)?s:.5,l=l>=0&&Sn(l)?l:.5;var u=r.createRadialGradient(o,s,0,o,s,l);return u}function Hf(r,t,e){for(var n=t.type==="radial"?gA(r,t,e):pA(r,t,e),i=t.colorStops,a=0;a<i.length;a++)n.addColorStop(i[a].offset,i[a].color);return n}function yA(r,t){if(r===t||!r&&!t)return!1;if(!r||!t||r.length!==t.length)return!0;for(var e=0;e<r.length;e++)if(r[e]!==t[e])return!0;return!1}function Ao(r){return parseInt(r,10)}function Mo(r,t,e){var n=["width","height"][t],i=["clientWidth","clientHeight"][t],a=["paddingLeft","paddingTop"][t],o=["paddingRight","paddingBottom"][t];if(e[n]!=null&&e[n]!=="auto")return parseFloat(e[n]);var s=document.defaultView.getComputedStyle(r);return(r[i]||Ao(s[n])||Ao(r.style[n]))-(Ao(s[a])||0)-(Ao(s[o])||0)|0}function mA(r,t){return!r||r==="solid"||!(t>0)?null:r==="dashed"?[4*t,2*t]:r==="dotted"?[t]:ct(r)?[r]:V(r)?r:null}function Z0(r){var t=r.style,e=t.lineDash&&t.lineWidth>0&&mA(t.lineDash,t.lineWidth),n=t.lineDashOffset;if(e){var i=t.strokeNoScale&&r.getLineScale?r.getLineScale():1;i&&i!==1&&(e=H(e,function(a){return a/i}),n/=i)}return[e,n]}var _A=new yr(!0);function As(r){var t=r.stroke;return!(t==null||t==="none"||!(r.lineWidth>0))}function Wd(r){return typeof r=="string"&&r!=="none"}function Ms(r){var t=r.fill;return t!=null&&t!=="none"}function Ud(r,t){if(t.fillOpacity!=null&&t.fillOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.fillOpacity*t.opacity,r.fill(),r.globalAlpha=e}else r.fill()}function Yd(r,t){if(t.strokeOpacity!=null&&t.strokeOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.strokeOpacity*t.opacity,r.stroke(),r.globalAlpha=e}else r.stroke()}function Wf(r,t,e){var n=sm(t.image,t.__image,e);if(Zs(n)){var i=r.createPattern(n,t.repeat||"repeat");if(typeof DOMMatrix=="function"&&i&&i.setTransform){var a=new DOMMatrix;a.translateSelf(t.x||0,t.y||0),a.rotateSelf(0,0,(t.rotation||0)*sx),a.scaleSelf(t.scaleX||1,t.scaleY||1),i.setTransform(a)}return i}}function SA(r,t,e,n){var i,a=As(e),o=Ms(e),s=e.strokePercent,l=s<1,u=!t.path;(!t.silent||l)&&u&&t.createPathProxy();var f=t.path||_A,h=t.__dirty;if(!n){var c=e.fill,v=e.stroke,d=o&&!!c.colorStops,p=a&&!!v.colorStops,g=o&&!!c.image,y=a&&!!v.image,m=void 0,_=void 0,S=void 0,w=void 0,x=void 0;(d||p)&&(x=t.getBoundingRect()),d&&(m=h?Hf(r,c,x):t.__canvasFillGradient,t.__canvasFillGradient=m),p&&(_=h?Hf(r,v,x):t.__canvasStrokeGradient,t.__canvasStrokeGradient=_),g&&(S=h||!t.__canvasFillPattern?Wf(r,c,t):t.__canvasFillPattern,t.__canvasFillPattern=S),y&&(w=h||!t.__canvasStrokePattern?Wf(r,v,t):t.__canvasStrokePattern,t.__canvasStrokePattern=S),d?r.fillStyle=m:g&&(S?r.fillStyle=S:o=!1),p?r.strokeStyle=_:y&&(w?r.strokeStyle=w:a=!1)}var b=t.getGlobalScale();f.setScale(b[0],b[1],t.segmentIgnoreThreshold);var T,C;r.setLineDash&&e.lineDash&&(i=Z0(t),T=i[0],C=i[1]);var D=!0;(u||h&sa)&&(f.setDPR(r.dpr),l?f.setContext(null):(f.setContext(r),D=!1),f.reset(),t.buildPath(f,t.shape,n),f.toStatic(),t.pathUpdated()),D&&f.rebuildPath(r,l?s:1),T&&(r.setLineDash(T),r.lineDashOffset=C),n||(e.strokeFirst?(a&&Yd(r,e),o&&Ud(r,e)):(o&&Ud(r,e),a&&Yd(r,e))),T&&r.setLineDash([])}function xA(r,t,e){var n=t.__image=sm(e.image,t.__image,t,t.onload);if(!(!n||!Zs(n))){var i=e.x||0,a=e.y||0,o=t.getWidth(),s=t.getHeight(),l=n.width/n.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=n.width,s=n.height),e.sWidth&&e.sHeight){var u=e.sx||0,f=e.sy||0;r.drawImage(n,u,f,e.sWidth,e.sHeight,i,a,o,s)}else if(e.sx&&e.sy){var u=e.sx,f=e.sy,h=o-u,c=s-f;r.drawImage(n,u,f,h,c,i,a,o,s)}else r.drawImage(n,i,a,o,s)}}function wA(r,t,e){var n,i=e.text;if(i!=null&&(i+=""),i){r.font=e.font||Cn,r.textAlign=e.textAlign,r.textBaseline=e.textBaseline;var a=void 0,o=void 0;r.setLineDash&&e.lineDash&&(n=Z0(t),a=n[0],o=n[1]),a&&(r.setLineDash(a),r.lineDashOffset=o),e.strokeFirst?(As(e)&&r.strokeText(i,e.x,e.y),Ms(e)&&r.fillText(i,e.x,e.y)):(Ms(e)&&r.fillText(i,e.x,e.y),As(e)&&r.strokeText(i,e.x,e.y)),a&&r.setLineDash([])}}var Xd=["shadowBlur","shadowOffsetX","shadowOffsetY"],Zd=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function $0(r,t,e,n,i){var a=!1;if(!n&&(e=e||{},t===e))return!1;if(n||t.opacity!==e.opacity){ae(r,i),a=!0;var o=Math.max(Math.min(t.opacity,1),0);r.globalAlpha=isNaN(o)?wn.opacity:o}(n||t.blend!==e.blend)&&(a||(ae(r,i),a=!0),r.globalCompositeOperation=t.blend||wn.blend);for(var s=0;s<Xd.length;s++){var l=Xd[s];(n||t[l]!==e[l])&&(a||(ae(r,i),a=!0),r[l]=r.dpr*(t[l]||0))}return(n||t.shadowColor!==e.shadowColor)&&(a||(ae(r,i),a=!0),r.shadowColor=t.shadowColor||wn.shadowColor),a}function $d(r,t,e,n,i){var a=Ha(t,i.inHover),o=n?null:e&&Ha(e,i.inHover)||{};if(a===o)return!1;var s=$0(r,a,o,n,i);if((n||a.fill!==o.fill)&&(s||(ae(r,i),s=!0),Wd(a.fill)&&(r.fillStyle=a.fill)),(n||a.stroke!==o.stroke)&&(s||(ae(r,i),s=!0),Wd(a.stroke)&&(r.strokeStyle=a.stroke)),(n||a.opacity!==o.opacity)&&(s||(ae(r,i),s=!0),r.globalAlpha=a.opacity==null?1:a.opacity),t.hasStroke()){var l=a.lineWidth,u=l/(a.strokeNoScale&&t.getLineScale?t.getLineScale():1);r.lineWidth!==u&&(s||(ae(r,i),s=!0),r.lineWidth=u)}for(var f=0;f<Zd.length;f++){var h=Zd[f],c=h[0];(n||a[c]!==o[c])&&(s||(ae(r,i),s=!0),r[c]=a[c]||h[1])}return s}function bA(r,t,e,n,i){return $0(r,Ha(t,i.inHover),e&&Ha(e,i.inHover),n,i)}function q0(r,t){var e=t.transform,n=r.dpr||1;e?r.setTransform(n*e[0],n*e[1],n*e[2],n*e[3],n*e[4],n*e[5]):r.setTransform(n,0,0,n,0,0)}function TA(r,t,e){for(var n=!1,i=0;i<r.length;i++){var a=r[i];n=n||a.isZeroArea(),q0(t,a),t.beginPath(),a.buildPath(t,a.shape),t.clip()}e.allClipped=n}function CA(r,t){return r&&t?r[0]!==t[0]||r[1]!==t[1]||r[2]!==t[2]||r[3]!==t[3]||r[4]!==t[4]||r[5]!==t[5]:!(!r&&!t)}var qd=1,Kd=2,Qd=3,Jd=4;function DA(r){var t=Ms(r),e=As(r);return!(r.lineDash||!(+t^+e)||t&&typeof r.fill!="string"||e&&typeof r.stroke!="string"||r.strokePercent<1||r.strokeOpacity<1||r.fillOpacity<1)}function ae(r,t){t.batchFill&&r.fill(),t.batchStroke&&r.stroke(),t.batchFill="",t.batchStroke=""}function Ha(r,t){return t&&r.__hoverStyle||r.style}function K0(r,t){xn(r,t,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function xn(r,t,e,n){var i=t.transform;if(!t.shouldBePainted(e.viewWidth,e.viewHeight,!1,!1)){t.__dirty&=-2,t.__isRendered=!1;return}var a=t.__clipPaths,o=e.prevElClipPaths,s=!1,l=!1;if((!o||yA(a,o))&&(o&&o.length&&(ae(r,e),r.restore(),l=s=!0,e.prevElClipPaths=null,e.allClipped=!1,e.prevEl=null),a&&a.length&&(ae(r,e),r.save(),TA(a,r,e),s=!0),e.prevElClipPaths=a),e.allClipped){t.__isRendered=!1;return}t.beforeBrush&&t.beforeBrush(),t.innerBeforeBrush();var u=e.prevEl;u||(l=s=!0);var f=t instanceof it&&t.autoBatch&&DA(t.style);s||CA(i,u.transform)?(ae(r,e),q0(r,t)):f||ae(r,e);var h=Ha(t,e.inHover);t instanceof it?(e.lastDrawType!==qd&&(l=!0,e.lastDrawType=qd),$d(r,t,u,l,e),(!f||!e.batchFill&&!e.batchStroke)&&r.beginPath(),SA(r,t,h,f),f&&(e.batchFill=h.fill||"",e.batchStroke=h.stroke||"")):t instanceof ms?(e.lastDrawType!==Qd&&(l=!0,e.lastDrawType=Qd),$d(r,t,u,l,e),wA(r,t,h)):t instanceof Ne?(e.lastDrawType!==Kd&&(l=!0,e.lastDrawType=Kd),bA(r,t,u,l,e),xA(r,t,h)):t.getTemporalDisplayables&&(e.lastDrawType!==Jd&&(l=!0,e.lastDrawType=Jd),AA(r,t,e)),f&&n&&ae(r,e),t.innerAfterBrush(),t.afterBrush&&t.afterBrush(),e.prevEl=t,t.__dirty=0,t.__isRendered=!0}function AA(r,t,e){var n=t.getDisplayables(),i=t.getTemporalDisplayables();r.save();var a={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:e.viewWidth,viewHeight:e.viewHeight,inHover:e.inHover},o,s;for(o=t.getCursor(),s=n.length;o<s;o++){var l=n[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),xn(r,l,a,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}for(var u=0,f=i.length;u<f;u++){var l=i[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),xn(r,l,a,u===f-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}t.clearTemporalDisplayables(),t.notClear=!0,r.restore()}var gu=new oA,jd=new qa(100),tp=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function Uf(r,t){if(r==="none")return null;var e=t.getDevicePixelRatio(),n=t.getZr(),i=n.painter.type==="svg";r.dirty&&gu.delete(r);var a=gu.get(r);if(a)return a;var o=Q(r,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=i?1:1/e,gu.set(r,s),r.dirty=!1,s;function l(u){for(var f=[e],h=!0,c=0;c<tp.length;++c){var v=o[tp[c]];if(v!=null&&!V(v)&&!W(v)&&!ct(v)&&typeof v!="boolean"){h=!1;break}f.push(v)}var d;if(h){d=f.join(",")+(i?"-svg":"");var p=jd.get(d);p&&(i?u.svgElement=p:u.image=p)}var g=J0(o.dashArrayX),y=MA(o.dashArrayY),m=Q0(o.symbol),_=IA(g),S=j0(y),w=!i&&Mi.createCanvas(),x=i&&{tag:"g",attrs:{},key:"dcl",children:[]},b=C(),T;w&&(w.width=b.width*e,w.height=b.height*e,T=w.getContext("2d")),D(),h&&jd.put(d,w||x),u.image=w,u.svgElement=x,u.svgWidth=b.width,u.svgHeight=b.height;function C(){for(var A=1,I=0,L=_.length;I<L;++I)A=dc(A,_[I]);for(var P=1,I=0,L=m.length;I<L;++I)P=dc(P,m[I].length);A*=P;var R=S*_.length*m.length;return{width:Math.max(1,Math.min(A,o.maxTileWidth)),height:Math.max(1,Math.min(R,o.maxTileHeight))}}function D(){T&&(T.clearRect(0,0,w.width,w.height),o.backgroundColor&&(T.fillStyle=o.backgroundColor,T.fillRect(0,0,w.width,w.height)));for(var A=0,I=0;I<y.length;++I)A+=y[I];if(A<=0)return;for(var L=-S,P=0,R=0,E=0;L<b.height;){if(P%2===0){for(var O=R/2%m.length,k=0,B=0,z=0;k<b.width*2;){for(var G=0,I=0;I<g[E].length;++I)G+=g[E][I];if(G<=0)break;if(B%2===0){var U=(1-o.symbolSize)*.5,j=k+g[E][B]*U,et=L+y[P]*U,at=g[E][B]*o.symbolSize,Rt=y[P]*o.symbolSize,jt=z/2%m[O].length;Nt(j,et,at,Rt,m[O][jt])}k+=g[E][B],++z,++B,B===g[E].length&&(B=0)}++E,E===g.length&&(E=0)}L+=y[P],++R,++P,P===y.length&&(P=0)}function Nt(Lt,xt,K,ot,ze){var kt=i?1:e,Sr=Ee(ze,Lt*kt,xt*kt,K*kt,ot*kt,o.color,o.symbolKeepAspect);if(i){var ar=n.painter.renderOneToVNode(Sr);ar&&x.children.push(ar)}else K0(T,Sr)}}}}function Q0(r){if(!r||r.length===0)return[["rect"]];if(W(r))return[[r]];for(var t=!0,e=0;e<r.length;++e)if(!W(r[e])){t=!1;break}if(t)return Q0([r]);for(var n=[],e=0;e<r.length;++e)W(r[e])?n.push([r[e]]):n.push(r[e]);return n}function J0(r){if(!r||r.length===0)return[[0,0]];if(ct(r)){var t=Math.ceil(r);return[[t,t]]}for(var e=!0,n=0;n<r.length;++n)if(!ct(r[n])){e=!1;break}if(e)return J0([r]);for(var i=[],n=0;n<r.length;++n)if(ct(r[n])){var t=Math.ceil(r[n]);i.push([t,t])}else{var t=H(r[n],function(s){return Math.ceil(s)});t.length%2===1?i.push(t.concat(t)):i.push(t)}return i}function MA(r){if(!r||typeof r=="object"&&r.length===0)return[0,0];if(ct(r)){var t=Math.ceil(r);return[t,t]}var e=H(r,function(n){return Math.ceil(n)});return r.length%2?e.concat(e):e}function IA(r){return H(r,function(t){return j0(t)})}function j0(r){for(var t=0,e=0;e<r.length;++e)t+=r[e];return r.length%2===1?t*2:t}function LA(r,t){r.eachRawSeries(function(e){if(!r.isSeriesFiltered(e)){var n=e.getData();n.hasItemVisual()&&n.each(function(o){var s=n.getItemVisual(o,"decal");if(s){var l=n.ensureUniqueItemVisual(o,"style");l.decal=Uf(s,t)}});var i=n.getVisual("decal");if(i){var a=n.getVisual("style");a.decal=Uf(i,t)}}})}var Ae=new Be,t_={};function PA(r,t){t_[r]=t}function RA(r){return t_[r]}var EA=1,kA=800,OA=900,BA=1e3,NA=2e3,FA=5e3,e_=1e3,zA=1100,lv=2e3,r_=3e3,VA=4e3,dl=4500,GA=4600,HA=5e3,WA=6e3,n_=7e3,UA={PROCESSOR:{FILTER:BA,SERIES_FILTER:kA,STATISTIC:FA},VISUAL:{LAYOUT:e_,PROGRESSIVE_LAYOUT:zA,GLOBAL:lv,CHART:r_,POST_CHART_LAYOUT:GA,COMPONENT:VA,BRUSH:HA,CHART_ITEM:dl,ARIA:WA,DECAL:n_}},zt="__flagInMainProcess",ee="__pendingUpdate",yu="__needsUpdateStatus",ep=/^[a-zA-Z0-9_]+$/,mu="__connectUpdateStatus",rp=0,YA=1,XA=2;function i_(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];if(this.isDisposed()){this.id;return}return o_(this,r,t)}}function a_(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];return o_(this,r,t)}}function o_(r,t,e){return e[0]=e[0]&&e[0].toLowerCase(),Be.prototype[t].apply(r,e)}var s_=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t}(Be),l_=s_.prototype;l_.on=a_("on");l_.off=a_("off");var $n,_u,Io,Cr,Su,xu,wu,qi,Ki,np,ip,bu,ap,Lo,op,u_,ue,sp,f_=function(r){N(t,r);function t(e,n,i){var a=r.call(this,new QD)||this;a._chartsViews=[],a._chartsMap={},a._componentsViews=[],a._componentsMap={},a._pendingActions=[],i=i||{},W(n)&&(n=h_[n]),a._dom=e;var o="canvas",s="auto",l=!1;i.ssr;var u=a._zr=cc(e,{renderer:i.renderer||o,devicePixelRatio:i.devicePixelRatio,width:i.width,height:i.height,ssr:i.ssr,useDirtyRect:rt(i.useDirtyRect,l),useCoarsePointer:rt(i.useCoarsePointer,s),pointerSize:i.pointerSize});a._ssr=i.ssr,a._throttledZrFlush=ov(dt(u.flush,u),17),n=tt(n),n&&p0(n,!0),a._theme=n,a._locale=nC(i.locale||$m),a._coordSysMgr=new ev;var f=a._api=op(a);function h(c,v){return c.__prio-v.__prio}return Zo(Ls,h),Zo(Yf,h),a._scheduler=new G0(a,f,Yf,Ls),a._messageCenter=new s_,a._initEvents(),a.resize=dt(a.resize,a),u.animation.on("frame",a._onframe,a),np(u,a),ip(u,a),fs(a),a}return t.prototype._onframe=function(){if(!this._disposed){sp(this);var e=this._scheduler;if(this[ee]){var n=this[ee].silent;this[zt]=!0;try{$n(this),Cr.update.call(this,null,this[ee].updateParams)}catch(l){throw this[zt]=!1,this[ee]=null,l}this._zr.flush(),this[zt]=!1,this[ee]=null,qi.call(this,n),Ki.call(this,n)}else if(e.unfinished){var i=EA,a=this._model,o=this._api;e.unfinished=!1;do{var s=+new Date;e.performSeriesTasks(a),e.performDataProcessorTasks(a),xu(this,a),e.performVisualTasks(a),Lo(this,this._model,o,"remain",{}),i-=+new Date-s}while(i>0&&e.unfinished);e.unfinished||this._zr.flush()}}},t.prototype.getDom=function(){return this._dom},t.prototype.getId=function(){return this.id},t.prototype.getZr=function(){return this._zr},t.prototype.isSSR=function(){return this._ssr},t.prototype.setOption=function(e,n,i){if(!this[zt]){if(this._disposed){this.id;return}var a,o,s;if(Y(n)&&(i=n.lazyUpdate,a=n.silent,o=n.replaceMerge,s=n.transition,n=n.notMerge),this[zt]=!0,!this._model||n){var l=new PC(this._api),u=this._theme,f=this._model=new tv;f.scheduler=this._scheduler,f.ssr=this._ssr,f.init(null,null,null,u,this._locale,l)}this._model.setOption(e,{replaceMerge:o},Xf);var h={seriesTransition:s,optionChanged:!0};if(i)this[ee]={silent:a,updateParams:h},this[zt]=!1,this.getZr().wakeUp();else{try{$n(this),Cr.update.call(this,null,h)}catch(c){throw this[ee]=null,this[zt]=!1,c}this._ssr||this._zr.flush(),this[ee]=null,this[zt]=!1,qi.call(this,a),Ki.call(this,a)}}},t.prototype.setTheme=function(){},t.prototype.getModel=function(){return this._model},t.prototype.getOption=function(){return this._model&&this._model.getOption()},t.prototype.getWidth=function(){return this._zr.getWidth()},t.prototype.getHeight=function(){return this._zr.getHeight()},t.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||J.hasGlobalWindow&&window.devicePixelRatio||1},t.prototype.getRenderedCanvas=function(e){return this.renderToCanvas(e)},t.prototype.renderToCanvas=function(e){e=e||{};var n=this._zr.painter;return n.getRenderedCanvas({backgroundColor:e.backgroundColor||this._model.get("backgroundColor"),pixelRatio:e.pixelRatio||this.getDevicePixelRatio()})},t.prototype.renderToSVGString=function(e){e=e||{};var n=this._zr.painter;return n.renderToString({useViewBox:e.useViewBox})},t.prototype.getSvgDataURL=function(){if(J.svgSupported){var e=this._zr,n=e.storage.getDisplayList();return M(n,function(i){i.stopAnimation(null,!0)}),e.painter.toDataURL()}},t.prototype.getDataURL=function(e){if(this._disposed){this.id;return}e=e||{};var n=e.excludeComponents,i=this._model,a=[],o=this;M(n,function(l){i.eachComponent({mainType:l},function(u){var f=o._componentsMap[u.__viewId];f.group.ignore||(a.push(f),f.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(e).toDataURL("image/"+(e&&e.type||"png"));return M(a,function(l){l.group.ignore=!1}),s},t.prototype.getConnectedDataURL=function(e){if(this._disposed){this.id;return}var n=e.type==="svg",i=this.group,a=Math.min,o=Math.max,s=1/0;if(lp[i]){var l=s,u=s,f=-s,h=-s,c=[],v=e&&e.pixelRatio||this.getDevicePixelRatio();M(Ma,function(_,S){if(_.group===i){var w=n?_.getZr().painter.getSvgDom().innerHTML:_.renderToCanvas(tt(e)),x=_.getDom().getBoundingClientRect();l=a(x.left,l),u=a(x.top,u),f=o(x.right,f),h=o(x.bottom,h),c.push({dom:w,left:x.left,top:x.top})}}),l*=v,u*=v,f*=v,h*=v;var d=f-l,p=h-u,g=Mi.createCanvas(),y=cc(g,{renderer:n?"svg":"canvas"});if(y.resize({width:d,height:p}),n){var m="";return M(c,function(_){var S=_.left-l,w=_.top-u;m+='<g transform="translate('+S+","+w+')">'+_.dom+"</g>"}),y.painter.getSvgRoot().innerHTML=m,e.connectedBackgroundColor&&y.painter.setBackgroundColor(e.connectedBackgroundColor),y.refreshImmediately(),y.painter.toDataURL()}else return e.connectedBackgroundColor&&y.add(new St({shape:{x:0,y:0,width:d,height:p},style:{fill:e.connectedBackgroundColor}})),M(c,function(_){var S=new Ne({style:{x:_.left*v-l,y:_.top*v-u,image:_.dom}});y.add(S)}),y.refreshImmediately(),g.toDataURL("image/"+(e&&e.type||"png"))}else return this.getDataURL(e)},t.prototype.convertToPixel=function(e,n){return Su(this,"convertToPixel",e,n)},t.prototype.convertFromPixel=function(e,n){return Su(this,"convertFromPixel",e,n)},t.prototype.containPixel=function(e,n){if(this._disposed){this.id;return}var i=this._model,a,o=xa(i,e);return M(o,function(s,l){l.indexOf("Models")>=0&&M(s,function(u){var f=u.coordinateSystem;if(f&&f.containPoint)a=a||!!f.containPoint(n);else if(l==="seriesModels"){var h=this._chartsMap[u.__viewId];h&&h.containPoint&&(a=a||h.containPoint(n,u))}},this)},this),!!a},t.prototype.getVisual=function(e,n){var i=this._model,a=xa(i,e,{defaultMainType:"series"}),o=a.seriesModel,s=o.getData(),l=a.hasOwnProperty("dataIndexInside")?a.dataIndexInside:a.hasOwnProperty("dataIndex")?s.indexOfRawIndex(a.dataIndex):null;return l!=null?tA(s,l,n):eA(s,n)},t.prototype.getViewOfComponentModel=function(e){return this._componentsMap[e.__viewId]},t.prototype.getViewOfSeriesModel=function(e){return this._chartsMap[e.__viewId]},t.prototype._initEvents=function(){var e=this;M(ZA,function(n){var i=function(a){var o=e.getModel(),s=a.target,l,u=n==="globalout";if(u?l={}:s&&ca(s,function(d){var p=st(d);if(p&&p.dataIndex!=null){var g=p.dataModel||o.getSeriesByIndex(p.seriesIndex);return l=g&&g.getDataParams(p.dataIndex,p.dataType,s)||{},!0}else if(p.eventData)return l=F({},p.eventData),!0},!0),l){var f=l.componentType,h=l.componentIndex;(f==="markLine"||f==="markPoint"||f==="markArea")&&(f="series",h=l.seriesIndex);var c=f&&h!=null&&o.getComponent(f,h),v=c&&e[c.mainType==="series"?"_chartsMap":"_componentsMap"][c.__viewId];l.event=a,l.type=n,e._$eventProcessor.eventInfo={targetEl:s,packedEvent:l,model:c,view:v},e.trigger(n,l)}};i.zrEventfulCallAtLast=!0,e._zr.on(n,i,e)}),M(Aa,function(n,i){e._messageCenter.on(i,function(a){this.trigger(i,a)},e)}),M(["selectchanged"],function(n){e._messageCenter.on(n,function(i){this.trigger(n,i)},e)}),nA(this._messageCenter,this,this._api)},t.prototype.isDisposed=function(){return this._disposed},t.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},t.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var e=this.getDom();e&&nm(this.getDom(),fv,"");var n=this,i=n._api,a=n._model;M(n._componentsViews,function(o){o.dispose(a,i)}),M(n._chartsViews,function(o){o.dispose(a,i)}),n._zr.dispose(),n._dom=n._model=n._chartsMap=n._componentsMap=n._chartsViews=n._componentsViews=n._scheduler=n._api=n._zr=n._throttledZrFlush=n._theme=n._coordSysMgr=n._messageCenter=null,delete Ma[n.id]},t.prototype.resize=function(e){if(!this[zt]){if(this._disposed){this.id;return}this._zr.resize(e);var n=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!n){var i=n.resetOption("media"),a=e&&e.silent;this[ee]&&(a==null&&(a=this[ee].silent),i=!0,this[ee]=null),this[zt]=!0;try{i&&$n(this),Cr.update.call(this,{type:"resize",animation:F({duration:0},e&&e.animation)})}catch(o){throw this[zt]=!1,o}this[zt]=!1,qi.call(this,a),Ki.call(this,a)}}},t.prototype.showLoading=function(e,n){if(this._disposed){this.id;return}if(Y(e)&&(n=e,e=""),e=e||"default",this.hideLoading(),!!Zf[e]){var i=Zf[e](this._api,n),a=this._zr;this._loadingFX=i,a.add(i)}},t.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},t.prototype.makeActionFromEvent=function(e){var n=F({},e);return n.type=Aa[e.type],n},t.prototype.dispatchAction=function(e,n){if(this._disposed){this.id;return}if(Y(n)||(n={silent:!!n}),!!Is[e.type]&&this._model){if(this[zt]){this._pendingActions.push(e);return}var i=n.silent;wu.call(this,e,i);var a=n.flush;a?this._zr.flush():a!==!1&&J.browser.weChat&&this._throttledZrFlush(),qi.call(this,i),Ki.call(this,i)}},t.prototype.updateLabelLayout=function(){Ae.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},t.prototype.appendData=function(e){if(this._disposed){this.id;return}var n=e.seriesIndex,i=this.getModel(),a=i.getSeriesByIndex(n);a.appendData(e),this._scheduler.unfinished=!0,this.getZr().wakeUp()},t.internalField=function(){$n=function(h){var c=h._scheduler;c.restorePipelines(h._model),c.prepareStageTasks(),_u(h,!0),_u(h,!1),c.plan()},_u=function(h,c){for(var v=h._model,d=h._scheduler,p=c?h._componentsViews:h._chartsViews,g=c?h._componentsMap:h._chartsMap,y=h._zr,m=h._api,_=0;_<p.length;_++)p[_].__alive=!1;c?v.eachComponent(function(x,b){x!=="series"&&S(b)}):v.eachSeries(S);function S(x){var b=x.__requireNewView;x.__requireNewView=!1;var T="_ec_"+x.id+"_"+x.type,C=!b&&g[T];if(!C){var D=$e(x.type),A=c?Jt.getClass(D.main,D.sub):Wt.getClass(D.sub);C=new A,C.init(v,m),g[T]=C,p.push(C),y.add(C.group)}x.__viewId=C.__id=T,C.__alive=!0,C.__model=x,C.group.__ecComponentInfo={mainType:x.mainType,index:x.componentIndex},!c&&d.prepareView(C,x,v,m)}for(var _=0;_<p.length;){var w=p[_];w.__alive?_++:(!c&&w.renderTask.dispose(),y.remove(w.group),w.dispose(v,m),p.splice(_,1),g[w.__id]===w&&delete g[w.__id],w.__id=w.group.__ecComponentInfo=null)}},Io=function(h,c,v,d,p){var g=h._model;if(g.setUpdatePayload(v),!d){M([].concat(h._componentsViews).concat(h._chartsViews),w);return}var y={};y[d+"Id"]=v[d+"Id"],y[d+"Index"]=v[d+"Index"],y[d+"Name"]=v[d+"Name"];var m={mainType:d,query:y};p&&(m.subType=p);var _=v.excludeSeriesId,S;_!=null&&(S=$(),M(It(_),function(x){var b=Qe(x,null);b!=null&&S.set(b,!0)})),g&&g.eachComponent(m,function(x){var b=S&&S.get(x.id)!=null;if(!b)if(Gc(v))if(x instanceof se)v.type===bn&&!v.notBlur&&!x.get(["emphasis","disabled"])&&Kb(x,v,h._api);else{var T=Nh(x.mainType,x.componentIndex,v.name,h._api),C=T.focusSelf,D=T.dispatchers;v.type===bn&&C&&!v.notBlur&&Tf(x.mainType,x.componentIndex,h._api),D&&M(D,function(A){v.type===bn?xi(A):wi(A)})}else Af(v)&&x instanceof se&&(jb(x,v,h._api),zc(x),ue(h))},h),g&&g.eachComponent(m,function(x){var b=S&&S.get(x.id)!=null;b||w(h[d==="series"?"_chartsMap":"_componentsMap"][x.__viewId])},h);function w(x){x&&x.__alive&&x[c]&&x[c](x.__model,g,h._api,v)}},Cr={prepareAndUpdate:function(h){$n(this),Cr.update.call(this,h,{optionChanged:h.newOption!=null})},update:function(h,c){var v=this._model,d=this._api,p=this._zr,g=this._coordSysMgr,y=this._scheduler;if(v){v.setUpdatePayload(h),y.restoreData(v,h),y.performSeriesTasks(v),g.create(v,d),y.performDataProcessorTasks(v,h),xu(this,v),g.update(v,d),e(v),y.performVisualTasks(v,h),bu(this,v,d,h,c);var m=v.get("backgroundColor")||"transparent",_=v.get("darkMode");p.setBackgroundColor(m),_!=null&&_!=="auto"&&p.setDarkMode(_),Ae.trigger("afterupdate",v,d)}},updateTransform:function(h){var c=this,v=this._model,d=this._api;if(v){v.setUpdatePayload(h);var p=[];v.eachComponent(function(y,m){if(y!=="series"){var _=c.getViewOfComponentModel(m);if(_&&_.__alive)if(_.updateTransform){var S=_.updateTransform(m,v,d,h);S&&S.update&&p.push(_)}else p.push(_)}});var g=$();v.eachSeries(function(y){var m=c._chartsMap[y.__viewId];if(m.updateTransform){var _=m.updateTransform(y,v,d,h);_&&_.update&&g.set(y.uid,1)}else g.set(y.uid,1)}),e(v),this._scheduler.performVisualTasks(v,h,{setDirty:!0,dirtyMap:g}),Lo(this,v,d,h,{},g),Ae.trigger("afterupdate",v,d)}},updateView:function(h){var c=this._model;c&&(c.setUpdatePayload(h),Wt.markUpdateMethod(h,"updateView"),e(c),this._scheduler.performVisualTasks(c,h,{setDirty:!0}),bu(this,c,this._api,h,{}),Ae.trigger("afterupdate",c,this._api))},updateVisual:function(h){var c=this,v=this._model;v&&(v.setUpdatePayload(h),v.eachSeries(function(d){d.getData().clearAllVisual()}),Wt.markUpdateMethod(h,"updateVisual"),e(v),this._scheduler.performVisualTasks(v,h,{visualType:"visual",setDirty:!0}),v.eachComponent(function(d,p){if(d!=="series"){var g=c.getViewOfComponentModel(p);g&&g.__alive&&g.updateVisual(p,v,c._api,h)}}),v.eachSeries(function(d){var p=c._chartsMap[d.__viewId];p.updateVisual(d,v,c._api,h)}),Ae.trigger("afterupdate",v,this._api))},updateLayout:function(h){Cr.update.call(this,h)}},Su=function(h,c,v,d){if(h._disposed){h.id;return}for(var p=h._model,g=h._coordSysMgr.getCoordinateSystems(),y,m=xa(p,v),_=0;_<g.length;_++){var S=g[_];if(S[c]&&(y=S[c](p,m,d))!=null)return y}},xu=function(h,c){var v=h._chartsMap,d=h._scheduler;c.eachSeries(function(p){d.updateStreamModes(p,v[p.__viewId])})},wu=function(h,c){var v=this,d=this.getModel(),p=h.type,g=h.escapeConnect,y=Is[p],m=y.actionInfo,_=(m.update||"update").split(":"),S=_.pop(),w=_[0]!=null&&$e(_[0]);this[zt]=!0;var x=[h],b=!1;h.batch&&(b=!0,x=H(h.batch,function(P){return P=Q(F({},P),h),P.batch=null,P}));var T=[],C,D=Af(h),A=Gc(h);if(A&&Tm(this._api),M(x,function(P){if(C=y.action(P,v._model,v._api),C=C||F({},P),C.type=m.event||C.type,T.push(C),A){var R=Ph(h),E=R.queryOptionMap,O=R.mainTypeSpecified,k=O?E.keys()[0]:"series";Io(v,S,P,k),ue(v)}else D?(Io(v,S,P,"series"),ue(v)):w&&Io(v,S,P,w.main,w.sub)}),S!=="none"&&!A&&!D&&!w)try{this[ee]?($n(this),Cr.update.call(this,h),this[ee]=null):Cr[S].call(this,h)}catch(P){throw this[zt]=!1,P}if(b?C={type:m.event||p,escapeConnect:g,batch:T}:C=T[0],this[zt]=!1,!c){var I=this._messageCenter;if(I.trigger(C.type,C),D){var L={type:"selectchanged",escapeConnect:g,selected:tT(d),isFromClick:h.isFromClick||!1,fromAction:h.type,fromActionPayload:h};I.trigger(L.type,L)}}},qi=function(h){for(var c=this._pendingActions;c.length;){var v=c.shift();wu.call(this,v,h)}},Ki=function(h){!h&&this.trigger("updated")},np=function(h,c){h.on("rendered",function(v){c.trigger("rendered",v),h.animation.isFinished()&&!c[ee]&&!c._scheduler.unfinished&&!c._pendingActions.length&&c.trigger("finished")})},ip=function(h,c){h.on("mouseover",function(v){var d=v.target,p=ca(d,Df);p&&(Qb(p,v,c._api),ue(c))}).on("mouseout",function(v){var d=v.target,p=ca(d,Df);p&&(Jb(p,v,c._api),ue(c))}).on("click",function(v){var d=v.target,p=ca(d,function(m){return st(m).dataIndex!=null},!0);if(p){var g=p.selected?"unselect":"select",y=st(p);c._api.dispatchAction({type:g,dataType:y.dataType,dataIndexInside:y.dataIndex,seriesIndex:y.seriesIndex,isFromClick:!0})}})};function e(h){h.clearColorPalette(),h.eachSeries(function(c){c.clearColorPalette()})}function n(h){var c=[],v=[],d=!1;if(h.eachComponent(function(m,_){var S=_.get("zlevel")||0,w=_.get("z")||0,x=_.getZLevelKey();d=d||!!x,(m==="series"?v:c).push({zlevel:S,z:w,idx:_.componentIndex,type:m,key:x})}),d){var p=c.concat(v),g,y;Zo(p,function(m,_){return m.zlevel===_.zlevel?m.z-_.z:m.zlevel-_.zlevel}),M(p,function(m){var _=h.getComponent(m.type,m.idx),S=m.zlevel,w=m.key;g!=null&&(S=Math.max(g,S)),w?(S===g&&w!==y&&S++,y=w):y&&(S===g&&S++,y=""),g=S,_.setZLevel(S)})}}bu=function(h,c,v,d,p){n(c),ap(h,c,v,d,p),M(h._chartsViews,function(g){g.__alive=!1}),Lo(h,c,v,d,p),M(h._chartsViews,function(g){g.__alive||g.remove(c,v)})},ap=function(h,c,v,d,p,g){M(g||h._componentsViews,function(y){var m=y.__model;u(m,y),y.render(m,c,v,d),s(m,y),f(m,y)})},Lo=function(h,c,v,d,p,g){var y=h._scheduler;p=F(p||{},{updatedSeries:c.getSeries()}),Ae.trigger("series:beforeupdate",c,v,p);var m=!1;c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];S.__alive=!0;var w=S.renderTask;y.updatePayload(w,d),u(_,S),g&&g.get(_.uid)&&w.dirty(),w.perform(y.getPerformArgs(w))&&(m=!0),S.group.silent=!!_.get("silent"),o(_,S),zc(_)}),y.unfinished=m||y.unfinished,Ae.trigger("series:layoutlabels",c,v,p),Ae.trigger("series:transition",c,v,p),c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];s(_,S),f(_,S)}),a(h,c),Ae.trigger("series:afterupdate",c,v,p)},ue=function(h){h[yu]=!0,h.getZr().wakeUp()},sp=function(h){h[yu]&&(h.getZr().storage.traverse(function(c){ci(c)||i(c)}),h[yu]=!1)};function i(h){for(var c=[],v=h.currentStates,d=0;d<v.length;d++){var p=v[d];p==="emphasis"||p==="blur"||p==="select"||c.push(p)}h.selected&&h.states.select&&c.push("select"),h.hoverState===Ks&&h.states.emphasis?c.push("emphasis"):h.hoverState===qs&&h.states.blur&&c.push("blur"),h.useStates(c)}function a(h,c){var v=h._zr,d=v.storage,p=0;d.traverse(function(g){g.isGroup||p++}),p>c.get("hoverLayerThreshold")&&!J.node&&!J.worker&&c.eachSeries(function(g){if(!g.preventUsingHoverLayer){var y=h._chartsMap[g.__viewId];y.__alive&&y.eachRendered(function(m){m.states.emphasis&&(m.states.emphasis.hoverLayer=!0)})}})}function o(h,c){var v=h.get("blendMode")||null;c.eachRendered(function(d){d.isGroup||(d.style.blend=v)})}function s(h,c){if(!h.preventAutoZ){var v=h.get("z")||0,d=h.get("zlevel")||0;c.eachRendered(function(p){return l(p,v,d,-1/0),!0})}}function l(h,c,v,d){var p=h.getTextContent(),g=h.getTextGuideLine(),y=h.isGroup;if(y)for(var m=h.childrenRef(),_=0;_<m.length;_++)d=Math.max(l(m[_],c,v,d),d);else h.z=c,h.zlevel=v,d=Math.max(h.z2,d);if(p&&(p.z=c,p.zlevel=v,isFinite(d)&&(p.z2=d+2)),g){var S=h.textGuideLineConfig;g.z=c,g.zlevel=v,isFinite(d)&&(g.z2=d+(S&&S.showAbove?1:-1))}return d}function u(h,c){c.eachRendered(function(v){if(!ci(v)){var d=v.getTextContent(),p=v.getTextGuideLine();v.stateTransition&&(v.stateTransition=null),d&&d.stateTransition&&(d.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),v.hasState()?(v.prevStates=v.currentStates,v.clearStates()):v.prevStates&&(v.prevStates=null)}})}function f(h,c){var v=h.getModel("stateAnimation"),d=h.isAnimationEnabled(),p=v.get("duration"),g=p>0?{duration:p,delay:v.get("delay"),easing:v.get("easing")}:null;c.eachRendered(function(y){if(y.states&&y.states.emphasis){if(ci(y))return;if(y instanceof it&&aT(y),y.__dirty){var m=y.prevStates;m&&y.useStates(m)}if(d){y.stateTransition=g;var _=y.getTextContent(),S=y.getTextGuideLine();_&&(_.stateTransition=g),S&&(S.stateTransition=g)}y.__dirty&&i(y)}})}op=function(h){return new(function(c){N(v,c);function v(){return c!==null&&c.apply(this,arguments)||this}return v.prototype.getCoordinateSystems=function(){return h._coordSysMgr.getCoordinateSystems()},v.prototype.getComponentByElement=function(d){for(;d;){var p=d.__ecComponentInfo;if(p!=null)return h._model.getComponent(p.mainType,p.index);d=d.parent}},v.prototype.enterEmphasis=function(d,p){xi(d,p),ue(h)},v.prototype.leaveEmphasis=function(d,p){wi(d,p),ue(h)},v.prototype.enterBlur=function(d){qb(d),ue(h)},v.prototype.leaveBlur=function(d){Sm(d),ue(h)},v.prototype.enterSelect=function(d){xm(d),ue(h)},v.prototype.leaveSelect=function(d){wm(d),ue(h)},v.prototype.getModel=function(){return h.getModel()},v.prototype.getViewOfComponentModel=function(d){return h.getViewOfComponentModel(d)},v.prototype.getViewOfSeriesModel=function(d){return h.getViewOfSeriesModel(d)},v}(c0))(h)},u_=function(h){function c(v,d){for(var p=0;p<v.length;p++){var g=v[p];g[mu]=d}}M(Aa,function(v,d){h._messageCenter.on(d,function(p){if(lp[h.group]&&h[mu]!==rp){if(p&&p.escapeConnect)return;var g=h.makeActionFromEvent(p),y=[];M(Ma,function(m){m!==h&&m.group===h.group&&y.push(m)}),c(y,rp),M(y,function(m){m[mu]!==YA&&m.dispatchAction(g)}),c(y,XA)}})})}}(),t}(Be),uv=f_.prototype;uv.on=i_("on");uv.off=i_("off");uv.one=function(r,t,e){var n=this;function i(){for(var a=[],o=0;o<arguments.length;o++)a[o]=arguments[o];t&&t.apply&&t.apply(this,a),n.off(r,i)}this.on.call(this,r,i,e)};var ZA=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var Is={},Aa={},Yf=[],Xf=[],Ls=[],h_={},Zf={},Ma={},lp={},$A=+new Date-0,fv="_echarts_instance_";function qA(r,t,e){{var n=KA(r);if(n)return n}var i=new f_(r,t,e);return i.id="ec_"+$A++,Ma[i.id]=i,nm(r,fv,i.id),u_(i),Ae.trigger("afterinit",i),i}function KA(r){return Ma[Gw(r,fv)]}function v_(r,t){h_[r]=t}function c_(r){lt(Xf,r)<0&&Xf.push(r)}function d_(r,t){vv(Yf,r,t,NA)}function QA(r){hv("afterinit",r)}function JA(r){hv("afterupdate",r)}function hv(r,t){Ae.on(r,t)}function nr(r,t,e){q(t)&&(e=t,t="");var n=Y(r)?r.type:[r,r={event:t}][0];r.event=(r.event||n).toLowerCase(),t=r.event,!Aa[t]&&(je(ep.test(n)&&ep.test(t)),Is[n]||(Is[n]={action:e,actionInfo:r}),Aa[t]=n)}function jA(r,t){ev.register(r,t)}function tM(r,t){vv(Ls,r,t,e_,"layout")}function kn(r,t){vv(Ls,r,t,r_,"visual")}var up=[];function vv(r,t,e,n,i){if((q(t)||Y(t))&&(e=t,t=n),!(lt(up,e)>=0)){up.push(e);var a=G0.wrapStageHandler(e,i);a.__prio=t,a.__raw=e,r.push(a)}}function p_(r,t){Zf[r]=t}function eM(r,t,e){var n=RA("registerMap");n&&n(r,t,e)}var rM=fD;kn(lv,ND);kn(dl,FD);kn(dl,zD);kn(lv,JD);kn(dl,jD);kn(n_,LA);c_(p0);d_(OA,WC);p_("default",VD);nr({type:bn,event:bn,update:bn},qt);nr({type:ts,event:ts,update:ts},qt);nr({type:wa,event:wa,update:wa},qt);nr({type:es,event:es,update:es},qt);nr({type:ba,event:ba,update:ba},qt);v_("light",KD);v_("dark",Y0);function Qi(r){return r==null?0:r.length||1}function fp(r){return r}var Wa=function(){function r(t,e,n,i,a,o){this._old=t,this._new=e,this._oldKeyGetter=n||fp,this._newKeyGetter=i||fp,this.context=a,this._diffModeMultiple=o==="multiple"}return r.prototype.add=function(t){return this._add=t,this},r.prototype.update=function(t){return this._update=t,this},r.prototype.updateManyToOne=function(t){return this._updateManyToOne=t,this},r.prototype.updateOneToMany=function(t){return this._updateOneToMany=t,this},r.prototype.updateManyToMany=function(t){return this._updateManyToMany=t,this},r.prototype.remove=function(t){return this._remove=t,this},r.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},r.prototype._executeOneToOne=function(){var t=this._old,e=this._new,n={},i=new Array(t.length),a=new Array(e.length);this._initIndexMap(t,null,i,"_oldKeyGetter"),this._initIndexMap(e,n,a,"_newKeyGetter");for(var o=0;o<t.length;o++){var s=i[o],l=n[s],u=Qi(l);if(u>1){var f=l.shift();l.length===1&&(n[s]=l[0]),this._update&&this._update(f,o)}else u===1?(n[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(a,n)},r.prototype._executeMultiple=function(){var t=this._old,e=this._new,n={},i={},a=[],o=[];this._initIndexMap(t,n,a,"_oldKeyGetter"),this._initIndexMap(e,i,o,"_newKeyGetter");for(var s=0;s<a.length;s++){var l=a[s],u=n[l],f=i[l],h=Qi(u),c=Qi(f);if(h>1&&c===1)this._updateManyToOne&&this._updateManyToOne(f,u),i[l]=null;else if(h===1&&c>1)this._updateOneToMany&&this._updateOneToMany(f,u),i[l]=null;else if(h===1&&c===1)this._update&&this._update(f,u),i[l]=null;else if(h>1&&c>1)this._updateManyToMany&&this._updateManyToMany(f,u),i[l]=null;else if(h>1)for(var v=0;v<h;v++)this._remove&&this._remove(u[v]);else this._remove&&this._remove(u)}this._performRestAdd(o,i)},r.prototype._performRestAdd=function(t,e){for(var n=0;n<t.length;n++){var i=t[n],a=e[i],o=Qi(a);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(a[s]);else o===1&&this._add&&this._add(a);e[i]=null}},r.prototype._initIndexMap=function(t,e,n,i){for(var a=this._diffModeMultiple,o=0;o<t.length;o++){var s="_ec_"+this[i](t[o],o);if(a||(n[o]=s),!!e){var l=e[s],u=Qi(l);u===0?(e[s]=o,a&&n.push(s)):u===1?e[s]=[l,o]:l.push(o)}}},r}(),nM=function(){function r(t,e){this._encode=t,this._schema=e}return r.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},r.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},r}();function iM(r,t){var e={},n=e.encode={},i=$(),a=[],o=[],s={};M(r.dimensions,function(c){var v=r.getDimensionInfo(c),d=v.coordDim;if(d){var p=v.coordDimIndex;Tu(n,d)[p]=c,v.isExtraCoord||(i.set(d,1),oM(v.type)&&(a[0]=c),Tu(s,d)[p]=r.getDimensionIndex(v.name)),v.defaultTooltip&&o.push(c)}l0.each(function(g,y){var m=Tu(n,y),_=v.otherDims[y];_!=null&&_!==!1&&(m[_]=v.name)})});var l=[],u={};i.each(function(c,v){var d=n[v];u[v]=d[0],l=l.concat(d)}),e.dataDimsOnCoord=l,e.dataDimIndicesOnCoord=H(l,function(c){return r.getDimensionInfo(c).storeDimIndex}),e.encodeFirstDimNotExtra=u;var f=n.label;f&&f.length&&(a=f.slice());var h=n.tooltip;return h&&h.length?o=h.slice():o.length||(o=a.slice()),n.defaultedLabel=a,n.defaultedTooltip=o,e.userOutput=new nM(s,t),e}function Tu(r,t){return r.hasOwnProperty(t)||(r[t]=[]),r[t]}function aM(r){return r==="category"?"ordinal":r==="time"?"time":"float"}function oM(r){return!(r==="ordinal"||r==="time")}var os=function(){function r(t){this.otherDims={},t!=null&&F(this,t)}return r}(),sM=_t(),lM={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},g_=function(){function r(t){this.dimensions=t.dimensions,this._dimOmitted=t.dimensionOmitted,this.source=t.source,this._fullDimCount=t.fullDimensionCount,this._updateDimOmitted(t.dimensionOmitted)}return r.prototype.isDimensionOmitted=function(){return this._dimOmitted},r.prototype._updateDimOmitted=function(t){this._dimOmitted=t,t&&(this._dimNameMap||(this._dimNameMap=__(this.source)))},r.prototype.getSourceDimensionIndex=function(t){return rt(this._dimNameMap.get(t),-1)},r.prototype.getSourceDimension=function(t){var e=this.source.dimensionsDefine;if(e)return e[t]},r.prototype.makeStoreSchema=function(){for(var t=this._fullDimCount,e=m0(this.source),n=!S_(t),i="",a=[],o=0,s=0;o<t;o++){var l=void 0,u=void 0,f=void 0,h=this.dimensions[s];if(h&&h.storeDimIndex===o)l=e?h.name:null,u=h.type,f=h.ordinalMeta,s++;else{var c=this.getSourceDimension(o);c&&(l=e?c.name:null,u=c.type)}a.push({property:l,type:u,ordinalMeta:f}),e&&l!=null&&(!h||!h.isCalculationCoord)&&(i+=n?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),i+="$",i+=lM[u]||"f",f&&(i+=f.uid),i+="$"}var v=this.source,d=[v.seriesLayoutBy,v.startIndex,i].join("$$");return{dimensions:a,hash:d}},r.prototype.makeOutputDimensionNames=function(){for(var t=[],e=0,n=0;e<this._fullDimCount;e++){var i=void 0,a=this.dimensions[n];if(a&&a.storeDimIndex===e)a.isCalculationCoord||(i=a.name),n++;else{var o=this.getSourceDimension(e);o&&(i=o.name)}t.push(i)}return t},r.prototype.appendCalculationDimension=function(t){this.dimensions.push(t),t.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},r}();function y_(r){return r instanceof g_}function m_(r){for(var t=$(),e=0;e<(r||[]).length;e++){var n=r[e],i=Y(n)?n.name:n;i!=null&&t.get(i)==null&&t.set(i,e)}return t}function __(r){var t=sM(r);return t.dimNameMap||(t.dimNameMap=m_(r.dimensionsDefine))}function S_(r){return r>30}var Ji=Y,Dr=H,uM=typeof Int32Array>"u"?Array:Int32Array,fM="e\0\0",hp=-1,hM=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],vM=["_approximateExtent"],vp,Po,ji,ta,Cu,ea,Du,x_=function(){function r(t,e){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","minmaxDownSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","minmaxDownSample","lttbDownSample"];var n,i=!1;y_(t)?(n=t.dimensions,this._dimOmitted=t.isDimensionOmitted(),this._schema=t):(i=!0,n=t),n=n||["x","y"];for(var a={},o=[],s={},l=!1,u={},f=0;f<n.length;f++){var h=n[f],c=W(h)?new os({name:h}):h instanceof os?h:new os(h),v=c.name;c.type=c.type||"float",c.coordDim||(c.coordDim=v,c.coordDimIndex=0);var d=c.otherDims=c.otherDims||{};o.push(v),a[v]=c,u[v]!=null&&(l=!0),c.createInvertedIndices&&(s[v]=[]),d.itemName===0&&(this._nameDimIdx=f),d.itemId===0&&(this._idDimIdx=f),i&&(c.storeDimIndex=f)}if(this.dimensions=o,this._dimInfos=a,this._initGetDimensionInfo(l),this.hostModel=e,this._invertedIndicesMap=s,this._dimOmitted){var p=this._dimIdxToName=$();M(o,function(g){p.set(a[g].storeDimIndex,g)})}}return r.prototype.getDimension=function(t){var e=this._recognizeDimIndex(t);if(e==null)return t;if(e=t,!this._dimOmitted)return this.dimensions[e];var n=this._dimIdxToName.get(e);if(n!=null)return n;var i=this._schema.getSourceDimension(e);if(i)return i.name},r.prototype.getDimensionIndex=function(t){var e=this._recognizeDimIndex(t);if(e!=null)return e;if(t==null)return-1;var n=this._getDimInfo(t);return n?n.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(t):-1},r.prototype._recognizeDimIndex=function(t){if(ct(t)||t!=null&&!isNaN(t)&&!this._getDimInfo(t)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(t)<0))return+t},r.prototype._getStoreDimIndex=function(t){var e=this.getDimensionIndex(t);return e},r.prototype.getDimensionInfo=function(t){return this._getDimInfo(this.getDimension(t))},r.prototype._initGetDimensionInfo=function(t){var e=this._dimInfos;this._getDimInfo=t?function(n){return e.hasOwnProperty(n)?e[n]:void 0}:function(n){return e[n]}},r.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},r.prototype.mapDimension=function(t,e){var n=this._dimSummary;if(e==null)return n.encodeFirstDimNotExtra[t];var i=n.encode[t];return i?i[e]:null},r.prototype.mapDimensionsAll=function(t){var e=this._dimSummary,n=e.encode[t];return(n||[]).slice()},r.prototype.getStore=function(){return this._store},r.prototype.initData=function(t,e,n){var i=this,a;if(t instanceof Of&&(a=t),!a){var o=this.dimensions,s=rv(t)||Kt(t)?new _0(t,o.length):t;a=new Of;var l=Dr(o,function(u){return{type:i._dimInfos[u].type,property:u}});a.initData(s,l,n)}this._store=a,this._nameList=(e||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,a.count()),this._dimSummary=iM(this,this._schema),this.userOutput=this._dimSummary.userOutput},r.prototype.appendData=function(t){var e=this._store.appendData(t);this._doInit(e[0],e[1])},r.prototype.appendValues=function(t,e){var n=this._store.appendValues(t,e&&e.length),i=n.start,a=n.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),e)for(var s=i;s<a;s++){var l=s-i;this._nameList[s]=e[l],o&&Du(this,s)}},r.prototype._updateOrdinalMeta=function(){for(var t=this._store,e=this.dimensions,n=0;n<e.length;n++){var i=this._dimInfos[e[n]];i.ordinalMeta&&t.collectOrdinalMeta(i.storeDimIndex,i.ordinalMeta)}},r.prototype._shouldMakeIdFromName=function(){var t=this._store.getProvider();return this._idDimIdx==null&&t.getSource().sourceFormat!==Fr&&!t.fillStorage},r.prototype._doInit=function(t,e){if(!(t>=e)){var n=this._store,i=n.getProvider();this._updateOrdinalMeta();var a=this._nameList,o=this._idList,s=i.getSource().sourceFormat,l=s===xe;if(l&&!i.pure)for(var u=[],f=t;f<e;f++){var h=i.getItem(f,u);if(!this.hasItemOption&&Mw(h)&&(this.hasItemOption=!0),h){var c=h.name;a[f]==null&&c!=null&&(a[f]=Qe(c,null));var v=h.id;o[f]==null&&v!=null&&(o[f]=Qe(v,null))}}if(this._shouldMakeIdFromName())for(var f=t;f<e;f++)Du(this,f);vp(this)}},r.prototype.getApproximateExtent=function(t){return this._approximateExtent[t]||this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.setApproximateExtent=function(t,e){e=this.getDimension(e),this._approximateExtent[e]=t.slice()},r.prototype.getCalculationInfo=function(t){return this._calculationInfo[t]},r.prototype.setCalculationInfo=function(t,e){Ji(t)?F(this._calculationInfo,t):this._calculationInfo[t]=e},r.prototype.getName=function(t){var e=this.getRawIndex(t),n=this._nameList[e];return n==null&&this._nameDimIdx!=null&&(n=ji(this,this._nameDimIdx,e)),n==null&&(n=""),n},r.prototype._getCategory=function(t,e){var n=this._store.get(t,e),i=this._store.getOrdinalMeta(t);return i?i.categories[n]:n},r.prototype.getId=function(t){return Po(this,this.getRawIndex(t))},r.prototype.count=function(){return this._store.count()},r.prototype.get=function(t,e){var n=this._store,i=this._dimInfos[t];if(i)return n.get(i.storeDimIndex,e)},r.prototype.getByRawIndex=function(t,e){var n=this._store,i=this._dimInfos[t];if(i)return n.getByRawIndex(i.storeDimIndex,e)},r.prototype.getIndices=function(){return this._store.getIndices()},r.prototype.getDataExtent=function(t){return this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.getSum=function(t){return this._store.getSum(this._getStoreDimIndex(t))},r.prototype.getMedian=function(t){return this._store.getMedian(this._getStoreDimIndex(t))},r.prototype.getValues=function(t,e){var n=this,i=this._store;return V(t)?i.getValues(Dr(t,function(a){return n._getStoreDimIndex(a)}),e):i.getValues(t)},r.prototype.hasValue=function(t){for(var e=this._dimSummary.dataDimIndicesOnCoord,n=0,i=e.length;n<i;n++)if(isNaN(this._store.get(e[n],t)))return!1;return!0},r.prototype.indexOfName=function(t){for(var e=0,n=this._store.count();e<n;e++)if(this.getName(e)===t)return e;return-1},r.prototype.getRawIndex=function(t){return this._store.getRawIndex(t)},r.prototype.indexOfRawIndex=function(t){return this._store.indexOfRawIndex(t)},r.prototype.rawIndexOf=function(t,e){var n=t&&this._invertedIndicesMap[t],i=n&&n[e];return i==null||isNaN(i)?hp:i},r.prototype.indicesOfNearest=function(t,e,n){return this._store.indicesOfNearest(this._getStoreDimIndex(t),e,n)},r.prototype.each=function(t,e,n){q(t)&&(n=e,e=t,t=[]);var i=n||this,a=Dr(ta(t),this._getStoreDimIndex,this);this._store.each(a,i?dt(e,i):e)},r.prototype.filterSelf=function(t,e,n){q(t)&&(n=e,e=t,t=[]);var i=n||this,a=Dr(ta(t),this._getStoreDimIndex,this);return this._store=this._store.filter(a,i?dt(e,i):e),this},r.prototype.selectRange=function(t){var e=this,n={},i=mt(t);return M(i,function(a){var o=e._getStoreDimIndex(a);n[o]=t[a]}),this._store=this._store.selectRange(n),this},r.prototype.mapArray=function(t,e,n){q(t)&&(n=e,e=t,t=[]),n=n||this;var i=[];return this.each(t,function(){i.push(e&&e.apply(this,arguments))},n),i},r.prototype.map=function(t,e,n,i){var a=n||i||this,o=Dr(ta(t),this._getStoreDimIndex,this),s=ea(this);return s._store=this._store.map(o,a?dt(e,a):e),s},r.prototype.modify=function(t,e,n,i){var a=n||i||this,o=Dr(ta(t),this._getStoreDimIndex,this);this._store.modify(o,a?dt(e,a):e)},r.prototype.downSample=function(t,e,n,i){var a=ea(this);return a._store=this._store.downSample(this._getStoreDimIndex(t),e,n,i),a},r.prototype.minmaxDownSample=function(t,e){var n=ea(this);return n._store=this._store.minmaxDownSample(this._getStoreDimIndex(t),e),n},r.prototype.lttbDownSample=function(t,e){var n=ea(this);return n._store=this._store.lttbDownSample(this._getStoreDimIndex(t),e),n},r.prototype.getRawDataItem=function(t){return this._store.getRawDataItem(t)},r.prototype.getItemModel=function(t){var e=this.hostModel,n=this.getRawDataItem(t);return new wt(n,e,e&&e.ecModel)},r.prototype.diff=function(t){var e=this;return new Wa(t?t.getStore().getIndices():[],this.getStore().getIndices(),function(n){return Po(t,n)},function(n){return Po(e,n)})},r.prototype.getVisual=function(t){var e=this._visual;return e&&e[t]},r.prototype.setVisual=function(t,e){this._visual=this._visual||{},Ji(t)?F(this._visual,t):this._visual[t]=e},r.prototype.getItemVisual=function(t,e){var n=this._itemVisuals[t],i=n&&n[e];return i??this.getVisual(e)},r.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},r.prototype.ensureUniqueItemVisual=function(t,e){var n=this._itemVisuals,i=n[t];i||(i=n[t]={});var a=i[e];return a==null&&(a=this.getVisual(e),V(a)?a=a.slice():Ji(a)&&(a=F({},a)),i[e]=a),a},r.prototype.setItemVisual=function(t,e,n){var i=this._itemVisuals[t]||{};this._itemVisuals[t]=i,Ji(e)?F(i,e):i[e]=n},r.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},r.prototype.setLayout=function(t,e){Ji(t)?F(this._layout,t):this._layout[t]=e},r.prototype.getLayout=function(t){return this._layout[t]},r.prototype.getItemLayout=function(t){return this._itemLayouts[t]},r.prototype.setItemLayout=function(t,e,n){this._itemLayouts[t]=n?F(this._itemLayouts[t]||{},e):e},r.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},r.prototype.setItemGraphicEl=function(t,e){var n=this.hostModel&&this.hostModel.seriesIndex;wf(n,this.dataType,t,e),this._graphicEls[t]=e},r.prototype.getItemGraphicEl=function(t){return this._graphicEls[t]},r.prototype.eachItemGraphicEl=function(t,e){M(this._graphicEls,function(n,i){n&&t&&t.call(e,n,i)})},r.prototype.cloneShallow=function(t){return t||(t=new r(this._schema?this._schema:Dr(this.dimensions,this._getDimInfo,this),this.hostModel)),Cu(t,this),t._store=this._store,t},r.prototype.wrapMethod=function(t,e){var n=this[t];q(n)&&(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(t),this[t]=function(){var i=n.apply(this,arguments);return e.apply(this,[i].concat(bh(arguments)))})},r.internalField=function(){vp=function(t){var e=t._invertedIndicesMap;M(e,function(n,i){var a=t._dimInfos[i],o=a.ordinalMeta,s=t._store;if(o){n=e[i]=new uM(o.categories.length);for(var l=0;l<n.length;l++)n[l]=hp;for(var l=0;l<s.count();l++)n[s.get(a.storeDimIndex,l)]=l}})},ji=function(t,e,n){return Qe(t._getCategory(e,n),null)},Po=function(t,e){var n=t._idList[e];return n==null&&t._idDimIdx!=null&&(n=ji(t,t._idDimIdx,e)),n==null&&(n=fM+e),n},ta=function(t){return V(t)||(t=t!=null?[t]:[]),t},ea=function(t){var e=new r(t._schema?t._schema:Dr(t.dimensions,t._getDimInfo,t),t.hostModel);return Cu(e,t),e},Cu=function(t,e){M(hM.concat(e.__wrappedMethods||[]),function(n){e.hasOwnProperty(n)&&(t[n]=e[n])}),t.__wrappedMethods=e.__wrappedMethods,M(vM,function(n){t[n]=tt(e[n])}),t._calculationInfo=F({},e._calculationInfo)},Du=function(t,e){var n=t._nameList,i=t._idList,a=t._nameDimIdx,o=t._idDimIdx,s=n[e],l=i[e];if(s==null&&a!=null&&(n[e]=s=ji(t,a,e)),l==null&&o!=null&&(i[e]=l=ji(t,o,e)),l==null&&s!=null){var u=t._nameRepeatCount,f=u[s]=(u[s]||0)+1;l=s,f>1&&(l+="__ec__"+f),i[e]=l}}}(),r}();function w_(r,t){rv(r)||(r=g0(r)),t=t||{};var e=t.coordDimensions||[],n=t.dimensionsDefine||r.dimensionsDefine||[],i=$(),a=[],o=dM(r,e,n,t.dimensionsCount),s=t.canOmitUnusedDimensions&&S_(o),l=n===r.dimensionsDefine,u=l?__(r):m_(n),f=t.encodeDefine;!f&&t.encodeDefaulter&&(f=t.encodeDefaulter(r,o));for(var h=$(f),c=new A0(o),v=0;v<c.length;v++)c[v]=-1;function d(C){var D=c[C];if(D<0){var A=n[C],I=Y(A)?A:{name:A},L=new os,P=I.name;P!=null&&u.get(P)!=null&&(L.name=L.displayName=P),I.type!=null&&(L.type=I.type),I.displayName!=null&&(L.displayName=I.displayName);var R=a.length;return c[C]=R,L.storeDimIndex=C,a.push(L),L}return a[D]}if(!s)for(var v=0;v<o;v++)d(v);h.each(function(C,D){var A=It(C).slice();if(A.length===1&&!W(A[0])&&A[0]<0){h.set(D,!1);return}var I=h.set(D,[]);M(A,function(L,P){var R=W(L)?u.get(L):L;R!=null&&R<o&&(I[P]=R,g(d(R),D,P))})});var p=0;M(e,function(C){var D,A,I,L;if(W(C))D=C,L={};else{L=C,D=L.name;var P=L.ordinalMeta;L.ordinalMeta=null,L=F({},L),L.ordinalMeta=P,A=L.dimsDef,I=L.otherDims,L.name=L.coordDim=L.coordDimIndex=L.dimsDef=L.otherDims=null}var R=h.get(D);if(R!==!1){if(R=It(R),!R.length)for(var E=0;E<(A&&A.length||1);E++){for(;p<o&&d(p).coordDim!=null;)p++;p<o&&R.push(p++)}M(R,function(O,k){var B=d(O);if(l&&L.type!=null&&(B.type=L.type),g(Q(B,L),D,k),B.name==null&&A){var z=A[k];!Y(z)&&(z={name:z}),B.name=B.displayName=z.name,B.defaultTooltip=z.defaultTooltip}I&&Q(B.otherDims,I)})}});function g(C,D,A){l0.get(D)!=null?C.otherDims[D]=A:(C.coordDim=D,C.coordDimIndex=A,i.set(D,!0))}var y=t.generateCoord,m=t.generateCoordCount,_=m!=null;m=y?m||1:0;var S=y||"value";function w(C){C.name==null&&(C.name=C.coordDim)}if(s)M(a,function(C){w(C)}),a.sort(function(C,D){return C.storeDimIndex-D.storeDimIndex});else for(var x=0;x<o;x++){var b=d(x),T=b.coordDim;T==null&&(b.coordDim=pM(S,i,_),b.coordDimIndex=0,(!y||m<=0)&&(b.isExtraCoord=!0),m--),w(b),b.type==null&&(h0(r,x)===Ot.Must||b.isExtraCoord&&(b.otherDims.itemName!=null||b.otherDims.seriesName!=null))&&(b.type="ordinal")}return cM(a),new g_({source:r,dimensions:a,fullDimensionCount:o,dimensionOmitted:s})}function cM(r){for(var t=$(),e=0;e<r.length;e++){var n=r[e],i=n.name,a=t.get(i)||0;a>0&&(n.name=i+(a-1)),a++,t.set(i,a)}}function dM(r,t,e,n){var i=Math.max(r.dimensionsDetectedCount||1,t.length,e.length,n||0);return M(t,function(a){var o;Y(a)&&(o=a.dimsDef)&&(i=Math.max(i,o.length))}),i}function pM(r,t,e){if(e||t.hasKey(r)){for(var n=0;t.hasKey(r+n);)n++;r+=n}return t.set(r,!0),r}var gM=function(){function r(t){this.coordSysDims=[],this.axisMap=$(),this.categoryAxisMap=$(),this.coordSysName=t}return r}();function yM(r){var t=r.get("coordinateSystem"),e=new gM(t),n=mM[t];if(n)return n(r,e,e.axisMap,e.categoryAxisMap),e}var mM={cartesian2d:function(r,t,e,n){var i=r.getReferringComponents("xAxis",$t).models[0],a=r.getReferringComponents("yAxis",$t).models[0];t.coordSysDims=["x","y"],e.set("x",i),e.set("y",a),qn(i)&&(n.set("x",i),t.firstCategoryDimIndex=0),qn(a)&&(n.set("y",a),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},singleAxis:function(r,t,e,n){var i=r.getReferringComponents("singleAxis",$t).models[0];t.coordSysDims=["single"],e.set("single",i),qn(i)&&(n.set("single",i),t.firstCategoryDimIndex=0)},polar:function(r,t,e,n){var i=r.getReferringComponents("polar",$t).models[0],a=i.findAxisModel("radiusAxis"),o=i.findAxisModel("angleAxis");t.coordSysDims=["radius","angle"],e.set("radius",a),e.set("angle",o),qn(a)&&(n.set("radius",a),t.firstCategoryDimIndex=0),qn(o)&&(n.set("angle",o),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},geo:function(r,t,e,n){t.coordSysDims=["lng","lat"]},parallel:function(r,t,e,n){var i=r.ecModel,a=i.getComponent("parallel",r.get("parallelIndex")),o=t.coordSysDims=a.dimensions.slice();M(a.parallelAxisIndex,function(s,l){var u=i.getComponent("parallelAxis",s),f=o[l];e.set(f,u),qn(u)&&(n.set(f,u),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=l))})}};function qn(r){return r.get("type")==="category"}function _M(r,t,e){e=e||{};var n=e.byIndex,i=e.stackedCoordDimension,a,o,s;SM(t)?a=t:(o=t.schema,a=o.dimensions,s=t.store);var l=!!(r&&r.get("stack")),u,f,h,c;if(M(a,function(m,_){W(m)&&(a[_]=m={name:m}),l&&!m.isExtraCoord&&(!n&&!u&&m.ordinalMeta&&(u=m),!f&&m.type!=="ordinal"&&m.type!=="time"&&(!i||i===m.coordDim)&&(f=m))}),f&&!n&&!u&&(n=!0),f){h="__\0ecstackresult_"+r.id,c="__\0ecstackedover_"+r.id,u&&(u.createInvertedIndices=!0);var v=f.coordDim,d=f.type,p=0;M(a,function(m){m.coordDim===v&&p++});var g={name:h,coordDim:v,coordDimIndex:p,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length},y={name:c,coordDim:c,coordDimIndex:p+1,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length+1};o?(s&&(g.storeDimIndex=s.ensureCalculationDimension(c,d),y.storeDimIndex=s.ensureCalculationDimension(h,d)),o.appendCalculationDimension(g),o.appendCalculationDimension(y)):(a.push(g),a.push(y))}return{stackedDimension:f&&f.name,stackedByDimension:u&&u.name,isStackedByIndex:n,stackedOverDimension:c,stackResultDimension:h}}function SM(r){return!y_(r.schema)}function Ci(r,t){return!!t&&t===r.getCalculationInfo("stackedDimension")}function xM(r,t){return Ci(r,t)?r.getCalculationInfo("stackResultDimension"):t}function wM(r,t){var e=r.get("coordinateSystem"),n=ev.get(e),i;return t&&t.coordSysDims&&(i=H(t.coordSysDims,function(a){var o={name:a},s=t.axisMap.get(a);if(s){var l=s.get("type");o.type=aM(l)}return o})),i||(i=n&&(n.getDimensionsInfo?n.getDimensionsInfo():n.dimensions.slice())||["x","y"]),i}function bM(r,t,e){var n,i;return e&&M(r,function(a,o){var s=a.coordDim,l=e.categoryAxisMap.get(s);l&&(n==null&&(n=o),a.ordinalMeta=l.getOrdinalMeta(),t&&(a.createInvertedIndices=!0)),a.otherDims.itemName!=null&&(i=!0)}),!i&&n!=null&&(r[n].otherDims.itemName=0),n}function pl(r,t,e){e=e||{};var n=t.getSourceManager(),i,a=!1;i=n.getSource(),a=i.sourceFormat===xe;var o=yM(t),s=wM(t,o),l=e.useEncodeDefaulter,u=q(l)?l:l?vt(mC,s,t):null,f={coordDimensions:s,generateCoord:e.generateCoord,encodeDefine:t.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!a},h=w_(i,f),c=bM(h.dimensions,e.createInvertedIndices,o),v=a?null:n.getSharedDataStore(h),d=_M(t,{schema:h,store:v}),p=new x_(h,t);p.setCalculationInfo(d);var g=c!=null&&TM(i)?function(y,m,_,S){return S===c?_:this.defaultDimValueGetter(y,m,_,S)}:null;return p.hasItemOption=!1,p.initData(a?i:v,null,g),p}function TM(r){if(r.sourceFormat===xe){var t=CM(r.data||[]);return!V(Qa(t))}}function CM(r){for(var t=0;t<r.length&&r[t]==null;)t++;return r[t]}var ir=function(){function r(t){this._setting=t||{},this._extent=[1/0,-1/0]}return r.prototype.getSetting=function(t){return this._setting[t]},r.prototype.unionExtent=function(t){var e=this._extent;t[0]<e[0]&&(e[0]=t[0]),t[1]>e[1]&&(e[1]=t[1])},r.prototype.unionExtentFromData=function(t,e){this.unionExtent(t.getApproximateExtent(e))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.setExtent=function(t,e){var n=this._extent;isNaN(t)||(n[0]=t),isNaN(e)||(n[1]=e)},r.prototype.isInExtentRange=function(t){return this._extent[0]<=t&&this._extent[1]>=t},r.prototype.isBlank=function(){return this._isBlank},r.prototype.setBlank=function(t){this._isBlank=t},r}();Xs(ir);var DM=0,$f=function(){function r(t){this.categories=t.categories||[],this._needCollect=t.needCollect,this._deduplication=t.deduplication,this.uid=++DM}return r.createByAxisModel=function(t){var e=t.option,n=e.data,i=n&&H(n,AM);return new r({categories:i,needCollect:!i,deduplication:e.dedplication!==!1})},r.prototype.getOrdinal=function(t){return this._getOrCreateMap().get(t)},r.prototype.parseAndCollect=function(t){var e,n=this._needCollect;if(!W(t)&&!n)return t;if(n&&!this._deduplication)return e=this.categories.length,this.categories[e]=t,e;var i=this._getOrCreateMap();return e=i.get(t),e==null&&(n?(e=this.categories.length,this.categories[e]=t,i.set(t,e)):e=NaN),e},r.prototype._getOrCreateMap=function(){return this._map||(this._map=$(this.categories))},r}();function AM(r){return Y(r)&&r.value!=null?r.value:r+""}function qf(r){return r.type==="interval"||r.type==="log"}function MM(r,t,e,n){var i={},a=r[1]-r[0],o=i.interval=Ky(a/t);e!=null&&o<e&&(o=i.interval=e),n!=null&&o>n&&(o=i.interval=n);var s=i.intervalPrecision=b_(o),l=i.niceTickExtent=[Mt(Math.ceil(r[0]/o)*o,s),Mt(Math.floor(r[1]/o)*o,s)];return IM(l,r),i}function Au(r){var t=Math.pow(10,Ih(r)),e=r/t;return e?e===2?e=3:e===3?e=5:e*=2:e=1,Mt(e*t)}function b_(r){return fr(r)+2}function cp(r,t,e){r[t]=Math.max(Math.min(r[t],e[1]),e[0])}function IM(r,t){!isFinite(r[0])&&(r[0]=t[0]),!isFinite(r[1])&&(r[1]=t[1]),cp(r,0,t),cp(r,1,t),r[0]>r[1]&&(r[0]=r[1])}function gl(r,t){return r>=t[0]&&r<=t[1]}function yl(r,t){return t[1]===t[0]?.5:(r-t[0])/(t[1]-t[0])}function ml(r,t){return r*(t[1]-t[0])+t[0]}var cv=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;n.type="ordinal";var i=n.getSetting("ordinalMeta");return i||(i=new $f({})),V(i)&&(i=new $f({categories:H(i,function(a){return Y(a)?a.value:a})})),n._ordinalMeta=i,n._extent=n.getSetting("extent")||[0,i.categories.length-1],n}return t.prototype.parse=function(e){return e==null?NaN:W(e)?this._ordinalMeta.getOrdinal(e):Math.round(e)},t.prototype.contain=function(e){return e=this.parse(e),gl(e,this._extent)&&this._ordinalMeta.categories[e]!=null},t.prototype.normalize=function(e){return e=this._getTickNumber(this.parse(e)),yl(e,this._extent)},t.prototype.scale=function(e){return e=Math.round(ml(e,this._extent)),this.getRawOrdinalNumber(e)},t.prototype.getTicks=function(){for(var e=[],n=this._extent,i=n[0];i<=n[1];)e.push({value:i}),i++;return e},t.prototype.getMinorTicks=function(e){},t.prototype.setSortInfo=function(e){if(e==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var n=e.ordinalNumbers,i=this._ordinalNumbersByTick=[],a=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,n.length);o<l;++o){var u=n[o];i[o]=u,a[u]=o}for(var f=0;o<s;++o){for(;a[f]!=null;)f++;i.push(f),a[f]=o}},t.prototype._getTickNumber=function(e){var n=this._ticksByOrdinalNumber;return n&&e>=0&&e<n.length?n[e]:e},t.prototype.getRawOrdinalNumber=function(e){var n=this._ordinalNumbersByTick;return n&&e>=0&&e<n.length?n[e]:e},t.prototype.getLabel=function(e){if(!this.isBlank()){var n=this.getRawOrdinalNumber(e.value),i=this._ordinalMeta.categories[n];return i==null?"":i+""}},t.prototype.count=function(){return this._extent[1]-this._extent[0]+1},t.prototype.unionExtentFromData=function(e,n){this.unionExtent(e.getApproximateExtent(n))},t.prototype.isInExtentRange=function(e){return e=this._getTickNumber(e),this._extent[0]<=e&&this._extent[1]>=e},t.prototype.getOrdinalMeta=function(){return this._ordinalMeta},t.prototype.calcNiceTicks=function(){},t.prototype.calcNiceExtent=function(){},t.type="ordinal",t}(ir);ir.registerClass(cv);var dn=Mt,Yr=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="interval",e._interval=0,e._intervalPrecision=2,e}return t.prototype.parse=function(e){return e},t.prototype.contain=function(e){return gl(e,this._extent)},t.prototype.normalize=function(e){return yl(e,this._extent)},t.prototype.scale=function(e){return ml(e,this._extent)},t.prototype.setExtent=function(e,n){var i=this._extent;isNaN(e)||(i[0]=parseFloat(e)),isNaN(n)||(i[1]=parseFloat(n))},t.prototype.unionExtent=function(e){var n=this._extent;e[0]<n[0]&&(n[0]=e[0]),e[1]>n[1]&&(n[1]=e[1]),this.setExtent(n[0],n[1])},t.prototype.getInterval=function(){return this._interval},t.prototype.setInterval=function(e){this._interval=e,this._niceExtent=this._extent.slice(),this._intervalPrecision=b_(e)},t.prototype.getTicks=function(e){var n=this._interval,i=this._extent,a=this._niceExtent,o=this._intervalPrecision,s=[];if(!n)return s;var l=1e4;i[0]<a[0]&&(e?s.push({value:dn(a[0]-n,o)}):s.push({value:i[0]}));for(var u=a[0];u<=a[1]&&(s.push({value:u}),u=dn(u+n,o),u!==s[s.length-1].value);)if(s.length>l)return[];var f=s.length?s[s.length-1].value:a[1];return i[1]>f&&(e?s.push({value:dn(f+n,o)}):s.push({value:i[1]})),s},t.prototype.getMinorTicks=function(e){for(var n=this.getTicks(!0),i=[],a=this.getExtent(),o=1;o<n.length;o++){for(var s=n[o],l=n[o-1],u=0,f=[],h=s.value-l.value,c=h/e;u<e-1;){var v=dn(l.value+(u+1)*c);v>a[0]&&v<a[1]&&f.push(v),u++}i.push(f)}return i},t.prototype.getLabel=function(e,n){if(e==null)return"";var i=n&&n.precision;i==null?i=fr(e.value)||0:i==="auto"&&(i=this._intervalPrecision);var a=dn(e.value,i,!0);return i0(a)},t.prototype.calcNiceTicks=function(e,n,i){e=e||5;var a=this._extent,o=a[1]-a[0];if(isFinite(o)){o<0&&(o=-o,a.reverse());var s=MM(a,e,n,i);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},t.prototype.calcNiceExtent=function(e){var n=this._extent;if(n[0]===n[1])if(n[0]!==0){var i=Math.abs(n[0]);e.fixMax||(n[1]+=i/2),n[0]-=i/2}else n[1]=1;var a=n[1]-n[0];isFinite(a)||(n[0]=0,n[1]=1),this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval);var o=this._interval;e.fixMin||(n[0]=dn(Math.floor(n[0]/o)*o)),e.fixMax||(n[1]=dn(Math.ceil(n[1]/o)*o))},t.prototype.setNiceExtent=function(e,n){this._niceExtent=[e,n]},t.type="interval",t}(ir);ir.registerClass(Yr);var T_=typeof Float32Array<"u",LM=T_?Float32Array:Array;function vr(r){return V(r)?T_?new Float32Array(r):r:new LM(r)}var PM="__ec_stack_";function C_(r){return r.get("stack")||PM+r.seriesIndex}function dv(r){return r.dim+r.index}function D_(r,t){var e=[];return t.eachSeriesByType(r,function(n){L_(n)&&e.push(n)}),e}function RM(r){var t={};M(r,function(l){var u=l.coordinateSystem,f=u.getBaseAxis();if(!(f.type!=="time"&&f.type!=="value"))for(var h=l.getData(),c=f.dim+"_"+f.index,v=h.getDimensionIndex(h.mapDimension(f.dim)),d=h.getStore(),p=0,g=d.count();p<g;++p){var y=d.get(v,p);t[c]?t[c].push(y):t[c]=[y]}});var e={};for(var n in t)if(t.hasOwnProperty(n)){var i=t[n];if(i){i.sort(function(l,u){return l-u});for(var a=null,o=1;o<i.length;++o){var s=i[o]-i[o-1];s>0&&(a=a===null?s:Math.min(a,s))}e[n]=a}}return e}function A_(r){var t=RM(r),e=[];return M(r,function(n){var i=n.coordinateSystem,a=i.getBaseAxis(),o=a.getExtent(),s;if(a.type==="category")s=a.getBandWidth();else if(a.type==="value"||a.type==="time"){var l=a.dim+"_"+a.index,u=t[l],f=Math.abs(o[1]-o[0]),h=a.scale.getExtent(),c=Math.abs(h[1]-h[0]);s=u?f/c*u:f}else{var v=n.getData();s=Math.abs(o[1]-o[0])/v.count()}var d=Z(n.get("barWidth"),s),p=Z(n.get("barMaxWidth"),s),g=Z(n.get("barMinWidth")||(P_(n)?.5:1),s),y=n.get("barGap"),m=n.get("barCategoryGap");e.push({bandWidth:s,barWidth:d,barMaxWidth:p,barMinWidth:g,barGap:y,barCategoryGap:m,axisKey:dv(a),stackId:C_(n)})}),EM(e)}function EM(r){var t={};M(r,function(n,i){var a=n.axisKey,o=n.bandWidth,s=t[a]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:"20%",stacks:{}},l=s.stacks;t[a]=s;var u=n.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var f=n.barWidth;f&&!l[u].width&&(l[u].width=f,f=Math.min(s.remainedWidth,f),s.remainedWidth-=f);var h=n.barMaxWidth;h&&(l[u].maxWidth=h);var c=n.barMinWidth;c&&(l[u].minWidth=c);var v=n.barGap;v!=null&&(s.gap=v);var d=n.barCategoryGap;d!=null&&(s.categoryGap=d)});var e={};return M(t,function(n,i){e[i]={};var a=n.stacks,o=n.bandWidth,s=n.categoryGap;if(s==null){var l=mt(a).length;s=Math.max(35-l*4,15)+"%"}var u=Z(s,o),f=Z(n.gap,1),h=n.remainedWidth,c=n.autoWidthCount,v=(h-u)/(c+(c-1)*f);v=Math.max(v,0),M(a,function(y){var m=y.maxWidth,_=y.minWidth;if(y.width){var S=y.width;m&&(S=Math.min(S,m)),_&&(S=Math.max(S,_)),y.width=S,h-=S+f*S,c--}else{var S=v;m&&m<S&&(S=Math.min(m,h)),_&&_>S&&(S=_),S!==v&&(y.width=S,h-=S+f*S,c--)}}),v=(h-u)/(c+(c-1)*f),v=Math.max(v,0);var d=0,p;M(a,function(y,m){y.width||(y.width=v),p=y,d+=y.width*(1+f)}),p&&(d-=p.width*f);var g=-d/2;M(a,function(y,m){e[i][m]=e[i][m]||{bandWidth:o,offset:g,width:y.width},g+=y.width*(1+f)})}),e}function kM(r,t,e){if(r&&t){var n=r[dv(t)];return n}}function M_(r,t){var e=D_(r,t),n=A_(e);M(e,function(i){var a=i.getData(),o=i.coordinateSystem,s=o.getBaseAxis(),l=C_(i),u=n[dv(s)][l],f=u.offset,h=u.width;a.setLayout({bandWidth:u.bandWidth,offset:f,size:h})})}function I_(r){return{seriesType:r,plan:av(),reset:function(t){if(L_(t)){var e=t.getData(),n=t.coordinateSystem,i=n.getBaseAxis(),a=n.getOtherAxis(i),o=e.getDimensionIndex(e.mapDimension(a.dim)),s=e.getDimensionIndex(e.mapDimension(i.dim)),l=t.get("showBackground",!0),u=e.mapDimension(a.dim),f=e.getCalculationInfo("stackResultDimension"),h=Ci(e,u)&&!!e.getCalculationInfo("stackedOnSeries"),c=a.isHorizontal(),v=OM(i,a),d=P_(t),p=t.get("barMinHeight")||0,g=f&&e.getDimensionIndex(f),y=e.getLayout("size"),m=e.getLayout("offset");return{progress:function(_,S){for(var w=_.count,x=d&&vr(w*3),b=d&&l&&vr(w*3),T=d&&vr(w),C=n.master.getRect(),D=c?C.width:C.height,A,I=S.getStore(),L=0;(A=_.next())!=null;){var P=I.get(h?g:o,A),R=I.get(s,A),E=v,O=void 0;h&&(O=+P-I.get(o,A));var k=void 0,B=void 0,z=void 0,G=void 0;if(c){var U=n.dataToPoint([P,R]);if(h){var j=n.dataToPoint([O,R]);E=j[0]}k=E,B=U[1]+m,z=U[0]-E,G=y,Math.abs(z)<p&&(z=(z<0?-1:1)*p)}else{var U=n.dataToPoint([R,P]);if(h){var j=n.dataToPoint([R,O]);E=j[1]}k=U[0]+m,B=E,z=y,G=U[1]-E,Math.abs(G)<p&&(G=(G<=0?-1:1)*p)}d?(x[L]=k,x[L+1]=B,x[L+2]=c?z:G,b&&(b[L]=c?C.x:k,b[L+1]=c?B:C.y,b[L+2]=D),T[A]=A):S.setItemLayout(A,{x:k,y:B,width:z,height:G}),L+=3}d&&S.setLayout({largePoints:x,largeDataIndices:T,largeBackgroundPoints:b,valueAxisHorizontal:c})}}}}}}function L_(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function P_(r){return r.pipelineContext&&r.pipelineContext.large}function OM(r,t){var e=t.model.get("startValue");return e||(e=0),t.toGlobalCoord(t.dataToCoord(t.type==="log"?e>0?e:1:e))}var BM=function(r,t,e,n){for(;e<n;){var i=e+n>>>1;r[i][1]<t?e=i+1:n=i}return e},R_=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n.type="time",n}return t.prototype.getLabel=function(e){var n=this.getSetting("useUTC");return al(e.value,nd[sC(pi(this._minLevelUnit))]||nd.second,n,this.getSetting("locale"))},t.prototype.getFormattedLabel=function(e,n,i){var a=this.getSetting("useUTC"),o=this.getSetting("locale");return lC(e,n,i,o,a)},t.prototype.getTicks=function(){var e=this._interval,n=this._extent,i=[];if(!e)return i;i.push({value:n[0],level:0});var a=this.getSetting("useUTC"),o=WM(this._minLevelUnit,this._approxInterval,a,n);return i=i.concat(o),i.push({value:n[1],level:0}),i},t.prototype.calcNiceExtent=function(e){var n=this._extent;if(n[0]===n[1]&&(n[0]-=ge,n[1]+=ge),n[1]===-1/0&&n[0]===1/0){var i=new Date;n[1]=+new Date(i.getFullYear(),i.getMonth(),i.getDate()),n[0]=n[1]-ge}this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval)},t.prototype.calcNiceTicks=function(e,n,i){e=e||10;var a=this._extent,o=a[1]-a[0];this._approxInterval=o/e,n!=null&&this._approxInterval<n&&(this._approxInterval=n),i!=null&&this._approxInterval>i&&(this._approxInterval=i);var s=Ro.length,l=Math.min(BM(Ro,this._approxInterval,0,s),s-1);this._interval=Ro[l][1],this._minLevelUnit=Ro[Math.max(l-1,0)][0]},t.prototype.parse=function(e){return ct(e)?e:+gr(e)},t.prototype.contain=function(e){return gl(this.parse(e),this._extent)},t.prototype.normalize=function(e){return yl(this.parse(e),this._extent)},t.prototype.scale=function(e){return ml(e,this._extent)},t.type="time",t}(Yr),Ro=[["second",$h],["minute",qh],["hour",Ca],["quarter-day",Ca*6],["half-day",Ca*12],["day",ge*1.2],["half-week",ge*3.5],["week",ge*7],["month",ge*31],["quarter",ge*95],["half-year",rd/2],["year",rd]];function NM(r,t,e,n){var i=gr(t),a=gr(e),o=function(d){return id(i,d,n)===id(a,d,n)},s=function(){return o("year")},l=function(){return s()&&o("month")},u=function(){return l()&&o("day")},f=function(){return u()&&o("hour")},h=function(){return f()&&o("minute")},c=function(){return h()&&o("second")},v=function(){return c()&&o("millisecond")};switch(r){case"year":return s();case"month":return l();case"day":return u();case"hour":return f();case"minute":return h();case"second":return c();case"millisecond":return v()}}function FM(r,t){return r/=ge,r>16?16:r>7.5?7:r>3.5?4:r>1.5?2:1}function zM(r){var t=30*ge;return r/=t,r>6?6:r>3?3:r>2?2:1}function VM(r){return r/=Ca,r>12?12:r>6?6:r>3.5?4:r>2?2:1}function dp(r,t){return r/=t?qh:$h,r>30?30:r>20?20:r>15?15:r>10?10:r>5?5:r>2?2:1}function GM(r){return Ky(r)}function HM(r,t,e){var n=new Date(r);switch(pi(t)){case"year":case"month":n[Jm(e)](0);case"day":n[jm(e)](1);case"hour":n[t0(e)](0);case"minute":n[e0(e)](0);case"second":n[r0(e)](0),n[n0(e)](0)}return n.getTime()}function WM(r,t,e,n){var i=1e4,a=Km,o=0;function s(D,A,I,L,P,R,E){for(var O=new Date(A),k=A,B=O[L]();k<I&&k<=n[1];)E.push({value:k}),B+=D,O[P](B),k=O.getTime();E.push({value:k,notAdd:!0})}function l(D,A,I){var L=[],P=!A.length;if(!NM(pi(D),n[0],n[1],e)){P&&(A=[{value:HM(new Date(n[0]),D,e)},{value:n[1]}]);for(var R=0;R<A.length-1;R++){var E=A[R].value,O=A[R+1].value;if(E!==O){var k=void 0,B=void 0,z=void 0,G=!1;switch(D){case"year":k=Math.max(1,Math.round(t/ge/365)),B=Kh(e),z=uC(e);break;case"half-year":case"quarter":case"month":k=zM(t),B=gi(e),z=Jm(e);break;case"week":case"half-week":case"day":k=FM(t),B=ol(e),z=jm(e),G=!0;break;case"half-day":case"quarter-day":case"hour":k=VM(t),B=Fa(e),z=t0(e);break;case"minute":k=dp(t,!0),B=sl(e),z=e0(e);break;case"second":k=dp(t,!1),B=ll(e),z=r0(e);break;case"millisecond":k=GM(t),B=ul(e),z=n0(e);break}s(k,E,O,B,z,G,L),D==="year"&&I.length>1&&R===0&&I.unshift({value:I[0].value-k})}}for(var R=0;R<L.length;R++)I.push(L[R]);return L}}for(var u=[],f=[],h=0,c=0,v=0;v<a.length&&o++<i;++v){var d=pi(a[v]);if(oC(a[v])){l(a[v],u[u.length-1]||[],f);var p=a[v+1]?pi(a[v+1]):null;if(d!==p){if(f.length){c=h,f.sort(function(D,A){return D.value-A.value});for(var g=[],y=0;y<f.length;++y){var m=f[y].value;(y===0||f[y-1].value!==m)&&(g.push(f[y]),m>=n[0]&&m<=n[1]&&h++)}var _=(n[1]-n[0])/t;if(h>_*1.5&&c>_/1.5||(u.push(g),h>_||r===a[v]))break}f=[]}}}for(var S=Tt(H(u,function(D){return Tt(D,function(A){return A.value>=n[0]&&A.value<=n[1]&&!A.notAdd})}),function(D){return D.length>0}),w=[],x=S.length-1,v=0;v<S.length;++v)for(var b=S[v],T=0;T<b.length;++T)w.push({value:b[T].value,level:x-v});w.sort(function(D,A){return D.value-A.value});for(var C=[],v=0;v<w.length;++v)(v===0||w[v].value!==w[v-1].value)&&C.push(w[v]);return C}ir.registerClass(R_);var pp=ir.prototype,Ia=Yr.prototype,UM=Mt,YM=Math.floor,XM=Math.ceil,Eo=Math.pow,Te=Math.log,pv=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="log",e.base=10,e._originalScale=new Yr,e._interval=0,e}return t.prototype.getTicks=function(e){var n=this._originalScale,i=this._extent,a=n.getExtent(),o=Ia.getTicks.call(this,e);return H(o,function(s){var l=s.value,u=Mt(Eo(this.base,l));return u=l===i[0]&&this._fixMin?ko(u,a[0]):u,u=l===i[1]&&this._fixMax?ko(u,a[1]):u,{value:u}},this)},t.prototype.setExtent=function(e,n){var i=Te(this.base);e=Te(Math.max(0,e))/i,n=Te(Math.max(0,n))/i,Ia.setExtent.call(this,e,n)},t.prototype.getExtent=function(){var e=this.base,n=pp.getExtent.call(this);n[0]=Eo(e,n[0]),n[1]=Eo(e,n[1]);var i=this._originalScale,a=i.getExtent();return this._fixMin&&(n[0]=ko(n[0],a[0])),this._fixMax&&(n[1]=ko(n[1],a[1])),n},t.prototype.unionExtent=function(e){this._originalScale.unionExtent(e);var n=this.base;e[0]=Te(e[0])/Te(n),e[1]=Te(e[1])/Te(n),pp.unionExtent.call(this,e)},t.prototype.unionExtentFromData=function(e,n){this.unionExtent(e.getApproximateExtent(n))},t.prototype.calcNiceTicks=function(e){e=e||10;var n=this._extent,i=n[1]-n[0];if(!(i===1/0||i<=0)){var a=Aw(i),o=e/i*a;for(o<=.5&&(a*=10);!isNaN(a)&&Math.abs(a)<1&&Math.abs(a)>0;)a*=10;var s=[Mt(XM(n[0]/a)*a),Mt(YM(n[1]/a)*a)];this._interval=a,this._niceExtent=s}},t.prototype.calcNiceExtent=function(e){Ia.calcNiceExtent.call(this,e),this._fixMin=e.fixMin,this._fixMax=e.fixMax},t.prototype.parse=function(e){return e},t.prototype.contain=function(e){return e=Te(e)/Te(this.base),gl(e,this._extent)},t.prototype.normalize=function(e){return e=Te(e)/Te(this.base),yl(e,this._extent)},t.prototype.scale=function(e){return e=ml(e,this._extent),Eo(this.base,e)},t.type="log",t}(ir),E_=pv.prototype;E_.getMinorTicks=Ia.getMinorTicks;E_.getLabel=Ia.getLabel;function ko(r,t){return UM(r,fr(t))}ir.registerClass(pv);var ZM=function(){function r(t,e,n){this._prepareParams(t,e,n)}return r.prototype._prepareParams=function(t,e,n){n[1]<n[0]&&(n=[NaN,NaN]),this._dataMin=n[0],this._dataMax=n[1];var i=this._isOrdinal=t.type==="ordinal";this._needCrossZero=t.type==="interval"&&e.getNeedCrossZero&&e.getNeedCrossZero();var a=e.get("min",!0);a==null&&(a=e.get("startValue",!0));var o=this._modelMinRaw=a;q(o)?this._modelMinNum=Oo(t,o({min:n[0],max:n[1]})):o!=="dataMin"&&(this._modelMinNum=Oo(t,o));var s=this._modelMaxRaw=e.get("max",!0);if(q(s)?this._modelMaxNum=Oo(t,s({min:n[0],max:n[1]})):s!=="dataMax"&&(this._modelMaxNum=Oo(t,s)),i)this._axisDataLen=e.getCategories().length;else{var l=e.get("boundaryGap"),u=V(l)?l:[l||0,l||0];typeof u[0]=="boolean"||typeof u[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[Gr(u[0],1),Gr(u[1],1)]}},r.prototype.calculate=function(){var t=this._isOrdinal,e=this._dataMin,n=this._dataMax,i=this._axisDataLen,a=this._boundaryGapInner,o=t?null:n-e||Math.abs(e),s=this._modelMinRaw==="dataMin"?e:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?n:this._modelMaxNum,u=s!=null,f=l!=null;s==null&&(s=t?i?0:NaN:e-a[0]*o),l==null&&(l=t?i?i-1:NaN:n+a[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var h=us(s)||us(l)||t&&!i;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!f&&(l=0));var c=this._determinedMin,v=this._determinedMax;return c!=null&&(s=c,u=!0),v!=null&&(l=v,f=!0),{min:s,max:l,minFixed:u,maxFixed:f,isBlank:h}},r.prototype.modifyDataMinMax=function(t,e){this[qM[t]]=e},r.prototype.setDeterminedMinMax=function(t,e){var n=$M[t];this[n]=e},r.prototype.freeze=function(){this.frozen=!0},r}(),$M={min:"_determinedMin",max:"_determinedMax"},qM={min:"_dataMin",max:"_dataMax"};function k_(r,t,e){var n=r.rawExtentInfo;return n||(n=new ZM(r,t,e),r.rawExtentInfo=n,n)}function Oo(r,t){return t==null?null:us(t)?NaN:r.parse(t)}function O_(r,t){var e=r.type,n=k_(r,t,r.getExtent()).calculate();r.setBlank(n.isBlank);var i=n.min,a=n.max,o=t.ecModel;if(o&&e==="time"){var s=D_("bar",o),l=!1;if(M(s,function(h){l=l||h.getBaseAxis()===t.axis}),l){var u=A_(s),f=KM(i,a,t,u);i=f.min,a=f.max}}return{extent:[i,a],fixMin:n.minFixed,fixMax:n.maxFixed}}function KM(r,t,e,n){var i=e.axis.getExtent(),a=Math.abs(i[1]-i[0]),o=kM(n,e.axis);if(o===void 0)return{min:r,max:t};var s=1/0;M(o,function(v){s=Math.min(v.offset,s)});var l=-1/0;M(o,function(v){l=Math.max(v.offset+v.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,f=t-r,h=1-(s+l)/a,c=f/h-f;return t+=c*(l/u),r-=c*(s/u),{min:r,max:t}}function gp(r,t){var e=t,n=O_(r,e),i=n.extent,a=e.get("splitNumber");r instanceof pv&&(r.base=e.get("logBase"));var o=r.type,s=e.get("interval"),l=o==="interval"||o==="time";r.setExtent(i[0],i[1]),r.calcNiceExtent({splitNumber:a,fixMin:n.fixMin,fixMax:n.fixMax,minInterval:l?e.get("minInterval"):null,maxInterval:l?e.get("maxInterval"):null}),s!=null&&r.setInterval&&r.setInterval(s)}function QM(r,t){if(t=t||r.get("type"),t)switch(t){case"category":return new cv({ordinalMeta:r.getOrdinalMeta?r.getOrdinalMeta():r.getCategories(),extent:[1/0,-1/0]});case"time":return new R_({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new(ir.getClass(t)||Yr)}}function JM(r){var t=r.scale.getExtent(),e=t[0],n=t[1];return!(e>0&&n>0||e<0&&n<0)}function Oi(r){var t=r.getLabelModel().get("formatter"),e=r.type==="category"?r.scale.getExtent()[0]:null;return r.scale.type==="time"?function(n){return function(i,a){return r.scale.getFormattedLabel(i,a,n)}}(t):W(t)?function(n){return function(i){var a=r.scale.getLabel(i),o=n.replace("{value}",a??"");return o}}(t):q(t)?function(n){return function(i,a){return e!=null&&(a=i.value-e),n(gv(r,i),a,i.level!=null?{level:i.level}:null)}}(t):function(n){return r.scale.getLabel(n)}}function gv(r,t){return r.type==="category"?r.scale.getLabel(t):t.value}function jM(r){var t=r.model,e=r.scale;if(!(!t.get(["axisLabel","show"])||e.isBlank())){var n,i,a=e.getExtent();e instanceof cv?i=e.count():(n=e.getTicks(),i=n.length);var o=r.getLabelModel(),s=Oi(r),l,u=1;i>40&&(u=Math.ceil(i/40));for(var f=0;f<i;f+=u){var h=n?n[f]:{value:a[0]+f},c=s(h,f),v=o.getTextRect(c),d=t2(v,o.get("rotate")||0);l?l.union(d):l=d}return l}}function t2(r,t){var e=t*Math.PI/180,n=r.width,i=r.height,a=n*Math.abs(Math.cos(e))+Math.abs(i*Math.sin(e)),o=n*Math.abs(Math.sin(e))+Math.abs(i*Math.cos(e)),s=new ut(r.x,r.y,a,o);return s}function yv(r){var t=r.get("interval");return t??"auto"}function B_(r){return r.type==="category"&&yv(r.getLabelModel())===0}function N_(r,t){var e={};return M(r.mapDimensionsAll(t),function(n){e[xM(r,n)]=!0}),mt(e)}function e2(r,t,e){t&&M(N_(t,e),function(n){var i=t.getApproximateExtent(n);i[0]<r[0]&&(r[0]=i[0]),i[1]>r[1]&&(r[1]=i[1])})}var F_=function(){function r(){}return r.prototype.getNeedCrossZero=function(){var t=this.option;return!t.scale},r.prototype.getCoordSysModel=function(){},r}(),yp=[],r2={registerPreprocessor:c_,registerProcessor:d_,registerPostInit:QA,registerPostUpdate:JA,registerUpdateLifecycle:hv,registerAction:nr,registerCoordinateSystem:jA,registerLayout:tM,registerVisual:kn,registerTransform:rM,registerLoading:p_,registerMap:eM,registerImpl:PA,PRIORITY:UA,ComponentModel:ht,ComponentView:Jt,SeriesModel:se,ChartView:Wt,registerComponentModel:function(r){ht.registerClass(r)},registerComponentView:function(r){Jt.registerClass(r)},registerSeriesModel:function(r){se.registerClass(r)},registerChartView:function(r){Wt.registerClass(r)},registerSubTypeDefaulter:function(r,t){ht.registerSubTypeDefaulter(r,t)},registerPainter:function(r,t){_w(r,t)}};function ke(r){if(V(r)){M(r,function(t){ke(t)});return}lt(yp,r)>=0||(yp.push(r),q(r)&&(r={install:r}),r.install(r2))}var Ua=_t();function z_(r,t){var e=H(t,function(n){return r.scale.parse(n)});return r.type==="time"&&e.length>0&&(e.sort(),e.unshift(e[0]),e.push(e[e.length-1])),e}function n2(r){var t=r.getLabelModel().get("customValues");if(t){var e=Oi(r),n=r.scale.getExtent(),i=z_(r,t),a=Tt(i,function(o){return o>=n[0]&&o<=n[1]});return{labels:H(a,function(o){var s={value:o};return{formattedLabel:e(s),rawLabel:r.scale.getLabel(s),tickValue:o}})}}return r.type==="category"?a2(r):s2(r)}function i2(r,t){var e=r.getTickModel().get("customValues");if(e){var n=r.scale.getExtent(),i=z_(r,e);return{ticks:Tt(i,function(a){return a>=n[0]&&a<=n[1]})}}return r.type==="category"?o2(r,t):{ticks:H(r.scale.getTicks(),function(a){return a.value})}}function a2(r){var t=r.getLabelModel(),e=V_(r,t);return!t.get("show")||r.scale.isBlank()?{labels:[],labelCategoryInterval:e.labelCategoryInterval}:e}function V_(r,t){var e=G_(r,"labels"),n=yv(t),i=H_(e,n);if(i)return i;var a,o;return q(n)?a=Y_(r,n):(o=n==="auto"?l2(r):n,a=U_(r,o)),W_(e,n,{labels:a,labelCategoryInterval:o})}function o2(r,t){var e=G_(r,"ticks"),n=yv(t),i=H_(e,n);if(i)return i;var a,o;if((!t.get("show")||r.scale.isBlank())&&(a=[]),q(n))a=Y_(r,n,!0);else if(n==="auto"){var s=V_(r,r.getLabelModel());o=s.labelCategoryInterval,a=H(s.labels,function(l){return l.tickValue})}else o=n,a=U_(r,o,!0);return W_(e,n,{ticks:a,tickCategoryInterval:o})}function s2(r){var t=r.scale.getTicks(),e=Oi(r);return{labels:H(t,function(n,i){return{level:n.level,formattedLabel:e(n,i),rawLabel:r.scale.getLabel(n),tickValue:n.value}})}}function G_(r,t){return Ua(r)[t]||(Ua(r)[t]=[])}function H_(r,t){for(var e=0;e<r.length;e++)if(r[e].key===t)return r[e].value}function W_(r,t,e){return r.push({key:t,value:e}),e}function l2(r){var t=Ua(r).autoInterval;return t??(Ua(r).autoInterval=r.calculateCategoryInterval())}function u2(r){var t=f2(r),e=Oi(r),n=(t.axisRotate-t.labelRotate)/180*Math.PI,i=r.scale,a=i.getExtent(),o=i.count();if(a[1]-a[0]<1)return 0;var s=1;o>40&&(s=Math.max(1,Math.floor(o/40)));for(var l=a[0],u=r.dataToCoord(l+1)-r.dataToCoord(l),f=Math.abs(u*Math.cos(n)),h=Math.abs(u*Math.sin(n)),c=0,v=0;l<=a[1];l+=s){var d=0,p=0,g=Us(e({value:l}),t.font,"center","top");d=g.width*1.3,p=g.height*1.3,c=Math.max(c,d,7),v=Math.max(v,p,7)}var y=c/f,m=v/h;isNaN(y)&&(y=1/0),isNaN(m)&&(m=1/0);var _=Math.max(0,Math.floor(Math.min(y,m))),S=Ua(r.model),w=r.getExtent(),x=S.lastAutoInterval,b=S.lastTickCount;return x!=null&&b!=null&&Math.abs(x-_)<=1&&Math.abs(b-o)<=1&&x>_&&S.axisExtent0===w[0]&&S.axisExtent1===w[1]?_=x:(S.lastTickCount=o,S.lastAutoInterval=_,S.axisExtent0=w[0],S.axisExtent1=w[1]),_}function f2(r){var t=r.getLabelModel();return{axisRotate:r.getRotate?r.getRotate():r.isHorizontal&&!r.isHorizontal()?90:0,labelRotate:t.get("rotate")||0,font:t.getFont()}}function U_(r,t,e){var n=Oi(r),i=r.scale,a=i.getExtent(),o=r.getLabelModel(),s=[],l=Math.max((t||0)+1,1),u=a[0],f=i.count();u!==0&&l>1&&f/l>2&&(u=Math.round(Math.ceil(u/l)*l));var h=B_(r),c=o.get("showMinLabel")||h,v=o.get("showMaxLabel")||h;c&&u!==a[0]&&p(a[0]);for(var d=u;d<=a[1];d+=l)p(d);v&&d-l!==a[1]&&p(a[1]);function p(g){var y={value:g};s.push(e?g:{formattedLabel:n(y),rawLabel:i.getLabel(y),tickValue:g})}return s}function Y_(r,t,e){var n=r.scale,i=Oi(r),a=[];return M(n.getTicks(),function(o){var s=n.getLabel(o),l=o.value;t(o.value,s)&&a.push(e?l:{formattedLabel:i(o),rawLabel:s,tickValue:l})}),a}var mp=[0,1],X_=function(){function r(t,e,n){this.onBand=!1,this.inverse=!1,this.dim=t,this.scale=e,this._extent=n||[0,0]}return r.prototype.contain=function(t){var e=this._extent,n=Math.min(e[0],e[1]),i=Math.max(e[0],e[1]);return t>=n&&t<=i},r.prototype.containData=function(t){return this.scale.contain(t)},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.getPixelPrecision=function(t){return $y(t||this.scale.getExtent(),this._extent)},r.prototype.setExtent=function(t,e){var n=this._extent;n[0]=t,n[1]=e},r.prototype.dataToCoord=function(t,e){var n=this._extent,i=this.scale;return t=i.normalize(t),this.onBand&&i.type==="ordinal"&&(n=n.slice(),_p(n,i.count())),Zt(t,mp,n,e)},r.prototype.coordToData=function(t,e){var n=this._extent,i=this.scale;this.onBand&&i.type==="ordinal"&&(n=n.slice(),_p(n,i.count()));var a=Zt(t,n,mp,e);return this.scale.scale(a)},r.prototype.pointToData=function(t,e){},r.prototype.getTicksCoords=function(t){t=t||{};var e=t.tickModel||this.getTickModel(),n=i2(this,e),i=n.ticks,a=H(i,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=e.get("alignWithLabel");return h2(this,a,o,t.clamp),a},r.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var t=this.model.getModel("minorTick"),e=t.get("splitNumber");e>0&&e<100||(e=5);var n=this.scale.getMinorTicks(e),i=H(n,function(a){return H(a,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return i},r.prototype.getViewLabels=function(){return n2(this).labels},r.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},r.prototype.getTickModel=function(){return this.model.getModel("axisTick")},r.prototype.getBandWidth=function(){var t=this._extent,e=this.scale.getExtent(),n=e[1]-e[0]+(this.onBand?1:0);n===0&&(n=1);var i=Math.abs(t[1]-t[0]);return Math.abs(i)/n},r.prototype.calculateCategoryInterval=function(){return u2(this)},r}();function _p(r,t){var e=r[1]-r[0],n=t,i=e/n/2;r[0]+=i,r[1]-=i}function h2(r,t,e,n){var i=t.length;if(!r.onBand||e||!i)return;var a=r.getExtent(),o,s;if(i===1)t[0].coord=a[0],o=t[1]={coord:a[1],tickValue:t[0].tickValue};else{var l=t[i-1].tickValue-t[0].tickValue,u=(t[i-1].coord-t[0].coord)/l;M(t,function(v){v.coord-=u/2});var f=r.scale.getExtent();s=1+f[1]-t[i-1].tickValue,o={coord:t[i-1].coord+u*s,tickValue:f[1]+1},t.push(o)}var h=a[0]>a[1];c(t[0].coord,a[0])&&(n?t[0].coord=a[0]:t.shift()),n&&c(a[0],t[0].coord)&&t.unshift({coord:a[0]}),c(a[1],o.coord)&&(n?o.coord=a[1]:t.pop()),n&&c(o.coord,a[1])&&t.push({coord:a[1]});function c(v,d){return v=Mt(v),d=Mt(d),h?v>d:v<d}}var ra=Math.PI*2,pn=yr.CMD,v2=["top","right","bottom","left"];function c2(r,t,e,n,i){var a=e.width,o=e.height;switch(r){case"top":n.set(e.x+a/2,e.y-t),i.set(0,-1);break;case"bottom":n.set(e.x+a/2,e.y+o+t),i.set(0,1);break;case"left":n.set(e.x-t,e.y+o/2),i.set(-1,0);break;case"right":n.set(e.x+a+t,e.y+o/2),i.set(1,0);break}}function d2(r,t,e,n,i,a,o,s,l){o-=r,s-=t;var u=Math.sqrt(o*o+s*s);o/=u,s/=u;var f=o*e+r,h=s*e+t;if(Math.abs(n-i)%ra<1e-4)return l[0]=f,l[1]=h,u-e;if(a){var c=n;n=hr(i),i=hr(c)}else n=hr(n),i=hr(i);n>i&&(i+=ra);var v=Math.atan2(s,o);if(v<0&&(v+=ra),v>=n&&v<=i||v+ra>=n&&v+ra<=i)return l[0]=f,l[1]=h,u-e;var d=e*Math.cos(n)+r,p=e*Math.sin(n)+t,g=e*Math.cos(i)+r,y=e*Math.sin(i)+t,m=(d-o)*(d-o)+(p-s)*(p-s),_=(g-o)*(g-o)+(y-s)*(y-s);return m<_?(l[0]=d,l[1]=p,Math.sqrt(m)):(l[0]=g,l[1]=y,Math.sqrt(_))}function Ps(r,t,e,n,i,a,o,s){var l=i-r,u=a-t,f=e-r,h=n-t,c=Math.sqrt(f*f+h*h);f/=c,h/=c;var v=l*f+u*h,d=v/c;s&&(d=Math.min(Math.max(d,0),1)),d*=c;var p=o[0]=r+d*f,g=o[1]=t+d*h;return Math.sqrt((p-i)*(p-i)+(g-a)*(g-a))}function Z_(r,t,e,n,i,a,o){e<0&&(r=r+e,e=-e),n<0&&(t=t+n,n=-n);var s=r+e,l=t+n,u=o[0]=Math.min(Math.max(i,r),s),f=o[1]=Math.min(Math.max(a,t),l);return Math.sqrt((u-i)*(u-i)+(f-a)*(f-a))}var Me=[];function p2(r,t,e){var n=Z_(t.x,t.y,t.width,t.height,r.x,r.y,Me);return e.set(Me[0],Me[1]),n}function g2(r,t,e){for(var n=0,i=0,a=0,o=0,s,l,u=1/0,f=t.data,h=r.x,c=r.y,v=0;v<f.length;){var d=f[v++];v===1&&(n=f[v],i=f[v+1],a=n,o=i);var p=u;switch(d){case pn.M:a=f[v++],o=f[v++],n=a,i=o;break;case pn.L:p=Ps(n,i,f[v],f[v+1],h,c,Me,!0),n=f[v++],i=f[v++];break;case pn.C:p=By(n,i,f[v++],f[v++],f[v++],f[v++],f[v],f[v+1],h,c,Me),n=f[v++],i=f[v++];break;case pn.Q:p=Fy(n,i,f[v++],f[v++],f[v],f[v+1],h,c,Me),n=f[v++],i=f[v++];break;case pn.A:var g=f[v++],y=f[v++],m=f[v++],_=f[v++],S=f[v++],w=f[v++];v+=1;var x=!!(1-f[v++]);s=Math.cos(S)*m+g,l=Math.sin(S)*_+y,v<=1&&(a=s,o=l);var b=(h-g)*_/m+g;p=d2(g,y,_,S,S+w,x,b,c,Me),n=Math.cos(S+w)*m+g,i=Math.sin(S+w)*_+y;break;case pn.R:a=n=f[v++],o=i=f[v++];var T=f[v++],C=f[v++];p=Z_(a,o,T,C,h,c,Me);break;case pn.Z:p=Ps(n,i,a,o,h,c,Me,!0),n=a,i=o;break}p<u&&(u=p,e.set(Me[0],Me[1]))}return u}var Re=new X,gt=new X,Dt=new X,qe=new X,Xe=new X;function Sp(r,t){if(r){var e=r.getTextGuideLine(),n=r.getTextContent();if(n&&e){var i=r.textGuideLineConfig||{},a=[[0,0],[0,0],[0,0]],o=i.candidates||v2,s=n.getBoundingRect().clone();s.applyTransform(n.getComputedTransform());var l=1/0,u=i.anchor,f=r.getComputedTransform(),h=f&&Hs([],f),c=t.get("length2")||0;u&&Dt.copy(u);for(var v=0;v<o.length;v++){var d=o[v];c2(d,0,s,Re,qe),X.scaleAndAdd(gt,Re,qe,c),gt.transform(h);var p=r.getBoundingRect(),g=u?u.distance(gt):r instanceof it?g2(gt,r.path,Dt):p2(gt,p,Dt);g<l&&(l=g,gt.transform(f),Dt.transform(f),Dt.toArray(a[0]),gt.toArray(a[1]),Re.toArray(a[2]))}$_(a,t.get("minTurnAngle")),e.setShape({points:a})}}}var Rs=[],Xt=new X;function $_(r,t){if(t<=180&&t>0){t=t/180*Math.PI,Re.fromArray(r[0]),gt.fromArray(r[1]),Dt.fromArray(r[2]),X.sub(qe,Re,gt),X.sub(Xe,Dt,gt);var e=qe.len(),n=Xe.len();if(!(e<.001||n<.001)){qe.scale(1/e),Xe.scale(1/n);var i=qe.dot(Xe),a=Math.cos(t);if(a<i){var o=Ps(gt.x,gt.y,Dt.x,Dt.y,Re.x,Re.y,Rs,!1);Xt.fromArray(Rs),Xt.scaleAndAdd(Xe,o/Math.tan(Math.PI-t));var s=Dt.x!==gt.x?(Xt.x-gt.x)/(Dt.x-gt.x):(Xt.y-gt.y)/(Dt.y-gt.y);if(isNaN(s))return;s<0?X.copy(Xt,gt):s>1&&X.copy(Xt,Dt),Xt.toArray(r[1])}}}}function y2(r,t,e){if(e<=180&&e>0){e=e/180*Math.PI,Re.fromArray(r[0]),gt.fromArray(r[1]),Dt.fromArray(r[2]),X.sub(qe,gt,Re),X.sub(Xe,Dt,gt);var n=qe.len(),i=Xe.len();if(!(n<.001||i<.001)){qe.scale(1/n),Xe.scale(1/i);var a=qe.dot(t),o=Math.cos(e);if(a<o){var s=Ps(gt.x,gt.y,Dt.x,Dt.y,Re.x,Re.y,Rs,!1);Xt.fromArray(Rs);var l=Math.PI/2,u=Math.acos(Xe.dot(t)),f=l+u-e;if(f>=l)X.copy(Xt,Dt);else{Xt.scaleAndAdd(Xe,s/Math.tan(Math.PI/2-f));var h=Dt.x!==gt.x?(Xt.x-gt.x)/(Dt.x-gt.x):(Xt.y-gt.y)/(Dt.y-gt.y);if(isNaN(h))return;h<0?X.copy(Xt,gt):h>1&&X.copy(Xt,Dt)}Xt.toArray(r[1])}}}}function Mu(r,t,e,n){var i=e==="normal",a=i?r:r.ensureState(e);a.ignore=t;var o=n.get("smooth");o&&o===!0&&(o=.3),a.shape=a.shape||{},o>0&&(a.shape.smooth=o);var s=n.getModel("lineStyle").getLineStyle();i?r.useStyle(s):a.style=s}function m2(r,t){var e=t.smooth,n=t.points;if(n)if(r.moveTo(n[0][0],n[0][1]),e>0&&n.length>=3){var i=ef(n[0],n[1]),a=ef(n[1],n[2]);if(!i||!a){r.lineTo(n[1][0],n[1][1]),r.lineTo(n[2][0],n[2][1]);return}var o=Math.min(i,a)*e,s=Xo([],n[1],n[0],o/i),l=Xo([],n[1],n[2],o/a),u=Xo([],s,l,.5);r.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),r.bezierCurveTo(l[0],l[1],l[0],l[1],n[2][0],n[2][1])}else for(var f=1;f<n.length;f++)r.lineTo(n[f][0],n[f][1])}function q_(r,t,e){var n=r.getTextGuideLine(),i=r.getTextContent();if(!i){n&&r.removeTextGuideLine();return}for(var a=t.normal,o=a.get("show"),s=i.ignore,l=0;l<_s.length;l++){var u=_s[l],f=t[u],h=u==="normal";if(f){var c=f.get("show"),v=h?s:rt(i.states[u]&&i.states[u].ignore,s);if(v||!rt(c,o)){var d=h?n:n&&n.states[u];d&&(d.ignore=!0),n&&Mu(n,!0,u,f);continue}n||(n=new Xr,r.setTextGuideLine(n),!h&&(s||!o)&&Mu(n,!0,"normal",t.normal),r.stateProxy&&(n.stateProxy=r.stateProxy)),Mu(n,!1,u,f)}}if(n){Q(n.style,e),n.style.fill=null;var p=a.get("showAbove"),g=r.textGuideLineConfig=r.textGuideLineConfig||{};g.showAbove=p||!1,n.buildPath=m2}}function K_(r,t){t=t||"labelLine";for(var e={normal:r.getModel(t)},n=0;n<_e.length;n++){var i=_e[n];e[i]=r.getModel([i,t])}return e}function Q_(r){for(var t=[],e=0;e<r.length;e++){var n=r[e];if(!n.defaultAttr.ignore){var i=n.label,a=i.getComputedTransform(),o=i.getBoundingRect(),s=!a||a[1]<1e-5&&a[2]<1e-5,l=i.style.margin||0,u=o.clone();u.applyTransform(a),u.x-=l/2,u.y-=l/2,u.width+=l,u.height+=l;var f=s?new Ss(o,a):null;t.push({label:i,labelLine:n.labelLine,rect:u,localRect:o,obb:f,priority:n.priority,defaultAttr:n.defaultAttr,layoutOption:n.computedLayoutOption,axisAligned:s,transform:a})}}return t}function J_(r,t,e,n,i,a){var o=r.length;if(o<2)return;r.sort(function(x,b){return x.rect[t]-b.rect[t]});for(var s=0,l,u=!1,f=0;f<o;f++){var h=r[f],c=h.rect;l=c[t]-s,l<0&&(c[t]-=l,h.label[t]-=l,u=!0),s=c[t]+c[e]}var v=r[0],d=r[o-1],p,g;y(),p<0&&S(-p,.8),g<0&&S(g,.8),y(),m(p,g,1),m(g,p,-1),y(),p<0&&w(-p),g<0&&w(g);function y(){p=v.rect[t]-n,g=i-d.rect[t]-d.rect[e]}function m(x,b,T){if(x<0){var C=Math.min(b,-x);if(C>0){_(C*T,0,o);var D=C+x;D<0&&S(-D*T,1)}else S(-x*T,1)}}function _(x,b,T){x!==0&&(u=!0);for(var C=b;C<T;C++){var D=r[C],A=D.rect;A[t]+=x,D.label[t]+=x}}function S(x,b){for(var T=[],C=0,D=1;D<o;D++){var A=r[D-1].rect,I=Math.max(r[D].rect[t]-A[t]-A[e],0);T.push(I),C+=I}if(C){var L=Math.min(Math.abs(x)/C,b);if(x>0)for(var D=0;D<o-1;D++){var P=T[D]*L;_(P,0,D+1)}else for(var D=o-1;D>0;D--){var P=T[D-1]*L;_(-P,D,o)}}}function w(x){var b=x<0?-1:1;x=Math.abs(x);for(var T=Math.ceil(x/(o-1)),C=0;C<o-1;C++)if(b>0?_(T,0,C+1):_(-T,o-C-1,o),x-=T,x<=0)return}return u}function _2(r,t,e,n){return J_(r,"x","width",t,e)}function j_(r,t,e,n){return J_(r,"y","height",t,e)}function t1(r){var t=[];r.sort(function(p,g){return g.priority-p.priority});var e=new ut(0,0,0,0);function n(p){if(!p.ignore){var g=p.ensureState("emphasis");g.ignore==null&&(g.ignore=!1)}p.ignore=!0}for(var i=0;i<r.length;i++){var a=r[i],o=a.axisAligned,s=a.localRect,l=a.transform,u=a.label,f=a.labelLine;e.copy(a.rect),e.width-=.1,e.height-=.1,e.x+=.05,e.y+=.05;for(var h=a.obb,c=!1,v=0;v<t.length;v++){var d=t[v];if(e.intersect(d.rect)){if(o&&d.axisAligned){c=!0;break}if(d.obb||(d.obb=new Ss(d.localRect,d.transform)),h||(h=new Ss(s,l)),h.intersect(d.obb)){c=!0;break}}}c?(n(u),f&&n(f)):(u.attr("ignore",a.defaultAttr.ignore),f&&f.attr("ignore",a.defaultAttr.labelGuideIgnore),t.push(a))}}function S2(r){if(r){for(var t=[],e=0;e<r.length;e++)t.push(r[e].slice());return t}}function x2(r,t){var e=r.label,n=t&&t.getTextGuideLine();return{dataIndex:r.dataIndex,dataType:r.dataType,seriesIndex:r.seriesModel.seriesIndex,text:r.label.style.text,rect:r.hostRect,labelRect:r.rect,align:e.style.align,verticalAlign:e.style.verticalAlign,labelLinePoints:S2(n&&n.shape.points)}}var xp=["align","verticalAlign","width","height","fontSize"],Ut=new Ka,Iu=_t(),w2=_t();function Bo(r,t,e){for(var n=0;n<e.length;n++){var i=e[n];t[i]!=null&&(r[i]=t[i])}}var No=["x","y","rotation"],b2=function(){function r(){this._labelList=[],this._chartViewList=[]}return r.prototype.clearLabels=function(){this._labelList=[],this._chartViewList=[]},r.prototype._addLabel=function(t,e,n,i,a){var o=i.style,s=i.__hostTarget,l=s.textConfig||{},u=i.getComputedTransform(),f=i.getBoundingRect().plain();ut.applyTransform(f,f,u),u?Ut.setLocalTransform(u):(Ut.x=Ut.y=Ut.rotation=Ut.originX=Ut.originY=0,Ut.scaleX=Ut.scaleY=1),Ut.rotation=hr(Ut.rotation);var h=i.__hostTarget,c;if(h){c=h.getBoundingRect().plain();var v=h.getComputedTransform();ut.applyTransform(c,c,v)}var d=c&&h.getTextGuideLine();this._labelList.push({label:i,labelLine:d,seriesModel:n,dataIndex:t,dataType:e,layoutOption:a,computedLayoutOption:null,rect:f,hostRect:c,priority:c?c.width*c.height:0,defaultAttr:{ignore:i.ignore,labelGuideIgnore:d&&d.ignore,x:Ut.x,y:Ut.y,scaleX:Ut.scaleX,scaleY:Ut.scaleY,rotation:Ut.rotation,style:{x:o.x,y:o.y,align:o.align,verticalAlign:o.verticalAlign,width:o.width,height:o.height,fontSize:o.fontSize},cursor:i.cursor,attachedPos:l.position,attachedRot:l.rotation}})},r.prototype.addLabelsOfSeries=function(t){var e=this;this._chartViewList.push(t);var n=t.__model,i=n.get("labelLayout");(q(i)||mt(i).length)&&t.group.traverse(function(a){if(a.ignore)return!0;var o=a.getTextContent(),s=st(a);o&&!o.disableLabelLayout&&e._addLabel(s.dataIndex,s.dataType,n,o,i)})},r.prototype.updateLayoutConfig=function(t){var e=t.getWidth(),n=t.getHeight();function i(_,S){return function(){Sp(_,S)}}for(var a=0;a<this._labelList.length;a++){var o=this._labelList[a],s=o.label,l=s.__hostTarget,u=o.defaultAttr,f=void 0;q(o.layoutOption)?f=o.layoutOption(x2(o,l)):f=o.layoutOption,f=f||{},o.computedLayoutOption=f;var h=Math.PI/180;l&&l.setTextConfig({local:!1,position:f.x!=null||f.y!=null?null:u.attachedPos,rotation:f.rotate!=null?f.rotate*h:u.attachedRot,offset:[f.dx||0,f.dy||0]});var c=!1;if(f.x!=null?(s.x=Z(f.x,e),s.setStyle("x",0),c=!0):(s.x=u.x,s.setStyle("x",u.style.x)),f.y!=null?(s.y=Z(f.y,n),s.setStyle("y",0),c=!0):(s.y=u.y,s.setStyle("y",u.style.y)),f.labelLinePoints){var v=l.getTextGuideLine();v&&(v.setShape({points:f.labelLinePoints}),c=!1)}var d=Iu(s);d.needsUpdateLabelLine=c,s.rotation=f.rotate!=null?f.rotate*h:u.rotation,s.scaleX=u.scaleX,s.scaleY=u.scaleY;for(var p=0;p<xp.length;p++){var g=xp[p];s.setStyle(g,f[g]!=null?f[g]:u.style[g])}if(f.draggable){if(s.draggable=!0,s.cursor="move",l){var y=o.seriesModel;if(o.dataIndex!=null){var m=o.seriesModel.getData(o.dataType);y=m.getItemModel(o.dataIndex)}s.on("drag",i(l,y.getModel("labelLine")))}}else s.off("drag"),s.cursor=u.cursor}},r.prototype.layout=function(t){var e=t.getWidth(),n=t.getHeight(),i=Q_(this._labelList),a=Tt(i,function(l){return l.layoutOption.moveOverlap==="shiftX"}),o=Tt(i,function(l){return l.layoutOption.moveOverlap==="shiftY"});_2(a,0,e),j_(o,0,n);var s=Tt(i,function(l){return l.layoutOption.hideOverlap});t1(s)},r.prototype.processLabelsOverall=function(){var t=this;M(this._chartViewList,function(e){var n=e.__model,i=e.ignoreLabelLineUpdate,a=n.isAnimationEnabled();e.group.traverse(function(o){if(o.ignore&&!o.forceLabelAnimation)return!0;var s=!i,l=o.getTextContent();!s&&l&&(s=Iu(l).needsUpdateLabelLine),s&&t._updateLabelLine(o,n),a&&t._animateLabels(o,n)})})},r.prototype._updateLabelLine=function(t,e){var n=t.getTextContent(),i=st(t),a=i.dataIndex;if(n&&a!=null){var o=e.getData(i.dataType),s=o.getItemModel(a),l={},u=o.getItemVisual(a,"style");if(u){var f=o.getVisual("drawType");l.stroke=u[f]}var h=s.getModel("labelLine");q_(t,K_(s),l),Sp(t,h)}},r.prototype._animateLabels=function(t,e){var n=t.getTextContent(),i=t.getTextGuideLine();if(n&&(t.forceLabelAnimation||!n.ignore&&!n.invisible&&!t.disableLabelAnimation&&!ci(t))){var a=Iu(n),o=a.oldLayout,s=st(t),l=s.dataIndex,u={x:n.x,y:n.y,rotation:n.rotation},f=e.getData(s.dataType);if(o){n.attr(o);var c=t.prevStates;c&&(lt(c,"select")>=0&&n.attr(a.oldLayoutSelect),lt(c,"emphasis")>=0&&n.attr(a.oldLayoutEmphasis)),bt(n,u,e,l)}else if(n.attr(u),!Ei(n).valueAnimation){var h=rt(n.style.opacity,1);n.style.opacity=0,Pt(n,{style:{opacity:h}},e,l)}if(a.oldLayout=u,n.states.select){var v=a.oldLayoutSelect={};Bo(v,u,No),Bo(v,n.states.select,No)}if(n.states.emphasis){var d=a.oldLayoutEmphasis={};Bo(d,u,No),Bo(d,n.states.emphasis,No)}Ym(n,l,f,e,e)}if(i&&!i.ignore&&!i.invisible){var a=w2(i),o=a.oldLayout,p={points:i.shape.points};o?(i.attr({shape:o}),bt(i,{shape:p},e)):(i.setShape(p),i.style.strokePercent=0,Pt(i,{style:{strokePercent:1}},e)),a.oldLayout=p}},r}(),Lu=_t();function T2(r){r.registerUpdateLifecycle("series:beforeupdate",function(t,e,n){var i=Lu(e).labelManager;i||(i=Lu(e).labelManager=new b2),i.clearLabels()}),r.registerUpdateLifecycle("series:layoutlabels",function(t,e,n){var i=Lu(e).labelManager;n.updatedSeries.forEach(function(a){i.addLabelsOfSeries(e.getViewOfSeriesModel(a))}),i.updateLayoutConfig(e),i.layout(e),i.processLabelsOverall()})}var C2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e){return pl(null,this,{useEncodeDefaulter:!0})},t.prototype.getLegendIcon=function(e){var n=new yt,i=Ee("line",0,e.itemHeight/2,e.itemWidth,0,e.lineStyle.stroke,!1);n.add(i),i.setStyle(e.lineStyle);var a=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=a==="none"?"circle":a,l=e.itemHeight*.8,u=Ee(s,(e.itemWidth-l)/2,(e.itemHeight-l)/2,l,l,e.itemStyle.fill);n.add(u),u.setStyle(e.itemStyle);var f=e.iconRotate==="inherit"?o:e.iconRotate||0;return u.rotation=f*Math.PI/180,u.setOrigin([e.itemWidth/2,e.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill="#fff",u.style.lineWidth=2),n},t.type="series.line",t.dependencies=["grid","polar"],t.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:4,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},t}(se);function _l(r,t){var e=r.mapDimensionsAll("defaultedLabel"),n=e.length;if(n===1){var i=Ti(r,t,e[0]);return i!=null?i+"":null}else if(n){for(var a=[],o=0;o<e.length;o++)a.push(Ti(r,t,e[o]));return a.join(" ")}}function e1(r,t){var e=r.mapDimensionsAll("defaultedLabel");if(!V(t))return t+"";for(var n=[],i=0;i<e.length;i++){var a=r.getDimensionIndex(e[i]);a>=0&&n.push(t[a])}return n.join(" ")}var mv=function(r){N(t,r);function t(e,n,i,a){var o=r.call(this)||this;return o.updateData(e,n,i,a),o}return t.prototype._createSymbol=function(e,n,i,a,o){this.removeAll();var s=Ee(e,-1,-1,2,2,null,o);s.attr({z2:100,culling:!0,scaleX:a[0]/2,scaleY:a[1]/2}),s.drift=D2,this._symbolType=e,this.add(s)},t.prototype.stopSymbolAnimation=function(e){this.childAt(0).stopAnimation(null,e)},t.prototype.getSymbolType=function(){return this._symbolType},t.prototype.getSymbolPath=function(){return this.childAt(0)},t.prototype.highlight=function(){xi(this.childAt(0))},t.prototype.downplay=function(){wi(this.childAt(0))},t.prototype.setZ=function(e,n){var i=this.childAt(0);i.zlevel=e,i.z=n},t.prototype.setDraggable=function(e,n){var i=this.childAt(0);i.draggable=e,i.cursor=!n&&e?"move":i.cursor},t.prototype.updateData=function(e,n,i,a){this.silent=!1;var o=e.getItemVisual(n,"symbol")||"circle",s=e.hostModel,l=t.getSymbolSize(e,n),u=o!==this._symbolType,f=a&&a.disableAnimation;if(u){var h=e.getItemVisual(n,"symbolKeepAspect");this._createSymbol(o,e,n,l,h)}else{var c=this.childAt(0);c.silent=!1;var v={scaleX:l[0]/2,scaleY:l[1]/2};f?c.attr(v):bt(c,v,s,n),Ba(c)}if(this._updateCommon(e,n,l,i,a),u){var c=this.childAt(0);if(!f){var v={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:c.style.opacity}};c.scaleX=c.scaleY=0,c.style.opacity=0,Pt(c,v,s,n)}}f&&this.childAt(0).stopAnimation("leave")},t.prototype._updateCommon=function(e,n,i,a,o){var s=this.childAt(0),l=e.hostModel,u,f,h,c,v,d,p,g,y;if(a&&(u=a.emphasisItemStyle,f=a.blurItemStyle,h=a.selectItemStyle,c=a.focus,v=a.blurScope,p=a.labelStatesModels,g=a.hoverScale,y=a.cursorStyle,d=a.emphasisDisabled),!a||e.hasItemOption){var m=a&&a.itemModel?a.itemModel:e.getItemModel(n),_=m.getModel("emphasis");u=_.getModel("itemStyle").getItemStyle(),h=m.getModel(["select","itemStyle"]).getItemStyle(),f=m.getModel(["blur","itemStyle"]).getItemStyle(),c=_.get("focus"),v=_.get("blurScope"),d=_.get("disabled"),p=En(m),g=_.getShallow("scale"),y=m.getShallow("cursor")}var S=e.getItemVisual(n,"symbolRotate");s.attr("rotation",(S||0)*Math.PI/180||0);var w=sv(e.getItemVisual(n,"symbolOffset"),i);w&&(s.x=w[0],s.y=w[1]),y&&s.attr("cursor",y);var x=e.getItemVisual(n,"style"),b=x.fill;if(s instanceof Ne){var T=s.style;s.useStyle(F({image:T.image,x:T.x,y:T.y,width:T.width,height:T.height},x))}else s.__isEmptyBrush?s.useStyle(F({},x)):s.useStyle(x),s.style.decal=null,s.setColor(b,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var C=e.getItemVisual(n,"liftZ"),D=this._z2;C!=null?D==null&&(this._z2=s.z2,s.z2+=C):D!=null&&(s.z2=D,this._z2=null);var A=o&&o.useNameLabel;Rn(s,p,{labelFetcher:l,labelDataIndex:n,defaultText:I,inheritColor:b,defaultOpacity:x.opacity});function I(R){return A?e.getName(R):_l(e,R)}this._sizeX=i[0]/2,this._sizeY=i[1]/2;var L=s.ensureState("emphasis");L.style=u,s.ensureState("select").style=h,s.ensureState("blur").style=f;var P=g==null||g===!0?Math.max(1.1,3/this._sizeY):isFinite(g)&&g>0?+g:1;L.scaleX=this._sizeX*P,L.scaleY=this._sizeY*P,this.setSymbolScale(1),mr(this,c,v,d)},t.prototype.setSymbolScale=function(e){this.scaleX=this.scaleY=e},t.prototype.fadeOut=function(e,n,i){var a=this.childAt(0),o=st(this).dataIndex,s=i&&i.animation;if(this.silent=a.silent=!0,i&&i.fadeLabel){var l=a.getTextContent();l&&Oa(l,{style:{opacity:0}},n,{dataIndex:o,removeOpt:s,cb:function(){a.removeTextContent()}})}else a.removeTextContent();Oa(a,{style:{opacity:0},scaleX:0,scaleY:0},n,{dataIndex:o,cb:e,removeOpt:s})},t.getSymbolSize=function(e,n){return X0(e.getItemVisual(n,"symbolSize"))},t}(yt);function D2(r,t){this.parent.drift(r,t)}function Pu(r,t,e,n){return t&&!isNaN(t[0])&&!isNaN(t[1])&&!(n.isIgnore&&n.isIgnore(e))&&!(n.clipShape&&!n.clipShape.contain(t[0],t[1]))&&r.getItemVisual(e,"symbol")!=="none"}function wp(r){return r!=null&&!Y(r)&&(r={isIgnore:r}),r||{}}function bp(r){var t=r.hostModel,e=t.getModel("emphasis");return{emphasisItemStyle:e.getModel("itemStyle").getItemStyle(),blurItemStyle:t.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:t.getModel(["select","itemStyle"]).getItemStyle(),focus:e.get("focus"),blurScope:e.get("blurScope"),emphasisDisabled:e.get("disabled"),hoverScale:e.get("scale"),labelStatesModels:En(t),cursorStyle:t.get("cursor")}}var r1=function(){function r(t){this.group=new yt,this._SymbolCtor=t||mv}return r.prototype.updateData=function(t,e){this._progressiveEls=null,e=wp(e);var n=this.group,i=t.hostModel,a=this._data,o=this._SymbolCtor,s=e.disableAnimation,l=bp(t),u={disableAnimation:s},f=e.getSymbolPoint||function(h){return t.getItemLayout(h)};a||n.removeAll(),t.diff(a).add(function(h){var c=f(h);if(Pu(t,c,h,e)){var v=new o(t,h,l,u);v.setPosition(c),t.setItemGraphicEl(h,v),n.add(v)}}).update(function(h,c){var v=a.getItemGraphicEl(c),d=f(h);if(!Pu(t,d,h,e)){n.remove(v);return}var p=t.getItemVisual(h,"symbol")||"circle",g=v&&v.getSymbolType&&v.getSymbolType();if(!v||g&&g!==p)n.remove(v),v=new o(t,h,l,u),v.setPosition(d);else{v.updateData(t,h,l,u);var y={x:d[0],y:d[1]};s?v.attr(y):bt(v,y,i)}n.add(v),t.setItemGraphicEl(h,v)}).remove(function(h){var c=a.getItemGraphicEl(h);c&&c.fadeOut(function(){n.remove(c)},i)}).execute(),this._getSymbolPoint=f,this._data=t},r.prototype.updateLayout=function(){var t=this,e=this._data;e&&e.eachItemGraphicEl(function(n,i){var a=t._getSymbolPoint(i);n.setPosition(a),n.markRedraw()})},r.prototype.incrementalPrepareUpdate=function(t){this._seriesScope=bp(t),this._data=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(t,e,n){this._progressiveEls=[],n=wp(n);function i(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var a=t.start;a<t.end;a++){var o=e.getItemLayout(a);if(Pu(e,o,a,n)){var s=new this._SymbolCtor(e,a,this._seriesScope);s.traverse(i),s.setPosition(o),this.group.add(s),e.setItemGraphicEl(a,s),this._progressiveEls.push(s)}}},r.prototype.eachRendered=function(t){rl(this._progressiveEls||this.group,t)},r.prototype.remove=function(t){var e=this.group,n=this._data;n&&t?n.eachItemGraphicEl(function(i){i.fadeOut(function(){e.remove(i)},n.hostModel)}):e.removeAll()},r}();function n1(r,t,e){var n=r.getBaseAxis(),i=r.getOtherAxis(n),a=A2(i,e),o=n.dim,s=i.dim,l=t.mapDimension(s),u=t.mapDimension(o),f=s==="x"||s==="radius"?1:0,h=H(r.dimensions,function(d){return t.mapDimension(d)}),c=!1,v=t.getCalculationInfo("stackResultDimension");return Ci(t,h[0])&&(c=!0,h[0]=v),Ci(t,h[1])&&(c=!0,h[1]=v),{dataDimsForPoint:h,valueStart:a,valueAxisDim:s,baseAxisDim:o,stacked:!!c,valueDim:l,baseDim:u,baseDataOffset:f,stackedOverDimension:t.getCalculationInfo("stackedOverDimension")}}function A2(r,t){var e=0,n=r.scale.getExtent();return t==="start"?e=n[0]:t==="end"?e=n[1]:ct(t)&&!isNaN(t)?e=t:n[0]>0?e=n[0]:n[1]<0&&(e=n[1]),e}function i1(r,t,e,n){var i=NaN;r.stacked&&(i=e.get(e.getCalculationInfo("stackedOverDimension"),n)),isNaN(i)&&(i=r.valueStart);var a=r.baseDataOffset,o=[];return o[a]=e.get(r.baseDim,n),o[1-a]=i,t.dataToPoint(o)}function M2(r,t){var e=[];return t.diff(r).add(function(n){e.push({cmd:"+",idx:n})}).update(function(n,i){e.push({cmd:"=",idx:i,idx1:n})}).remove(function(n){e.push({cmd:"-",idx:n})}).execute(),e}function I2(r,t,e,n,i,a,o,s){for(var l=M2(r,t),u=[],f=[],h=[],c=[],v=[],d=[],p=[],g=n1(i,t,o),y=r.getLayout("points")||[],m=t.getLayout("points")||[],_=0;_<l.length;_++){var S=l[_],w=!0,x=void 0,b=void 0;switch(S.cmd){case"=":x=S.idx*2,b=S.idx1*2;var T=y[x],C=y[x+1],D=m[b],A=m[b+1];(isNaN(T)||isNaN(C))&&(T=D,C=A),u.push(T,C),f.push(D,A),h.push(e[x],e[x+1]),c.push(n[b],n[b+1]),p.push(t.getRawIndex(S.idx1));break;case"+":var I=S.idx,L=g.dataDimsForPoint,P=i.dataToPoint([t.get(L[0],I),t.get(L[1],I)]);b=I*2,u.push(P[0],P[1]),f.push(m[b],m[b+1]);var R=i1(g,i,t,I);h.push(R[0],R[1]),c.push(n[b],n[b+1]),p.push(t.getRawIndex(I));break;case"-":w=!1}w&&(v.push(S),d.push(d.length))}d.sort(function(at,Rt){return p[at]-p[Rt]});for(var E=u.length,O=vr(E),k=vr(E),B=vr(E),z=vr(E),G=[],_=0;_<d.length;_++){var U=d[_],j=_*2,et=U*2;O[j]=u[et],O[j+1]=u[et+1],k[j]=f[et],k[j+1]=f[et+1],B[j]=h[et],B[j+1]=h[et+1],z[j]=c[et],z[j+1]=c[et+1],G[_]=v[U]}return{current:O,next:k,stackedOnCurrent:B,stackedOnNext:z,status:G}}var Ar=Math.min,Mr=Math.max;function Tn(r,t){return isNaN(r)||isNaN(t)}function Kf(r,t,e,n,i,a,o,s,l){for(var u,f,h,c,v,d,p=e,g=0;g<n;g++){var y=t[p*2],m=t[p*2+1];if(p>=i||p<0)break;if(Tn(y,m)){if(l){p+=a;continue}break}if(p===e)r[a>0?"moveTo":"lineTo"](y,m),h=y,c=m;else{var _=y-u,S=m-f;if(_*_+S*S<.5){p+=a;continue}if(o>0){for(var w=p+a,x=t[w*2],b=t[w*2+1];x===y&&b===m&&g<n;)g++,w+=a,p+=a,x=t[w*2],b=t[w*2+1],y=t[p*2],m=t[p*2+1],_=y-u,S=m-f;var T=g+1;if(l)for(;Tn(x,b)&&T<n;)T++,w+=a,x=t[w*2],b=t[w*2+1];var C=.5,D=0,A=0,I=void 0,L=void 0;if(T>=n||Tn(x,b))v=y,d=m;else{D=x-u,A=b-f;var P=y-u,R=x-y,E=m-f,O=b-m,k=void 0,B=void 0;if(s==="x"){k=Math.abs(P),B=Math.abs(R);var z=D>0?1:-1;v=y-z*k*o,d=m,I=y+z*B*o,L=m}else if(s==="y"){k=Math.abs(E),B=Math.abs(O);var G=A>0?1:-1;v=y,d=m-G*k*o,I=y,L=m+G*B*o}else k=Math.sqrt(P*P+E*E),B=Math.sqrt(R*R+O*O),C=B/(B+k),v=y-D*o*(1-C),d=m-A*o*(1-C),I=y+D*o*C,L=m+A*o*C,I=Ar(I,Mr(x,y)),L=Ar(L,Mr(b,m)),I=Mr(I,Ar(x,y)),L=Mr(L,Ar(b,m)),D=I-y,A=L-m,v=y-D*k/B,d=m-A*k/B,v=Ar(v,Mr(u,y)),d=Ar(d,Mr(f,m)),v=Mr(v,Ar(u,y)),d=Mr(d,Ar(f,m)),D=y-v,A=m-d,I=y+D*B/k,L=m+A*B/k}r.bezierCurveTo(h,c,v,d,y,m),h=I,c=L}else r.lineTo(y,m)}u=y,f=m,p+=a}return g}var a1=function(){function r(){this.smooth=0,this.smoothConstraint=!0}return r}(),L2=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n.type="ec-polyline",n}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new a1},t.prototype.buildPath=function(e,n){var i=n.points,a=0,o=i.length/2;if(n.connectNulls){for(;o>0&&Tn(i[o*2-2],i[o*2-1]);o--);for(;a<o&&Tn(i[a*2],i[a*2+1]);a++);}for(;a<o;)a+=Kf(e,i,a,o,o,1,n.smooth,n.smoothMonotone,n.connectNulls)+1},t.prototype.getPointOn=function(e,n){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var i=this.path,a=i.data,o=yr.CMD,s,l,u=n==="x",f=[],h=0;h<a.length;){var c=a[h++],v=void 0,d=void 0,p=void 0,g=void 0,y=void 0,m=void 0,_=void 0;switch(c){case o.M:s=a[h++],l=a[h++];break;case o.L:if(v=a[h++],d=a[h++],_=u?(e-s)/(v-s):(e-l)/(d-l),_<=1&&_>=0){var S=u?(d-l)*_+l:(v-s)*_+s;return u?[e,S]:[S,e]}s=v,l=d;break;case o.C:v=a[h++],d=a[h++],p=a[h++],g=a[h++],y=a[h++],m=a[h++];var w=u?vs(s,v,p,y,e,f):vs(l,d,g,m,e,f);if(w>0)for(var x=0;x<w;x++){var b=f[x];if(b<=1&&b>=0){var S=u?Et(l,d,g,m,b):Et(s,v,p,y,b);return u?[e,S]:[S,e]}}s=y,l=m;break}}},t}(it),P2=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t}(a1),R2=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n.type="ec-polygon",n}return t.prototype.getDefaultShape=function(){return new P2},t.prototype.buildPath=function(e,n){var i=n.points,a=n.stackedOnPoints,o=0,s=i.length/2,l=n.smoothMonotone;if(n.connectNulls){for(;s>0&&Tn(i[s*2-2],i[s*2-1]);s--);for(;o<s&&Tn(i[o*2],i[o*2+1]);o++);}for(;o<s;){var u=Kf(e,i,o,s,s,1,n.smooth,l,n.connectNulls);Kf(e,a,o+u-1,u,s,-1,n.stackedOnSmooth,l,n.connectNulls),o+=u+1,e.closePath()}},t}(it);function o1(r,t,e,n,i){var a=r.getArea(),o=a.x,s=a.y,l=a.width,u=a.height,f=e.get(["lineStyle","width"])||0;o-=f/2,s-=f/2,l+=f,u+=f,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var h=new St({shape:{x:o,y:s,width:l,height:u}});if(t){var c=r.getBaseAxis(),v=c.isHorizontal(),d=c.inverse;v?(d&&(h.shape.x+=l),h.shape.width=0):(d||(h.shape.y+=u),h.shape.height=0);var p=q(i)?function(g){i(g,h)}:null;Pt(h,{shape:{width:l,height:u,x:o,y:s}},e,null,n,p)}return h}function s1(r,t,e){var n=r.getArea(),i=Mt(n.r0,1),a=Mt(n.r,1),o=new Se({shape:{cx:Mt(r.cx,1),cy:Mt(r.cy,1),r0:i,r:a,startAngle:n.startAngle,endAngle:n.endAngle,clockwise:n.clockwise}});if(t){var s=r.getBaseAxis().dim==="angle";s?o.shape.endAngle=n.startAngle:o.shape.r=i,Pt(o,{shape:{endAngle:n.endAngle,r:a}},e)}return o}function l1(r,t,e,n,i){if(r){if(r.type==="polar")return s1(r,t,e);if(r.type==="cartesian2d")return o1(r,t,e,n,i)}else return null;return null}function _v(r,t){return r.type===t}function Tp(r,t){if(r.length===t.length){for(var e=0;e<r.length;e++)if(r[e]!==t[e])return;return!0}}function Cp(r){for(var t=1/0,e=1/0,n=-1/0,i=-1/0,a=0;a<r.length;){var o=r[a++],s=r[a++];isNaN(o)||(t=Math.min(o,t),n=Math.max(o,n)),isNaN(s)||(e=Math.min(s,e),i=Math.max(s,i))}return[[t,e],[n,i]]}function Dp(r,t){var e=Cp(r),n=e[0],i=e[1],a=Cp(t),o=a[0],s=a[1];return Math.max(Math.abs(n[0]-o[0]),Math.abs(n[1]-o[1]),Math.abs(i[0]-s[0]),Math.abs(i[1]-s[1]))}function Ap(r){return ct(r)?r:r?.5:0}function E2(r,t,e){if(!e.valueDim)return[];for(var n=t.count(),i=vr(n*2),a=0;a<n;a++){var o=i1(e,r,t,a);i[a*2]=o[0],i[a*2+1]=o[1]}return i}function Ir(r,t,e,n,i){var a=e.getBaseAxis(),o=a.dim==="x"||a.dim==="radius"?0:1,s=[],l=0,u=[],f=[],h=[],c=[];if(i){for(l=0;l<r.length;l+=2){var v=t||r;!isNaN(v[l])&&!isNaN(v[l+1])&&c.push(r[l],r[l+1])}r=c}for(l=0;l<r.length-2;l+=2)switch(h[0]=r[l+2],h[1]=r[l+3],f[0]=r[l],f[1]=r[l+1],s.push(f[0],f[1]),n){case"end":u[o]=h[o],u[1-o]=f[1-o],s.push(u[0],u[1]);break;case"middle":var d=(f[o]+h[o])/2,p=[];u[o]=p[o]=d,u[1-o]=f[1-o],p[1-o]=h[1-o],s.push(u[0],u[1]),s.push(p[0],p[1]);break;default:u[o]=f[o],u[1-o]=h[1-o],s.push(u[0],u[1])}return s.push(r[l++],r[l++]),s}function k2(r,t){var e=[],n=r.length,i,a;function o(f,h,c){var v=f.coord,d=(c-v)/(h.coord-v),p=Yx(d,[f.color,h.color]);return{coord:c,color:p}}for(var s=0;s<n;s++){var l=r[s],u=l.coord;if(u<0)i=l;else if(u>t){a?e.push(o(a,l,t)):i&&e.push(o(i,l,0),o(i,l,t));break}else i&&(e.push(o(i,l,0)),i=null),e.push(l),a=l}return e}function O2(r,t,e){var n=r.getVisual("visualMeta");if(!(!n||!n.length||!r.count())&&t.type==="cartesian2d"){for(var i,a,o=n.length-1;o>=0;o--){var s=r.getDimensionInfo(n[o].dimension);if(i=s&&s.coordDim,i==="x"||i==="y"){a=n[o];break}}if(a){var l=t.getAxis(i),u=H(a.stops,function(_){return{coord:l.toGlobalCoord(l.dataToCoord(_.value)),color:_.color}}),f=u.length,h=a.outerColors.slice();f&&u[0].coord>u[f-1].coord&&(u.reverse(),h.reverse());var c=k2(u,i==="x"?e.getWidth():e.getHeight()),v=c.length;if(!v&&f)return u[0].coord<0?h[1]?h[1]:u[f-1].color:h[0]?h[0]:u[0].color;var d=10,p=c[0].coord-d,g=c[v-1].coord+d,y=g-p;if(y<.001)return"transparent";M(c,function(_){_.offset=(_.coord-p)/y}),c.push({offset:v?c[v-1].offset:.5,color:h[1]||"transparent"}),c.unshift({offset:v?c[0].offset:.5,color:h[0]||"transparent"});var m=new Em(0,0,0,0,c,!0);return m[i]=p,m[i+"2"]=g,m}}}function B2(r,t,e){var n=r.get("showAllSymbol"),i=n==="auto";if(!(n&&!i)){var a=e.getAxesByScale("ordinal")[0];if(a&&!(i&&N2(a,t))){var o=t.mapDimension(a.dim),s={};return M(a.getViewLabels(),function(l){var u=a.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(t.get(o,l))}}}}function N2(r,t){var e=r.getExtent(),n=Math.abs(e[1]-e[0])/r.scale.count();isNaN(n)&&(n=0);for(var i=t.count(),a=Math.max(1,Math.round(i/5)),o=0;o<i;o+=a)if(mv.getSymbolSize(t,o)[r.isHorizontal()?1:0]*1.5>n)return!1;return!0}function F2(r,t){return isNaN(r)||isNaN(t)}function z2(r){for(var t=r.length/2;t>0&&F2(r[t*2-2],r[t*2-1]);t--);return t-1}function Mp(r,t){return[r[t*2],r[t*2+1]]}function V2(r,t,e){for(var n=r.length/2,i=e==="x"?0:1,a,o,s=0,l=-1,u=0;u<n;u++)if(o=r[u*2+i],!(isNaN(o)||isNaN(r[u*2+1-i]))){if(u===0){a=o;continue}if(a<=t&&o>=t||a>=t&&o<=t){l=u;break}s=u,a=o}return{range:[s,l],t:(t-a)/(o-a)}}function u1(r){if(r.get(["endLabel","show"]))return!0;for(var t=0;t<_e.length;t++)if(r.get([_e[t],"endLabel","show"]))return!0;return!1}function Ru(r,t,e,n){if(_v(t,"cartesian2d")){var i=n.getModel("endLabel"),a=i.get("valueAnimation"),o=n.getData(),s={lastFrameIndex:0},l=u1(n)?function(v,d){r._endLabelOnDuring(v,d,o,s,a,i,t)}:null,u=t.getBaseAxis().isHorizontal(),f=o1(t,e,n,function(){var v=r._endLabel;v&&e&&s.originalX!=null&&v.attr({x:s.originalX,y:s.originalY})},l);if(!n.get("clip",!0)){var h=f.shape,c=Math.max(h.width,h.height);u?(h.y-=c,h.height+=c*2):(h.x-=c,h.width+=c*2)}return l&&l(1,f),f}else return s1(t,e,n)}function G2(r,t){var e=t.getBaseAxis(),n=e.isHorizontal(),i=e.inverse,a=n?i?"right":"left":"center",o=n?"middle":i?"top":"bottom";return{normal:{align:r.get("align")||a,verticalAlign:r.get("verticalAlign")||o}}}var H2=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(){var e=new yt,n=new r1;this.group.add(n.group),this._symbolDraw=n,this._lineGroup=e,this._changePolyState=dt(this._changePolyState,this)},t.prototype.render=function(e,n,i){var a=e.coordinateSystem,o=this.group,s=e.getData(),l=e.getModel("lineStyle"),u=e.getModel("areaStyle"),f=s.getLayout("points")||[],h=a.type==="polar",c=this._coordSys,v=this._symbolDraw,d=this._polyline,p=this._polygon,g=this._lineGroup,y=!n.ssr&&e.get("animation"),m=!u.isEmpty(),_=u.get("origin"),S=n1(a,s,_),w=m&&E2(a,s,S),x=e.get("showSymbol"),b=e.get("connectNulls"),T=x&&!h&&B2(e,s,a),C=this._data;C&&C.eachItemGraphicEl(function(at,Rt){at.__temp&&(o.remove(at),C.setItemGraphicEl(Rt,null))}),x||v.remove(),o.add(g);var D=h?!1:e.get("step"),A;a&&a.getArea&&e.get("clip",!0)&&(A=a.getArea(),A.width!=null?(A.x-=.1,A.y-=.1,A.width+=.2,A.height+=.2):A.r0&&(A.r0-=.5,A.r+=.5)),this._clipShapeForSymbol=A;var I=O2(s,a,i)||s.getVisual("style")[s.getVisual("drawType")];if(!(d&&c.type===a.type&&D===this._step))x&&v.updateData(s,{isIgnore:T,clipShape:A,disableAnimation:!0,getSymbolPoint:function(at){return[f[at*2],f[at*2+1]]}}),y&&this._initSymbolLabelAnimation(s,a,A),D&&(w&&(w=Ir(w,f,a,D,b)),f=Ir(f,null,a,D,b)),d=this._newPolyline(f),m?p=this._newPolygon(f,w):p&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(e,a,An(I)),g.setClipPath(Ru(this,a,!0,e));else{m&&!p?p=this._newPolygon(f,w):p&&!m&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(e,a,An(I));var L=g.getClipPath();if(L){var P=Ru(this,a,!1,e);Pt(L,{shape:P.shape},e)}else g.setClipPath(Ru(this,a,!0,e));x&&v.updateData(s,{isIgnore:T,clipShape:A,disableAnimation:!0,getSymbolPoint:function(at){return[f[at*2],f[at*2+1]]}}),(!Tp(this._stackedOnPoints,w)||!Tp(this._points,f))&&(y?this._doUpdateAnimation(s,w,a,i,D,_,b):(D&&(w&&(w=Ir(w,f,a,D,b)),f=Ir(f,null,a,D,b)),d.setShape({points:f}),p&&p.setShape({points:f,stackedOnPoints:w})))}var R=e.getModel("emphasis"),E=R.get("focus"),O=R.get("blurScope"),k=R.get("disabled");if(d.useStyle(Q(l.getLineStyle(),{fill:"none",stroke:I,lineJoin:"bevel"})),Wr(d,e,"lineStyle"),d.style.lineWidth>0&&e.get(["emphasis","lineStyle","width"])==="bolder"){var B=d.getState("emphasis").style;B.lineWidth=+d.style.lineWidth+1}st(d).seriesIndex=e.seriesIndex,mr(d,E,O,k);var z=Ap(e.get("smooth")),G=e.get("smoothMonotone");if(d.setShape({smooth:z,smoothMonotone:G,connectNulls:b}),p){var U=s.getCalculationInfo("stackedOnSeries"),j=0;p.useStyle(Q(u.getAreaStyle(),{fill:I,opacity:.7,lineJoin:"bevel",decal:s.getVisual("style").decal})),U&&(j=Ap(U.get("smooth"))),p.setShape({smooth:z,stackedOnSmooth:j,smoothMonotone:G,connectNulls:b}),Wr(p,e,"areaStyle"),st(p).seriesIndex=e.seriesIndex,mr(p,E,O,k)}var et=this._changePolyState;s.eachItemGraphicEl(function(at){at&&(at.onHoverStateChange=et)}),this._polyline.onHoverStateChange=et,this._data=s,this._coordSys=a,this._stackedOnPoints=w,this._points=f,this._step=D,this._valueOrigin=_,e.get("triggerLineEvent")&&(this.packEventData(e,d),p&&this.packEventData(e,p))},t.prototype.packEventData=function(e,n){st(n).eventData={componentType:"series",componentSubType:"line",componentIndex:e.componentIndex,seriesIndex:e.seriesIndex,seriesName:e.name,seriesType:"line"}},t.prototype.highlight=function(e,n,i,a){var o=e.getData(),s=Dn(o,a);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var f=l[s*2],h=l[s*2+1];if(isNaN(f)||isNaN(h)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(f,h))return;var c=e.get("zlevel")||0,v=e.get("z")||0;u=new mv(o,s),u.x=f,u.y=h,u.setZ(c,v);var d=u.getSymbolPath().getTextContent();d&&(d.zlevel=c,d.z=v,d.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else Wt.prototype.highlight.call(this,e,n,i,a)},t.prototype.downplay=function(e,n,i,a){var o=e.getData(),s=Dn(o,a);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else Wt.prototype.downplay.call(this,e,n,i,a)},t.prototype._changePolyState=function(e){var n=this._polygon;Bc(this._polyline,e),n&&Bc(n,e)},t.prototype._newPolyline=function(e){var n=this._polyline;return n&&this._lineGroup.remove(n),n=new L2({shape:{points:e},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(n),this._polyline=n,n},t.prototype._newPolygon=function(e,n){var i=this._polygon;return i&&this._lineGroup.remove(i),i=new R2({shape:{points:e,stackedOnPoints:n},segmentIgnoreThreshold:2}),this._lineGroup.add(i),this._polygon=i,i},t.prototype._initSymbolLabelAnimation=function(e,n,i){var a,o,s=n.getBaseAxis(),l=s.inverse;n.type==="cartesian2d"?(a=s.isHorizontal(),o=!1):n.type==="polar"&&(a=s.dim==="angle",o=!0);var u=e.hostModel,f=u.get("animationDuration");q(f)&&(f=f(null));var h=u.get("animationDelay")||0,c=q(h)?h(null):h;e.eachItemGraphicEl(function(v,d){var p=v;if(p){var g=[v.x,v.y],y=void 0,m=void 0,_=void 0;if(i)if(o){var S=i,w=n.pointToCoord(g);a?(y=S.startAngle,m=S.endAngle,_=-w[1]/180*Math.PI):(y=S.r0,m=S.r,_=w[0])}else{var x=i;a?(y=x.x,m=x.x+x.width,_=v.x):(y=x.y+x.height,m=x.y,_=v.y)}var b=m===y?0:(_-y)/(m-y);l&&(b=1-b);var T=q(h)?h(d):f*b+c,C=p.getSymbolPath(),D=C.getTextContent();p.attr({scaleX:0,scaleY:0}),p.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:T}),D&&D.animateFrom({style:{opacity:0}},{duration:300,delay:T}),C.disableLabelAnimation=!0}})},t.prototype._initOrUpdateEndLabel=function(e,n,i){var a=e.getModel("endLabel");if(u1(e)){var o=e.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new Ct({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var f=z2(l);f>=0&&(Rn(s,En(e,"endLabel"),{inheritColor:i,labelFetcher:e,labelDataIndex:f,defaultText:function(h,c,v){return v!=null?e1(o,v):_l(o,h)},enableTextSetter:!0},G2(a,n)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},t.prototype._endLabelOnDuring=function(e,n,i,a,o,s,l){var u=this._endLabel,f=this._polyline;if(u){e<1&&a.originalX==null&&(a.originalX=u.x,a.originalY=u.y);var h=i.getLayout("points"),c=i.hostModel,v=c.get("connectNulls"),d=s.get("precision"),p=s.get("distance")||0,g=l.getBaseAxis(),y=g.isHorizontal(),m=g.inverse,_=n.shape,S=m?y?_.x:_.y+_.height:y?_.x+_.width:_.y,w=(y?p:0)*(m?-1:1),x=(y?0:-p)*(m?-1:1),b=y?"x":"y",T=V2(h,S,b),C=T.range,D=C[1]-C[0],A=void 0;if(D>=1){if(D>1&&!v){var I=Mp(h,C[0]);u.attr({x:I[0]+w,y:I[1]+x}),o&&(A=c.getRawValue(C[0]))}else{var I=f.getPointOn(S,b);I&&u.attr({x:I[0]+w,y:I[1]+x});var L=c.getRawValue(C[0]),P=c.getRawValue(C[1]);o&&(A=im(i,d,L,P,T.t))}a.lastFrameIndex=C[0]}else{var R=e===1||a.lastFrameIndex>0?C[0]:0,I=Mp(h,R);o&&(A=c.getRawValue(R)),u.attr({x:I[0]+w,y:I[1]+x})}if(o){var E=Ei(u);typeof E.setLabelText=="function"&&E.setLabelText(A)}}},t.prototype._doUpdateAnimation=function(e,n,i,a,o,s,l){var u=this._polyline,f=this._polygon,h=e.hostModel,c=I2(this._data,e,this._stackedOnPoints,n,this._coordSys,i,this._valueOrigin),v=c.current,d=c.stackedOnCurrent,p=c.next,g=c.stackedOnNext;if(o&&(d=Ir(c.stackedOnCurrent,c.current,i,o,l),v=Ir(c.current,null,i,o,l),g=Ir(c.stackedOnNext,c.next,i,o,l),p=Ir(c.next,null,i,o,l)),Dp(v,p)>3e3||f&&Dp(d,g)>3e3){u.stopAnimation(),u.setShape({points:p}),f&&(f.stopAnimation(),f.setShape({points:p,stackedOnPoints:g}));return}u.shape.__points=c.current,u.shape.points=v;var y={shape:{points:p}};c.current!==v&&(y.shape.__points=c.next),u.stopAnimation(),bt(u,y,h),f&&(f.setShape({points:v,stackedOnPoints:d}),f.stopAnimation(),bt(f,{shape:{stackedOnPoints:g}},h),u.shape.points!==f.shape.points&&(f.shape.points=u.shape.points));for(var m=[],_=c.status,S=0;S<_.length;S++){var w=_[S].cmd;if(w==="="){var x=e.getItemGraphicEl(_[S].idx1);x&&m.push({el:x,ptIdx:S})}}u.animators&&u.animators.length&&u.animators[0].during(function(){f&&f.dirtyShape();for(var b=u.shape.__points,T=0;T<m.length;T++){var C=m[T].el,D=m[T].ptIdx*2;C.x=b[D],C.y=b[D+1],C.markRedraw()}})},t.prototype.remove=function(e){var n=this.group,i=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),i&&i.eachItemGraphicEl(function(a,o){a.__temp&&(n.remove(a),i.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},t.type="line",t}(Wt);function Sv(r,t){return{seriesType:r,plan:av(),reset:function(e){var n=e.getData(),i=e.coordinateSystem,a=e.pipelineContext,o=t||a.large;if(i){var s=H(i.dimensions,function(v){return n.mapDimension(v)}).slice(0,2),l=s.length,u=n.getCalculationInfo("stackResultDimension");Ci(n,s[0])&&(s[0]=u),Ci(n,s[1])&&(s[1]=u);var f=n.getStore(),h=n.getDimensionIndex(s[0]),c=n.getDimensionIndex(s[1]);return l&&{progress:function(v,d){for(var p=v.end-v.start,g=o&&vr(p*l),y=[],m=[],_=v.start,S=0;_<v.end;_++){var w=void 0;if(l===1){var x=f.get(h,_);w=i.dataToPoint(x,null,m)}else y[0]=f.get(h,_),y[1]=f.get(c,_),w=i.dataToPoint(y,null,m);o?(g[S++]=w[0],g[S++]=w[1]):d.setItemLayout(_,w.slice())}o&&d.setLayout("points",g)}}}}}}var W2={average:function(r){for(var t=0,e=0,n=0;n<r.length;n++)isNaN(r[n])||(t+=r[n],e++);return e===0?NaN:t/e},sum:function(r){for(var t=0,e=0;e<r.length;e++)t+=r[e]||0;return t},max:function(r){for(var t=-1/0,e=0;e<r.length;e++)r[e]>t&&(t=r[e]);return isFinite(t)?t:NaN},min:function(r){for(var t=1/0,e=0;e<r.length;e++)r[e]<t&&(t=r[e]);return isFinite(t)?t:NaN},nearest:function(r){return r[0]}},U2=function(r){return Math.round(r.length/2)};function f1(r){return{seriesType:r,reset:function(t,e,n){var i=t.getData(),a=t.get("sampling"),o=t.coordinateSystem,s=i.count();if(s>10&&o.type==="cartesian2d"&&a){var l=o.getBaseAxis(),u=o.getOtherAxis(l),f=l.getExtent(),h=n.getDevicePixelRatio(),c=Math.abs(f[1]-f[0])*(h||1),v=Math.round(s/c);if(isFinite(v)&&v>1){a==="lttb"?t.setData(i.lttbDownSample(i.mapDimension(u.dim),1/v)):a==="minmax"&&t.setData(i.minmaxDownSample(i.mapDimension(u.dim),1/v));var d=void 0;W(a)?d=W2[a]:q(a)&&(d=a),d&&t.setData(i.downSample(i.mapDimension(u.dim),1/v,d,U2))}}}}}function Y2(r){r.registerChartView(H2),r.registerSeriesModel(C2),r.registerLayout(Sv("line",!0)),r.registerVisual({seriesType:"line",reset:function(t){var e=t.getData(),n=t.getModel("lineStyle").getLineStyle();n&&!n.stroke&&(n.stroke=e.getVisual("style").fill),e.setVisual("legendLineStyle",n)}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,f1("line"))}var Ya=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(e,n){return pl(null,this,{useEncodeDefaulter:!0})},t.prototype.getMarkerPosition=function(e,n,i){var a=this.coordinateSystem;if(a&&a.clampData){var o=a.clampData(e),s=a.dataToPoint(o);if(i)M(a.getAxes(),function(c,v){if(c.type==="category"&&n!=null){var d=c.getTicksCoords(),p=c.getTickModel().get("alignWithLabel"),g=o[v],y=n[v]==="x1"||n[v]==="y1";if(y&&!p&&(g+=1),d.length<2)return;if(d.length===2){s[v]=c.toGlobalCoord(c.getExtent()[y?1:0]);return}for(var m=void 0,_=void 0,S=1,w=0;w<d.length;w++){var x=d[w].coord,b=w===d.length-1?d[w-1].tickValue+S:d[w].tickValue;if(b===g){_=x;break}else if(b<g)m=x;else if(m!=null&&b>g){_=(x+m)/2;break}w===1&&(S=b-d[0].tickValue)}_==null&&(m?m&&(_=d[d.length-1].coord):_=d[0].coord),s[v]=c.toGlobalCoord(_)}});else{var l=this.getData(),u=l.getLayout("offset"),f=l.getLayout("size"),h=a.getBaseAxis().isHorizontal()?0:1;s[h]+=u+f/2}return s}return[NaN,NaN]},t.type="series.__base_bar__",t.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,barMinHeight:0,barMinAngle:0,large:!1,largeThreshold:400,progressive:3e3,progressiveChunkMode:"mod"},t}(se);se.registerClass(Ya);var X2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(){return pl(null,this,{useEncodeDefaulter:!0,createInvertedIndices:!!this.get("realtimeSort",!0)||null})},t.prototype.getProgressive=function(){return this.get("large")?this.get("progressive"):!1},t.prototype.getProgressiveThreshold=function(){var e=this.get("progressiveThreshold"),n=this.get("largeThreshold");return n>e&&(e=n),e},t.prototype.brushSelector=function(e,n,i){return i.rect(n.getItemLayout(e))},t.type="series.bar",t.dependencies=["grid","polar"],t.defaultOption=Yh(Ya.defaultOption,{clip:!0,roundCap:!1,showBackground:!1,backgroundStyle:{color:"rgba(180, 180, 180, 0.2)",borderColor:null,borderWidth:0,borderType:"solid",borderRadius:0,shadowBlur:0,shadowColor:null,shadowOffsetX:0,shadowOffsetY:0,opacity:1},select:{itemStyle:{borderColor:"#212121"}},realtimeSort:!1}),t}(Ya),Z2=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),Es=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n.type="sausage",n}return t.prototype.getDefaultShape=function(){return new Z2},t.prototype.buildPath=function(e,n){var i=n.cx,a=n.cy,o=Math.max(n.r0||0,0),s=Math.max(n.r,0),l=(s-o)*.5,u=o+l,f=n.startAngle,h=n.endAngle,c=n.clockwise,v=Math.PI*2,d=c?h-f<v:f-h<v;d||(f=h-(c?v:-v));var p=Math.cos(f),g=Math.sin(f),y=Math.cos(h),m=Math.sin(h);d?(e.moveTo(p*o+i,g*o+a),e.arc(p*u+i,g*u+a,l,-Math.PI+f,f,!c)):e.moveTo(p*s+i,g*s+a),e.arc(i,a,s,f,h,!c),e.arc(y*u+i,m*u+a,l,h-Math.PI*2,h-Math.PI,!c),o!==0&&e.arc(i,a,o,h,f,c)},t}(it);function $2(r,t){t=t||{};var e=t.isRoundCap;return function(n,i,a){var o=i.position;if(!o||o instanceof Array)return gs(n,i,a);var s=r(o),l=i.distance!=null?i.distance:5,u=this.shape,f=u.cx,h=u.cy,c=u.r,v=u.r0,d=(c+v)/2,p=u.startAngle,g=u.endAngle,y=(p+g)/2,m=e?Math.abs(c-v)/2:0,_=Math.cos,S=Math.sin,w=f+c*_(p),x=h+c*S(p),b="left",T="top";switch(s){case"startArc":w=f+(v-l)*_(y),x=h+(v-l)*S(y),b="center",T="top";break;case"insideStartArc":w=f+(v+l)*_(y),x=h+(v+l)*S(y),b="center",T="bottom";break;case"startAngle":w=f+d*_(p)+Fo(p,l+m,!1),x=h+d*S(p)+zo(p,l+m,!1),b="right",T="middle";break;case"insideStartAngle":w=f+d*_(p)+Fo(p,-l+m,!1),x=h+d*S(p)+zo(p,-l+m,!1),b="left",T="middle";break;case"middle":w=f+d*_(y),x=h+d*S(y),b="center",T="middle";break;case"endArc":w=f+(c+l)*_(y),x=h+(c+l)*S(y),b="center",T="bottom";break;case"insideEndArc":w=f+(c-l)*_(y),x=h+(c-l)*S(y),b="center",T="top";break;case"endAngle":w=f+d*_(g)+Fo(g,l+m,!0),x=h+d*S(g)+zo(g,l+m,!0),b="left",T="middle";break;case"insideEndAngle":w=f+d*_(g)+Fo(g,-l+m,!0),x=h+d*S(g)+zo(g,-l+m,!0),b="right",T="middle";break;default:return gs(n,i,a)}return n=n||{},n.x=w,n.y=x,n.align=b,n.verticalAlign=T,n}}function q2(r,t,e,n){if(ct(n)){r.setTextConfig({rotation:n});return}else if(V(t)){r.setTextConfig({rotation:0});return}var i=r.shape,a=i.clockwise?i.startAngle:i.endAngle,o=i.clockwise?i.endAngle:i.startAngle,s=(a+o)/2,l,u=e(t);switch(u){case"startArc":case"insideStartArc":case"middle":case"insideEndArc":case"endArc":l=s;break;case"startAngle":case"insideStartAngle":l=a;break;case"endAngle":case"insideEndAngle":l=o;break;default:r.setTextConfig({rotation:0});return}var f=Math.PI*1.5-l;u==="middle"&&f>Math.PI/2&&f<Math.PI*1.5&&(f-=Math.PI),r.setTextConfig({rotation:f})}function Fo(r,t,e){return t*Math.sin(r)*(e?-1:1)}function zo(r,t,e){return t*Math.cos(r)*(e?1:-1)}function da(r,t,e){var n=r.get("borderRadius");if(n==null)return e?{cornerRadius:0}:null;V(n)||(n=[n,n,n,n]);var i=Math.abs(t.r||0-t.r0||0);return{cornerRadius:H(n,function(a){return Gr(a,i)})}}var Eu=Math.max,ku=Math.min;function K2(r,t){var e=r.getArea&&r.getArea();if(_v(r,"cartesian2d")){var n=r.getBaseAxis();if(n.type!=="category"||!n.onBand){var i=t.getLayout("bandWidth");n.isHorizontal()?(e.x-=i,e.width+=i*2):(e.y-=i,e.height+=i*2)}}return e}var Q2=function(r){N(t,r);function t(){var e=r.call(this)||this;return e.type=t.type,e._isFirstFrame=!0,e}return t.prototype.render=function(e,n,i,a){this._model=e,this._removeOnRenderedListener(i),this._updateDrawMode(e);var o=e.get("coordinateSystem");(o==="cartesian2d"||o==="polar")&&(this._progressiveEls=null,this._isLargeDraw?this._renderLarge(e,n,i):this._renderNormal(e,n,i,a))},t.prototype.incrementalPrepareRender=function(e){this._clear(),this._updateDrawMode(e),this._updateLargeClip(e)},t.prototype.incrementalRender=function(e,n){this._progressiveEls=[],this._incrementalRenderLarge(e,n)},t.prototype.eachRendered=function(e){rl(this._progressiveEls||this.group,e)},t.prototype._updateDrawMode=function(e){var n=e.pipelineContext.large;(this._isLargeDraw==null||n!==this._isLargeDraw)&&(this._isLargeDraw=n,this._clear())},t.prototype._renderNormal=function(e,n,i,a){var o=this.group,s=e.getData(),l=this._data,u=e.coordinateSystem,f=u.getBaseAxis(),h;u.type==="cartesian2d"?h=f.isHorizontal():u.type==="polar"&&(h=f.dim==="angle");var c=e.isAnimationEnabled()?e:null,v=J2(e,u);v&&this._enableRealtimeSort(v,s,i);var d=e.get("clip",!0)||v,p=K2(u,s);o.removeClipPath();var g=e.get("roundCap",!0),y=e.get("showBackground",!0),m=e.getModel("backgroundStyle"),_=m.get("borderRadius")||0,S=[],w=this._backgroundEls,x=a&&a.isInitSort,b=a&&a.type==="changeAxisOrder";function T(A){var I=Vo[u.type](s,A),L=aI(u,h,I);return L.useStyle(m.getItemStyle()),u.type==="cartesian2d"?L.setShape("r",_):L.setShape("cornerRadius",_),S[A]=L,L}s.diff(l).add(function(A){var I=s.getItemModel(A),L=Vo[u.type](s,A,I);if(y&&T(A),!(!s.hasValue(A)||!Ep[u.type](L))){var P=!1;d&&(P=Ip[u.type](p,L));var R=Lp[u.type](e,s,A,L,h,c,f.model,!1,g);v&&(R.forceLabelAnimation=!0),kp(R,s,A,I,L,e,h,u.type==="polar"),x?R.attr({shape:L}):v?Pp(v,c,R,L,A,h,!1,!1):Pt(R,{shape:L},e,A),s.setItemGraphicEl(A,R),o.add(R),R.ignore=P}}).update(function(A,I){var L=s.getItemModel(A),P=Vo[u.type](s,A,L);if(y){var R=void 0;w.length===0?R=T(I):(R=w[I],R.useStyle(m.getItemStyle()),u.type==="cartesian2d"?R.setShape("r",_):R.setShape("cornerRadius",_),S[A]=R);var E=Vo[u.type](s,A),O=v1(h,E,u);bt(R,{shape:O},c,A)}var k=l.getItemGraphicEl(I);if(!s.hasValue(A)||!Ep[u.type](P)){o.remove(k);return}var B=!1;if(d&&(B=Ip[u.type](p,P),B&&o.remove(k)),k?Ba(k):k=Lp[u.type](e,s,A,P,h,c,f.model,!!k,g),v&&(k.forceLabelAnimation=!0),b){var z=k.getTextContent();if(z){var G=Ei(z);G.prevValue!=null&&(G.prevValue=G.value)}}else kp(k,s,A,L,P,e,h,u.type==="polar");x?k.attr({shape:P}):v?Pp(v,c,k,P,A,h,!0,b):bt(k,{shape:P},e,A,null),s.setItemGraphicEl(A,k),k.ignore=B,o.add(k)}).remove(function(A){var I=l.getItemGraphicEl(A);I&&xs(I,e,A)}).execute();var C=this._backgroundGroup||(this._backgroundGroup=new yt);C.removeAll();for(var D=0;D<S.length;++D)C.add(S[D]);o.add(C),this._backgroundEls=S,this._data=s},t.prototype._renderLarge=function(e,n,i){this._clear(),Bp(e,this.group),this._updateLargeClip(e)},t.prototype._incrementalRenderLarge=function(e,n){this._removeBackground(),Bp(n,this.group,this._progressiveEls,!0)},t.prototype._updateLargeClip=function(e){var n=e.get("clip",!0)&&l1(e.coordinateSystem,!1,e),i=this.group;n?i.setClipPath(n):i.removeClipPath()},t.prototype._enableRealtimeSort=function(e,n,i){var a=this;if(n.count()){var o=e.baseAxis;if(this._isFirstFrame)this._dispatchInitSort(n,e,i),this._isFirstFrame=!1;else{var s=function(l){var u=n.getItemGraphicEl(l),f=u&&u.shape;return f&&Math.abs(o.isHorizontal()?f.height:f.width)||0};this._onRendered=function(){a._updateSortWithinSameData(n,s,o,i)},i.getZr().on("rendered",this._onRendered)}}},t.prototype._dataSort=function(e,n,i){var a=[];return e.each(e.mapDimension(n.dim),function(o,s){var l=i(s);l=l??NaN,a.push({dataIndex:s,mappedValue:l,ordinalNumber:o})}),a.sort(function(o,s){return s.mappedValue-o.mappedValue}),{ordinalNumbers:H(a,function(o){return o.ordinalNumber})}},t.prototype._isOrderChangedWithinSameData=function(e,n,i){for(var a=i.scale,o=e.mapDimension(i.dim),s=Number.MAX_VALUE,l=0,u=a.getOrdinalMeta().categories.length;l<u;++l){var f=e.rawIndexOf(o,a.getRawOrdinalNumber(l)),h=f<0?Number.MIN_VALUE:n(e.indexOfRawIndex(f));if(h>s)return!0;s=h}return!1},t.prototype._isOrderDifferentInView=function(e,n){for(var i=n.scale,a=i.getExtent(),o=Math.max(0,a[0]),s=Math.min(a[1],i.getOrdinalMeta().categories.length-1);o<=s;++o)if(e.ordinalNumbers[o]!==i.getRawOrdinalNumber(o))return!0},t.prototype._updateSortWithinSameData=function(e,n,i,a){if(this._isOrderChangedWithinSameData(e,n,i)){var o=this._dataSort(e,i,n);this._isOrderDifferentInView(o,i)&&(this._removeOnRenderedListener(a),a.dispatchAction({type:"changeAxisOrder",componentType:i.dim+"Axis",axisId:i.index,sortInfo:o}))}},t.prototype._dispatchInitSort=function(e,n,i){var a=n.baseAxis,o=this._dataSort(e,a,function(s){return e.get(e.mapDimension(n.otherAxis.dim),s)});i.dispatchAction({type:"changeAxisOrder",componentType:a.dim+"Axis",isInitSort:!0,axisId:a.index,sortInfo:o})},t.prototype.remove=function(e,n){this._clear(this._model),this._removeOnRenderedListener(n)},t.prototype.dispose=function(e,n){this._removeOnRenderedListener(n)},t.prototype._removeOnRenderedListener=function(e){this._onRendered&&(e.getZr().off("rendered",this._onRendered),this._onRendered=null)},t.prototype._clear=function(e){var n=this.group,i=this._data;e&&e.isAnimationEnabled()&&i&&!this._isLargeDraw?(this._removeBackground(),this._backgroundEls=[],i.eachItemGraphicEl(function(a){xs(a,e,st(a).dataIndex)})):n.removeAll(),this._data=null,this._isFirstFrame=!0},t.prototype._removeBackground=function(){this.group.remove(this._backgroundGroup),this._backgroundGroup=null},t.type="bar",t}(Wt),Ip={cartesian2d:function(r,t){var e=t.width<0?-1:1,n=t.height<0?-1:1;e<0&&(t.x+=t.width,t.width=-t.width),n<0&&(t.y+=t.height,t.height=-t.height);var i=r.x+r.width,a=r.y+r.height,o=Eu(t.x,r.x),s=ku(t.x+t.width,i),l=Eu(t.y,r.y),u=ku(t.y+t.height,a),f=s<o,h=u<l;return t.x=f&&o>i?s:o,t.y=h&&l>a?u:l,t.width=f?0:s-o,t.height=h?0:u-l,e<0&&(t.x+=t.width,t.width=-t.width),n<0&&(t.y+=t.height,t.height=-t.height),f||h},polar:function(r,t){var e=t.r0<=t.r?1:-1;if(e<0){var n=t.r;t.r=t.r0,t.r0=n}var i=ku(t.r,r.r),a=Eu(t.r0,r.r0);t.r=i,t.r0=a;var o=i-a<0;if(e<0){var n=t.r;t.r=t.r0,t.r0=n}return o}},Lp={cartesian2d:function(r,t,e,n,i,a,o,s,l){var u=new St({shape:F({},n),z2:1});if(u.__dataIndex=e,u.name="item",a){var f=u.shape,h=i?"height":"width";f[h]=0}return u},polar:function(r,t,e,n,i,a,o,s,l){var u=!i&&l?Es:Se,f=new u({shape:n,z2:1});f.name="item";var h=h1(i);if(f.calculateTextPosition=$2(h,{isRoundCap:u===Es}),a){var c=f.shape,v=i?"r":"endAngle",d={};c[v]=i?n.r0:n.startAngle,d[v]=n[v],(s?bt:Pt)(f,{shape:d},a)}return f}};function J2(r,t){var e=r.get("realtimeSort",!0),n=t.getBaseAxis();if(e&&n.type==="category"&&t.type==="cartesian2d")return{baseAxis:n,otherAxis:t.getOtherAxis(n)}}function Pp(r,t,e,n,i,a,o,s){var l,u;a?(u={x:n.x,width:n.width},l={y:n.y,height:n.height}):(u={y:n.y,height:n.height},l={x:n.x,width:n.width}),s||(o?bt:Pt)(e,{shape:l},t,i,null);var f=t?r.baseAxis.model:null;(o?bt:Pt)(e,{shape:u},f,i)}function Rp(r,t){for(var e=0;e<t.length;e++)if(!isFinite(r[t[e]]))return!0;return!1}var j2=["x","y","width","height"],tI=["cx","cy","r","startAngle","endAngle"],Ep={cartesian2d:function(r){return!Rp(r,j2)},polar:function(r){return!Rp(r,tI)}},Vo={cartesian2d:function(r,t,e){var n=r.getItemLayout(t),i=e?rI(e,n):0,a=n.width>0?1:-1,o=n.height>0?1:-1;return{x:n.x+a*i/2,y:n.y+o*i/2,width:n.width-a*i,height:n.height-o*i}},polar:function(r,t,e){var n=r.getItemLayout(t);return{cx:n.cx,cy:n.cy,r0:n.r0,r:n.r,startAngle:n.startAngle,endAngle:n.endAngle,clockwise:n.clockwise}}};function eI(r){return r.startAngle!=null&&r.endAngle!=null&&r.startAngle===r.endAngle}function h1(r){return function(t){var e=t?"Arc":"Angle";return function(n){switch(n){case"start":case"insideStart":case"end":case"insideEnd":return n+e;default:return n}}}(r)}function kp(r,t,e,n,i,a,o,s){var l=t.getItemVisual(e,"style");if(s){if(!a.get("roundCap")){var f=r.shape,h=da(n.getModel("itemStyle"),f,!0);F(f,h),r.setShape(f)}}else{var u=n.get(["itemStyle","borderRadius"])||0;r.setShape("r",u)}r.useStyle(l);var c=n.getShallow("cursor");c&&r.attr("cursor",c);var v=s?o?i.r>=i.r0?"endArc":"startArc":i.endAngle>=i.startAngle?"endAngle":"startAngle":o?i.height>=0?"bottom":"top":i.width>=0?"right":"left",d=En(n);Rn(r,d,{labelFetcher:a,labelDataIndex:e,defaultText:_l(a.getData(),e),inheritColor:l.fill,defaultOpacity:l.opacity,defaultOutsidePosition:v});var p=r.getTextContent();if(s&&p){var g=n.get(["label","position"]);r.textConfig.inside=g==="middle"?!0:null,q2(r,g==="outside"?v:g,h1(o),n.get(["label","rotate"]))}Um(p,d,a.getRawValue(e),function(m){return e1(t,m)});var y=n.getModel(["emphasis"]);mr(r,y.get("focus"),y.get("blurScope"),y.get("disabled")),Wr(r,n),eI(i)&&(r.style.fill="none",r.style.stroke="none",M(r.states,function(m){m.style&&(m.style.fill=m.style.stroke="none")}))}function rI(r,t){var e=r.get(["itemStyle","borderColor"]);if(!e||e==="none")return 0;var n=r.get(["itemStyle","borderWidth"])||0,i=isNaN(t.width)?Number.MAX_VALUE:Math.abs(t.width),a=isNaN(t.height)?Number.MAX_VALUE:Math.abs(t.height);return Math.min(n,i,a)}var nI=function(){function r(){}return r}(),Op=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n.type="largeBar",n}return t.prototype.getDefaultShape=function(){return new nI},t.prototype.buildPath=function(e,n){for(var i=n.points,a=this.baseDimIdx,o=1-this.baseDimIdx,s=[],l=[],u=this.barWidth,f=0;f<i.length;f+=3)l[a]=u,l[o]=i[f+2],s[a]=i[f+a],s[o]=i[f+o],e.rect(s[0],s[1],l[0],l[1])},t}(it);function Bp(r,t,e,n){var i=r.getData(),a=i.getLayout("valueAxisHorizontal")?1:0,o=i.getLayout("largeDataIndices"),s=i.getLayout("size"),l=r.getModel("backgroundStyle"),u=i.getLayout("largeBackgroundPoints");if(u){var f=new Op({shape:{points:u},incremental:!!n,silent:!0,z2:0});f.baseDimIdx=a,f.largeDataIndices=o,f.barWidth=s,f.useStyle(l.getItemStyle()),t.add(f),e&&e.push(f)}var h=new Op({shape:{points:i.getLayout("largePoints")},incremental:!!n,ignoreCoarsePointer:!0,z2:1});h.baseDimIdx=a,h.largeDataIndices=o,h.barWidth=s,t.add(h),h.useStyle(i.getVisual("style")),h.style.stroke=null,st(h).seriesIndex=r.seriesIndex,r.get("silent")||(h.on("mousedown",Np),h.on("mousemove",Np)),e&&e.push(h)}var Np=ov(function(r){var t=this,e=iI(t,r.offsetX,r.offsetY);st(t).dataIndex=e>=0?e:null},30,!1);function iI(r,t,e){for(var n=r.baseDimIdx,i=1-n,a=r.shape.points,o=r.largeDataIndices,s=[],l=[],u=r.barWidth,f=0,h=a.length/3;f<h;f++){var c=f*3;if(l[n]=u,l[i]=a[c+2],s[n]=a[c+n],s[i]=a[c+i],l[i]<0&&(s[i]+=l[i],l[i]=-l[i]),t>=s[0]&&t<=s[0]+l[0]&&e>=s[1]&&e<=s[1]+l[1])return o[f]}return-1}function v1(r,t,e){if(_v(e,"cartesian2d")){var n=t,i=e.getArea();return{x:r?n.x:i.x,y:r?i.y:n.y,width:r?n.width:i.width,height:r?i.height:n.height}}else{var i=e.getArea(),a=t;return{cx:i.cx,cy:i.cy,r0:r?i.r0:a.r0,r:r?i.r:a.r,startAngle:r?a.startAngle:0,endAngle:r?a.endAngle:Math.PI*2}}}function aI(r,t,e){var n=r.type==="polar"?Se:St;return new n({shape:v1(t,e,r),silent:!0,z2:0})}function oI(r){r.registerChartView(Q2),r.registerSeriesModel(X2),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,vt(M_,"bar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,I_("bar")),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,f1("bar")),r.registerAction({type:"changeAxisOrder",event:"changeAxisOrder",update:"update"},function(t,e){var n=t.componentType||"series";e.eachComponent({mainType:n,query:t},function(i){t.sortInfo&&i.axis.setCategorySortInfo(t.sortInfo)})})}var Fp=Math.PI*2,Go=Math.PI/180;function c1(r,t){return Ur(r.getBoxLayoutParams(),{width:t.getWidth(),height:t.getHeight()})}function d1(r,t){var e=c1(r,t),n=r.get("center"),i=r.get("radius");V(i)||(i=[0,i]);var a=Z(e.width,t.getWidth()),o=Z(e.height,t.getHeight()),s=Math.min(a,o),l=Z(i[0],s/2),u=Z(i[1],s/2),f,h,c=r.coordinateSystem;if(c){var v=c.dataToPoint(n);f=v[0]||0,h=v[1]||0}else V(n)||(n=[n,n]),f=Z(n[0],a)+e.x,h=Z(n[1],o)+e.y;return{cx:f,cy:h,r0:l,r:u}}function sI(r,t,e){t.eachSeriesByType(r,function(n){var i=n.getData(),a=i.mapDimension("value"),o=c1(n,e),s=d1(n,e),l=s.cx,u=s.cy,f=s.r,h=s.r0,c=-n.get("startAngle")*Go,v=n.get("endAngle"),d=n.get("padAngle")*Go;v=v==="auto"?c-Fp:-v*Go;var p=n.get("minAngle")*Go,g=p+d,y=0;i.each(a,function(O){!isNaN(O)&&y++});var m=i.getSum(a),_=Math.PI/(m||y)*2,S=n.get("clockwise"),w=n.get("roseType"),x=n.get("stillShowZeroSum"),b=i.getDataExtent(a);b[0]=0;var T=S?1:-1,C=[c,v],D=T*d/2;Eh(C,!S),c=C[0],v=C[1];var A=p1(n);A.startAngle=c,A.endAngle=v,A.clockwise=S;var I=Math.abs(v-c),L=I,P=0,R=c;if(i.setLayout({viewRect:o,r:f}),i.each(a,function(O,k){var B;if(isNaN(O)){i.setItemLayout(k,{angle:NaN,startAngle:NaN,endAngle:NaN,clockwise:S,cx:l,cy:u,r0:h,r:w?NaN:f});return}w!=="area"?B=m===0&&x?_:O*_:B=I/y,B<g?(B=g,L-=g):P+=O;var z=R+T*B,G=0,U=0;d>B?(G=R+T*B/2,U=G):(G=R+D,U=z-D),i.setItemLayout(k,{angle:B,startAngle:G,endAngle:U,clockwise:S,cx:l,cy:u,r0:h,r:w?Zt(O,b,[h,f]):f}),R=z}),L<Fp&&y)if(L<=.001){var E=I/y;i.each(a,function(O,k){if(!isNaN(O)){var B=i.getItemLayout(k);B.angle=E;var z=0,G=0;E<d?(z=c+T*(k+1/2)*E,G=z):(z=c+T*k*E+D,G=c+T*(k+1)*E-D),B.startAngle=z,B.endAngle=G}})}else _=L/P,R=c,i.each(a,function(O,k){if(!isNaN(O)){var B=i.getItemLayout(k),z=B.angle===g?g:O*_,G=0,U=0;z<d?(G=R+T*z/2,U=G):(G=R+D,U=R+T*z-D),B.startAngle=G,B.endAngle=U,R+=T*z}})})}var p1=_t();function g1(r){return{seriesType:r,reset:function(t,e){var n=e.findComponents({mainType:"legend"});if(!(!n||!n.length)){var i=t.getData();i.filterSelf(function(a){for(var o=i.getName(a),s=0;s<n.length;s++)if(!n[s].isSelected(o))return!1;return!0})}}}}var lI=Math.PI/180;function zp(r,t,e,n,i,a,o,s,l,u){if(r.length<2)return;function f(p){for(var g=p.rB,y=g*g,m=0;m<p.list.length;m++){var _=p.list[m],S=Math.abs(_.label.y-e),w=n+_.len,x=w*w,b=Math.sqrt(Math.abs((1-S*S/y)*x)),T=t+(b+_.len2)*i,C=T-_.label.x,D=_.targetTextWidth-C*i;y1(_,D,!0),_.label.x=T}}function h(p){for(var g={list:[],maxY:0},y={list:[],maxY:0},m=0;m<p.length;m++)if(p[m].labelAlignTo==="none"){var _=p[m],S=_.label.y>e?y:g,w=Math.abs(_.label.y-e);if(w>=S.maxY){var x=_.label.x-t-_.len2*i,b=n+_.len,T=Math.abs(x)<b?Math.sqrt(w*w/(1-x*x/b/b)):b;S.rB=T,S.maxY=w}S.list.push(_)}f(g),f(y)}for(var c=r.length,v=0;v<c;v++)if(r[v].position==="outer"&&r[v].labelAlignTo==="labelLine"){var d=r[v].label.x-u;r[v].linePoints[1][0]+=d,r[v].label.x=u}j_(r,l,l+o)&&h(r)}function uI(r,t,e,n,i,a,o,s){for(var l=[],u=[],f=Number.MAX_VALUE,h=-Number.MAX_VALUE,c=0;c<r.length;c++){var v=r[c].label;Ou(r[c])||(v.x<t?(f=Math.min(f,v.x),l.push(r[c])):(h=Math.max(h,v.x),u.push(r[c])))}for(var c=0;c<r.length;c++){var d=r[c];if(!Ou(d)&&d.linePoints){if(d.labelStyleWidth!=null)continue;var v=d.label,p=d.linePoints,g=void 0;d.labelAlignTo==="edge"?v.x<t?g=p[2][0]-d.labelDistance-o-d.edgeDistance:g=o+i-d.edgeDistance-p[2][0]-d.labelDistance:d.labelAlignTo==="labelLine"?v.x<t?g=f-o-d.bleedMargin:g=o+i-h-d.bleedMargin:v.x<t?g=v.x-o-d.bleedMargin:g=o+i-v.x-d.bleedMargin,d.targetTextWidth=g,y1(d,g)}}zp(u,t,e,n,1,i,a,o,s,h),zp(l,t,e,n,-1,i,a,o,s,f);for(var c=0;c<r.length;c++){var d=r[c];if(!Ou(d)&&d.linePoints){var v=d.label,p=d.linePoints,y=d.labelAlignTo==="edge",m=v.style.padding,_=m?m[1]+m[3]:0,S=v.style.backgroundColor?0:_,w=d.rect.width+S,x=p[1][0]-p[2][0];y?v.x<t?p[2][0]=o+d.edgeDistance+w+d.labelDistance:p[2][0]=o+i-d.edgeDistance-w-d.labelDistance:(v.x<t?p[2][0]=v.x+d.labelDistance:p[2][0]=v.x-d.labelDistance,p[1][0]=p[2][0]+x),p[1][1]=p[2][1]=v.y}}}function y1(r,t,e){if(e===void 0&&(e=!1),r.labelStyleWidth==null){var n=r.label,i=n.style,a=r.rect,o=i.backgroundColor,s=i.padding,l=s?s[1]+s[3]:0,u=i.overflow,f=a.width+(o?0:l);if(t<f||e){var h=a.height;if(u&&u.match("break")){n.setStyle("backgroundColor",null),n.setStyle("width",t-l);var c=n.getBoundingRect();n.setStyle("width",Math.ceil(c.width)),n.setStyle("backgroundColor",o)}else{var v=t-l,d=t<f?v:e?v>r.unconstrainedWidth?null:v:null;n.setStyle("width",d)}var p=n.getBoundingRect();a.width=p.width;var g=(n.style.margin||0)+2.1;a.height=p.height+g,a.y-=(a.height-h)/2}}}function Ou(r){return r.position==="center"}function fI(r){var t=r.getData(),e=[],n,i,a=!1,o=(r.get("minShowLabelAngle")||0)*lI,s=t.getLayout("viewRect"),l=t.getLayout("r"),u=s.width,f=s.x,h=s.y,c=s.height;function v(x){x.ignore=!0}function d(x){if(!x.ignore)return!0;for(var b in x.states)if(x.states[b].ignore===!1)return!0;return!1}t.each(function(x){var b=t.getItemGraphicEl(x),T=b.shape,C=b.getTextContent(),D=b.getTextGuideLine(),A=t.getItemModel(x),I=A.getModel("label"),L=I.get("position")||A.get(["emphasis","label","position"]),P=I.get("distanceToLabelLine"),R=I.get("alignTo"),E=Z(I.get("edgeDistance"),u),O=I.get("bleedMargin"),k=A.getModel("labelLine"),B=k.get("length");B=Z(B,u);var z=k.get("length2");if(z=Z(z,u),Math.abs(T.endAngle-T.startAngle)<o){M(C.states,v),C.ignore=!0,D&&(M(D.states,v),D.ignore=!0);return}if(d(C)){var G=(T.startAngle+T.endAngle)/2,U=Math.cos(G),j=Math.sin(G),et,at,Rt,jt;n=T.cx,i=T.cy;var Nt=L==="inside"||L==="inner";if(L==="center")et=T.cx,at=T.cy,jt="center";else{var Lt=(Nt?(T.r+T.r0)/2*U:T.r*U)+n,xt=(Nt?(T.r+T.r0)/2*j:T.r*j)+i;if(et=Lt+U*3,at=xt+j*3,!Nt){var K=Lt+U*(B+l-T.r),ot=xt+j*(B+l-T.r),ze=K+(U<0?-1:1)*z,kt=ot;R==="edge"?et=U<0?f+E:f+u-E:et=ze+(U<0?-P:P),at=kt,Rt=[[Lt,xt],[K,ot],[ze,kt]]}jt=Nt?"center":R==="edge"?U>0?"right":"left":U>0?"left":"right"}var Sr=Math.PI,ar=0,Bi=I.get("rotate");if(ct(Bi))ar=Bi*(Sr/180);else if(L==="center")ar=0;else if(Bi==="radial"||Bi===!0){var SS=U<0?-G+Sr:-G;ar=SS}else if(Bi==="tangential"&&L!=="outside"&&L!=="outer"){var On=Math.atan2(U,j);On<0&&(On=Sr*2+On);var xS=j>0;xS&&(On=Sr+On),ar=On-Sr}if(a=!!ar,C.x=et,C.y=at,C.rotation=ar,C.setStyle({verticalAlign:"middle"}),Nt){C.setStyle({align:jt});var wl=C.states.select;wl&&(wl.x+=C.x,wl.y+=C.y)}else{var Ni=C.getBoundingRect().clone();Ni.applyTransform(C.getComputedTransform());var Bv=(C.style.margin||0)+2.1;Ni.y-=Bv/2,Ni.height+=Bv,e.push({label:C,labelLine:D,position:L,len:B,len2:z,minTurnAngle:k.get("minTurnAngle"),maxSurfaceAngle:k.get("maxSurfaceAngle"),surfaceNormal:new X(U,j),linePoints:Rt,textAlign:jt,labelDistance:P,labelAlignTo:R,edgeDistance:E,bleedMargin:O,rect:Ni,unconstrainedWidth:Ni.width,labelStyleWidth:C.style.width})}b.setTextConfig({inside:Nt})}}),!a&&r.get("avoidLabelOverlap")&&uI(e,n,i,l,u,c,f,h);for(var p=0;p<e.length;p++){var g=e[p],y=g.label,m=g.labelLine,_=isNaN(y.x)||isNaN(y.y);if(y){y.setStyle({align:g.textAlign}),_&&(M(y.states,v),y.ignore=!0);var S=y.states.select;S&&(S.x+=y.x,S.y+=y.y)}if(m){var w=g.linePoints;_||!w?(M(m.states,v),m.ignore=!0):($_(w,g.minTurnAngle),y2(w,g.surfaceNormal,g.maxSurfaceAngle),m.setShape({points:w}),y.__hostTarget.textGuideLineConfig={anchor:new X(w[0][0],w[0][1])})}}}var hI=function(r){N(t,r);function t(e,n,i){var a=r.call(this)||this;a.z2=2;var o=new Ct;return a.setTextContent(o),a.updateData(e,n,i,!0),a}return t.prototype.updateData=function(e,n,i,a){var o=this,s=e.hostModel,l=e.getItemModel(n),u=l.getModel("emphasis"),f=e.getItemLayout(n),h=F(da(l.getModel("itemStyle"),f,!0),f);if(isNaN(h.startAngle)){o.setShape(h);return}if(a){o.setShape(h);var c=s.getShallow("animationType");s.ecModel.ssr?(Pt(o,{scaleX:0,scaleY:0},s,{dataIndex:n,isFrom:!0}),o.originX=h.cx,o.originY=h.cy):c==="scale"?(o.shape.r=f.r0,Pt(o,{shape:{r:f.r}},s,n)):i!=null?(o.setShape({startAngle:i,endAngle:i}),Pt(o,{shape:{startAngle:f.startAngle,endAngle:f.endAngle}},s,n)):(o.shape.endAngle=f.startAngle,bt(o,{shape:{endAngle:f.endAngle}},s,n))}else Ba(o),bt(o,{shape:h},s,n);o.useStyle(e.getItemVisual(n,"style")),Wr(o,l);var v=(f.startAngle+f.endAngle)/2,d=s.get("selectedOffset"),p=Math.cos(v)*d,g=Math.sin(v)*d,y=l.getShallow("cursor");y&&o.attr("cursor",y),this._updateLabel(s,e,n),o.ensureState("emphasis").shape=F({r:f.r+(u.get("scale")&&u.get("scaleSize")||0)},da(u.getModel("itemStyle"),f)),F(o.ensureState("select"),{x:p,y:g,shape:da(l.getModel(["select","itemStyle"]),f)}),F(o.ensureState("blur"),{shape:da(l.getModel(["blur","itemStyle"]),f)});var m=o.getTextGuideLine(),_=o.getTextContent();m&&F(m.ensureState("select"),{x:p,y:g}),F(_.ensureState("select"),{x:p,y:g}),mr(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},t.prototype._updateLabel=function(e,n,i){var a=this,o=n.getItemModel(i),s=o.getModel("labelLine"),l=n.getItemVisual(i,"style"),u=l&&l.fill,f=l&&l.opacity;Rn(a,En(o),{labelFetcher:n.hostModel,labelDataIndex:i,inheritColor:u,defaultOpacity:f,defaultText:e.getFormattedLabel(i,"normal")||n.getName(i)});var h=a.getTextContent();a.setTextConfig({position:null,rotation:null}),h.attr({z2:10});var c=e.get(["label","position"]);if(c!=="outside"&&c!=="outer")a.removeTextGuideLine();else{var v=this.getTextGuideLine();v||(v=new Xr,this.setTextGuideLine(v)),q_(this,K_(o),{stroke:u,opacity:ga(s.get(["lineStyle","opacity"]),f,1)})}},t}(Se),vI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.ignoreLabelLineUpdate=!0,e}return t.prototype.render=function(e,n,i,a){var o=e.getData(),s=this._data,l=this.group,u;if(!s&&o.count()>0){for(var f=o.getItemLayout(0),h=1;isNaN(f&&f.startAngle)&&h<o.count();++h)f=o.getItemLayout(h);f&&(u=f.startAngle)}if(this._emptyCircleSector&&l.remove(this._emptyCircleSector),o.count()===0&&e.get("showEmptyCircle")){var c=p1(e),v=new Se({shape:F(d1(e,i),c)});v.useStyle(e.getModel("emptyCircleStyle").getItemStyle()),this._emptyCircleSector=v,l.add(v)}o.diff(s).add(function(d){var p=new hI(o,d,u);o.setItemGraphicEl(d,p),l.add(p)}).update(function(d,p){var g=s.getItemGraphicEl(p);g.updateData(o,d,u),g.off("click"),l.add(g),o.setItemGraphicEl(d,g)}).remove(function(d){var p=s.getItemGraphicEl(d);xs(p,e,d)}).execute(),fI(e),e.get("animationTypeUpdate")!=="expansion"&&(this._data=o)},t.prototype.dispose=function(){},t.prototype.containPoint=function(e,n){var i=n.getData(),a=i.getItemLayout(0);if(a){var o=e[0]-a.cx,s=e[1]-a.cy,l=Math.sqrt(o*o+s*s);return l<=a.r&&l>=a.r0}},t.type="pie",t}(Wt);function xv(r,t,e){t=V(t)&&{coordDimensions:t}||F({encodeDefine:r.getEncode()},t);var n=r.getSource(),i=w_(n,t).dimensions,a=new x_(i,r);return a.initData(n,e),a}var m1=function(){function r(t,e){this._getDataWithEncodedVisual=t,this._getRawData=e}return r.prototype.getAllNames=function(){var t=this._getRawData();return t.mapArray(t.getName)},r.prototype.containName=function(t){var e=this._getRawData();return e.indexOfName(t)>=0},r.prototype.indexOfName=function(t){var e=this._getDataWithEncodedVisual();return e.indexOfName(t)},r.prototype.getItemVisual=function(t,e){var n=this._getDataWithEncodedVisual();return n.getItemVisual(t,e)},r}(),cI=_t(),dI=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new m1(dt(this.getData,this),dt(this.getRawData,this)),this._defaultLabelLine(e)},t.prototype.mergeOption=function(){r.prototype.mergeOption.apply(this,arguments)},t.prototype.getInitialData=function(){return xv(this,{coordDimensions:["value"],encodeDefaulter:vt(_C,this)})},t.prototype.getDataParams=function(e){var n=this.getData(),i=cI(n),a=i.seats;if(!a){var o=[];n.each(n.mapDimension("value"),function(l){o.push(l)}),a=i.seats=Tw(o,n.hostModel.get("percentPrecision"))}var s=r.prototype.getDataParams.call(this,e);return s.percent=a[e]||0,s.$vars.push("percent"),s},t.prototype._defaultLabelLine=function(e){mf(e,"labelLine",["show"]);var n=e.labelLine,i=e.emphasis.labelLine;n.show=n.show&&e.label.show,i.show=i.show&&e.emphasis.label.show},t.type="series.pie",t.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,endAngle:"auto",padAngle:0,minAngle:0,minShowLabelAngle:0,selectedOffset:10,percentPrecision:2,stillShowZeroSum:!0,left:0,top:0,right:0,bottom:0,width:null,height:null,label:{rotate:0,show:!0,overflow:"truncate",position:"outer",alignTo:"none",edgeDistance:"25%",bleedMargin:10,distanceToLabelLine:5},labelLine:{show:!0,length:15,length2:15,smooth:!1,minTurnAngle:90,maxSurfaceAngle:90,lineStyle:{width:1,type:"solid"}},itemStyle:{borderWidth:1,borderJoin:"round"},showEmptyCircle:!0,emptyCircleStyle:{color:"lightgray",opacity:1},labelLayout:{hideOverlap:!0},emphasis:{scale:!0,scaleSize:5},avoidLabelOverlap:!0,animationType:"expansion",animationDuration:1e3,animationTypeUpdate:"transition",animationEasingUpdate:"cubicInOut",animationDurationUpdate:500,animationEasing:"cubicInOut"},t}(se);function pI(r){return{seriesType:r,reset:function(t,e){var n=t.getData();n.filterSelf(function(i){var a=n.mapDimension("value"),o=n.get(a,i);return!(ct(o)&&!isNaN(o)&&o<0)})}}}function gI(r){r.registerChartView(vI),r.registerSeriesModel(dI),rA("pie",r.registerAction),r.registerLayout(vt(sI,"pie")),r.registerProcessor(g1("pie")),r.registerProcessor(pI("pie"))}var yI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e,n){return pl(null,this,{useEncodeDefaulter:!0})},t.prototype.getProgressive=function(){var e=this.option.progressive;return e??(this.option.large?5e3:this.get("progressive"))},t.prototype.getProgressiveThreshold=function(){var e=this.option.progressiveThreshold;return e??(this.option.large?1e4:this.get("progressiveThreshold"))},t.prototype.brushSelector=function(e,n,i){return i.point(n.getItemLayout(e))},t.prototype.getZLevelKey=function(){return this.getData().count()>this.getProgressiveThreshold()?this.id:""},t.type="series.scatter",t.dependencies=["grid","polar","geo","singleAxis","calendar"],t.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,symbolSize:10,large:!1,largeThreshold:2e3,itemStyle:{opacity:.8},emphasis:{scale:!0},clip:!0,select:{itemStyle:{borderColor:"#212121"}},universalTransition:{divideShape:"clone"}},t}(se),_1=4,mI=function(){function r(){}return r}(),_I=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n._off=0,n.hoverDataIdx=-1,n}return t.prototype.getDefaultShape=function(){return new mI},t.prototype.reset=function(){this.notClear=!1,this._off=0},t.prototype.buildPath=function(e,n){var i=n.points,a=n.size,o=this.symbolProxy,s=o.shape,l=e.getContext?e.getContext():e,u=l&&a[0]<_1,f=this.softClipShape,h;if(u){this._ctx=l;return}for(this._ctx=null,h=this._off;h<i.length;){var c=i[h++],v=i[h++];isNaN(c)||isNaN(v)||f&&!f.contain(c,v)||(s.x=c-a[0]/2,s.y=v-a[1]/2,s.width=a[0],s.height=a[1],o.buildPath(e,s,!0))}this.incremental&&(this._off=h,this.notClear=!0)},t.prototype.afterBrush=function(){var e=this.shape,n=e.points,i=e.size,a=this._ctx,o=this.softClipShape,s;if(a){for(s=this._off;s<n.length;){var l=n[s++],u=n[s++];isNaN(l)||isNaN(u)||o&&!o.contain(l,u)||a.fillRect(l-i[0]/2,u-i[1]/2,i[0],i[1])}this.incremental&&(this._off=s,this.notClear=!0)}},t.prototype.findDataIndex=function(e,n){for(var i=this.shape,a=i.points,o=i.size,s=Math.max(o[0],4),l=Math.max(o[1],4),u=a.length/2-1;u>=0;u--){var f=u*2,h=a[f]-s/2,c=a[f+1]-l/2;if(e>=h&&n>=c&&e<=h+s&&n<=c+l)return u}return-1},t.prototype.contain=function(e,n){var i=this.transformCoordToLocal(e,n),a=this.getBoundingRect();if(e=i[0],n=i[1],a.contain(e,n)){var o=this.hoverDataIdx=this.findDataIndex(e,n);return o>=0}return this.hoverDataIdx=-1,!1},t.prototype.getBoundingRect=function(){var e=this._rect;if(!e){for(var n=this.shape,i=n.points,a=n.size,o=a[0],s=a[1],l=1/0,u=1/0,f=-1/0,h=-1/0,c=0;c<i.length;){var v=i[c++],d=i[c++];l=Math.min(v,l),f=Math.max(v,f),u=Math.min(d,u),h=Math.max(d,h)}e=this._rect=new ut(l-o/2,u-s/2,f-l+o,h-u+s)}return e},t}(it),SI=function(){function r(){this.group=new yt}return r.prototype.updateData=function(t,e){this._clear();var n=this._create();n.setShape({points:t.getLayout("points")}),this._setCommon(n,t,e)},r.prototype.updateLayout=function(t){var e=t.getLayout("points");this.group.eachChild(function(n){if(n.startIndex!=null){var i=(n.endIndex-n.startIndex)*2,a=n.startIndex*4*2;e=new Float32Array(e.buffer,a,i)}n.setShape("points",e),n.reset()})},r.prototype.incrementalPrepareUpdate=function(t){this._clear()},r.prototype.incrementalUpdate=function(t,e,n){var i=this._newAdded[0],a=e.getLayout("points"),o=i&&i.shape.points;if(o&&o.length<2e4){var s=o.length,l=new Float32Array(s+a.length);l.set(o),l.set(a,s),i.endIndex=t.end,i.setShape({points:l})}else{this._newAdded=[];var u=this._create();u.startIndex=t.start,u.endIndex=t.end,u.incremental=!0,u.setShape({points:a}),this._setCommon(u,e,n)}},r.prototype.eachRendered=function(t){this._newAdded[0]&&t(this._newAdded[0])},r.prototype._create=function(){var t=new _I({cursor:"default"});return t.ignoreCoarsePointer=!0,this.group.add(t),this._newAdded.push(t),t},r.prototype._setCommon=function(t,e,n){var i=e.hostModel;n=n||{};var a=e.getVisual("symbolSize");t.setShape("size",a instanceof Array?a:[a,a]),t.softClipShape=n.clipShape||null,t.symbolProxy=Ee(e.getVisual("symbol"),0,0,0,0),t.setColor=t.symbolProxy.setColor;var o=t.shape.size[0]<_1;t.useStyle(i.getModel("itemStyle").getItemStyle(o?["color","shadowBlur","shadowColor"]:["color"]));var s=e.getVisual("style"),l=s&&s.fill;l&&t.setColor(l);var u=st(t);u.seriesIndex=i.seriesIndex,t.on("mousemove",function(f){u.dataIndex=null;var h=t.hoverDataIdx;h>=0&&(u.dataIndex=h+(t.startIndex||0))})},r.prototype.remove=function(){this._clear()},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),xI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){var a=e.getData(),o=this._updateSymbolDraw(a,e);o.updateData(a,{clipShape:this._getClipShape(e)}),this._finished=!0},t.prototype.incrementalPrepareRender=function(e,n,i){var a=e.getData(),o=this._updateSymbolDraw(a,e);o.incrementalPrepareUpdate(a),this._finished=!1},t.prototype.incrementalRender=function(e,n,i){this._symbolDraw.incrementalUpdate(e,n.getData(),{clipShape:this._getClipShape(n)}),this._finished=e.end===n.getData().count()},t.prototype.updateTransform=function(e,n,i){var a=e.getData();if(this.group.dirty(),!this._finished||a.count()>1e4)return{update:!0};var o=Sv("").reset(e,n,i);o.progress&&o.progress({start:0,end:a.count(),count:a.count()},a),this._symbolDraw.updateLayout(a)},t.prototype.eachRendered=function(e){this._symbolDraw&&this._symbolDraw.eachRendered(e)},t.prototype._getClipShape=function(e){if(e.get("clip",!0)){var n=e.coordinateSystem;return n&&n.getArea&&n.getArea(.1)}},t.prototype._updateSymbolDraw=function(e,n){var i=this._symbolDraw,a=n.pipelineContext,o=a.large;return(!i||o!==this._isLargeDraw)&&(i&&i.remove(),i=this._symbolDraw=o?new SI:new r1,this._isLargeDraw=o,this.group.removeAll()),this.group.add(i.group),i},t.prototype.remove=function(e,n){this._symbolDraw&&this._symbolDraw.remove(!0),this._symbolDraw=null},t.prototype.dispose=function(){},t.type="scatter",t}(Wt),wI=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.type="grid",t.dependencies=["xAxis","yAxis"],t.layoutMode="box",t.defaultOption={show:!1,z:0,left:"10%",top:60,right:"10%",bottom:70,containLabel:!1,backgroundColor:"rgba(0,0,0,0)",borderWidth:1,borderColor:"#ccc"},t}(ht),Qf=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",$t).models[0]},t.type="cartesian2dAxis",t}(ht);Oe(Qf,F_);var S1={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:"#6E7079",width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15]},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12},splitLine:{show:!0,showMinLine:!0,showMaxLine:!0,lineStyle:{color:["#E0E6F1"],width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:["rgba(250,250,250,0.2)","rgba(210,219,238,0.2)"]}}},bI=nt({boundaryGap:!0,deduplication:null,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto"},axisLabel:{interval:"auto"}},S1),wv=nt({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:"#F4F7FD",width:1}}},S1),TI=nt({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},wv),CI=Q({logBase:10},wv);const x1={category:bI,value:wv,time:TI,log:CI};var DI={value:1,category:1,time:1,log:1};function Vp(r,t,e,n){M(DI,function(i,a){var o=nt(nt({},x1[a],!0),n,!0),s=function(l){N(u,l);function u(){var f=l!==null&&l.apply(this,arguments)||this;return f.type=t+"Axis."+a,f}return u.prototype.mergeDefaultAndTheme=function(f,h){var c=za(this),v=c?hl(f):{},d=h.getTheme();nt(f,d.get(a+"Axis")),nt(f,this.getDefaultOption()),f.type=Gp(f),c&&bi(f,v,c)},u.prototype.optionUpdated=function(){var f=this.option;f.type==="category"&&(this.__ordinalMeta=$f.createByAxisModel(this))},u.prototype.getCategories=function(f){var h=this.option;if(h.type==="category")return f?h.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.type=t+"Axis."+a,u.defaultOption=o,u}(e);r.registerComponentModel(s)}),r.registerSubTypeDefaulter(t+"Axis",Gp)}function Gp(r){return r.type||(r.data?"category":"value")}var AI=function(){function r(t){this.type="cartesian",this._dimList=[],this._axes={},this.name=t||""}return r.prototype.getAxis=function(t){return this._axes[t]},r.prototype.getAxes=function(){return H(this._dimList,function(t){return this._axes[t]},this)},r.prototype.getAxesByScale=function(t){return t=t.toLowerCase(),Tt(this.getAxes(),function(e){return e.scale.type===t})},r.prototype.addAxis=function(t){var e=t.dim;this._axes[e]=t,this._dimList.push(e)},r}(),Jf=["x","y"];function Hp(r){return r.type==="interval"||r.type==="time"}var MI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="cartesian2d",e.dimensions=Jf,e}return t.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var e=this.getAxis("x").scale,n=this.getAxis("y").scale;if(!(!Hp(e)||!Hp(n))){var i=e.getExtent(),a=n.getExtent(),o=this.dataToPoint([i[0],a[0]]),s=this.dataToPoint([i[1],a[1]]),l=i[1]-i[0],u=a[1]-a[0];if(!(!l||!u)){var f=(s[0]-o[0])/l,h=(s[1]-o[1])/u,c=o[0]-i[0]*f,v=o[1]-a[0]*h,d=this._transform=[f,0,0,h,c,v];this._invTransform=Hs([],d)}}},t.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},t.prototype.containPoint=function(e){var n=this.getAxis("x"),i=this.getAxis("y");return n.contain(n.toLocalCoord(e[0]))&&i.contain(i.toLocalCoord(e[1]))},t.prototype.containData=function(e){return this.getAxis("x").containData(e[0])&&this.getAxis("y").containData(e[1])},t.prototype.containZone=function(e,n){var i=this.dataToPoint(e),a=this.dataToPoint(n),o=this.getArea(),s=new ut(i[0],i[1],a[0]-i[0],a[1]-i[1]);return o.intersect(s)},t.prototype.dataToPoint=function(e,n,i){i=i||[];var a=e[0],o=e[1];if(this._transform&&a!=null&&isFinite(a)&&o!=null&&isFinite(o))return me(i,e,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return i[0]=s.toGlobalCoord(s.dataToCoord(a,n)),i[1]=l.toGlobalCoord(l.dataToCoord(o,n)),i},t.prototype.clampData=function(e,n){var i=this.getAxis("x").scale,a=this.getAxis("y").scale,o=i.getExtent(),s=a.getExtent(),l=i.parse(e[0]),u=a.parse(e[1]);return n=n||[],n[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),n[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),n},t.prototype.pointToData=function(e,n){var i=[];if(this._invTransform)return me(i,e,this._invTransform);var a=this.getAxis("x"),o=this.getAxis("y");return i[0]=a.coordToData(a.toLocalCoord(e[0]),n),i[1]=o.coordToData(o.toLocalCoord(e[1]),n),i},t.prototype.getOtherAxis=function(e){return this.getAxis(e.dim==="x"?"y":"x")},t.prototype.getArea=function(e){e=e||0;var n=this.getAxis("x").getGlobalExtent(),i=this.getAxis("y").getGlobalExtent(),a=Math.min(n[0],n[1])-e,o=Math.min(i[0],i[1])-e,s=Math.max(n[0],n[1])-a+e,l=Math.max(i[0],i[1])-o+e;return new ut(a,o,s,l)},t}(AI),II=function(r){N(t,r);function t(e,n,i,a,o){var s=r.call(this,e,n,i)||this;return s.index=0,s.type=a||"value",s.position=o||"bottom",s}return t.prototype.isHorizontal=function(){var e=this.position;return e==="top"||e==="bottom"},t.prototype.getGlobalExtent=function(e){var n=this.getExtent();return n[0]=this.toGlobalCoord(n[0]),n[1]=this.toGlobalCoord(n[1]),e&&n[0]>n[1]&&n.reverse(),n},t.prototype.pointToData=function(e,n){return this.coordToData(this.toLocalCoord(e[this.dim==="x"?0:1]),n)},t.prototype.setCategorySortInfo=function(e){if(this.type!=="category")return!1;this.model.option.categorySortInfo=e,this.scale.setSortInfo(e)},t}(X_);function jf(r,t,e){e=e||{};var n=r.coordinateSystem,i=t.axis,a={},o=i.getAxesOnZeroOf()[0],s=i.position,l=o?"onZero":s,u=i.dim,f=n.getRect(),h=[f.x,f.x+f.width,f.y,f.y+f.height],c={left:0,right:1,top:0,bottom:1,onZero:2},v=t.get("offset")||0,d=u==="x"?[h[2]-v,h[3]+v]:[h[0]-v,h[1]+v];if(o){var p=o.toGlobalCoord(o.dataToCoord(0));d[c.onZero]=Math.max(Math.min(p,d[1]),d[0])}a.position=[u==="y"?d[c[l]]:h[0],u==="x"?d[c[l]]:h[3]],a.rotation=Math.PI/2*(u==="x"?0:1);var g={top:-1,bottom:1,left:-1,right:1};a.labelDirection=a.tickDirection=a.nameDirection=g[s],a.labelOffset=o?d[c[s]]-d[c.onZero]:0,t.get(["axisTick","inside"])&&(a.tickDirection=-a.tickDirection),Si(e.labelInside,t.get(["axisLabel","inside"]))&&(a.labelDirection=-a.labelDirection);var y=t.get(["axisLabel","rotate"]);return a.labelRotate=l==="top"?-y:y,a.z2=1,a}function Wp(r){return r.get("coordinateSystem")==="cartesian2d"}function Up(r){var t={xAxisModel:null,yAxisModel:null};return M(t,function(e,n){var i=n.replace(/Model$/,""),a=r.getReferringComponents(i,$t).models[0];t[n]=a}),t}var Bu=Math.log;function w1(r,t,e){var n=Yr.prototype,i=n.getTicks.call(e),a=n.getTicks.call(e,!0),o=i.length-1,s=n.getInterval.call(e),l=O_(r,t),u=l.extent,f=l.fixMin,h=l.fixMax;if(r.type==="log"){var c=Bu(r.base);u=[Bu(u[0])/c,Bu(u[1])/c]}r.setExtent(u[0],u[1]),r.calcNiceExtent({splitNumber:o,fixMin:f,fixMax:h});var v=n.getExtent.call(r);f&&(u[0]=v[0]),h&&(u[1]=v[1]);var d=n.getInterval.call(r),p=u[0],g=u[1];if(f&&h)d=(g-p)/o;else if(f)for(g=u[0]+d*o;g<u[1]&&isFinite(g)&&isFinite(u[1]);)d=Au(d),g=u[0]+d*o;else if(h)for(p=u[1]-d*o;p>u[0]&&isFinite(p)&&isFinite(u[0]);)d=Au(d),p=u[1]-d*o;else{var y=r.getTicks().length-1;y>o&&(d=Au(d));var m=d*o;g=Math.ceil(u[1]/d)*d,p=Mt(g-m),p<0&&u[0]>=0?(p=0,g=Mt(m)):g>0&&u[1]<=0&&(g=0,p=-Mt(m))}var _=(i[0].value-a[0].value)/s,S=(i[o].value-a[o].value)/s;n.setExtent.call(r,p+d*_,g+d*S),n.setInterval.call(r,d),(_||S)&&n.setNiceExtent.call(r,p+d,g-d)}var LI=function(){function r(t,e,n){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=Jf,this._initCartesian(t,e,n),this.model=t}return r.prototype.getRect=function(){return this._rect},r.prototype.update=function(t,e){var n=this._axesMap;this._updateScale(t,this.model);function i(o){var s,l=mt(o),u=l.length;if(u){for(var f=[],h=u-1;h>=0;h--){var c=+l[h],v=o[c],d=v.model,p=v.scale;qf(p)&&d.get("alignTicks")&&d.get("interval")==null?f.push(v):(gp(p,d),qf(p)&&(s=v))}f.length&&(s||(s=f.pop(),gp(s.scale,s.model)),M(f,function(g){w1(g.scale,g.model,s.scale)}))}}i(n.x),i(n.y);var a={};M(n.x,function(o){Yp(n,"y",o,a)}),M(n.y,function(o){Yp(n,"x",o,a)}),this.resize(this.model,e)},r.prototype.resize=function(t,e,n){var i=t.getBoxLayoutParams(),a=!n&&t.get("containLabel"),o=Ur(i,{width:e.getWidth(),height:e.getHeight()});this._rect=o;var s=this._axesList;l(),a&&(M(s,function(u){if(!u.model.get(["axisLabel","inside"])){var f=jM(u);if(f){var h=u.isHorizontal()?"height":"width",c=u.model.get(["axisLabel","margin"]);o[h]-=f[h]+c,u.position==="top"?o.y+=f.height+c:u.position==="left"&&(o.x+=f.width+c)}}}),l()),M(this._coordsList,function(u){u.calcAffineTransform()});function l(){M(s,function(u){var f=u.isHorizontal(),h=f?[0,o.width]:[0,o.height],c=u.inverse?1:0;u.setExtent(h[c],h[1-c]),PI(u,f?o.x:o.y)})}},r.prototype.getAxis=function(t,e){var n=this._axesMap[t];if(n!=null)return n[e||0]},r.prototype.getAxes=function(){return this._axesList.slice()},r.prototype.getCartesian=function(t,e){if(t!=null&&e!=null){var n="x"+t+"y"+e;return this._coordsMap[n]}Y(t)&&(e=t.yAxisIndex,t=t.xAxisIndex);for(var i=0,a=this._coordsList;i<a.length;i++)if(a[i].getAxis("x").index===t||a[i].getAxis("y").index===e)return a[i]},r.prototype.getCartesians=function(){return this._coordsList.slice()},r.prototype.convertToPixel=function(t,e,n){var i=this._findConvertTarget(e);return i.cartesian?i.cartesian.dataToPoint(n):i.axis?i.axis.toGlobalCoord(i.axis.dataToCoord(n)):null},r.prototype.convertFromPixel=function(t,e,n){var i=this._findConvertTarget(e);return i.cartesian?i.cartesian.pointToData(n):i.axis?i.axis.coordToData(i.axis.toLocalCoord(n)):null},r.prototype._findConvertTarget=function(t){var e=t.seriesModel,n=t.xAxisModel||e&&e.getReferringComponents("xAxis",$t).models[0],i=t.yAxisModel||e&&e.getReferringComponents("yAxis",$t).models[0],a=t.gridModel,o=this._coordsList,s,l;if(e)s=e.coordinateSystem,lt(o,s)<0&&(s=null);else if(n&&i)s=this.getCartesian(n.componentIndex,i.componentIndex);else if(n)l=this.getAxis("x",n.componentIndex);else if(i)l=this.getAxis("y",i.componentIndex);else if(a){var u=a.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},r.prototype.containPoint=function(t){var e=this._coordsList[0];if(e)return e.containPoint(t)},r.prototype._initCartesian=function(t,e,n){var i=this,a=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(e.eachComponent("xAxis",u("x"),this),e.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,M(s.x,function(f,h){M(s.y,function(c,v){var d="x"+h+"y"+v,p=new MI(d);p.master=i,p.model=t,i._coordsMap[d]=p,i._coordsList.push(p),p.addAxis(f),p.addAxis(c)})});function u(f){return function(h,c){if(Nu(h,t)){var v=h.get("position");f==="x"?v!=="top"&&v!=="bottom"&&(v=o.bottom?"top":"bottom"):v!=="left"&&v!=="right"&&(v=o.left?"right":"left"),o[v]=!0;var d=new II(f,QM(h),[0,0],h.get("type"),v),p=d.type==="category";d.onBand=p&&h.get("boundaryGap"),d.inverse=h.get("inverse"),h.axis=d,d.model=h,d.grid=a,d.index=c,a._axesList.push(d),s[f][c]=d,l[f]++}}}},r.prototype._updateScale=function(t,e){M(this._axesList,function(i){if(i.scale.setExtent(1/0,-1/0),i.type==="category"){var a=i.model.get("categorySortInfo");i.scale.setSortInfo(a)}}),t.eachSeries(function(i){if(Wp(i)){var a=Up(i),o=a.xAxisModel,s=a.yAxisModel;if(!Nu(o,e)||!Nu(s,e))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=i.getData(),f=l.getAxis("x"),h=l.getAxis("y");n(u,f),n(u,h)}},this);function n(i,a){M(N_(i,a.dim),function(o){a.scale.unionExtentFromData(i,o)})}},r.prototype.getTooltipAxes=function(t){var e=[],n=[];return M(this.getCartesians(),function(i){var a=t!=null&&t!=="auto"?i.getAxis(t):i.getBaseAxis(),o=i.getOtherAxis(a);lt(e,a)<0&&e.push(a),lt(n,o)<0&&n.push(o)}),{baseAxes:e,otherAxes:n}},r.create=function(t,e){var n=[];return t.eachComponent("grid",function(i,a){var o=new r(i,t,e);o.name="grid_"+a,o.resize(i,e,!0),i.coordinateSystem=o,n.push(o)}),t.eachSeries(function(i){if(Wp(i)){var a=Up(i),o=a.xAxisModel,s=a.yAxisModel,l=o.getCoordSysModel(),u=l.coordinateSystem;i.coordinateSystem=u.getCartesian(o.componentIndex,s.componentIndex)}}),n},r.dimensions=Jf,r}();function Nu(r,t){return r.getCoordSysModel()===t}function Yp(r,t,e,n){e.getAxesOnZeroOf=function(){return a?[a]:[]};var i=r[t],a,o=e.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)Xp(i[l])&&(a=i[l]);else for(var u in i)if(i.hasOwnProperty(u)&&Xp(i[u])&&!n[f(i[u])]){a=i[u];break}a&&(n[f(a)]=!0);function f(h){return h.dim+"_"+h.index}}function Xp(r){return r&&r.type!=="category"&&r.type!=="time"&&JM(r)}function PI(r,t){var e=r.getExtent(),n=e[0]+e[1];r.toGlobalCoord=r.dim==="x"?function(i){return i+t}:function(i){return n-i+t},r.toLocalCoord=r.dim==="x"?function(i){return i-t}:function(i){return n-i+t}}var Or=Math.PI,pr=function(){function r(t,e){this.group=new yt,this.opt=e,this.axisModel=t,Q(e,{labelOffset:0,nameDirection:1,tickDirection:1,labelDirection:1,silent:!0,handleAutoShown:function(){return!0}});var n=new yt({x:e.position[0],y:e.position[1],rotation:e.rotation});n.updateTransform(),this._transformGroup=n}return r.prototype.hasBuilder=function(t){return!!Zp[t]},r.prototype.add=function(t){Zp[t](this.opt,this.axisModel,this.group,this._transformGroup)},r.prototype.getGroup=function(){return this.group},r.innerTextLayout=function(t,e,n){var i=qy(e-t),a,o;return ys(i)?(o=n>0?"top":"bottom",a="center"):ys(i-Or)?(o=n>0?"bottom":"top",a="center"):(o="middle",i>0&&i<Or?a=n>0?"right":"left":a=n>0?"left":"right"),{rotation:i,textAlign:a,textVerticalAlign:o}},r.makeAxisEventDataBase=function(t){var e={componentType:t.mainType,componentIndex:t.componentIndex};return e[t.mainType+"Index"]=t.componentIndex,e},r.isLabelSilent=function(t){var e=t.get("tooltip");return t.get("silent")||!(t.get("triggerEvent")||e&&e.show)},r}(),Zp={axisLine:function(r,t,e,n){var i=t.get(["axisLine","show"]);if(i==="auto"&&r.handleAutoShown&&(i=r.handleAutoShown("axisLine")),!!i){var a=t.axis.getExtent(),o=n.transform,s=[a[0],0],l=[a[1],0],u=s[0]>l[0];o&&(me(s,s,o),me(l,l,o));var f=F({lineCap:"round"},t.getModel(["axisLine","lineStyle"]).getLineStyle()),h=new er({shape:{x1:s[0],y1:s[1],x2:l[0],y2:l[1]},style:f,strokeContainThreshold:r.strokeContainThreshold||5,silent:!0,z2:1});Na(h.shape,h.style.lineWidth),h.anid="line",e.add(h);var c=t.get(["axisLine","symbol"]);if(c!=null){var v=t.get(["axisLine","symbolSize"]);W(c)&&(c=[c,c]),(W(v)||ct(v))&&(v=[v,v]);var d=sv(t.get(["axisLine","symbolOffset"])||0,v),p=v[0],g=v[1];M([{rotate:r.rotation+Math.PI/2,offset:d[0],r:0},{rotate:r.rotation-Math.PI/2,offset:d[1],r:Math.sqrt((s[0]-l[0])*(s[0]-l[0])+(s[1]-l[1])*(s[1]-l[1]))}],function(y,m){if(c[m]!=="none"&&c[m]!=null){var _=Ee(c[m],-p/2,-g/2,p,g,f.stroke,!0),S=y.r+y.offset,w=u?l:s;_.attr({rotation:y.rotate,x:w[0]+S*Math.cos(r.rotation),y:w[1]-S*Math.sin(r.rotation),silent:!0,z2:11}),e.add(_)}})}}},axisTickLabel:function(r,t,e,n){var i=kI(e,n,t,r),a=BI(e,n,t,r);if(EI(t,a,i),OI(e,n,t,r.tickDirection),t.get(["axisLabel","hideOverlap"])){var o=Q_(H(a,function(s){return{label:s,priority:s.z2,defaultAttr:{ignore:s.ignore}}}));t1(o)}},axisName:function(r,t,e,n){var i=Si(r.axisName,t.get("name"));if(i){var a=t.get("nameLocation"),o=r.nameDirection,s=t.getModel("nameTextStyle"),l=t.get("nameGap")||0,u=t.axis.getExtent(),f=u[0]>u[1]?-1:1,h=[a==="start"?u[0]-f*l:a==="end"?u[1]+f*l:(u[0]+u[1])/2,qp(a)?r.labelOffset+o*l:0],c,v=t.get("nameRotate");v!=null&&(v=v*Or/180);var d;qp(a)?c=pr.innerTextLayout(r.rotation,v??r.rotation,o):(c=RI(r.rotation,a,v||0,u),d=r.axisNameAvailableWidth,d!=null&&(d=Math.abs(d/Math.sin(c.rotation)),!isFinite(d)&&(d=null)));var p=s.getFont(),g=t.get("nameTruncate",!0)||{},y=g.ellipsis,m=Si(r.nameTruncateMaxWidth,g.maxWidth,d),_=new Ct({x:h[0],y:h[1],rotation:c.rotation,silent:pr.isLabelSilent(t),style:ye(s,{text:i,font:p,overflow:"truncate",width:m,ellipsis:y,fill:s.getTextColor()||t.get(["axisLine","lineStyle","color"]),align:s.get("align")||c.textAlign,verticalAlign:s.get("verticalAlign")||c.textVerticalAlign}),z2:1});if(ja({el:_,componentModel:t,itemName:i}),_.__fullText=i,_.anid="name",t.get("triggerEvent")){var S=pr.makeAxisEventDataBase(t);S.targetType="axisName",S.name=i,st(_).eventData=S}n.add(_),_.updateTransform(),e.add(_),_.decomposeTransform()}}};function RI(r,t,e,n){var i=qy(e-r),a,o,s=n[0]>n[1],l=t==="start"&&!s||t!=="start"&&s;return ys(i-Or/2)?(o=l?"bottom":"top",a="center"):ys(i-Or*1.5)?(o=l?"top":"bottom",a="center"):(o="middle",i<Or*1.5&&i>Or/2?a=l?"left":"right":a=l?"right":"left"),{rotation:i,textAlign:a,textVerticalAlign:o}}function EI(r,t,e){if(!B_(r.axis)){var n=r.get(["axisLabel","showMinLabel"]),i=r.get(["axisLabel","showMaxLabel"]);t=t||[],e=e||[];var a=t[0],o=t[1],s=t[t.length-1],l=t[t.length-2],u=e[0],f=e[1],h=e[e.length-1],c=e[e.length-2];n===!1?(fe(a),fe(u)):$p(a,o)&&(n?(fe(o),fe(f)):(fe(a),fe(u))),i===!1?(fe(s),fe(h)):$p(l,s)&&(i?(fe(l),fe(c)):(fe(s),fe(h)))}}function fe(r){r&&(r.ignore=!0)}function $p(r,t){var e=r&&r.getBoundingRect().clone(),n=t&&t.getBoundingRect().clone();if(!(!e||!n)){var i=Ch([]);return Dh(i,i,-r.rotation),e.applyTransform(hi([],i,r.getLocalTransform())),n.applyTransform(hi([],i,t.getLocalTransform())),e.intersect(n)}}function qp(r){return r==="middle"||r==="center"}function b1(r,t,e,n,i){for(var a=[],o=[],s=[],l=0;l<r.length;l++){var u=r[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=e,t&&(me(o,o,t),me(s,s,t));var f=new er({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:n,z2:2,autoBatch:!0,silent:!0});Na(f.shape,f.style.lineWidth),f.anid=i+"_"+r[l].tickValue,a.push(f)}return a}function kI(r,t,e,n){var i=e.axis,a=e.getModel("axisTick"),o=a.get("show");if(o==="auto"&&n.handleAutoShown&&(o=n.handleAutoShown("axisTick")),!(!o||i.scale.isBlank())){for(var s=a.getModel("lineStyle"),l=n.tickDirection*a.get("length"),u=i.getTicksCoords(),f=b1(u,t.transform,l,Q(s.getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])}),"ticks"),h=0;h<f.length;h++)r.add(f[h]);return f}}function OI(r,t,e,n){var i=e.axis,a=e.getModel("minorTick");if(!(!a.get("show")||i.scale.isBlank())){var o=i.getMinorTicksCoords();if(o.length)for(var s=a.getModel("lineStyle"),l=n*a.get("length"),u=Q(s.getLineStyle(),Q(e.getModel("axisTick").getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])})),f=0;f<o.length;f++)for(var h=b1(o[f],t.transform,l,u,"minorticks_"+f),c=0;c<h.length;c++)r.add(h[c])}}function BI(r,t,e,n){var i=e.axis,a=Si(n.axisLabelShow,e.get(["axisLabel","show"]));if(!(!a||i.scale.isBlank())){var o=e.getModel("axisLabel"),s=o.get("margin"),l=i.getViewLabels(),u=(Si(n.labelRotate,o.get("rotate"))||0)*Or/180,f=pr.innerTextLayout(n.rotation,u,n.labelDirection),h=e.getCategories&&e.getCategories(!0),c=[],v=pr.isLabelSilent(e),d=e.get("triggerEvent");return M(l,function(p,g){var y=i.scale.type==="ordinal"?i.scale.getRawOrdinalNumber(p.tickValue):p.tickValue,m=p.formattedLabel,_=p.rawLabel,S=o;if(h&&h[y]){var w=h[y];Y(w)&&w.textStyle&&(S=new wt(w.textStyle,o,e.ecModel))}var x=S.getTextColor()||e.get(["axisLine","lineStyle","color"]),b=i.dataToCoord(y),T=S.getShallow("align",!0)||f.textAlign,C=rt(S.getShallow("alignMinLabel",!0),T),D=rt(S.getShallow("alignMaxLabel",!0),T),A=S.getShallow("verticalAlign",!0)||S.getShallow("baseline",!0)||f.textVerticalAlign,I=rt(S.getShallow("verticalAlignMinLabel",!0),A),L=rt(S.getShallow("verticalAlignMaxLabel",!0),A),P=new Ct({x:b,y:n.labelOffset+n.labelDirection*s,rotation:f.rotation,silent:v,z2:10+(p.level||0),style:ye(S,{text:m,align:g===0?C:g===l.length-1?D:T,verticalAlign:g===0?I:g===l.length-1?L:A,fill:q(x)?x(i.type==="category"?_:i.type==="value"?y+"":y,g):x})});if(P.anid="label_"+y,ja({el:P,componentModel:e,itemName:m,formatterParamsExtra:{isTruncated:function(){return P.isTruncated},value:_,tickIndex:g}}),d){var R=pr.makeAxisEventDataBase(e);R.targetType="axisLabel",R.value=_,R.tickIndex=g,i.type==="category"&&(R.dataIndex=y),st(P).eventData=R}t.add(P),P.updateTransform(),c.push(P),r.add(P),P.decomposeTransform()}),c}}function NI(r,t){var e={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return FI(e,r,t),e.seriesInvolved&&VI(e,r),e}function FI(r,t,e){var n=t.getComponent("tooltip"),i=t.getComponent("axisPointer"),a=i.get("link",!0)||[],o=[];M(e.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=Xa(s.model),u=r.coordSysAxesInfo[l]={};r.coordSysMap[l]=s;var f=s.model,h=f.getModel("tooltip",n);if(M(s.getAxes(),vt(p,!1,null)),s.getTooltipAxes&&n&&h.get("show")){var c=h.get("trigger")==="axis",v=h.get(["axisPointer","type"])==="cross",d=s.getTooltipAxes(h.get(["axisPointer","axis"]));(c||v)&&M(d.baseAxes,vt(p,v?"cross":!0,c)),v&&M(d.otherAxes,vt(p,"cross",!1))}function p(g,y,m){var _=m.model.getModel("axisPointer",i),S=_.get("show");if(!(!S||S==="auto"&&!g&&!th(_))){y==null&&(y=_.get("triggerTooltip")),_=g?zI(m,h,i,t,g,y):_;var w=_.get("snap"),x=_.get("triggerEmphasis"),b=Xa(m.model),T=y||w||m.type==="category",C=r.axesInfo[b]={key:b,axis:m,coordSys:s,axisPointerModel:_,triggerTooltip:y,triggerEmphasis:x,involveSeries:T,snap:w,useHandle:th(_),seriesModels:[],linkGroup:null};u[b]=C,r.seriesInvolved=r.seriesInvolved||T;var D=GI(a,m);if(D!=null){var A=o[D]||(o[D]={axesInfo:{}});A.axesInfo[b]=C,A.mapper=a[D].mapper,C.linkGroup=A}}}})}function zI(r,t,e,n,i,a){var o=t.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};M(s,function(c){l[c]=tt(o.get(c))}),l.snap=r.type!=="category"&&!!a,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),i==="cross"){var f=o.get(["label","show"]);if(u.show=f??!0,!a){var h=l.lineStyle=o.get("crossStyle");h&&Q(u,h.textStyle)}}return r.model.getModel("axisPointer",new wt(l,e,n))}function VI(r,t){t.eachSeries(function(e){var n=e.coordinateSystem,i=e.get(["tooltip","trigger"],!0),a=e.get(["tooltip","show"],!0);!n||i==="none"||i===!1||i==="item"||a===!1||e.get(["axisPointer","show"],!0)===!1||M(r.coordSysAxesInfo[Xa(n.model)],function(o){var s=o.axis;n.getAxis(s.dim)===s&&(o.seriesModels.push(e),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=e.getData().count())})})}function GI(r,t){for(var e=t.model,n=t.dim,i=0;i<r.length;i++){var a=r[i]||{};if(Fu(a[n+"AxisId"],e.id)||Fu(a[n+"AxisIndex"],e.componentIndex)||Fu(a[n+"AxisName"],e.name))return i}}function Fu(r,t){return r==="all"||V(r)&&lt(r,t)>=0||r===t}function HI(r){var t=bv(r);if(t){var e=t.axisPointerModel,n=t.axis.scale,i=e.option,a=e.get("status"),o=e.get("value");o!=null&&(o=n.parse(o));var s=th(e);a==null&&(i.status=s?"show":"hide");var l=n.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),i.value=o,s&&(i.status=t.axis.scale.isBlank()?"hide":"show")}}function bv(r){var t=(r.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return t&&t.axesInfo[Xa(r)]}function WI(r){var t=bv(r);return t&&t.axisPointerModel}function th(r){return!!r.get(["handle","show"])}function Xa(r){return r.type+"||"+r.id}var Kp={},T1=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i,a){this.axisPointerClass&&HI(e),r.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(e,i,!0)},t.prototype.updateAxisPointer=function(e,n,i,a){this._doUpdateAxisPointerClass(e,i,!1)},t.prototype.remove=function(e,n){var i=this._axisPointer;i&&i.remove(n)},t.prototype.dispose=function(e,n){this._disposeAxisPointer(n),r.prototype.dispose.apply(this,arguments)},t.prototype._doUpdateAxisPointerClass=function(e,n,i){var a=t.getAxisPointerClass(this.axisPointerClass);if(a){var o=WI(e);o?(this._axisPointer||(this._axisPointer=new a)).render(e,o,n,i):this._disposeAxisPointer(n)}},t.prototype._disposeAxisPointer=function(e){this._axisPointer&&this._axisPointer.dispose(e),this._axisPointer=null},t.registerAxisPointerClass=function(e,n){Kp[e]=n},t.getAxisPointerClass=function(e){return e&&Kp[e]},t.type="axis",t}(Jt),eh=_t();function UI(r,t,e,n){var i=e.axis;if(!i.scale.isBlank()){var a=e.getModel("splitArea"),o=a.getModel("areaStyle"),s=o.get("color"),l=n.coordinateSystem.getRect(),u=i.getTicksCoords({tickModel:a,clamp:!0});if(u.length){var f=s.length,h=eh(r).splitAreaColors,c=$(),v=0;if(h)for(var d=0;d<u.length;d++){var p=h.get(u[d].tickValue);if(p!=null){v=(p+(f-1)*d)%f;break}}var g=i.toGlobalCoord(u[0].coord),y=o.getAreaStyle();s=V(s)?s:[s];for(var d=1;d<u.length;d++){var m=i.toGlobalCoord(u[d].coord),_=void 0,S=void 0,w=void 0,x=void 0;i.isHorizontal()?(_=g,S=l.y,w=m-_,x=l.height,g=_+w):(_=l.x,S=g,w=l.width,x=m-S,g=S+x);var b=u[d-1].tickValue;b!=null&&c.set(b,v),t.add(new St({anid:b!=null?"area_"+b:null,shape:{x:_,y:S,width:w,height:x},style:Q({fill:s[v]},y),autoBatch:!0,silent:!0})),v=(v+1)%f}eh(r).splitAreaColors=c}}}function YI(r){eh(r).splitAreaColors=null}var XI=["axisLine","axisTickLabel","axisName"],ZI=["splitArea","splitLine","minorSplitLine"],C1=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="CartesianAxisPointer",e}return t.prototype.render=function(e,n,i,a){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new yt,this.group.add(this._axisGroup),!!e.get("show")){var s=e.getCoordSysModel(),l=jf(s,e),u=new pr(e,F({handleAutoShown:function(h){for(var c=s.coordinateSystem.getCartesians(),v=0;v<c.length;v++)if(qf(c[v].getOtherAxis(e.axis).scale))return!0;return!1}},l));M(XI,u.add,u),this._axisGroup.add(u.getGroup()),M(ZI,function(h){e.get([h,"show"])&&$I[h](this,this._axisGroup,e,s)},this);var f=a&&a.type==="changeAxisOrder"&&a.isInitSort;f||zm(o,this._axisGroup,e),r.prototype.render.call(this,e,n,i,a)}},t.prototype.remove=function(){YI(this)},t.type="cartesianAxis",t}(T1),$I={splitLine:function(r,t,e,n){var i=e.axis;if(!i.scale.isBlank()){var a=e.getModel("splitLine"),o=a.getModel("lineStyle"),s=o.get("color"),l=a.get("showMinLine")!==!1,u=a.get("showMaxLine")!==!1;s=V(s)?s:[s];for(var f=n.coordinateSystem.getRect(),h=i.isHorizontal(),c=0,v=i.getTicksCoords({tickModel:a}),d=[],p=[],g=o.getLineStyle(),y=0;y<v.length;y++){var m=i.toGlobalCoord(v[y].coord);if(!(y===0&&!l||y===v.length-1&&!u)){var _=v[y].tickValue;h?(d[0]=m,d[1]=f.y,p[0]=m,p[1]=f.y+f.height):(d[0]=f.x,d[1]=m,p[0]=f.x+f.width,p[1]=m);var S=c++%s.length,w=new er({anid:_!=null?"line_"+_:null,autoBatch:!0,shape:{x1:d[0],y1:d[1],x2:p[0],y2:p[1]},style:Q({stroke:s[S]},g),silent:!0});Na(w.shape,g.lineWidth),t.add(w)}}}},minorSplitLine:function(r,t,e,n){var i=e.axis,a=e.getModel("minorSplitLine"),o=a.getModel("lineStyle"),s=n.coordinateSystem.getRect(),l=i.isHorizontal(),u=i.getMinorTicksCoords();if(u.length)for(var f=[],h=[],c=o.getLineStyle(),v=0;v<u.length;v++)for(var d=0;d<u[v].length;d++){var p=i.toGlobalCoord(u[v][d].coord);l?(f[0]=p,f[1]=s.y,h[0]=p,h[1]=s.y+s.height):(f[0]=s.x,f[1]=p,h[0]=s.x+s.width,h[1]=p);var g=new er({anid:"minor_line_"+u[v][d].tickValue,autoBatch:!0,shape:{x1:f[0],y1:f[1],x2:h[0],y2:h[1]},style:c,silent:!0});Na(g.shape,c.lineWidth),t.add(g)}},splitArea:function(r,t,e,n){UI(r,t,e,n)}},D1=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="xAxis",t}(C1),qI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=D1.type,e}return t.type="yAxis",t}(C1),KI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="grid",e}return t.prototype.render=function(e,n){this.group.removeAll(),e.get("show")&&this.group.add(new St({shape:e.coordinateSystem.getRect(),style:Q({fill:e.get("backgroundColor")},e.getItemStyle()),silent:!0,z2:-1}))},t.type="grid",t}(Jt),Qp={offset:0};function A1(r){r.registerComponentView(KI),r.registerComponentModel(wI),r.registerCoordinateSystem("cartesian2d",LI),Vp(r,"x",Qf,Qp),Vp(r,"y",Qf,Qp),r.registerComponentView(D1),r.registerComponentView(qI),r.registerPreprocessor(function(t){t.xAxis&&t.yAxis&&!t.grid&&(t.grid={})})}function QI(r){ke(A1),r.registerSeriesModel(yI),r.registerChartView(xI),r.registerLayout(Sv("scatter"))}function JI(r){r.eachSeriesByType("radar",function(t){var e=t.getData(),n=[],i=t.coordinateSystem;if(i){var a=i.getIndicatorAxes();M(a,function(o,s){e.each(e.mapDimension(a[s].dim),function(l,u){n[u]=n[u]||[];var f=i.dataToPoint(l,s);n[u][s]=Jp(f)?f:jp(i)})}),e.each(function(o){var s=jS(n[o],function(l){return Jp(l)})||jp(i);n[o].push(s.slice()),e.setItemLayout(o,n[o])})}})}function Jp(r){return!isNaN(r[0])&&!isNaN(r[1])}function jp(r){return[r.cx,r.cy]}function jI(r){var t=r.polar;if(t){V(t)||(t=[t]);var e=[];M(t,function(n,i){n.indicator?(n.type&&!n.shape&&(n.shape=n.type),r.radar=r.radar||[],V(r.radar)||(r.radar=[r.radar]),r.radar.push(n)):e.push(n)}),r.polar=e}M(r.series,function(n){n&&n.type==="radar"&&n.polarIndex&&(n.radarIndex=n.polarIndex)})}var tL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){var a=e.coordinateSystem,o=this.group,s=e.getData(),l=this._data;function u(c,v){var d=c.getItemVisual(v,"symbol")||"circle";if(d!=="none"){var p=X0(c.getItemVisual(v,"symbolSize")),g=Ee(d,-1,-1,2,2),y=c.getItemVisual(v,"symbolRotate")||0;return g.attr({style:{strokeNoScale:!0},z2:100,scaleX:p[0]/2,scaleY:p[1]/2,rotation:y*Math.PI/180||0}),g}}function f(c,v,d,p,g,y){d.removeAll();for(var m=0;m<v.length-1;m++){var _=u(p,g);_&&(_.__dimIdx=m,c[m]?(_.setPosition(c[m]),nl[y?"initProps":"updateProps"](_,{x:v[m][0],y:v[m][1]},e,g)):_.setPosition(v[m]),d.add(_))}}function h(c){return H(c,function(v){return[a.cx,a.cy]})}s.diff(l).add(function(c){var v=s.getItemLayout(c);if(v){var d=new Pn,p=new Xr,g={shape:{points:v}};d.shape.points=h(v),p.shape.points=h(v),Pt(d,g,e,c),Pt(p,g,e,c);var y=new yt,m=new yt;y.add(p),y.add(d),y.add(m),f(p.shape.points,v,m,s,c,!0),s.setItemGraphicEl(c,y)}}).update(function(c,v){var d=l.getItemGraphicEl(v),p=d.childAt(0),g=d.childAt(1),y=d.childAt(2),m={shape:{points:s.getItemLayout(c)}};m.shape.points&&(f(p.shape.points,m.shape.points,y,s,c,!1),Ba(g),Ba(p),bt(p,m,e),bt(g,m,e),s.setItemGraphicEl(c,d))}).remove(function(c){o.remove(l.getItemGraphicEl(c))}).execute(),s.eachItemGraphicEl(function(c,v){var d=s.getItemModel(v),p=c.childAt(0),g=c.childAt(1),y=c.childAt(2),m=s.getItemVisual(v,"style"),_=m.fill;o.add(c),p.useStyle(Q(d.getModel("lineStyle").getLineStyle(),{fill:"none",stroke:_})),Wr(p,d,"lineStyle"),Wr(g,d,"areaStyle");var S=d.getModel("areaStyle"),w=S.isEmpty()&&S.parentModel.isEmpty();g.ignore=w,M(["emphasis","select","blur"],function(T){var C=d.getModel([T,"areaStyle"]),D=C.isEmpty()&&C.parentModel.isEmpty();g.ensureState(T).ignore=D&&w}),g.useStyle(Q(S.getAreaStyle(),{fill:_,opacity:.7,decal:m.decal}));var x=d.getModel("emphasis"),b=x.getModel("itemStyle").getItemStyle();y.eachChild(function(T){if(T instanceof Ne){var C=T.style;T.useStyle(F({image:C.image,x:C.x,y:C.y,width:C.width,height:C.height},m))}else T.useStyle(m),T.setColor(_),T.style.strokeNoScale=!0;var D=T.ensureState("emphasis");D.style=tt(b);var A=s.getStore().get(s.getDimensionIndex(T.__dimIdx),v);(A==null||isNaN(A))&&(A=""),Rn(T,En(d),{labelFetcher:s.hostModel,labelDataIndex:v,labelDimIndex:T.__dimIdx,defaultText:A,inheritColor:_,defaultOpacity:m.opacity})}),mr(c,x.get("focus"),x.get("blurScope"),x.get("disabled"))}),this._data=s},t.prototype.remove=function(){this.group.removeAll(),this._data=null},t.type="radar",t}(Wt),eL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new m1(dt(this.getData,this),dt(this.getRawData,this))},t.prototype.getInitialData=function(e,n){return xv(this,{generateCoord:"indicator_",generateCoordCount:1/0})},t.prototype.formatTooltip=function(e,n,i){var a=this.getData(),o=this.coordinateSystem,s=o.getIndicatorAxes(),l=this.getData().getName(e),u=l===""?this.name:l,f=O0(this,e);return Mn("section",{header:u,sortBlocks:!0,blocks:H(s,function(h){var c=a.get(a.mapDimension(h.dim),e);return Mn("nameValue",{markerType:"subItem",markerColor:f,name:h.name,value:c,sortParam:c})})})},t.prototype.getTooltipPosition=function(e){if(e!=null){for(var n=this.getData(),i=this.coordinateSystem,a=n.getValues(H(i.dimensions,function(u){return n.mapDimension(u)}),e),o=0,s=a.length;o<s;o++)if(!isNaN(a[o])){var l=i.getIndicatorAxes();return i.coordToPoint(l[o].dataToCoord(a[o]),o)}}},t.type="series.radar",t.dependencies=["radar"],t.defaultOption={z:2,colorBy:"data",coordinateSystem:"radar",legendHoverLink:!0,radarIndex:0,lineStyle:{width:2,type:"solid",join:"round"},label:{position:"top"},symbolSize:8},t}(se),na=x1.value;function Ho(r,t){return Q({show:t},r)}var rL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){var e=this.get("boundaryGap"),n=this.get("splitNumber"),i=this.get("scale"),a=this.get("axisLine"),o=this.get("axisTick"),s=this.get("axisLabel"),l=this.get("axisName"),u=this.get(["axisName","show"]),f=this.get(["axisName","formatter"]),h=this.get("axisNameGap"),c=this.get("triggerEvent"),v=H(this.get("indicator")||[],function(d){d.max!=null&&d.max>0&&!d.min?d.min=0:d.min!=null&&d.min<0&&!d.max&&(d.max=0);var p=l;d.color!=null&&(p=Q({color:d.color},l));var g=nt(tt(d),{boundaryGap:e,splitNumber:n,scale:i,axisLine:a,axisTick:o,axisLabel:s,name:d.text,showName:u,nameLocation:"end",nameGap:h,nameTextStyle:p,triggerEvent:c},!1);if(W(f)){var y=g.name;g.name=f.replace("{value}",y??"")}else q(f)&&(g.name=f(g.name,g));var m=new wt(g,null,this.ecModel);return Oe(m,F_.prototype),m.mainType="radar",m.componentIndex=this.componentIndex,m},this);this._indicatorModels=v},t.prototype.getIndicatorModels=function(){return this._indicatorModels},t.type="radar",t.defaultOption={z:0,center:["50%","50%"],radius:"75%",startAngle:90,axisName:{show:!0},boundaryGap:[0,0],splitNumber:5,axisNameGap:15,scale:!1,shape:"polygon",axisLine:nt({lineStyle:{color:"#bbb"}},na.axisLine),axisLabel:Ho(na.axisLabel,!1),axisTick:Ho(na.axisTick,!1),splitLine:Ho(na.splitLine,!0),splitArea:Ho(na.splitArea,!0),indicator:[]},t}(ht),nL=["axisLine","axisTickLabel","axisName"],iL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){var a=this.group;a.removeAll(),this._buildAxes(e),this._buildSplitLineAndArea(e)},t.prototype._buildAxes=function(e){var n=e.coordinateSystem,i=n.getIndicatorAxes(),a=H(i,function(o){var s=o.model.get("showName")?o.name:"",l=new pr(o.model,{axisName:s,position:[n.cx,n.cy],rotation:o.angle,labelDirection:-1,tickDirection:-1,nameDirection:1});return l});M(a,function(o){M(nL,o.add,o),this.group.add(o.getGroup())},this)},t.prototype._buildSplitLineAndArea=function(e){var n=e.coordinateSystem,i=n.getIndicatorAxes();if(!i.length)return;var a=e.get("shape"),o=e.getModel("splitLine"),s=e.getModel("splitArea"),l=o.getModel("lineStyle"),u=s.getModel("areaStyle"),f=o.get("show"),h=s.get("show"),c=l.get("color"),v=u.get("color"),d=V(c)?c:[c],p=V(v)?v:[v],g=[],y=[];function m(R,E,O){var k=O%E.length;return R[k]=R[k]||[],k}if(a==="circle")for(var _=i[0].getTicksCoords(),S=n.cx,w=n.cy,x=0;x<_.length;x++){if(f){var b=m(g,d,x);g[b].push(new Ri({shape:{cx:S,cy:w,r:_[x].coord}}))}if(h&&x<_.length-1){var b=m(y,p,x);y[b].push(new Js({shape:{cx:S,cy:w,r0:_[x].coord,r:_[x+1].coord}}))}}else for(var T,C=H(i,function(R,E){var O=R.getTicksCoords();return T=T==null?O.length-1:Math.min(O.length-1,T),H(O,function(k){return n.coordToPoint(k.coord,E)})}),D=[],x=0;x<=T;x++){for(var A=[],I=0;I<i.length;I++)A.push(C[I][x]);if(A[0]&&A.push(A[0].slice()),f){var b=m(g,d,x);g[b].push(new Xr({shape:{points:A}}))}if(h&&D){var b=m(y,p,x-1);y[b].push(new Pn({shape:{points:A.concat(D)}}))}D=A.slice().reverse()}var L=l.getLineStyle(),P=u.getAreaStyle();M(y,function(R,E){this.group.add(Lf(R,{style:Q({stroke:"none",fill:p[E%p.length]},P),silent:!0}))},this),M(g,function(R,E){this.group.add(Lf(R,{style:Q({fill:"none",stroke:d[E%d.length]},L),silent:!0}))},this)},t.type="radar",t}(Jt),aL=function(r){N(t,r);function t(e,n,i){var a=r.call(this,e,n,i)||this;return a.type="value",a.angle=0,a.name="",a}return t}(X_),oL=function(){function r(t,e,n){this.dimensions=[],this._model=t,this._indicatorAxes=H(t.getIndicatorModels(),function(i,a){var o="indicator_"+a,s=new aL(o,new Yr);return s.name=i.get("name"),s.model=i,i.axis=s,this.dimensions.push(o),s},this),this.resize(t,n)}return r.prototype.getIndicatorAxes=function(){return this._indicatorAxes},r.prototype.dataToPoint=function(t,e){var n=this._indicatorAxes[e];return this.coordToPoint(n.dataToCoord(t),e)},r.prototype.coordToPoint=function(t,e){var n=this._indicatorAxes[e],i=n.angle,a=this.cx+t*Math.cos(i),o=this.cy-t*Math.sin(i);return[a,o]},r.prototype.pointToData=function(t){var e=t[0]-this.cx,n=t[1]-this.cy,i=Math.sqrt(e*e+n*n);e/=i,n/=i;for(var a=Math.atan2(-n,e),o=1/0,s,l=-1,u=0;u<this._indicatorAxes.length;u++){var f=this._indicatorAxes[u],h=Math.abs(a-f.angle);h<o&&(s=f,l=u,o=h)}return[l,+(s&&s.coordToData(i))]},r.prototype.resize=function(t,e){var n=t.get("center"),i=e.getWidth(),a=e.getHeight(),o=Math.min(i,a)/2;this.cx=Z(n[0],i),this.cy=Z(n[1],a),this.startAngle=t.get("startAngle")*Math.PI/180;var s=t.get("radius");(W(s)||ct(s))&&(s=[0,s]),this.r0=Z(s[0],o),this.r=Z(s[1],o),M(this._indicatorAxes,function(l,u){l.setExtent(this.r0,this.r);var f=this.startAngle+u*Math.PI*2/this._indicatorAxes.length;f=Math.atan2(Math.sin(f),Math.cos(f)),l.angle=f},this)},r.prototype.update=function(t,e){var n=this._indicatorAxes,i=this._model;M(n,function(s){s.scale.setExtent(1/0,-1/0)}),t.eachSeriesByType("radar",function(s,l){if(!(s.get("coordinateSystem")!=="radar"||t.getComponent("radar",s.get("radarIndex"))!==i)){var u=s.getData();M(n,function(f){f.scale.unionExtentFromData(u,u.mapDimension(f.dim))})}},this);var a=i.get("splitNumber"),o=new Yr;o.setExtent(0,a),o.setInterval(1),M(n,function(s,l){w1(s.scale,s.model,o)})},r.prototype.convertToPixel=function(t,e,n){return console.warn("Not implemented."),null},r.prototype.convertFromPixel=function(t,e,n){return console.warn("Not implemented."),null},r.prototype.containPoint=function(t){return console.warn("Not implemented."),!1},r.create=function(t,e){var n=[];return t.eachComponent("radar",function(i){var a=new r(i,t,e);n.push(a),i.coordinateSystem=a}),t.eachSeriesByType("radar",function(i){i.get("coordinateSystem")==="radar"&&(i.coordinateSystem=n[i.get("radarIndex")||0])}),n},r.dimensions=[],r}();function sL(r){r.registerCoordinateSystem("radar",oL),r.registerComponentModel(rL),r.registerComponentView(iL),r.registerVisual({seriesType:"radar",reset:function(t){var e=t.getData();e.each(function(n){e.setItemVisual(n,"legendIcon","roundRect")}),e.setVisual("legendIcon","roundRect")}})}function lL(r){ke(sL),r.registerChartView(tL),r.registerSeriesModel(eL),r.registerLayout(JI),r.registerProcessor(g1("radar")),r.registerPreprocessor(jI)}var tg="\0_ec_interaction_mutex";function uL(r,t,e){var n=M1(r);n[t]=e}function fL(r,t,e){var n=M1(r),i=n[t];i===e&&(n[t]=null)}function M1(r){return r[tg]||(r[tg]={})}nr({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},qt);var hL={axisPointer:1,tooltip:1,brush:1};function vL(r,t,e){var n=t.getComponentByElement(r.topTarget),i=n&&n.coordinateSystem;return n&&n!==e&&!hL.hasOwnProperty(n.mainType)&&i&&i.model!==e}var cL=function(){function r(){this.angle=0,this.width=10,this.r=10,this.x=0,this.y=0}return r}(),dL=function(r){N(t,r);function t(e){var n=r.call(this,e)||this;return n.type="pointer",n}return t.prototype.getDefaultShape=function(){return new cL},t.prototype.buildPath=function(e,n){var i=Math.cos,a=Math.sin,o=n.r,s=n.width,l=n.angle,u=n.x-i(l)*s*(s>=o/3?1:2),f=n.y-a(l)*s*(s>=o/3?1:2);l=n.angle-Math.PI/2,e.moveTo(u,f),e.lineTo(n.x+i(l)*s,n.y+a(l)*s),e.lineTo(n.x+i(n.angle)*o,n.y+a(n.angle)*o),e.lineTo(n.x-i(l)*s,n.y-a(l)*s),e.lineTo(u,f)},t}(it);function pL(r,t){var e=r.get("center"),n=t.getWidth(),i=t.getHeight(),a=Math.min(n,i),o=Z(e[0],t.getWidth()),s=Z(e[1],t.getHeight()),l=Z(r.get("radius"),a/2);return{cx:o,cy:s,r:l}}function Wo(r,t){var e=r==null?"":r+"";return t&&(W(t)?e=t.replace("{value}",e):q(t)&&(e=t(r))),e}var gL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){this.group.removeAll();var a=e.get(["axisLine","lineStyle","color"]),o=pL(e,i);this._renderMain(e,n,i,a,o),this._data=e.getData()},t.prototype.dispose=function(){},t.prototype._renderMain=function(e,n,i,a,o){var s=this.group,l=e.get("clockwise"),u=-e.get("startAngle")/180*Math.PI,f=-e.get("endAngle")/180*Math.PI,h=e.getModel("axisLine"),c=h.get("roundCap"),v=c?Es:Se,d=h.get("show"),p=h.getModel("lineStyle"),g=p.get("width"),y=[u,f];Eh(y,!l),u=y[0],f=y[1];for(var m=f-u,_=u,S=[],w=0;d&&w<a.length;w++){var x=Math.min(Math.max(a[w][0],0),1);f=u+m*x;var b=new v({shape:{startAngle:_,endAngle:f,cx:o.cx,cy:o.cy,clockwise:l,r0:o.r-g,r:o.r},silent:!0});b.setStyle({fill:a[w][1]}),b.setStyle(p.getLineStyle(["color","width"])),S.push(b),_=f}S.reverse(),M(S,function(C){return s.add(C)});var T=function(C){if(C<=0)return a[0][1];var D;for(D=0;D<a.length;D++)if(a[D][0]>=C&&(D===0?0:a[D-1][0])<C)return a[D][1];return a[D-1][1]};this._renderTicks(e,n,i,T,o,u,f,l,g),this._renderTitleAndDetail(e,n,i,T,o),this._renderAnchor(e,o),this._renderPointer(e,n,i,T,o,u,f,l,g)},t.prototype._renderTicks=function(e,n,i,a,o,s,l,u,f){for(var h=this.group,c=o.cx,v=o.cy,d=o.r,p=+e.get("min"),g=+e.get("max"),y=e.getModel("splitLine"),m=e.getModel("axisTick"),_=e.getModel("axisLabel"),S=e.get("splitNumber"),w=m.get("splitNumber"),x=Z(y.get("length"),d),b=Z(m.get("length"),d),T=s,C=(l-s)/S,D=C/w,A=y.getModel("lineStyle").getLineStyle(),I=m.getModel("lineStyle").getLineStyle(),L=y.get("distance"),P,R,E=0;E<=S;E++){if(P=Math.cos(T),R=Math.sin(T),y.get("show")){var O=L?L+f:f,k=new er({shape:{x1:P*(d-O)+c,y1:R*(d-O)+v,x2:P*(d-x-O)+c,y2:R*(d-x-O)+v},style:A,silent:!0});A.stroke==="auto"&&k.setStyle({stroke:a(E/S)}),h.add(k)}if(_.get("show")){var O=_.get("distance")+L,B=Wo(Mt(E/S*(g-p)+p),_.get("formatter")),z=a(E/S),G=P*(d-x-O)+c,U=R*(d-x-O)+v,j=_.get("rotate"),et=0;j==="radial"?(et=-T+2*Math.PI,et>Math.PI/2&&(et+=Math.PI)):j==="tangential"?et=-T-Math.PI/2:ct(j)&&(et=j*Math.PI/180),et===0?h.add(new Ct({style:ye(_,{text:B,x:G,y:U,verticalAlign:R<-.8?"top":R>.8?"bottom":"middle",align:P<-.4?"left":P>.4?"right":"center"},{inheritColor:z}),silent:!0})):h.add(new Ct({style:ye(_,{text:B,x:G,y:U,verticalAlign:"middle",align:"center"},{inheritColor:z}),silent:!0,originX:G,originY:U,rotation:et}))}if(m.get("show")&&E!==S){var O=m.get("distance");O=O?O+f:f;for(var at=0;at<=w;at++){P=Math.cos(T),R=Math.sin(T);var Rt=new er({shape:{x1:P*(d-O)+c,y1:R*(d-O)+v,x2:P*(d-b-O)+c,y2:R*(d-b-O)+v},silent:!0,style:I});I.stroke==="auto"&&Rt.setStyle({stroke:a((E+at/w)/S)}),h.add(Rt),T+=D}T-=D}else T+=C}},t.prototype._renderPointer=function(e,n,i,a,o,s,l,u,f){var h=this.group,c=this._data,v=this._progressEls,d=[],p=e.get(["pointer","show"]),g=e.getModel("progress"),y=g.get("show"),m=e.getData(),_=m.mapDimension("value"),S=+e.get("min"),w=+e.get("max"),x=[S,w],b=[s,l];function T(D,A){var I=m.getItemModel(D),L=I.getModel("pointer"),P=Z(L.get("width"),o.r),R=Z(L.get("length"),o.r),E=e.get(["pointer","icon"]),O=L.get("offsetCenter"),k=Z(O[0],o.r),B=Z(O[1],o.r),z=L.get("keepAspect"),G;return E?G=Ee(E,k-P/2,B-R,P,R,null,z):G=new dL({shape:{angle:-Math.PI/2,width:P,r:R,x:k,y:B}}),G.rotation=-(A+Math.PI/2),G.x=o.cx,G.y=o.cy,G}function C(D,A){var I=g.get("roundCap"),L=I?Es:Se,P=g.get("overlap"),R=P?g.get("width"):f/m.count(),E=P?o.r-R:o.r-(D+1)*R,O=P?o.r:o.r-D*R,k=new L({shape:{startAngle:s,endAngle:A,cx:o.cx,cy:o.cy,clockwise:u,r0:E,r:O}});return P&&(k.z2=Zt(m.get(_,D),[S,w],[100,0],!0)),k}(y||p)&&(m.diff(c).add(function(D){var A=m.get(_,D);if(p){var I=T(D,s);Pt(I,{rotation:-((isNaN(+A)?b[0]:Zt(A,x,b,!0))+Math.PI/2)},e),h.add(I),m.setItemGraphicEl(D,I)}if(y){var L=C(D,s),P=g.get("clip");Pt(L,{shape:{endAngle:Zt(A,x,b,P)}},e),h.add(L),wf(e.seriesIndex,m.dataType,D,L),d[D]=L}}).update(function(D,A){var I=m.get(_,D);if(p){var L=c.getItemGraphicEl(A),P=L?L.rotation:s,R=T(D,P);R.rotation=P,bt(R,{rotation:-((isNaN(+I)?b[0]:Zt(I,x,b,!0))+Math.PI/2)},e),h.add(R),m.setItemGraphicEl(D,R)}if(y){var E=v[A],O=E?E.shape.endAngle:s,k=C(D,O),B=g.get("clip");bt(k,{shape:{endAngle:Zt(I,x,b,B)}},e),h.add(k),wf(e.seriesIndex,m.dataType,D,k),d[D]=k}}).execute(),m.each(function(D){var A=m.getItemModel(D),I=A.getModel("emphasis"),L=I.get("focus"),P=I.get("blurScope"),R=I.get("disabled");if(p){var E=m.getItemGraphicEl(D),O=m.getItemVisual(D,"style"),k=O.fill;if(E instanceof Ne){var B=E.style;E.useStyle(F({image:B.image,x:B.x,y:B.y,width:B.width,height:B.height},O))}else E.useStyle(O),E.type!=="pointer"&&E.setColor(k);E.setStyle(A.getModel(["pointer","itemStyle"]).getItemStyle()),E.style.fill==="auto"&&E.setStyle("fill",a(Zt(m.get(_,D),x,[0,1],!0))),E.z2EmphasisLift=0,Wr(E,A),mr(E,L,P,R)}if(y){var z=d[D];z.useStyle(m.getItemVisual(D,"style")),z.setStyle(A.getModel(["progress","itemStyle"]).getItemStyle()),z.z2EmphasisLift=0,Wr(z,A),mr(z,L,P,R)}}),this._progressEls=d)},t.prototype._renderAnchor=function(e,n){var i=e.getModel("anchor"),a=i.get("show");if(a){var o=i.get("size"),s=i.get("icon"),l=i.get("offsetCenter"),u=i.get("keepAspect"),f=Ee(s,n.cx-o/2+Z(l[0],n.r),n.cy-o/2+Z(l[1],n.r),o,o,null,u);f.z2=i.get("showAbove")?1:0,f.setStyle(i.getModel("itemStyle").getItemStyle()),this.group.add(f)}},t.prototype._renderTitleAndDetail=function(e,n,i,a,o){var s=this,l=e.getData(),u=l.mapDimension("value"),f=+e.get("min"),h=+e.get("max"),c=new yt,v=[],d=[],p=e.isAnimationEnabled(),g=e.get(["pointer","showAbove"]);l.diff(this._data).add(function(y){v[y]=new Ct({silent:!0}),d[y]=new Ct({silent:!0})}).update(function(y,m){v[y]=s._titleEls[m],d[y]=s._detailEls[m]}).execute(),l.each(function(y){var m=l.getItemModel(y),_=l.get(u,y),S=new yt,w=a(Zt(_,[f,h],[0,1],!0)),x=m.getModel("title");if(x.get("show")){var b=x.get("offsetCenter"),T=o.cx+Z(b[0],o.r),C=o.cy+Z(b[1],o.r),D=v[y];D.attr({z2:g?0:2,style:ye(x,{x:T,y:C,text:l.getName(y),align:"center",verticalAlign:"middle"},{inheritColor:w})}),S.add(D)}var A=m.getModel("detail");if(A.get("show")){var I=A.get("offsetCenter"),L=o.cx+Z(I[0],o.r),P=o.cy+Z(I[1],o.r),R=Z(A.get("width"),o.r),E=Z(A.get("height"),o.r),O=e.get(["progress","show"])?l.getItemVisual(y,"style").fill:w,D=d[y],k=A.get("formatter");D.attr({z2:g?0:2,style:ye(A,{x:L,y:P,text:Wo(_,k),width:isNaN(R)?null:R,height:isNaN(E)?null:E,align:"center",verticalAlign:"middle"},{inheritColor:O})}),Um(D,{normal:A},_,function(z){return Wo(z,k)}),p&&Ym(D,y,l,e,{getFormattedLabel:function(z,G,U,j,et,at){return Wo(at?at.interpolatedValue:_,k)}}),S.add(D)}c.add(S)}),this.group.add(c),this._titleEls=v,this._detailEls=d},t.type="gauge",t}(Wt),yL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.visualStyleAccessPath="itemStyle",e}return t.prototype.getInitialData=function(e,n){return xv(this,["value"])},t.type="series.gauge",t.defaultOption={z:2,colorBy:"data",center:["50%","50%"],legendHoverLink:!0,radius:"75%",startAngle:225,endAngle:-45,clockwise:!0,min:0,max:100,splitNumber:10,axisLine:{show:!0,roundCap:!1,lineStyle:{color:[[1,"#E6EBF8"]],width:10}},progress:{show:!1,overlap:!0,width:10,roundCap:!1,clip:!0},splitLine:{show:!0,length:10,distance:10,lineStyle:{color:"#63677A",width:3,type:"solid"}},axisTick:{show:!0,splitNumber:5,length:6,distance:10,lineStyle:{color:"#63677A",width:1,type:"solid"}},axisLabel:{show:!0,distance:15,color:"#464646",fontSize:12,rotate:0},pointer:{icon:null,offsetCenter:[0,0],show:!0,showAbove:!0,length:"60%",width:6,keepAspect:!1},anchor:{show:!1,showAbove:!1,size:6,icon:"circle",offsetCenter:[0,0],keepAspect:!1,itemStyle:{color:"#fff",borderWidth:0,borderColor:"#5470c6"}},title:{show:!0,offsetCenter:[0,"20%"],color:"#464646",fontSize:16,valueAnimation:!1},detail:{show:!0,backgroundColor:"rgba(0,0,0,0)",borderWidth:0,borderColor:"#ccc",width:100,height:null,padding:[5,10],offsetCenter:[0,"40%"],color:"#464646",fontSize:30,fontWeight:"bold",lineHeight:30,valueAnimation:!1}},t}(se);function mL(r){r.registerChartView(gL),r.registerSeriesModel(yL)}function I1(r,t,e,n,i,a){r=r||0;var o=e[1]-e[0];if(i!=null&&(i=Kn(i,[0,o])),a!=null&&(a=Math.max(a,i??0)),n==="all"){var s=Math.abs(t[1]-t[0]);s=Kn(s,[0,o]),i=a=Kn(s,[i,a]),n=0}t[0]=Kn(t[0],e),t[1]=Kn(t[1],e);var l=zu(t,n);t[n]+=r;var u=i||0,f=e.slice();l.sign<0?f[0]+=u:f[1]-=u,t[n]=Kn(t[n],f);var h;return h=zu(t,n),i!=null&&(h.sign!==l.sign||h.span<i)&&(t[1-n]=t[n]+l.sign*i),h=zu(t,n),a!=null&&h.span>a&&(t[1-n]=t[n]+h.sign*a),t}function zu(r,t){var e=r[t]-r[1-t];return{span:Math.abs(e),sign:e>0?-1:e<0?1:t?-1:1}}function Kn(r,t){return Math.min(t[1]!=null?t[1]:1/0,Math.max(t[0]!=null?t[0]:-1/0,r))}var In=!0,Za=Math.min,Di=Math.max,_L=Math.pow,SL=1e4,xL=6,wL=6,eg="globalPan",bL={w:[0,0],e:[0,1],n:[1,0],s:[1,1]},TL={w:"ew",e:"ew",n:"ns",s:"ns",ne:"nesw",sw:"nesw",nw:"nwse",se:"nwse"},rg={brushStyle:{lineWidth:2,stroke:"rgba(210,219,238,0.3)",fill:"#D2DBEE"},transformable:!0,brushMode:"single",removeOnClick:!1},CL=0,DL=function(r){N(t,r);function t(e){var n=r.call(this)||this;return n._track=[],n._covers=[],n._handlers={},n._zr=e,n.group=new yt,n._uid="brushController_"+CL++,M(EL,function(i,a){this._handlers[a]=dt(i,this)},n),n}return t.prototype.enableBrush=function(e){return this._brushType&&this._doDisableBrush(),e.brushType&&this._doEnableBrush(e),this},t.prototype._doEnableBrush=function(e){var n=this._zr;this._enableGlobalPan||uL(n,eg,this._uid),M(this._handlers,function(i,a){n.on(a,i)}),this._brushType=e.brushType,this._brushOption=nt(tt(rg),e,!0)},t.prototype._doDisableBrush=function(){var e=this._zr;fL(e,eg,this._uid),M(this._handlers,function(n,i){e.off(i,n)}),this._brushType=this._brushOption=null},t.prototype.setPanels=function(e){if(e&&e.length){var n=this._panels={};M(e,function(i){n[i.panelId]=tt(i)})}else this._panels=null;return this},t.prototype.mount=function(e){e=e||{},this._enableGlobalPan=e.enableGlobalPan;var n=this.group;return this._zr.add(n),n.attr({x:e.x||0,y:e.y||0,rotation:e.rotation||0,scaleX:e.scaleX||1,scaleY:e.scaleY||1}),this._transform=n.getLocalTransform(),this},t.prototype.updateCovers=function(e){e=H(e,function(c){return nt(tt(rg),c,!0)});var n="\0-brush-index-",i=this._covers,a=this._covers=[],o=this,s=this._creatingCover;return new Wa(i,e,u,l).add(f).update(f).remove(h).execute(),this;function l(c,v){return(c.id!=null?c.id:n+v)+"-"+c.brushType}function u(c,v){return l(c.__brushOption,v)}function f(c,v){var d=e[c];if(v!=null&&i[v]===s)a[c]=i[v];else{var p=a[c]=v!=null?(i[v].__brushOption=d,i[v]):P1(o,L1(o,d));Tv(o,p)}}function h(c){i[c]!==s&&o.group.remove(i[c])}},t.prototype.unmount=function(){return this.enableBrush(!1),rh(this),this._zr.remove(this.group),this},t.prototype.dispose=function(){this.unmount(),this.off()},t}(Be);function L1(r,t){var e=Sl[t.brushType].createCover(r,t);return e.__brushOption=t,E1(e,t),r.group.add(e),e}function P1(r,t){var e=Cv(t);return e.endCreating&&(e.endCreating(r,t),E1(t,t.__brushOption)),t}function R1(r,t){var e=t.__brushOption;Cv(t).updateCoverShape(r,t,e.range,e)}function E1(r,t){var e=t.z;e==null&&(e=SL),r.traverse(function(n){n.z=e,n.z2=e})}function Tv(r,t){Cv(t).updateCommon(r,t),R1(r,t)}function Cv(r){return Sl[r.__brushOption.brushType]}function Dv(r,t,e){var n=r._panels;if(!n)return In;var i,a=r._transform;return M(n,function(o){o.isTargetByCursor(t,e,a)&&(i=o)}),i}function k1(r,t){var e=r._panels;if(!e)return In;var n=t.__brushOption.panelId;return n!=null?e[n]:In}function rh(r){var t=r._covers,e=t.length;return M(t,function(n){r.group.remove(n)},r),t.length=0,!!e}function Ln(r,t){var e=H(r._covers,function(n){var i=n.__brushOption,a=tt(i.range);return{brushType:i.brushType,panelId:i.panelId,range:a}});r.trigger("brush",{areas:e,isEnd:!!t.isEnd,removeOnClick:!!t.removeOnClick})}function AL(r){var t=r._track;if(!t.length)return!1;var e=t[t.length-1],n=t[0],i=e[0]-n[0],a=e[1]-n[1],o=_L(i*i+a*a,.5);return o>xL}function O1(r){var t=r.length-1;return t<0&&(t=0),[r[0],r[t]]}function B1(r,t,e,n){var i=new yt;return i.add(new St({name:"main",style:Av(e),silent:!0,draggable:!0,cursor:"move",drift:vt(ng,r,t,i,["n","s","w","e"]),ondragend:vt(Ln,t,{isEnd:!0})})),M(n,function(a){i.add(new St({name:a.join(""),style:{opacity:0},draggable:!0,silent:!0,invisible:!0,drift:vt(ng,r,t,i,a),ondragend:vt(Ln,t,{isEnd:!0})}))}),i}function N1(r,t,e,n){var i=n.brushStyle.lineWidth||0,a=Di(i,wL),o=e[0][0],s=e[1][0],l=o-i/2,u=s-i/2,f=e[0][1],h=e[1][1],c=f-a+i/2,v=h-a+i/2,d=f-o,p=h-s,g=d+i,y=p+i;lr(r,t,"main",o,s,d,p),n.transformable&&(lr(r,t,"w",l,u,a,y),lr(r,t,"e",c,u,a,y),lr(r,t,"n",l,u,g,a),lr(r,t,"s",l,v,g,a),lr(r,t,"nw",l,u,a,a),lr(r,t,"ne",c,u,a,a),lr(r,t,"sw",l,v,a,a),lr(r,t,"se",c,v,a,a))}function nh(r,t){var e=t.__brushOption,n=e.transformable,i=t.childAt(0);i.useStyle(Av(e)),i.attr({silent:!n,cursor:n?"move":"default"}),M([["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]],function(a){var o=t.childOfName(a.join("")),s=a.length===1?ih(r,a[0]):IL(r,a);o&&o.attr({silent:!n,invisible:!n,cursor:n?TL[s]+"-resize":null})})}function lr(r,t,e,n,i,a,o){var s=t.childOfName(e);s&&s.setShape(PL(Mv(r,t,[[n,i],[n+a,i+o]])))}function Av(r){return Q({strokeNoScale:!0},r.brushStyle)}function F1(r,t,e,n){var i=[Za(r,e),Za(t,n)],a=[Di(r,e),Di(t,n)];return[[i[0],a[0]],[i[1],a[1]]]}function ML(r){return Wh(r.group)}function ih(r,t){var e={w:"left",e:"right",n:"top",s:"bottom"},n={left:"w",right:"e",top:"n",bottom:"s"},i=Fm(e[t],ML(r));return n[i]}function IL(r,t){var e=[ih(r,t[0]),ih(r,t[1])];return(e[0]==="e"||e[0]==="w")&&e.reverse(),e.join("")}function ng(r,t,e,n,i,a){var o=e.__brushOption,s=r.toRectRange(o.range),l=z1(t,i,a);M(n,function(u){var f=bL[u];s[f[0]][f[1]]+=l[f[0]]}),o.range=r.fromRectRange(F1(s[0][0],s[1][0],s[0][1],s[1][1])),Tv(t,e),Ln(t,{isEnd:!1})}function LL(r,t,e,n){var i=t.__brushOption.range,a=z1(r,e,n);M(i,function(o){o[0]+=a[0],o[1]+=a[1]}),Tv(r,t),Ln(r,{isEnd:!1})}function z1(r,t,e){var n=r.group,i=n.transformCoordToLocal(t,e),a=n.transformCoordToLocal(0,0);return[i[0]-a[0],i[1]-a[1]]}function Mv(r,t,e){var n=k1(r,t);return n&&n!==In?n.clipPath(e,r._transform):tt(e)}function PL(r){var t=Za(r[0][0],r[1][0]),e=Za(r[0][1],r[1][1]),n=Di(r[0][0],r[1][0]),i=Di(r[0][1],r[1][1]);return{x:t,y:e,width:n-t,height:i-e}}function RL(r,t,e){if(!(!r._brushType||kL(r,t.offsetX,t.offsetY))){var n=r._zr,i=r._covers,a=Dv(r,t,e);if(!r._dragging)for(var o=0;o<i.length;o++){var s=i[o].__brushOption;if(a&&(a===In||s.panelId===a.panelId)&&Sl[s.brushType].contain(i[o],e[0],e[1]))return}a&&n.setCursorStyle("crosshair")}}function ah(r){var t=r.event;t.preventDefault&&t.preventDefault()}function oh(r,t,e){return r.childOfName("main").contain(t,e)}function V1(r,t,e,n){var i=r._creatingCover,a=r._creatingPanel,o=r._brushOption,s;if(r._track.push(e.slice()),AL(r)||i){if(a&&!i){o.brushMode==="single"&&rh(r);var l=tt(o);l.brushType=ig(l.brushType,a),l.panelId=a===In?null:a.panelId,i=r._creatingCover=L1(r,l),r._covers.push(i)}if(i){var u=Sl[ig(r._brushType,a)],f=i.__brushOption;f.range=u.getCreatingRange(Mv(r,i,r._track)),n&&(P1(r,i),u.updateCommon(r,i)),R1(r,i),s={isEnd:n}}}else n&&o.brushMode==="single"&&o.removeOnClick&&Dv(r,t,e)&&rh(r)&&(s={isEnd:n,removeOnClick:!0});return s}function ig(r,t){return r==="auto"?t.defaultBrushType:r}var EL={mousedown:function(r){if(this._dragging)ag(this,r);else if(!r.target||!r.target.draggable){ah(r);var t=this.group.transformCoordToLocal(r.offsetX,r.offsetY);this._creatingCover=null;var e=this._creatingPanel=Dv(this,r,t);e&&(this._dragging=!0,this._track=[t.slice()])}},mousemove:function(r){var t=r.offsetX,e=r.offsetY,n=this.group.transformCoordToLocal(t,e);if(RL(this,r,n),this._dragging){ah(r);var i=V1(this,r,n,!1);i&&Ln(this,i)}},mouseup:function(r){ag(this,r)}};function ag(r,t){if(r._dragging){ah(t);var e=t.offsetX,n=t.offsetY,i=r.group.transformCoordToLocal(e,n),a=V1(r,t,i,!0);r._dragging=!1,r._track=[],r._creatingCover=null,a&&Ln(r,a)}}function kL(r,t,e){var n=r._zr;return t<0||t>n.getWidth()||e<0||e>n.getHeight()}var Sl={lineX:og(0),lineY:og(1),rect:{createCover:function(r,t){function e(n){return n}return B1({toRectRange:e,fromRectRange:e},r,t,[["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]])},getCreatingRange:function(r){var t=O1(r);return F1(t[1][0],t[1][1],t[0][0],t[0][1])},updateCoverShape:function(r,t,e,n){N1(r,t,e,n)},updateCommon:nh,contain:oh},polygon:{createCover:function(r,t){var e=new yt;return e.add(new Xr({name:"main",style:Av(t),silent:!0})),e},getCreatingRange:function(r){return r},endCreating:function(r,t){t.remove(t.childAt(0)),t.add(new Pn({name:"main",draggable:!0,drift:vt(LL,r,t),ondragend:vt(Ln,r,{isEnd:!0})}))},updateCoverShape:function(r,t,e,n){t.childAt(0).setShape({points:Mv(r,t,e)})},updateCommon:nh,contain:oh}};function og(r){return{createCover:function(t,e){return B1({toRectRange:function(n){var i=[n,[0,100]];return r&&i.reverse(),i},fromRectRange:function(n){return n[r]}},t,e,[[["w"],["e"]],[["n"],["s"]]][r])},getCreatingRange:function(t){var e=O1(t),n=Za(e[0][r],e[1][r]),i=Di(e[0][r],e[1][r]);return[n,i]},updateCoverShape:function(t,e,n,i){var a,o=k1(t,e);if(o!==In&&o.getLinearBrushOtherExtent)a=o.getLinearBrushOtherExtent(r);else{var s=t._zr;a=[0,[s.getWidth(),s.getHeight()][1-r]]}var l=[n,a];r&&l.reverse(),N1(t,e,l,i)},updateCommon:nh,contain:oh}}function OL(r){return r=Iv(r),function(t){return Vm(t,r)}}function BL(r,t){return r=Iv(r),function(e){var n=t??e,i=n?r.width:r.height,a=n?r.x:r.y;return[a,a+(i||0)]}}function NL(r,t,e){var n=Iv(r);return function(i,a){return n.contain(a[0],a[1])&&!vL(i,t,e)}}function Iv(r){return ut.create(r)}var FL=["itemStyle","borderWidth"],sg=[{xy:"x",wh:"width",index:0,posDesc:["left","right"]},{xy:"y",wh:"height",index:1,posDesc:["top","bottom"]}],Vu=new Ri,zL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){var a=this.group,o=e.getData(),s=this._data,l=e.coordinateSystem,u=l.getBaseAxis(),f=u.isHorizontal(),h=l.master.getRect(),c={ecSize:{width:i.getWidth(),height:i.getHeight()},seriesModel:e,coordSys:l,coordSysExtent:[[h.x,h.x+h.width],[h.y,h.y+h.height]],isHorizontal:f,valueDim:sg[+f],categoryDim:sg[1-+f]};o.diff(s).add(function(d){if(o.hasValue(d)){var p=ug(o,d),g=lg(o,d,p,c),y=fg(o,c,g);o.setItemGraphicEl(d,y),a.add(y),vg(y,c,g)}}).update(function(d,p){var g=s.getItemGraphicEl(p);if(!o.hasValue(d)){a.remove(g);return}var y=ug(o,d),m=lg(o,d,y,c),_=X1(o,m);g&&_!==g.__pictorialShapeStr&&(a.remove(g),o.setItemGraphicEl(d,null),g=null),g?XL(g,c,m):g=fg(o,c,m,!0),o.setItemGraphicEl(d,g),g.__pictorialSymbolMeta=m,a.add(g),vg(g,c,m)}).remove(function(d){var p=s.getItemGraphicEl(d);p&&hg(s,d,p.__pictorialSymbolMeta.animationModel,p)}).execute();var v=e.get("clip",!0)?l1(e.coordinateSystem,!1,e):null;return v?a.setClipPath(v):a.removeClipPath(),this._data=o,this.group},t.prototype.remove=function(e,n){var i=this.group,a=this._data;e.get("animation")?a&&a.eachItemGraphicEl(function(o){hg(a,st(o).dataIndex,e,o)}):i.removeAll()},t.type="pictorialBar",t}(Wt);function lg(r,t,e,n){var i=r.getItemLayout(t),a=e.get("symbolRepeat"),o=e.get("symbolClip"),s=e.get("symbolPosition")||"start",l=e.get("symbolRotate"),u=(l||0)*Math.PI/180||0,f=e.get("symbolPatternSize")||2,h=e.isAnimationEnabled(),c={dataIndex:t,layout:i,itemModel:e,symbolType:r.getItemVisual(t,"symbol")||"circle",style:r.getItemVisual(t,"style"),symbolClip:o,symbolRepeat:a,symbolRepeatDirection:e.get("symbolRepeatDirection"),symbolPatternSize:f,rotation:u,animationModel:h?e:null,hoverScale:h&&e.get(["emphasis","scale"]),z2:e.getShallow("z",!0)||0};VL(e,a,i,n,c),GL(r,t,i,a,o,c.boundingLength,c.pxSign,f,n,c),HL(e,c.symbolScale,u,n,c);var v=c.symbolSize,d=sv(e.get("symbolOffset"),v);return WL(e,v,i,a,o,d,s,c.valueLineWidth,c.boundingLength,c.repeatCutLength,n,c),c}function VL(r,t,e,n,i){var a=n.valueDim,o=r.get("symbolBoundingData"),s=n.coordSys.getOtherAxis(n.coordSys.getBaseAxis()),l=s.toGlobalCoord(s.dataToCoord(0)),u=1-+(e[a.wh]<=0),f;if(V(o)){var h=[Gu(s,o[0])-l,Gu(s,o[1])-l];h[1]<h[0]&&h.reverse(),f=h[u]}else o!=null?f=Gu(s,o)-l:t?f=n.coordSysExtent[a.index][u]-l:f=e[a.wh];i.boundingLength=f,t&&(i.repeatCutLength=e[a.wh]);var c=a.xy==="x",v=s.inverse;i.pxSign=c&&!v||!c&&v?f>=0?1:-1:f>0?1:-1}function Gu(r,t){return r.toGlobalCoord(r.dataToCoord(r.scale.parse(t)))}function GL(r,t,e,n,i,a,o,s,l,u){var f=l.valueDim,h=l.categoryDim,c=Math.abs(e[h.wh]),v=r.getItemVisual(t,"symbolSize"),d;V(v)?d=v.slice():v==null?d=["100%","100%"]:d=[v,v],d[h.index]=Z(d[h.index],c),d[f.index]=Z(d[f.index],n?c:Math.abs(a)),u.symbolSize=d;var p=u.symbolScale=[d[0]/s,d[1]/s];p[f.index]*=(l.isHorizontal?-1:1)*o}function HL(r,t,e,n,i){var a=r.get(FL)||0;a&&(Vu.attr({scaleX:t[0],scaleY:t[1],rotation:e}),Vu.updateTransform(),a/=Vu.getLineScale(),a*=t[n.valueDim.index]),i.valueLineWidth=a||0}function WL(r,t,e,n,i,a,o,s,l,u,f,h){var c=f.categoryDim,v=f.valueDim,d=h.pxSign,p=Math.max(t[v.index]+s,0),g=p;if(n){var y=Math.abs(l),m=Si(r.get("symbolMargin"),"15%")+"",_=!1;m.lastIndexOf("!")===m.length-1&&(_=!0,m=m.slice(0,m.length-1));var S=Z(m,t[v.index]),w=Math.max(p+S*2,0),x=_?0:S*2,b=Qy(n),T=b?n:cg((y+x)/w),C=y-T*p;S=C/2/(_?T:Math.max(T-1,1)),w=p+S*2,x=_?0:S*2,!b&&n!=="fixed"&&(T=u?cg((Math.abs(u)+x)/w):0),g=T*w-x,h.repeatTimes=T,h.symbolMargin=S}var D=d*(g/2),A=h.pathPosition=[];A[c.index]=e[c.wh]/2,A[v.index]=o==="start"?D:o==="end"?l-D:l/2,a&&(A[0]+=a[0],A[1]+=a[1]);var I=h.bundlePosition=[];I[c.index]=e[c.xy],I[v.index]=e[v.xy];var L=h.barRectShape=F({},e);L[v.wh]=d*Math.max(Math.abs(e[v.wh]),Math.abs(A[v.index]+D)),L[c.wh]=e[c.wh];var P=h.clipShape={};P[c.xy]=-e[c.xy],P[c.wh]=f.ecSize[c.wh],P[v.xy]=0,P[v.wh]=e[v.wh]}function G1(r){var t=r.symbolPatternSize,e=Ee(r.symbolType,-t/2,-t/2,t,t);return e.attr({culling:!0}),e.type!=="image"&&e.setStyle({strokeNoScale:!0}),e}function H1(r,t,e,n){var i=r.__pictorialBundle,a=e.symbolSize,o=e.valueLineWidth,s=e.pathPosition,l=t.valueDim,u=e.repeatTimes||0,f=0,h=a[t.valueDim.index]+o+e.symbolMargin*2;for(Lv(r,function(p){p.__pictorialAnimationIndex=f,p.__pictorialRepeatTimes=u,f<u?mi(p,null,d(f),e,n):mi(p,null,{scaleX:0,scaleY:0},e,n,function(){i.remove(p)}),f++});f<u;f++){var c=G1(e);c.__pictorialAnimationIndex=f,c.__pictorialRepeatTimes=u,i.add(c);var v=d(f);mi(c,{x:v.x,y:v.y,scaleX:0,scaleY:0},{scaleX:v.scaleX,scaleY:v.scaleY,rotation:v.rotation},e,n)}function d(p){var g=s.slice(),y=e.pxSign,m=p;return(e.symbolRepeatDirection==="start"?y>0:y<0)&&(m=u-1-p),g[l.index]=h*(m-u/2+.5)+s[l.index],{x:g[0],y:g[1],scaleX:e.symbolScale[0],scaleY:e.symbolScale[1],rotation:e.rotation}}}function W1(r,t,e,n){var i=r.__pictorialBundle,a=r.__pictorialMainPath;a?mi(a,null,{x:e.pathPosition[0],y:e.pathPosition[1],scaleX:e.symbolScale[0],scaleY:e.symbolScale[1],rotation:e.rotation},e,n):(a=r.__pictorialMainPath=G1(e),i.add(a),mi(a,{x:e.pathPosition[0],y:e.pathPosition[1],scaleX:0,scaleY:0,rotation:e.rotation},{scaleX:e.symbolScale[0],scaleY:e.symbolScale[1]},e,n))}function U1(r,t,e){var n=F({},t.barRectShape),i=r.__pictorialBarRect;i?mi(i,null,{shape:n},t,e):(i=r.__pictorialBarRect=new St({z2:2,shape:n,silent:!0,style:{stroke:"transparent",fill:"transparent",lineWidth:0}}),i.disableMorphing=!0,r.add(i))}function Y1(r,t,e,n){if(e.symbolClip){var i=r.__pictorialClipPath,a=F({},e.clipShape),o=t.valueDim,s=e.animationModel,l=e.dataIndex;if(i)bt(i,{shape:a},s,l);else{a[o.wh]=0,i=new St({shape:a}),r.__pictorialBundle.setClipPath(i),r.__pictorialClipPath=i;var u={};u[o.wh]=e.clipShape[o.wh],nl[n?"updateProps":"initProps"](i,{shape:u},s,l)}}}function ug(r,t){var e=r.getItemModel(t);return e.getAnimationDelayParams=UL,e.isAnimationEnabled=YL,e}function UL(r){return{index:r.__pictorialAnimationIndex,count:r.__pictorialRepeatTimes}}function YL(){return this.parentModel.isAnimationEnabled()&&!!this.getShallow("animation")}function fg(r,t,e,n){var i=new yt,a=new yt;return i.add(a),i.__pictorialBundle=a,a.x=e.bundlePosition[0],a.y=e.bundlePosition[1],e.symbolRepeat?H1(i,t,e):W1(i,t,e),U1(i,e,n),Y1(i,t,e,n),i.__pictorialShapeStr=X1(r,e),i.__pictorialSymbolMeta=e,i}function XL(r,t,e){var n=e.animationModel,i=e.dataIndex,a=r.__pictorialBundle;bt(a,{x:e.bundlePosition[0],y:e.bundlePosition[1]},n,i),e.symbolRepeat?H1(r,t,e,!0):W1(r,t,e,!0),U1(r,e,!0),Y1(r,t,e,!0)}function hg(r,t,e,n){var i=n.__pictorialBarRect;i&&i.removeTextContent();var a=[];Lv(n,function(o){a.push(o)}),n.__pictorialMainPath&&a.push(n.__pictorialMainPath),n.__pictorialClipPath&&(e=null),M(a,function(o){Oa(o,{scaleX:0,scaleY:0},e,t,function(){n.parent&&n.parent.remove(n)})}),r.setItemGraphicEl(t,null)}function X1(r,t){return[r.getItemVisual(t.dataIndex,"symbol")||"none",!!t.symbolRepeat,!!t.symbolClip].join(":")}function Lv(r,t,e){M(r.__pictorialBundle.children(),function(n){n!==r.__pictorialBarRect&&t.call(e,n)})}function mi(r,t,e,n,i,a){t&&r.attr(t),n.symbolClip&&!i?e&&r.attr(e):e&&nl[i?"updateProps":"initProps"](r,e,n.animationModel,n.dataIndex,a)}function vg(r,t,e){var n=e.dataIndex,i=e.itemModel,a=i.getModel("emphasis"),o=a.getModel("itemStyle").getItemStyle(),s=i.getModel(["blur","itemStyle"]).getItemStyle(),l=i.getModel(["select","itemStyle"]).getItemStyle(),u=i.getShallow("cursor"),f=a.get("focus"),h=a.get("blurScope"),c=a.get("scale");Lv(r,function(p){if(p instanceof Ne){var g=p.style;p.useStyle(F({image:g.image,x:g.x,y:g.y,width:g.width,height:g.height},e.style))}else p.useStyle(e.style);var y=p.ensureState("emphasis");y.style=o,c&&(y.scaleX=p.scaleX*1.1,y.scaleY=p.scaleY*1.1),p.ensureState("blur").style=s,p.ensureState("select").style=l,u&&(p.cursor=u),p.z2=e.z2});var v=t.valueDim.posDesc[+(e.boundingLength>0)],d=r.__pictorialBarRect;d.ignoreClip=!0,Rn(d,En(i),{labelFetcher:t.seriesModel,labelDataIndex:n,defaultText:_l(t.seriesModel.getData(),n),inheritColor:e.style.fill,defaultOpacity:e.style.opacity,defaultOutsidePosition:v}),mr(r,f,h,a.get("disabled"))}function cg(r){var t=Math.round(r);return Math.abs(r-t)<1e-4?t:Math.ceil(r)}var ZL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e.defaultSymbol="roundRect",e}return t.prototype.getInitialData=function(e){return e.stack=null,r.prototype.getInitialData.apply(this,arguments)},t.type="series.pictorialBar",t.dependencies=["grid"],t.defaultOption=Yh(Ya.defaultOption,{symbol:"circle",symbolSize:null,symbolRotate:null,symbolPosition:null,symbolOffset:null,symbolMargin:null,symbolRepeat:!1,symbolRepeatDirection:"end",symbolClip:!1,symbolBoundingData:null,symbolPatternSize:400,barGap:"-100%",clip:!1,progressive:0,emphasis:{scale:!1},select:{itemStyle:{borderColor:"#212121"}}}),t}(Ya);function $L(r){r.registerChartView(zL),r.registerSeriesModel(ZL),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,vt(M_,"pictorialBar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,I_("pictorialBar"))}var mn=_t(),dg=tt,Hu=dt,qL=function(){function r(){this._dragging=!1,this.animationThreshold=15}return r.prototype.render=function(t,e,n,i){var a=e.get("value"),o=e.get("status");if(this._axisModel=t,this._axisPointerModel=e,this._api=n,!(!i&&this._lastValue===a&&this._lastStatus===o)){this._lastValue=a,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,a,t,e,n);var f=u.graphicKey;f!==this._lastGraphicKey&&this.clear(n),this._lastGraphicKey=f;var h=this._moveAnimation=this.determineAnimation(t,e);if(!s)s=this._group=new yt,this.createPointerEl(s,u,t,e),this.createLabelEl(s,u,t,e),n.getZr().add(s);else{var c=vt(pg,e,h);this.updatePointerEl(s,u,c),this.updateLabelEl(s,u,c,e)}yg(s,e,!0),this._renderHandle(a)}},r.prototype.remove=function(t){this.clear(t)},r.prototype.dispose=function(t){this.clear(t)},r.prototype.determineAnimation=function(t,e){var n=e.get("animation"),i=t.axis,a=i.type==="category",o=e.get("snap");if(!o&&!a)return!1;if(n==="auto"||n==null){var s=this.animationThreshold;if(a&&i.getBandWidth()>s)return!0;if(o){var l=bv(t).seriesDataCount,u=i.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return n===!0},r.prototype.makeElOption=function(t,e,n,i,a){},r.prototype.createPointerEl=function(t,e,n,i){var a=e.pointer;if(a){var o=mn(t).pointerEl=new nl[a.type](dg(e.pointer));t.add(o)}},r.prototype.createLabelEl=function(t,e,n,i){if(e.label){var a=mn(t).labelEl=new Ct(dg(e.label));t.add(a),gg(a,i)}},r.prototype.updatePointerEl=function(t,e,n){var i=mn(t).pointerEl;i&&e.pointer&&(i.setStyle(e.pointer.style),n(i,{shape:e.pointer.shape}))},r.prototype.updateLabelEl=function(t,e,n,i){var a=mn(t).labelEl;a&&(a.setStyle(e.label.style),n(a,{x:e.label.x,y:e.label.y}),gg(a,i))},r.prototype._renderHandle=function(t){if(!(this._dragging||!this.updateHandleTransform)){var e=this._axisPointerModel,n=this._api.getZr(),i=this._handle,a=e.getModel("handle"),o=e.get("status");if(!a.get("show")||!o||o==="hide"){i&&n.remove(i),this._handle=null;return}var s;this._handle||(s=!0,i=this._handle=el(a.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){Ay(u.event)},onmousedown:Hu(this._onHandleDragMove,this,0,0),drift:Hu(this._onHandleDragMove,this),ondragend:Hu(this._onHandleDragEnd,this)}),n.add(i)),yg(i,e,!1),i.setStyle(a.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=a.get("size");V(l)||(l=[l,l]),i.scaleX=l[0]/2,i.scaleY=l[1]/2,F0(this,"_doDispatchAxisPointer",a.get("throttle")||0,"fixRate"),this._moveHandleToValue(t,s)}},r.prototype._moveHandleToValue=function(t,e){pg(this._axisPointerModel,!e&&this._moveAnimation,this._handle,Wu(this.getHandleTransform(t,this._axisModel,this._axisPointerModel)))},r.prototype._onHandleDragMove=function(t,e){var n=this._handle;if(n){this._dragging=!0;var i=this.updateHandleTransform(Wu(n),[t,e],this._axisModel,this._axisPointerModel);this._payloadInfo=i,n.stopAnimation(),n.attr(Wu(i)),mn(n).lastProp=null,this._doDispatchAxisPointer()}},r.prototype._doDispatchAxisPointer=function(){var t=this._handle;if(t){var e=this._payloadInfo,n=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:e.cursorPoint[0],y:e.cursorPoint[1],tooltipOption:e.tooltipOption,axesInfo:[{axisDim:n.axis.dim,axisIndex:n.componentIndex}]})}},r.prototype._onHandleDragEnd=function(){this._dragging=!1;var t=this._handle;if(t){var e=this._axisPointerModel.get("value");this._moveHandleToValue(e),this._api.dispatchAction({type:"hideTip"})}},r.prototype.clear=function(t){this._lastValue=null,this._lastStatus=null;var e=t.getZr(),n=this._group,i=this._handle;e&&n&&(this._lastGraphicKey=null,n&&e.remove(n),i&&e.remove(i),this._group=null,this._handle=null,this._payloadInfo=null),zf(this,"_doDispatchAxisPointer")},r.prototype.doClear=function(){},r.prototype.buildLabel=function(t,e,n){return n=n||0,{x:t[n],y:t[1-n],width:e[n],height:e[1-n]}},r}();function pg(r,t,e,n){Z1(mn(e).lastProp,n)||(mn(e).lastProp=n,t?bt(e,n,r):(e.stopAnimation(),e.attr(n)))}function Z1(r,t){if(Y(r)&&Y(t)){var e=!0;return M(t,function(n,i){e=e&&Z1(r[i],n)}),!!e}else return r===t}function gg(r,t){r[t.get(["label","show"])?"show":"hide"]()}function Wu(r){return{x:r.x||0,y:r.y||0,rotation:r.rotation||0}}function yg(r,t,e){var n=t.get("z"),i=t.get("zlevel");r&&r.traverse(function(a){a.type!=="group"&&(n!=null&&(a.z=n),i!=null&&(a.zlevel=i),a.silent=e)})}function KL(r){var t=r.get("type"),e=r.getModel(t+"Style"),n;return t==="line"?(n=e.getLineStyle(),n.fill=null):t==="shadow"&&(n=e.getAreaStyle(),n.stroke=null),n}function QL(r,t,e,n,i){var a=e.get("value"),o=$1(a,t.axis,t.ecModel,e.get("seriesDataIndices"),{precision:e.get(["label","precision"]),formatter:e.get(["label","formatter"])}),s=e.getModel("label"),l=fl(s.get("padding")||0),u=s.getFont(),f=Us(o,u),h=i.position,c=f.width+l[1]+l[3],v=f.height+l[0]+l[2],d=i.align;d==="right"&&(h[0]-=c),d==="center"&&(h[0]-=c/2);var p=i.verticalAlign;p==="bottom"&&(h[1]-=v),p==="middle"&&(h[1]-=v/2),JL(h,c,v,n);var g=s.get("backgroundColor");(!g||g==="auto")&&(g=t.get(["axisLine","lineStyle","color"])),r.label={x:h[0],y:h[1],style:ye(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:g}),z2:10}}function JL(r,t,e,n){var i=n.getWidth(),a=n.getHeight();r[0]=Math.min(r[0]+t,i)-t,r[1]=Math.min(r[1]+e,a)-e,r[0]=Math.max(r[0],0),r[1]=Math.max(r[1],0)}function $1(r,t,e,n,i){r=t.scale.parse(r);var a=t.scale.getLabel({value:r},{precision:i.precision}),o=i.formatter;if(o){var s={value:gv(t,{value:r}),axisDimension:t.dim,axisIndex:t.index,seriesData:[]};M(n,function(l){var u=e.getSeriesByIndex(l.seriesIndex),f=l.dataIndexInside,h=u&&u.getDataParams(f);h&&s.seriesData.push(h)}),W(o)?a=o.replace("{value}",a):q(o)&&(a=o(s))}return a}function q1(r,t,e){var n=fi();return Dh(n,n,e.rotation),sf(n,n,e.position),Uh([r.dataToCoord(t),(e.labelOffset||0)+(e.labelDirection||1)*(e.labelMargin||0)],n)}function jL(r,t,e,n,i,a){var o=pr.innerTextLayout(e.rotation,0,e.labelDirection);e.labelMargin=i.get(["label","margin"]),QL(t,n,i,a,{position:q1(n.axis,r,e),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function tP(r,t,e){return e=e||0,{x1:r[e],y1:r[1-e],x2:t[e],y2:t[1-e]}}function eP(r,t,e){return e=e||0,{x:r[e],y:r[1-e],width:t[e],height:t[1-e]}}var rP=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.makeElOption=function(e,n,i,a,o){var s=i.axis,l=s.grid,u=a.get("type"),f=mg(l,s).getOtherAxis(s).getGlobalExtent(),h=s.toGlobalCoord(s.dataToCoord(n,!0));if(u&&u!=="none"){var c=KL(a),v=nP[u](s,h,f);v.style=c,e.graphicKey=v.type,e.pointer=v}var d=jf(l.model,i);jL(n,e,d,i,a,o)},t.prototype.getHandleTransform=function(e,n,i){var a=jf(n.axis.grid.model,n,{labelInside:!1});a.labelMargin=i.get(["handle","margin"]);var o=q1(n.axis,e,a);return{x:o[0],y:o[1],rotation:a.rotation+(a.labelDirection<0?Math.PI:0)}},t.prototype.updateHandleTransform=function(e,n,i,a){var o=i.axis,s=o.grid,l=o.getGlobalExtent(!0),u=mg(s,o).getOtherAxis(o).getGlobalExtent(),f=o.dim==="x"?0:1,h=[e.x,e.y];h[f]+=n[f],h[f]=Math.min(l[1],h[f]),h[f]=Math.max(l[0],h[f]);var c=(u[1]+u[0])/2,v=[c,c];v[f]=h[f];var d=[{verticalAlign:"middle"},{align:"center"}];return{x:h[0],y:h[1],rotation:e.rotation,cursorPoint:v,tooltipOption:d[f]}},t}(qL);function mg(r,t){var e={};return e[t.dim+"AxisIndex"]=t.index,r.getCartesian(e)}var nP={line:function(r,t,e){var n=tP([t,e[0]],[t,e[1]],_g(r));return{type:"Line",subPixelOptimize:!0,shape:n}},shadow:function(r,t,e){var n=Math.max(1,r.getBandWidth()),i=e[1]-e[0];return{type:"Rect",shape:eP([t-n/2,e[0]],[n,i],_g(r))}}};function _g(r){return r.dim==="x"?0:1}var iP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="axisPointer",t.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:"#B9BEC9",width:1,type:"dashed"},shadowStyle:{color:"rgba(210,219,238,0.2)"},label:{show:!0,formatter:null,precision:"auto",margin:3,color:"#fff",padding:[5,7,5,7],backgroundColor:"auto",borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:"#333",shadowBlur:3,shadowColor:"#aaa",shadowOffsetX:0,shadowOffsetY:2,throttle:40}},t}(ht),cr=_t(),aP=M;function K1(r,t,e){if(!J.node){var n=t.getZr();cr(n).records||(cr(n).records={}),oP(n,t);var i=cr(n).records[r]||(cr(n).records[r]={});i.handler=e}}function oP(r,t){if(cr(r).initialized)return;cr(r).initialized=!0,e("click",vt(Sg,"click")),e("mousemove",vt(Sg,"mousemove")),e("globalout",lP);function e(n,i){r.on(n,function(a){var o=uP(t);aP(cr(r).records,function(s){s&&i(s,a,o.dispatchAction)}),sP(o.pendings,t)})}}function sP(r,t){var e=r.showTip.length,n=r.hideTip.length,i;e?i=r.showTip[e-1]:n&&(i=r.hideTip[n-1]),i&&(i.dispatchAction=null,t.dispatchAction(i))}function lP(r,t,e){r.handler("leave",null,e)}function Sg(r,t,e,n){t.handler(r,e,n)}function uP(r){var t={showTip:[],hideTip:[]},e=function(n){var i=t[n.type];i?i.push(n):(n.dispatchAction=e,r.dispatchAction(n))};return{dispatchAction:e,pendings:t}}function sh(r,t){if(!J.node){var e=t.getZr(),n=(cr(e).records||{})[r];n&&(cr(e).records[r]=null)}}var fP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){var a=n.getComponent("tooltip"),o=e.get("triggerOn")||a&&a.get("triggerOn")||"mousemove|click";K1("axisPointer",i,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},t.prototype.remove=function(e,n){sh("axisPointer",n)},t.prototype.dispose=function(e,n){sh("axisPointer",n)},t.type="axisPointer",t}(Jt);function Q1(r,t){var e=[],n=r.seriesIndex,i;if(n==null||!(i=t.getSeriesByIndex(n)))return{point:[]};var a=i.getData(),o=Dn(a,r);if(o==null||o<0||V(o))return{point:[]};var s=a.getItemGraphicEl(o),l=i.coordinateSystem;if(i.getTooltipPosition)e=i.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(r.isStacked){var u=l.getBaseAxis(),f=l.getOtherAxis(u),h=f.dim,c=u.dim,v=h==="x"||h==="radius"?1:0,d=a.mapDimension(c),p=[];p[v]=a.get(d,o),p[1-v]=a.get(a.getCalculationInfo("stackResultDimension"),o),e=l.dataToPoint(p)||[]}else e=l.dataToPoint(a.getValues(H(l.dimensions,function(y){return a.mapDimension(y)}),o))||[];else if(s){var g=s.getBoundingRect().clone();g.applyTransform(s.transform),e=[g.x+g.width/2,g.y+g.height/2]}return{point:e,el:s}}var xg=_t();function hP(r,t,e){var n=r.currTrigger,i=[r.x,r.y],a=r,o=r.dispatchAction||dt(e.dispatchAction,e),s=t.getComponent("axisPointer").coordSysAxesInfo;if(s){ss(i)&&(i=Q1({seriesIndex:a.seriesIndex,dataIndex:a.dataIndex},t).point);var l=ss(i),u=a.axesInfo,f=s.axesInfo,h=n==="leave"||ss(i),c={},v={},d={list:[],map:{}},p={showPointer:vt(cP,v),showTooltip:vt(dP,d)};M(s.coordSysMap,function(y,m){var _=l||y.containPoint(i);M(s.coordSysAxesInfo[m],function(S,w){var x=S.axis,b=mP(u,S);if(!h&&_&&(!u||b)){var T=b&&b.value;T==null&&!l&&(T=x.pointToData(i)),T!=null&&wg(S,T,p,!1,c)}})});var g={};return M(f,function(y,m){var _=y.linkGroup;_&&!v[m]&&M(_.axesInfo,function(S,w){var x=v[w];if(S!==y&&x){var b=x.value;_.mapper&&(b=y.axis.scale.parse(_.mapper(b,bg(S),bg(y)))),g[y.key]=b}})}),M(g,function(y,m){wg(f[m],y,p,!0,c)}),pP(v,f,c),gP(d,i,r,o),yP(f,o,e),c}}function wg(r,t,e,n,i){var a=r.axis;if(!(a.scale.isBlank()||!a.containData(t))){if(!r.involveSeries){e.showPointer(r,t);return}var o=vP(t,r),s=o.payloadBatch,l=o.snapToValue;s[0]&&i.seriesIndex==null&&F(i,s[0]),!n&&r.snap&&a.containData(l)&&l!=null&&(t=l),e.showPointer(r,t,s),e.showTooltip(r,o,l)}}function vP(r,t){var e=t.axis,n=e.dim,i=r,a=[],o=Number.MAX_VALUE,s=-1;return M(t.seriesModels,function(l,u){var f=l.getData().mapDimensionsAll(n),h,c;if(l.getAxisTooltipData){var v=l.getAxisTooltipData(f,r,e);c=v.dataIndices,h=v.nestestValue}else{if(c=l.getData().indicesOfNearest(f[0],r,e.type==="category"?.5:null),!c.length)return;h=l.getData().get(f[0],c[0])}if(!(h==null||!isFinite(h))){var d=r-h,p=Math.abs(d);p<=o&&((p<o||d>=0&&s<0)&&(o=p,s=d,i=h,a.length=0),M(c,function(g){a.push({seriesIndex:l.seriesIndex,dataIndexInside:g,dataIndex:l.getData().getRawIndex(g)})}))}}),{payloadBatch:a,snapToValue:i}}function cP(r,t,e,n){r[t.key]={value:e,payloadBatch:n}}function dP(r,t,e,n){var i=e.payloadBatch,a=t.axis,o=a.model,s=t.axisPointerModel;if(!(!t.triggerTooltip||!i.length)){var l=t.coordSys.model,u=Xa(l),f=r.map[u];f||(f=r.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},r.list.push(f)),f.dataByAxis.push({axisDim:a.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:n,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:i.slice()})}}function pP(r,t,e){var n=e.axesInfo=[];M(t,function(i,a){var o=i.axisPointerModel.option,s=r[a];s?(!i.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!i.useHandle&&(o.status="hide"),o.status==="show"&&n.push({axisDim:i.axis.dim,axisIndex:i.axis.model.componentIndex,value:o.value})})}function gP(r,t,e,n){if(ss(t)||!r.list.length){n({type:"hideTip"});return}var i=((r.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};n({type:"showTip",escapeConnect:!0,x:t[0],y:t[1],tooltipOption:e.tooltipOption,position:e.position,dataIndexInside:i.dataIndexInside,dataIndex:i.dataIndex,seriesIndex:i.seriesIndex,dataByCoordSys:r.list})}function yP(r,t,e){var n=e.getZr(),i="axisPointerLastHighlights",a=xg(n)[i]||{},o=xg(n)[i]={};M(r,function(u,f){var h=u.axisPointerModel.option;h.status==="show"&&u.triggerEmphasis&&M(h.seriesDataIndices,function(c){var v=c.seriesIndex+" | "+c.dataIndex;o[v]=c})});var s=[],l=[];M(a,function(u,f){!o[f]&&l.push(u)}),M(o,function(u,f){!a[f]&&s.push(u)}),l.length&&e.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&e.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function mP(r,t){for(var e=0;e<(r||[]).length;e++){var n=r[e];if(t.axis.dim===n.axisDim&&t.axis.model.componentIndex===n.axisIndex)return n}}function bg(r){var t=r.axis.model,e={},n=e.axisDim=r.axis.dim;return e.axisIndex=e[n+"AxisIndex"]=t.componentIndex,e.axisName=e[n+"AxisName"]=t.name,e.axisId=e[n+"AxisId"]=t.id,e}function ss(r){return!r||r[0]==null||isNaN(r[0])||r[1]==null||isNaN(r[1])}function J1(r){T1.registerAxisPointerClass("CartesianAxisPointer",rP),r.registerComponentModel(iP),r.registerComponentView(fP),r.registerPreprocessor(function(t){if(t){(!t.axisPointer||t.axisPointer.length===0)&&(t.axisPointer={});var e=t.axisPointer.link;e&&!V(e)&&(t.axisPointer.link=[e])}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,function(t,e){t.getComponent("axisPointer").coordSysAxesInfo=NI(t,e)}),r.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},hP)}function _P(r){ke(A1),ke(J1)}var Tg=["x","y","radius","angle","single"],SP=["cartesian2d","polar","singleAxis"];function xP(r){var t=r.get("coordinateSystem");return lt(SP,t)>=0}function oi(r){return r+"Axis"}function wP(r,t){var e=$(),n=[],i=$();r.eachComponent({mainType:"dataZoom",query:t},function(f){i.get(f.uid)||s(f)});var a;do a=!1,r.eachComponent("dataZoom",o);while(a);function o(f){!i.get(f.uid)&&l(f)&&(s(f),a=!0)}function s(f){i.set(f.uid,!0),n.push(f),u(f)}function l(f){var h=!1;return f.eachTargetAxis(function(c,v){var d=e.get(c);d&&d[v]&&(h=!0)}),h}function u(f){f.eachTargetAxis(function(h,c){(e.get(h)||e.set(h,[]))[c]=!0})}return n}var Uu=function(){function r(){this.indexList=[],this.indexMap=[]}return r.prototype.add=function(t){this.indexMap[t]||(this.indexList.push(t),this.indexMap[t]=!0)},r}(),bP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._autoThrottle=!0,e._noTarget=!0,e._rangePropMode=["percent","percent"],e}return t.prototype.init=function(e,n,i){var a=Cg(e);this.settledOption=a,this.mergeDefaultAndTheme(e,i),this._doInit(a)},t.prototype.mergeOption=function(e){var n=Cg(e);nt(this.option,e,!0),nt(this.settledOption,n,!0),this._doInit(n)},t.prototype._doInit=function(e){var n=this.option;this._setDefaultThrottle(e),this._updateRangeUse(e);var i=this.settledOption;M([["start","startValue"],["end","endValue"]],function(a,o){this._rangePropMode[o]==="value"&&(n[a[0]]=i[a[0]]=null)},this),this._resetTarget()},t.prototype._resetTarget=function(){var e=this.get("orient",!0),n=this._targetAxisInfoMap=$(),i=this._fillSpecifiedTargetAxis(n);i?this._orient=e||this._makeAutoOrientByTargetAxis():(this._orient=e||"horizontal",this._fillAutoTargetAxisByOrient(n,this._orient)),this._noTarget=!0,n.each(function(a){a.indexList.length&&(this._noTarget=!1)},this)},t.prototype._fillSpecifiedTargetAxis=function(e){var n=!1;return M(Tg,function(i){var a=this.getReferringComponents(oi(i),Vw);if(a.specified){n=!0;var o=new Uu;M(a.models,function(s){o.add(s.componentIndex)}),e.set(i,o)}},this),n},t.prototype._fillAutoTargetAxisByOrient=function(e,n){var i=this.ecModel,a=!0;if(a){var o=n==="vertical"?"y":"x",s=i.findComponents({mainType:o+"Axis"});l(s,o)}if(a){var s=i.findComponents({mainType:"singleAxis",filter:function(f){return f.get("orient",!0)===n}});l(s,"single")}function l(u,f){var h=u[0];if(h){var c=new Uu;if(c.add(h.componentIndex),e.set(f,c),a=!1,f==="x"||f==="y"){var v=h.getReferringComponents("grid",$t).models[0];v&&M(u,function(d){h.componentIndex!==d.componentIndex&&v===d.getReferringComponents("grid",$t).models[0]&&c.add(d.componentIndex)})}}}a&&M(Tg,function(u){if(a){var f=i.findComponents({mainType:oi(u),filter:function(c){return c.get("type",!0)==="category"}});if(f[0]){var h=new Uu;h.add(f[0].componentIndex),e.set(u,h),a=!1}}},this)},t.prototype._makeAutoOrientByTargetAxis=function(){var e;return this.eachTargetAxis(function(n){!e&&(e=n)},this),e==="y"?"vertical":"horizontal"},t.prototype._setDefaultThrottle=function(e){if(e.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var n=this.ecModel.option;this.option.throttle=n.animation&&n.animationDurationUpdate>0?100:20}},t.prototype._updateRangeUse=function(e){var n=this._rangePropMode,i=this.get("rangeMode");M([["start","startValue"],["end","endValue"]],function(a,o){var s=e[a[0]]!=null,l=e[a[1]]!=null;s&&!l?n[o]="percent":!s&&l?n[o]="value":i?n[o]=i[o]:s&&(n[o]="percent")})},t.prototype.noTarget=function(){return this._noTarget},t.prototype.getFirstTargetAxisModel=function(){var e;return this.eachTargetAxis(function(n,i){e==null&&(e=this.ecModel.getComponent(oi(n),i))},this),e},t.prototype.eachTargetAxis=function(e,n){this._targetAxisInfoMap.each(function(i,a){M(i.indexList,function(o){e.call(n,a,o)})})},t.prototype.getAxisProxy=function(e,n){var i=this.getAxisModel(e,n);if(i)return i.__dzAxisProxy},t.prototype.getAxisModel=function(e,n){var i=this._targetAxisInfoMap.get(e);if(i&&i.indexMap[n])return this.ecModel.getComponent(oi(e),n)},t.prototype.setRawRange=function(e){var n=this.option,i=this.settledOption;M([["start","startValue"],["end","endValue"]],function(a){(e[a[0]]!=null||e[a[1]]!=null)&&(n[a[0]]=i[a[0]]=e[a[0]],n[a[1]]=i[a[1]]=e[a[1]])},this),this._updateRangeUse(e)},t.prototype.setCalculatedRange=function(e){var n=this.option;M(["start","startValue","end","endValue"],function(i){n[i]=e[i]})},t.prototype.getPercentRange=function(){var e=this.findRepresentativeAxisProxy();if(e)return e.getDataPercentWindow()},t.prototype.getValueRange=function(e,n){if(e==null&&n==null){var i=this.findRepresentativeAxisProxy();if(i)return i.getDataValueWindow()}else return this.getAxisProxy(e,n).getDataValueWindow()},t.prototype.findRepresentativeAxisProxy=function(e){if(e)return e.__dzAxisProxy;for(var n,i=this._targetAxisInfoMap.keys(),a=0;a<i.length;a++)for(var o=i[a],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;n||(n=u)}return n},t.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},t.prototype.getOrient=function(){return this._orient},t.type="dataZoom",t.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],t.defaultOption={z:4,filterMode:"filter",start:0,end:100},t}(ht);function Cg(r){var t={};return M(["start","end","startValue","endValue","throttle"],function(e){r.hasOwnProperty(e)&&(t[e]=r[e])}),t}var TP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.select",t}(bP),CP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i,a){this.dataZoomModel=e,this.ecModel=n,this.api=i},t.type="dataZoom",t}(Jt),DP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.select",t}(CP),ei=M,Dg=ww,AP=function(){function r(t,e,n,i){this._dimName=t,this._axisIndex=e,this.ecModel=i,this._dataZoomModel=n}return r.prototype.hostedBy=function(t){return this._dataZoomModel===t},r.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},r.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},r.prototype.getTargetSeriesModels=function(){var t=[];return this.ecModel.eachSeries(function(e){if(xP(e)){var n=oi(this._dimName),i=e.getReferringComponents(n,$t).models[0];i&&this._axisIndex===i.componentIndex&&t.push(e)}},this),t},r.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},r.prototype.getMinMaxSpan=function(){return tt(this._minMaxSpan)},r.prototype.calculateDataWindow=function(t){var e=this._dataExtent,n=this.getAxisModel(),i=n.axis.scale,a=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;ei(["start","end"],function(c,v){var d=t[c],p=t[c+"Value"];a[v]==="percent"?(d==null&&(d=o[v]),p=i.parse(Zt(d,o,e))):(u=!0,p=p==null?e[v]:i.parse(p),d=Zt(p,e,o)),l[v]=p==null||isNaN(p)?e[v]:p,s[v]=d==null||isNaN(d)?o[v]:d}),Dg(l),Dg(s);var f=this._minMaxSpan;u?h(l,s,e,o,!1):h(s,l,o,e,!0);function h(c,v,d,p,g){var y=g?"Span":"ValueSpan";I1(0,c,d,"all",f["min"+y],f["max"+y]);for(var m=0;m<2;m++)v[m]=Zt(c[m],d,p,!0),g&&(v[m]=i.parse(v[m]))}return{valueWindow:l,percentWindow:s}},r.prototype.reset=function(t){if(t===this._dataZoomModel){var e=this.getTargetSeriesModels();this._dataExtent=MP(this,this._dimName,e),this._updateMinMaxSpan();var n=this.calculateDataWindow(t.settledOption);this._valueWindow=n.valueWindow,this._percentWindow=n.percentWindow,this._setAxisModel()}},r.prototype.filterData=function(t,e){if(t!==this._dataZoomModel)return;var n=this._dimName,i=this.getTargetSeriesModels(),a=t.get("filterMode"),o=this._valueWindow;if(a==="none")return;ei(i,function(l){var u=l.getData(),f=u.mapDimensionsAll(n);if(f.length){if(a==="weakFilter"){var h=u.getStore(),c=H(f,function(v){return u.getDimensionIndex(v)},u);u.filterSelf(function(v){for(var d,p,g,y=0;y<f.length;y++){var m=h.get(c[y],v),_=!isNaN(m),S=m<o[0],w=m>o[1];if(_&&!S&&!w)return!0;_&&(g=!0),S&&(d=!0),w&&(p=!0)}return g&&d&&p})}else ei(f,function(v){if(a==="empty")l.setData(u=u.map(v,function(p){return s(p)?p:NaN}));else{var d={};d[v]=o,u.selectRange(d)}});ei(f,function(v){u.setApproximateExtent(o,v)})}});function s(l){return l>=o[0]&&l<=o[1]}},r.prototype._updateMinMaxSpan=function(){var t=this._minMaxSpan={},e=this._dataZoomModel,n=this._dataExtent;ei(["min","max"],function(i){var a=e.get(i+"Span"),o=e.get(i+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?a=Zt(n[0]+o,n,[0,100],!0):a!=null&&(o=Zt(a,[0,100],n,!0)-n[0]),t[i+"Span"]=a,t[i+"ValueSpan"]=o},this)},r.prototype._setAxisModel=function(){var t=this.getAxisModel(),e=this._percentWindow,n=this._valueWindow;if(e){var i=$y(n,[0,500]);i=Math.min(i,20);var a=t.axis.scale.rawExtentInfo;e[0]!==0&&a.setDeterminedMinMax("min",+n[0].toFixed(i)),e[1]!==100&&a.setDeterminedMinMax("max",+n[1].toFixed(i)),a.freeze()}},r}();function MP(r,t,e){var n=[1/0,-1/0];ei(e,function(o){e2(n,o.getData(),t)});var i=r.getAxisModel(),a=k_(i.axis.scale,i,n).calculate();return[a.min,a.max]}var IP={getTargetSeries:function(r){function t(i){r.eachComponent("dataZoom",function(a){a.eachTargetAxis(function(o,s){var l=r.getComponent(oi(o),s);i(o,s,l,a)})})}t(function(i,a,o,s){o.__dzAxisProxy=null});var e=[];t(function(i,a,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new AP(i,a,s,r),e.push(o.__dzAxisProxy))});var n=$();return M(e,function(i){M(i.getTargetSeriesModels(),function(a){n.set(a.uid,a)})}),n},overallReset:function(r,t){r.eachComponent("dataZoom",function(e){e.eachTargetAxis(function(n,i){e.getAxisProxy(n,i).reset(e)}),e.eachTargetAxis(function(n,i){e.getAxisProxy(n,i).filterData(e,t)})}),r.eachComponent("dataZoom",function(e){var n=e.findRepresentativeAxisProxy();if(n){var i=n.getDataPercentWindow(),a=n.getDataValueWindow();e.setCalculatedRange({start:i[0],end:i[1],startValue:a[0],endValue:a[1]})}})}};function LP(r){r.registerAction("dataZoom",function(t,e){var n=wP(e,t);M(n,function(i){i.setRawRange({start:t.start,end:t.end,startValue:t.startValue,endValue:t.endValue})})})}var Ag=!1;function PP(r){Ag||(Ag=!0,r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,IP),LP(r),r.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}function RP(r){r.registerComponentModel(TP),r.registerComponentView(DP),PP(r)}var Le=function(){function r(){}return r}(),j1={};function ia(r,t){j1[r]=t}function tS(r){return j1[r]}var EP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){r.prototype.optionUpdated.apply(this,arguments);var e=this.ecModel;M(this.option.feature,function(n,i){var a=tS(i);a&&(a.getDefaultOption&&(a.defaultOption=a.getDefaultOption(e)),nt(n,a.defaultOption))})},t.type="toolbox",t.layoutMode={type:"box",ignoreSize:!0},t.defaultOption={show:!0,z:6,orient:"horizontal",left:"right",top:"top",backgroundColor:"transparent",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemSize:15,itemGap:8,showTitle:!0,iconStyle:{borderColor:"#666",color:"none"},emphasis:{iconStyle:{borderColor:"#3E98C5"}},tooltip:{show:!1,position:"bottom"}},t}(ht);function kP(r,t,e){var n=t.getBoxLayoutParams(),i=t.get("padding"),a={width:e.getWidth(),height:e.getHeight()},o=Ur(n,a,i);yi(t.get("orient"),r,t.get("itemGap"),o.width,o.height),vC(r,n,a,i)}function eS(r,t){var e=fl(t.get("padding")),n=t.getItemStyle(["color","opacity"]);return n.fill=t.get("backgroundColor"),r=new St({shape:{x:r.x-e[3],y:r.y-e[0],width:r.width+e[1]+e[3],height:r.height+e[0]+e[2],r:t.get("borderRadius")},style:n,silent:!0,z2:-1}),r}var OP=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.render=function(e,n,i,a){var o=this.group;if(o.removeAll(),!e.get("show"))return;var s=+e.get("itemSize"),l=e.get("orient")==="vertical",u=e.get("feature")||{},f=this._features||(this._features={}),h=[];M(u,function(d,p){h.push(p)}),new Wa(this._featureNames||[],h).add(c).update(c).remove(vt(c,null)).execute(),this._featureNames=h;function c(d,p){var g=h[d],y=h[p],m=u[g],_=new wt(m,e,e.ecModel),S;if(a&&a.newTitle!=null&&a.featureName===g&&(m.title=a.newTitle),g&&!y){if(BP(g))S={onclick:_.option.onclick,featureName:g};else{var w=tS(g);if(!w)return;S=new w}f[g]=S}else if(S=f[y],!S)return;S.uid=to("toolbox-feature"),S.model=_,S.ecModel=n,S.api=i;var x=S instanceof Le;if(!g&&y){x&&S.dispose&&S.dispose(n,i);return}if(!_.get("show")||x&&S.unusable){x&&S.remove&&S.remove(n,i);return}v(_,S,g),_.setIconStatus=function(b,T){var C=this.option,D=this.iconPaths;C.iconStatus=C.iconStatus||{},C.iconStatus[b]=T,D[b]&&(T==="emphasis"?xi:wi)(D[b])},S instanceof Le&&S.render&&S.render(_,n,i,a)}function v(d,p,g){var y=d.getModel("iconStyle"),m=d.getModel(["emphasis","iconStyle"]),_=p instanceof Le&&p.getIcons?p.getIcons():d.get("icon"),S=d.get("title")||{},w,x;W(_)?(w={},w[g]=_):w=_,W(S)?(x={},x[g]=S):x=S;var b=d.iconPaths={};M(w,function(T,C){var D=el(T,{},{x:-s/2,y:-s/2,width:s,height:s});D.setStyle(y.getItemStyle());var A=D.ensureState("emphasis");A.style=m.getItemStyle();var I=new Ct({style:{text:x[C],align:m.get("textAlign"),borderRadius:m.get("textBorderRadius"),padding:m.get("textPadding"),fill:null,font:Wm({fontStyle:m.get("textFontStyle"),fontFamily:m.get("textFontFamily"),fontSize:m.get("textFontSize"),fontWeight:m.get("textFontWeight")},n)},ignore:!0});D.setTextContent(I),ja({el:D,componentModel:e,itemName:C,formatterParamsExtra:{title:x[C]}}),D.__title=x[C],D.on("mouseover",function(){var L=m.getItemStyle(),P=l?e.get("right")==null&&e.get("left")!=="right"?"right":"left":e.get("bottom")==null&&e.get("top")!=="bottom"?"bottom":"top";I.setStyle({fill:m.get("textFill")||L.fill||L.stroke||"#000",backgroundColor:m.get("textBackgroundColor")}),D.setTextConfig({position:m.get("textPosition")||P}),I.ignore=!e.get("showTitle"),i.enterEmphasis(this)}).on("mouseout",function(){d.get(["iconStatus",C])!=="emphasis"&&i.leaveEmphasis(this),I.hide()}),(d.get(["iconStatus",C])==="emphasis"?xi:wi)(D),o.add(D),D.on("click",dt(p.onclick,p,n,i,C)),b[C]=D})}kP(o,e,i),o.add(eS(o.getBoundingRect(),e)),l||o.eachChild(function(d){var p=d.__title,g=d.ensureState("emphasis"),y=g.textConfig||(g.textConfig={}),m=d.getTextContent(),_=m&&m.ensureState("emphasis");if(_&&!q(_)&&p){var S=_.style||(_.style={}),w=Us(p,Ct.makeFont(S)),x=d.x+o.x,b=d.y+o.y+s,T=!1;b+w.height>i.getHeight()&&(y.position="top",T=!0);var C=T?-5-w.height:s+10;x+w.width/2>i.getWidth()?(y.position=["100%",C],S.align="right"):x-w.width/2<0&&(y.position=[0,C],S.align="left")}})},t.prototype.updateView=function(e,n,i,a){M(this._features,function(o){o instanceof Le&&o.updateView&&o.updateView(o.model,n,i,a)})},t.prototype.remove=function(e,n){M(this._features,function(i){i instanceof Le&&i.remove&&i.remove(e,n)}),this.group.removeAll()},t.prototype.dispose=function(e,n){M(this._features,function(i){i instanceof Le&&i.dispose&&i.dispose(e,n)})},t.type="toolbox",t}(Jt);function BP(r){return r.indexOf("my")===0}var NP=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.onclick=function(e,n){var i=this.model,a=i.get("name")||e.get("title.0.text")||"echarts",o=n.getZr().painter.getType()==="svg",s=o?"svg":i.get("type",!0)||"png",l=n.getConnectedDataURL({type:s,backgroundColor:i.get("backgroundColor",!0)||e.get("backgroundColor")||"#fff",connectedBackgroundColor:i.get("connectedBackgroundColor"),excludeComponents:i.get("excludeComponents"),pixelRatio:i.get("pixelRatio")}),u=J.browser;if(typeof MouseEvent=="function"&&(u.newEdge||!u.ie&&!u.edge)){var f=document.createElement("a");f.download=a+"."+s,f.target="_blank",f.href=l;var h=new MouseEvent("click",{view:document.defaultView,bubbles:!0,cancelable:!1});f.dispatchEvent(h)}else if(window.navigator.msSaveOrOpenBlob||o){var c=l.split(","),v=c[0].indexOf("base64")>-1,d=o?decodeURIComponent(c[1]):c[1];v&&(d=window.atob(d));var p=a+"."+s;if(window.navigator.msSaveOrOpenBlob){for(var g=d.length,y=new Uint8Array(g);g--;)y[g]=d.charCodeAt(g);var m=new Blob([y]);window.navigator.msSaveOrOpenBlob(m,p)}else{var _=document.createElement("iframe");document.body.appendChild(_);var S=_.contentWindow,w=S.document;w.open("image/svg+xml","replace"),w.write(d),w.close(),S.focus(),w.execCommand("SaveAs",!0,p),document.body.removeChild(_)}}else{var x=i.get("lang"),b='<body style="margin:0;"><img src="'+l+'" style="max-width:100%;" title="'+(x&&x[0]||"")+'" /></body>',T=window.open();T.document.write(b),T.document.title=a}},t.getDefaultOption=function(e){var n={show:!0,icon:"M4.7,22.9L29.3,45.5L54.7,23.4M4.6,43.6L4.6,58L53.8,58L53.8,43.6M29.2,45.1L29.2,0",title:e.getLocaleModel().get(["toolbox","saveAsImage","title"]),type:"png",connectedBackgroundColor:"#fff",name:"",excludeComponents:["toolbox"],lang:e.getLocaleModel().get(["toolbox","saveAsImage","lang"])};return n},t}(Le),Mg="__ec_magicType_stack__",FP=[["line","bar"],["stack"]],zP=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getIcons=function(){var e=this.model,n=e.get("icon"),i={};return M(e.get("type"),function(a){n[a]&&(i[a]=n[a])}),i},t.getDefaultOption=function(e){var n={show:!0,type:[],icon:{line:"M4.1,28.9h7.1l9.3-22l7.4,38l9.7-19.7l3,12.8h14.9M4.1,58h51.4",bar:"M6.7,22.9h10V48h-10V22.9zM24.9,13h10v35h-10V13zM43.2,2h10v46h-10V2zM3.1,58h53.7",stack:"M8.2,38.4l-8.4,4.1l30.6,15.3L60,42.5l-8.1-4.1l-21.5,11L8.2,38.4z M51.9,30l-8.1,4.2l-13.4,6.9l-13.9-6.9L8.2,30l-8.4,4.2l8.4,4.2l22.2,11l21.5-11l8.1-4.2L51.9,30z M51.9,21.7l-8.1,4.2L35.7,30l-5.3,2.8L24.9,30l-8.4-4.1l-8.3-4.2l-8.4,4.2L8.2,30l8.3,4.2l13.9,6.9l13.4-6.9l8.1-4.2l8.1-4.1L51.9,21.7zM30.4,2.2L-0.2,17.5l8.4,4.1l8.3,4.2l8.4,4.2l5.5,2.7l5.3-2.7l8.1-4.2l8.1-4.2l8.1-4.1L30.4,2.2z"},title:e.getLocaleModel().get(["toolbox","magicType","title"]),option:{},seriesIndex:{}};return n},t.prototype.onclick=function(e,n,i){var a=this.model,o=a.get(["seriesIndex",i]);if(Ig[i]){var s={series:[]},l=function(h){var c=h.subType,v=h.id,d=Ig[i](c,v,h,a);d&&(Q(d,h.option),s.series.push(d));var p=h.coordinateSystem;if(p&&p.type==="cartesian2d"&&(i==="line"||i==="bar")){var g=p.getAxesByScale("ordinal")[0];if(g){var y=g.dim,m=y+"Axis",_=h.getReferringComponents(m,$t).models[0],S=_.componentIndex;s[m]=s[m]||[];for(var w=0;w<=S;w++)s[m][S]=s[m][S]||{};s[m][S].boundaryGap=i==="bar"}}};M(FP,function(h){lt(h,i)>=0&&M(h,function(c){a.setIconStatus(c,"normal")})}),a.setIconStatus(i,"emphasis"),e.eachComponent({mainType:"series",query:o==null?null:{seriesIndex:o}},l);var u,f=i;i==="stack"&&(u=nt({stack:a.option.title.tiled,tiled:a.option.title.stack},a.option.title),a.get(["iconStatus",i])!=="emphasis"&&(f="tiled")),n.dispatchAction({type:"changeMagicType",currentType:f,newOption:s,newTitle:u,featureName:"magicType"})}},t}(Le),Ig={line:function(r,t,e,n){if(r==="bar")return nt({id:t,type:"line",data:e.get("data"),stack:e.get("stack"),markPoint:e.get("markPoint"),markLine:e.get("markLine")},n.get(["option","line"])||{},!0)},bar:function(r,t,e,n){if(r==="line")return nt({id:t,type:"bar",data:e.get("data"),stack:e.get("stack"),markPoint:e.get("markPoint"),markLine:e.get("markLine")},n.get(["option","bar"])||{},!0)},stack:function(r,t,e,n){var i=e.get("stack")===Mg;if(r==="line"||r==="bar")return n.setIconStatus("stack",i?"normal":"emphasis"),nt({id:t,stack:i?"":Mg},n.get(["option","stack"])||{},!0)}};nr({type:"changeMagicType",event:"magicTypeChanged",update:"prepareAndUpdate"},function(r,t){t.mergeOption(r.newOption)});var xl=new Array(60).join("-"),Ai="	";function VP(r){var t={},e=[],n=[];return r.eachRawSeries(function(i){var a=i.coordinateSystem;if(a&&(a.type==="cartesian2d"||a.type==="polar")){var o=a.getBaseAxis();if(o.type==="category"){var s=o.dim+"_"+o.index;t[s]||(t[s]={categoryAxis:o,valueAxis:a.getOtherAxis(o),series:[]},n.push({axisDim:o.dim,axisIndex:o.index})),t[s].series.push(i)}else e.push(i)}else e.push(i)}),{seriesGroupByCategoryAxis:t,other:e,meta:n}}function GP(r){var t=[];return M(r,function(e,n){var i=e.categoryAxis,a=e.valueAxis,o=a.dim,s=[" "].concat(H(e.series,function(v){return v.name})),l=[i.model.getCategories()];M(e.series,function(v){var d=v.getRawData();l.push(v.getRawData().mapArray(d.mapDimension(o),function(p){return p}))});for(var u=[s.join(Ai)],f=0;f<l[0].length;f++){for(var h=[],c=0;c<l.length;c++)h.push(l[c][f]);u.push(h.join(Ai))}t.push(u.join(`
`))}),t.join(`

`+xl+`

`)}function HP(r){return H(r,function(t){var e=t.getRawData(),n=[t.name],i=[];return e.each(e.dimensions,function(){for(var a=arguments.length,o=arguments[a-1],s=e.getName(o),l=0;l<a-1;l++)i[l]=arguments[l];n.push((s?s+Ai:"")+i.join(Ai))}),n.join(`
`)}).join(`

`+xl+`

`)}function WP(r){var t=VP(r);return{value:Tt([GP(t.seriesGroupByCategoryAxis),HP(t.other)],function(e){return!!e.replace(/[\n\t\s]/g,"")}).join(`

`+xl+`

`),meta:t.meta}}function ks(r){return r.replace(/^\s\s*/,"").replace(/\s\s*$/,"")}function UP(r){var t=r.slice(0,r.indexOf(`
`));if(t.indexOf(Ai)>=0)return!0}var lh=new RegExp("["+Ai+"]+","g");function YP(r){for(var t=r.split(/\n+/g),e=ks(t.shift()).split(lh),n=[],i=H(e,function(l){return{name:l,data:[]}}),a=0;a<t.length;a++){var o=ks(t[a]).split(lh);n.push(o.shift());for(var s=0;s<o.length;s++)i[s]&&(i[s].data[a]=o[s])}return{series:i,categories:n}}function XP(r){for(var t=r.split(/\n+/g),e=ks(t.shift()),n=[],i=0;i<t.length;i++){var a=ks(t[i]);if(a){var o=a.split(lh),s="",l=void 0,u=!1;isNaN(o[0])?(u=!0,s=o[0],o=o.slice(1),n[i]={name:s,value:[]},l=n[i].value):l=n[i]=[];for(var f=0;f<o.length;f++)l.push(+o[f]);l.length===1&&(u?n[i].value=l[0]:n[i]=l[0])}}return{name:e,data:n}}function ZP(r,t){var e=r.split(new RegExp(`
*`+xl+`
*`,"g")),n={series:[]};return M(e,function(i,a){if(UP(i)){var o=YP(i),s=t[a],l=s.axisDim+"Axis";s&&(n[l]=n[l]||[],n[l][s.axisIndex]={data:o.categories},n.series=n.series.concat(o.series))}else{var o=XP(i);n.series.push(o)}}),n}var $P=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.onclick=function(e,n){setTimeout(function(){n.dispatchAction({type:"hideTip"})});var i=n.getDom(),a=this.model;this._dom&&i.removeChild(this._dom);var o=document.createElement("div");o.style.cssText="position:absolute;top:0;bottom:0;left:0;right:0;padding:5px",o.style.backgroundColor=a.get("backgroundColor")||"#fff";var s=document.createElement("h4"),l=a.get("lang")||[];s.innerHTML=l[0]||a.get("title"),s.style.cssText="margin:10px 20px",s.style.color=a.get("textColor");var u=document.createElement("div"),f=document.createElement("textarea");u.style.cssText="overflow:auto";var h=a.get("optionToContent"),c=a.get("contentToOption"),v=WP(e);if(q(h)){var d=h(n.getOption());W(d)?u.innerHTML=d:_i(d)&&u.appendChild(d)}else{f.readOnly=a.get("readOnly");var p=f.style;p.cssText="display:block;width:100%;height:100%;font-family:monospace;font-size:14px;line-height:1.6rem;resize:none;box-sizing:border-box;outline:none",p.color=a.get("textColor"),p.borderColor=a.get("textareaBorderColor"),p.backgroundColor=a.get("textareaColor"),f.value=v.value,u.appendChild(f)}var g=v.meta,y=document.createElement("div");y.style.cssText="position:absolute;bottom:5px;left:0;right:0";var m="float:right;margin-right:20px;border:none;cursor:pointer;padding:2px 5px;font-size:12px;border-radius:3px",_=document.createElement("div"),S=document.createElement("div");m+=";background-color:"+a.get("buttonColor"),m+=";color:"+a.get("buttonTextColor");var w=this;function x(){i.removeChild(o),w._dom=null}of(_,"click",x),of(S,"click",function(){if(c==null&&h!=null||c!=null&&h==null){x();return}var b;try{q(c)?b=c(u,n.getOption()):b=ZP(f.value,g)}catch(T){throw x(),new Error("Data view format error "+T)}b&&n.dispatchAction({type:"changeDataView",newOption:b}),x()}),_.innerHTML=l[1],S.innerHTML=l[2],S.style.cssText=_.style.cssText=m,!a.get("readOnly")&&y.appendChild(S),y.appendChild(_),o.appendChild(s),o.appendChild(u),o.appendChild(y),u.style.height=i.clientHeight-80+"px",i.appendChild(o),this._dom=o},t.prototype.remove=function(e,n){this._dom&&n.getDom().removeChild(this._dom)},t.prototype.dispose=function(e,n){this.remove(e,n)},t.getDefaultOption=function(e){var n={show:!0,readOnly:!1,optionToContent:null,contentToOption:null,icon:"M17.5,17.3H33 M17.5,17.3H33 M45.4,29.5h-28 M11.5,2v56H51V14.8L38.4,2H11.5z M38.4,2.2v12.7H51 M45.4,41.7h-28",title:e.getLocaleModel().get(["toolbox","dataView","title"]),lang:e.getLocaleModel().get(["toolbox","dataView","lang"]),backgroundColor:"#fff",textColor:"#000",textareaColor:"#fff",textareaBorderColor:"#333",buttonColor:"#c23531",buttonTextColor:"#fff"};return n},t}(Le);function qP(r,t){return H(r,function(e,n){var i=t&&t[n];if(Y(i)&&!V(i)){var a=Y(e)&&!V(e);a||(e={value:e});var o=i.name!=null&&e.name==null;return e=Q(e,i),o&&delete e.name,e}else return e})}nr({type:"changeDataView",event:"dataViewChanged",update:"prepareAndUpdate"},function(r,t){var e=[];M(r.newOption.series,function(n){var i=t.getSeriesByName(n.name)[0];if(!i)e.push(F({type:"scatter"},n));else{var a=i.get("data");e.push({name:n.name,data:qP(n.data,a)})}}),t.mergeOption(Q({series:e},r.newOption))});var rS=M,nS=_t();function KP(r,t){var e=Pv(r);rS(t,function(n,i){for(var a=e.length-1;a>=0;a--){var o=e[a];if(o[i])break}if(a<0){var s=r.queryComponents({mainType:"dataZoom",subType:"select",id:i})[0];if(s){var l=s.getPercentRange();e[0][i]={dataZoomId:i,start:l[0],end:l[1]}}}}),e.push(t)}function QP(r){var t=Pv(r),e=t[t.length-1];t.length>1&&t.pop();var n={};return rS(e,function(i,a){for(var o=t.length-1;o>=0;o--)if(i=t[o][a],i){n[a]=i;break}}),n}function JP(r){nS(r).snapshots=null}function jP(r){return Pv(r).length}function Pv(r){var t=nS(r);return t.snapshots||(t.snapshots=[{}]),t.snapshots}var tR=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.onclick=function(e,n){JP(e),n.dispatchAction({type:"restore",from:this.uid})},t.getDefaultOption=function(e){var n={show:!0,icon:"M3.8,33.4 M47,18.9h9.8V8.7 M56.3,20.1 C52.1,9,40.5,0.6,26.8,2.1C12.6,3.7,1.6,16.2,2.1,30.6 M13,41.1H3.1v10.2 M3.7,39.9c4.2,11.1,15.8,19.5,29.5,18 c14.2-1.6,25.2-14.1,24.7-28.5",title:e.getLocaleModel().get(["toolbox","restore","title"])};return n},t}(Le);nr({type:"restore",event:"restore",update:"prepareAndUpdate"},function(r,t){t.resetOption("recreate")});var eR=["grid","xAxis","yAxis","geo","graph","polar","radiusAxis","angleAxis","bmap"],iS=function(){function r(t,e,n){var i=this;this._targetInfoList=[];var a=Lg(e,t);M(rR,function(o,s){(!n||!n.include||lt(n.include,s)>=0)&&o(a,i._targetInfoList)})}return r.prototype.setOutputRanges=function(t,e){return this.matchOutputRanges(t,e,function(n,i,a){if((n.coordRanges||(n.coordRanges=[])).push(i),!n.coordRange){n.coordRange=i;var o=Yu[n.brushType](0,a,i);n.__rangeOffset={offset:kg[n.brushType](o.values,n.range,[1,1]),xyMinMax:o.xyMinMax}}}),t},r.prototype.matchOutputRanges=function(t,e,n){M(t,function(i){var a=this.findTargetInfo(i,e);a&&a!==!0&&M(a.coordSyses,function(o){var s=Yu[i.brushType](1,o,i.range,!0);n(i,s.values,o,e)})},this)},r.prototype.setInputRanges=function(t,e){M(t,function(n){var i=this.findTargetInfo(n,e);if(n.range=n.range||[],i&&i!==!0){n.panelId=i.panelId;var a=Yu[n.brushType](0,i.coordSys,n.coordRange),o=n.__rangeOffset;n.range=o?kg[n.brushType](a.values,o.offset,nR(a.xyMinMax,o.xyMinMax)):a.values}},this)},r.prototype.makePanelOpts=function(t,e){return H(this._targetInfoList,function(n){var i=n.getPanelRect();return{panelId:n.panelId,defaultBrushType:e?e(n):null,clipPath:OL(i),isTargetByCursor:NL(i,t,n.coordSysModel),getLinearBrushOtherExtent:BL(i)}})},r.prototype.controlSeries=function(t,e,n){var i=this.findTargetInfo(t,n);return i===!0||i&&lt(i.coordSyses,e.coordinateSystem)>=0},r.prototype.findTargetInfo=function(t,e){for(var n=this._targetInfoList,i=Lg(e,t),a=0;a<n.length;a++){var o=n[a],s=t.panelId;if(s){if(o.panelId===s)return o}else for(var l=0;l<Pg.length;l++)if(Pg[l](i,o))return o}return!0},r}();function uh(r){return r[0]>r[1]&&r.reverse(),r}function Lg(r,t){return xa(r,t,{includeMainTypes:eR})}var rR={grid:function(r,t){var e=r.xAxisModels,n=r.yAxisModels,i=r.gridModels,a=$(),o={},s={};!e&&!n&&!i||(M(e,function(l){var u=l.axis.grid.model;a.set(u.id,u),o[u.id]=!0}),M(n,function(l){var u=l.axis.grid.model;a.set(u.id,u),s[u.id]=!0}),M(i,function(l){a.set(l.id,l),o[l.id]=!0,s[l.id]=!0}),a.each(function(l){var u=l.coordinateSystem,f=[];M(u.getCartesians(),function(h,c){(lt(e,h.getAxis("x").model)>=0||lt(n,h.getAxis("y").model)>=0)&&f.push(h)}),t.push({panelId:"grid--"+l.id,gridModel:l,coordSysModel:l,coordSys:f[0],coordSyses:f,getPanelRect:Rg.grid,xAxisDeclared:o[l.id],yAxisDeclared:s[l.id]})}))},geo:function(r,t){M(r.geoModels,function(e){var n=e.coordinateSystem;t.push({panelId:"geo--"+e.id,geoModel:e,coordSysModel:e,coordSys:n,coordSyses:[n],getPanelRect:Rg.geo})})}},Pg=[function(r,t){var e=r.xAxisModel,n=r.yAxisModel,i=r.gridModel;return!i&&e&&(i=e.axis.grid.model),!i&&n&&(i=n.axis.grid.model),i&&i===t.gridModel},function(r,t){var e=r.geoModel;return e&&e===t.geoModel}],Rg={grid:function(){return this.coordSys.master.getRect().clone()},geo:function(){var r=this.coordSys,t=r.getBoundingRect().clone();return t.applyTransform(Wh(r)),t}},Yu={lineX:vt(Eg,0),lineY:vt(Eg,1),rect:function(r,t,e,n){var i=r?t.pointToData([e[0][0],e[1][0]],n):t.dataToPoint([e[0][0],e[1][0]],n),a=r?t.pointToData([e[0][1],e[1][1]],n):t.dataToPoint([e[0][1],e[1][1]],n),o=[uh([i[0],a[0]]),uh([i[1],a[1]])];return{values:o,xyMinMax:o}},polygon:function(r,t,e,n){var i=[[1/0,-1/0],[1/0,-1/0]],a=H(e,function(o){var s=r?t.pointToData(o,n):t.dataToPoint(o,n);return i[0][0]=Math.min(i[0][0],s[0]),i[1][0]=Math.min(i[1][0],s[1]),i[0][1]=Math.max(i[0][1],s[0]),i[1][1]=Math.max(i[1][1],s[1]),s});return{values:a,xyMinMax:i}}};function Eg(r,t,e,n){var i=e.getAxis(["x","y"][r]),a=uh(H([0,1],function(s){return t?i.coordToData(i.toLocalCoord(n[s]),!0):i.toGlobalCoord(i.dataToCoord(n[s]))})),o=[];return o[r]=a,o[1-r]=[NaN,NaN],{values:a,xyMinMax:o}}var kg={lineX:vt(Og,0),lineY:vt(Og,1),rect:function(r,t,e){return[[r[0][0]-e[0]*t[0][0],r[0][1]-e[0]*t[0][1]],[r[1][0]-e[1]*t[1][0],r[1][1]-e[1]*t[1][1]]]},polygon:function(r,t,e){return H(r,function(n,i){return[n[0]-e[0]*t[i][0],n[1]-e[1]*t[i][1]]})}};function Og(r,t,e,n){return[t[0]-n[r]*e[0],t[1]-n[r]*e[1]]}function nR(r,t){var e=Bg(r),n=Bg(t),i=[e[0]/n[0],e[1]/n[1]];return isNaN(i[0])&&(i[0]=1),isNaN(i[1])&&(i[1]=1),i}function Bg(r){return r?[r[0][1]-r[0][0],r[1][1]-r[1][0]]:[NaN,NaN]}var fh=M,iR=Bw("toolbox-dataZoom_"),aR=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.render=function(e,n,i,a){this._brushController||(this._brushController=new DL(i.getZr()),this._brushController.on("brush",dt(this._onBrush,this)).mount()),lR(e,n,this,a,i),sR(e,n)},t.prototype.onclick=function(e,n,i){oR[i].call(this)},t.prototype.remove=function(e,n){this._brushController&&this._brushController.unmount()},t.prototype.dispose=function(e,n){this._brushController&&this._brushController.dispose()},t.prototype._onBrush=function(e){var n=e.areas;if(!e.isEnd||!n.length)return;var i={},a=this.ecModel;this._brushController.updateCovers([]);var o=new iS(Rv(this.model),a,{include:["grid"]});o.matchOutputRanges(n,a,function(u,f,h){if(h.type==="cartesian2d"){var c=u.brushType;c==="rect"?(s("x",h,f[0]),s("y",h,f[1])):s({lineX:"x",lineY:"y"}[c],h,f)}}),KP(a,i),this._dispatchZoomAction(i);function s(u,f,h){var c=f.getAxis(u),v=c.model,d=l(u,v,a),p=d.findRepresentativeAxisProxy(v).getMinMaxSpan();(p.minValueSpan!=null||p.maxValueSpan!=null)&&(h=I1(0,h.slice(),c.scale.getExtent(),0,p.minValueSpan,p.maxValueSpan)),d&&(i[d.id]={dataZoomId:d.id,startValue:h[0],endValue:h[1]})}function l(u,f,h){var c;return h.eachComponent({mainType:"dataZoom",subType:"select"},function(v){var d=v.getAxisModel(u,f.componentIndex);d&&(c=v)}),c}},t.prototype._dispatchZoomAction=function(e){var n=[];fh(e,function(i,a){n.push(tt(i))}),n.length&&this.api.dispatchAction({type:"dataZoom",from:this.uid,batch:n})},t.getDefaultOption=function(e){var n={show:!0,filterMode:"filter",icon:{zoom:"M0,13.5h26.9 M13.5,26.9V0 M32.1,13.5H58V58H13.5 V32.1",back:"M22,1.4L9.9,13.5l12.3,12.3 M10.3,13.5H54.9v44.6 H10.3v-26"},title:e.getLocaleModel().get(["toolbox","dataZoom","title"]),brushStyle:{borderWidth:0,color:"rgba(210,219,238,0.2)"}};return n},t}(Le),oR={zoom:function(){var r=!this._isZoomActive;this.api.dispatchAction({type:"takeGlobalCursor",key:"dataZoomSelect",dataZoomSelectActive:r})},back:function(){this._dispatchZoomAction(QP(this.ecModel))}};function Rv(r){var t={xAxisIndex:r.get("xAxisIndex",!0),yAxisIndex:r.get("yAxisIndex",!0),xAxisId:r.get("xAxisId",!0),yAxisId:r.get("yAxisId",!0)};return t.xAxisIndex==null&&t.xAxisId==null&&(t.xAxisIndex="all"),t.yAxisIndex==null&&t.yAxisId==null&&(t.yAxisIndex="all"),t}function sR(r,t){r.setIconStatus("back",jP(t)>1?"emphasis":"normal")}function lR(r,t,e,n,i){var a=e._isZoomActive;n&&n.type==="takeGlobalCursor"&&(a=n.key==="dataZoomSelect"?n.dataZoomSelectActive:!1),e._isZoomActive=a,r.setIconStatus("zoom",a?"emphasis":"normal");var o=new iS(Rv(r),t,{include:["grid"]}),s=o.makePanelOpts(i,function(l){return l.xAxisDeclared&&!l.yAxisDeclared?"lineX":!l.xAxisDeclared&&l.yAxisDeclared?"lineY":"rect"});e._brushController.setPanels(s).enableBrush(a&&s.length?{brushType:"auto",brushStyle:r.getModel("brushStyle").getItemStyle()}:!1)}xC("dataZoom",function(r){var t=r.getComponent("toolbox",0),e=["feature","dataZoom"];if(!t||t.get(e)==null)return;var n=t.getModel(e),i=[],a=Rv(n),o=xa(r,a);fh(o.xAxisModels,function(l){return s(l,"xAxis","xAxisIndex")}),fh(o.yAxisModels,function(l){return s(l,"yAxis","yAxisIndex")});function s(l,u,f){var h=l.componentIndex,c={type:"select",$fromToolbox:!0,filterMode:n.get("filterMode",!0)||"filter",id:iR+u+h};c[f]=h,i.push(c)}return i});function uR(r){r.registerComponentModel(EP),r.registerComponentView(OP),ia("saveAsImage",NP),ia("magicType",zP),ia("dataView",$P),ia("dataZoom",aR),ia("restore",tR),ke(RP)}var fR=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="tooltip",t.dependencies=["axisPointer"],t.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,displayMode:"single",renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,enterable:!1,backgroundColor:"#fff",shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:"#999",width:1,type:"dashed",textStyle:{}}},textStyle:{color:"#666",fontSize:14}},t}(ht);function aS(r){var t=r.get("confine");return t!=null?!!t:r.get("renderMode")==="richText"}function oS(r){if(J.domSupported){for(var t=document.documentElement.style,e=0,n=r.length;e<n;e++)if(r[e]in t)return r[e]}}var sS=oS(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),hR=oS(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function lS(r,t){if(!r)return t;t=a0(t,!0);var e=r.indexOf(t);return r=e===-1?t:"-"+r.slice(0,e)+"-"+t,r.toLowerCase()}function vR(r,t){var e=r.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(r);return e?e[t]:null}var cR=lS(hR,"transition"),Ev=lS(sS,"transform"),dR="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(J.transform3dSupported?"will-change:transform;":"");function pR(r){return r=r==="left"?"right":r==="right"?"left":r==="top"?"bottom":"top",r}function gR(r,t,e){if(!W(e)||e==="inside")return"";var n=r.get("backgroundColor"),i=r.get("borderWidth");t=An(t);var a=pR(e),o=Math.max(Math.round(i)*1.5,6),s="",l=Ev+":",u;lt(["left","right"],a)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=a==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=a==="top"?225:45)+"deg)");var f=u*Math.PI/180,h=o+i,c=h*Math.abs(Math.cos(f))+h*Math.abs(Math.sin(f)),v=Math.round(((c-Math.SQRT2*i)/2+Math.SQRT2*i-(c-h)/2)*100)/100;s+=";"+a+":-"+v+"px";var d=t+" solid "+i+"px;",p=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+d,"border-right:"+d,"background-color:"+n+";"];return'<div style="'+p.join("")+'"></div>'}function yR(r,t){var e="cubic-bezier(0.23,1,0.32,1)",n=" "+r/2+"s "+e,i="opacity"+n+",visibility"+n;return t||(n=" "+r+"s "+e,i+=J.transformSupported?","+Ev+n:",left"+n+",top"+n),cR+":"+i}function Ng(r,t,e){var n=r.toFixed(0)+"px",i=t.toFixed(0)+"px";if(!J.transformSupported)return e?"top:"+i+";left:"+n+";":[["top",i],["left",n]];var a=J.transform3dSupported,o="translate"+(a?"3d":"")+"("+n+","+i+(a?",0":"")+")";return e?"top:0;left:0;"+Ev+":"+o+";":[["top",0],["left",0],[sS,o]]}function mR(r){var t=[],e=r.get("fontSize"),n=r.getTextColor();n&&t.push("color:"+n),t.push("font:"+r.getFont());var i=rt(r.get("lineHeight"),Math.round(e*3/2));e&&t.push("line-height:"+i+"px");var a=r.get("textShadowColor"),o=r.get("textShadowBlur")||0,s=r.get("textShadowOffsetX")||0,l=r.get("textShadowOffsetY")||0;return a&&o&&t.push("text-shadow:"+s+"px "+l+"px "+o+"px "+a),M(["decoration","align"],function(u){var f=r.get(u);f&&t.push("text-"+u+":"+f)}),t.join(";")}function _R(r,t,e){var n=[],i=r.get("transitionDuration"),a=r.get("backgroundColor"),o=r.get("shadowBlur"),s=r.get("shadowColor"),l=r.get("shadowOffsetX"),u=r.get("shadowOffsetY"),f=r.getModel("textStyle"),h=B0(r,"html"),c=l+"px "+u+"px "+o+"px "+s;return n.push("box-shadow:"+c),t&&i&&n.push(yR(i,e)),a&&n.push("background-color:"+a),M(["width","color","radius"],function(v){var d="border-"+v,p=a0(d),g=r.get(p);g!=null&&n.push(d+":"+g+(v==="color"?"":"px"))}),n.push(mR(f)),h!=null&&n.push("padding:"+fl(h).join("px ")+"px"),n.join(";")+";"}function Fg(r,t,e,n,i){var a=t&&t.painter;if(e){var o=a&&a.getViewportRoot();o&&gx(r,o,e,n,i)}else{r[0]=n,r[1]=i;var s=a&&a.getViewportRootOffset();s&&(r[0]+=s.offsetLeft,r[1]+=s.offsetTop)}r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var SR=function(){function r(t,e){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,J.wxa)return null;var n=document.createElement("div");n.domBelongToZr=!0,this.el=n;var i=this._zr=t.getZr(),a=e.appendTo,o=a&&(W(a)?document.querySelector(a):_i(a)?a:q(a)&&a(t.getDom()));Fg(this._styleCoord,i,o,t.getWidth()/2,t.getHeight()/2),(o||t.getDom()).appendChild(n),this._api=t,this._container=o;var s=this;n.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},n.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=i.handler,f=i.painter.getViewportRoot();ve(f,l,!0),u.dispatch("mousemove",l)}},n.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return r.prototype.update=function(t){if(!this._container){var e=this._api.getDom(),n=vR(e,"position"),i=e.style;i.position!=="absolute"&&n!=="absolute"&&(i.position="relative")}var a=t.get("alwaysShowContent");a&&this._moveIfResized(),this._alwaysShowContent=a,this.el.className=t.get("className")||""},r.prototype.show=function(t,e){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var n=this.el,i=n.style,a=this._styleCoord;n.innerHTML?i.cssText=dR+_R(t,!this._firstShow,this._longHide)+Ng(a[0],a[1],!0)+("border-color:"+An(e)+";")+(t.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):i.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},r.prototype.setContent=function(t,e,n,i,a){var o=this.el;if(t==null){o.innerHTML="";return}var s="";if(W(a)&&n.get("trigger")==="item"&&!aS(n)&&(s=gR(n,i,a)),W(t))o.innerHTML=t+s;else if(t){o.innerHTML="",V(t)||(t=[t]);for(var l=0;l<t.length;l++)_i(t[l])&&t[l].parentNode!==o&&o.appendChild(t[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el;return t?[t.offsetWidth,t.offsetHeight]:[0,0]},r.prototype.moveTo=function(t,e){if(this.el){var n=this._styleCoord;if(Fg(n,this._zr,this._container,t,e),n[0]!=null&&n[1]!=null){var i=this.el.style,a=Ng(n[0],n[1]);M(a,function(o){i[o[0]]=o[1]})}}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){var t=this,e=this.el.style;e.visibility="hidden",e.opacity="0",J.transform3dSupported&&(e.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return t._longHide=!0},500)},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout(dt(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var t=this.el.parentNode;t&&t.removeChild(this.el),this.el=this._container=null},r}(),xR=function(){function r(t){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=t.getZr(),Vg(this._styleCoord,this._zr,t.getWidth()/2,t.getHeight()/2)}return r.prototype.update=function(t){var e=t.get("alwaysShowContent");e&&this._moveIfResized(),this._alwaysShowContent=e},r.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},r.prototype.setContent=function(t,e,n,i,a){var o=this;Y(t)&&ft(""),this.el&&this._zr.remove(this.el);var s=n.getModel("textStyle");this.el=new Ct({style:{rich:e.richTextStyles,text:t,lineHeight:22,borderWidth:1,borderColor:i,textShadowColor:s.get("textShadowColor"),fill:n.get(["textStyle","color"]),padding:B0(n,"richText"),verticalAlign:"top",align:"left"},z:n.get("z")}),M(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=n.get(u)}),M(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el,e=this.el.getBoundingRect(),n=zg(t.style);return[e.width+n.left+n.right,e.height+n.top+n.bottom]},r.prototype.moveTo=function(t,e){var n=this.el;if(n){var i=this._styleCoord;Vg(i,this._zr,t,e),t=i[0],e=i[1];var a=n.style,o=Pr(a.borderWidth||0),s=zg(a);n.x=t+o+s.left,n.y=e+o+s.top,n.markRedraw()}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout(dt(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){this._zr.remove(this.el)},r}();function Pr(r){return Math.max(0,r)}function zg(r){var t=Pr(r.shadowBlur||0),e=Pr(r.shadowOffsetX||0),n=Pr(r.shadowOffsetY||0);return{left:Pr(t-e),right:Pr(t+e),top:Pr(t-n),bottom:Pr(t+n)}}function Vg(r,t,e,n){r[0]=e,r[1]=n,r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var wR=new St({shape:{x:-1,y:-1,width:2,height:2}}),bR=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,n){if(!(J.node||!n.getDom())){var i=e.getComponent("tooltip"),a=this._renderMode=Hw(i.get("renderMode"));this._tooltipContent=a==="richText"?new xR(n):new SR(n,{appendTo:i.get("appendToBody",!0)?"body":i.get("appendTo",!0)})}},t.prototype.render=function(e,n,i){if(!(J.node||!i.getDom())){this.group.removeAll(),this._tooltipModel=e,this._ecModel=n,this._api=i;var a=this._tooltipContent;a.update(e),a.setEnterable(e.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&e.get("transitionDuration")?F0(this,"_updatePosition",50,"fixRate"):zf(this,"_updatePosition")}},t.prototype._initGlobalListener=function(){var e=this._tooltipModel,n=e.get("triggerOn");K1("itemTooltip",this._api,dt(function(i,a,o){n!=="none"&&(n.indexOf(i)>=0?this._tryShow(a,o):i==="leave"&&this._hide(o))},this))},t.prototype._keepShow=function(){var e=this._tooltipModel,n=this._ecModel,i=this._api,a=e.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&a!=="none"&&a!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!i.isDisposed()&&o.manuallyShowTip(e,n,i,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},t.prototype.manuallyShowTip=function(e,n,i,a){if(!(a.from===this.uid||J.node||!i.getDom())){var o=Gg(a,i);this._ticket="";var s=a.dataByCoordSys,l=AR(a,n,i);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:a.position,positionDefault:"bottom"},o)}else if(a.tooltip&&a.x!=null&&a.y!=null){var f=wR;f.x=a.x,f.y=a.y,f.update(),st(f).tooltipConfig={name:null,option:a.tooltip},this._tryShow({offsetX:a.x,offsetY:a.y,target:f},o)}else if(s)this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,dataByCoordSys:s,tooltipOption:a.tooltipOption},o);else if(a.seriesIndex!=null){if(this._manuallyAxisShowTip(e,n,i,a))return;var h=Q1(a,n),c=h.point[0],v=h.point[1];c!=null&&v!=null&&this._tryShow({offsetX:c,offsetY:v,target:h.el,position:a.position,positionDefault:"bottom"},o)}else a.x!=null&&a.y!=null&&(i.dispatchAction({type:"updateAxisPointer",x:a.x,y:a.y}),this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,target:i.getZr().findHover(a.x,a.y).target},o))}},t.prototype.manuallyHideTip=function(e,n,i,a){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,a.from!==this.uid&&this._hide(Gg(a,i))},t.prototype._manuallyAxisShowTip=function(e,n,i,a){var o=a.seriesIndex,s=a.dataIndex,l=n.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=n.getSeriesByIndex(o);if(u){var f=u.getData(),h=aa([f.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(h.get("trigger")==="axis")return i.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:a.position}),!0}}},t.prototype._tryShow=function(e,n){var i=e.target,a=this._tooltipModel;if(a){this._lastX=e.offsetX,this._lastY=e.offsetY;var o=e.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,e);else if(i){var s=st(i);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;ca(i,function(f){if(st(f).dataIndex!=null)return l=f,!0;if(st(f).tooltipConfig!=null)return u=f,!0},!0),l?this._showSeriesItemTooltip(e,l,n):u?this._showComponentItemTooltip(e,u,n):this._hide(n)}else this._lastDataByCoordSys=null,this._hide(n)}},t.prototype._showOrMove=function(e,n){var i=e.get("showDelay");n=dt(n,this),clearTimeout(this._showTimout),i>0?this._showTimout=setTimeout(n,i):n()},t.prototype._showAxisTooltip=function(e,n){var i=this._ecModel,a=this._tooltipModel,o=[n.offsetX,n.offsetY],s=aa([n.tooltipOption],a),l=this._renderMode,u=[],f=Mn("section",{blocks:[],noHeader:!0}),h=[],c=new pu;M(e,function(m){M(m.dataByAxis,function(_){var S=i.getComponent(_.axisDim+"Axis",_.axisIndex),w=_.value;if(!(!S||w==null)){var x=$1(w,S.axis,i,_.seriesDataIndices,_.valueLabelOpt),b=Mn("section",{header:x,noHeader:!Ze(x),sortBlocks:!0,blocks:[]});f.blocks.push(b),M(_.seriesDataIndices,function(T){var C=i.getSeriesByIndex(T.seriesIndex),D=T.dataIndexInside,A=C.getDataParams(D);if(!(A.dataIndex<0)){A.axisDim=_.axisDim,A.axisIndex=_.axisIndex,A.axisType=_.axisType,A.axisId=_.axisId,A.axisValue=gv(S.axis,{value:w}),A.axisValueLabel=x,A.marker=c.makeTooltipMarker("item",An(A.color),l);var I=Td(C.formatTooltip(D,!0,null)),L=I.frag;if(L){var P=aa([C],a).get("valueFormatter");b.blocks.push(P?F({valueFormatter:P},L):L)}I.text&&h.push(I.text),u.push(A)}})}})}),f.blocks.reverse(),h.reverse();var v=n.position,d=s.get("order"),p=Ld(f,c,l,d,i.get("useUTC"),s.get("textStyle"));p&&h.unshift(p);var g=l==="richText"?`

`:"<br/>",y=h.join(g);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(e,u)?this._updatePosition(s,v,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,y,u,Math.random()+"",o[0],o[1],v,null,c)})},t.prototype._showSeriesItemTooltip=function(e,n,i){var a=this._ecModel,o=st(n),s=o.seriesIndex,l=a.getSeriesByIndex(s),u=o.dataModel||l,f=o.dataIndex,h=o.dataType,c=u.getData(h),v=this._renderMode,d=e.positionDefault,p=aa([c.getItemModel(f),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,d?{position:d}:null),g=p.get("trigger");if(!(g!=null&&g!=="item")){var y=u.getDataParams(f,h),m=new pu;y.marker=m.makeTooltipMarker("item",An(y.color),v);var _=Td(u.formatTooltip(f,!1,h)),S=p.get("order"),w=p.get("valueFormatter"),x=_.frag,b=x?Ld(w?F({valueFormatter:w},x):x,m,v,S,a.get("useUTC"),p.get("textStyle")):_.text,T="item_"+u.name+"_"+f;this._showOrMove(p,function(){this._showTooltipContent(p,b,y,T,e.offsetX,e.offsetY,e.position,e.target,m)}),i({type:"showTip",dataIndexInside:f,dataIndex:c.getRawIndex(f),seriesIndex:s,from:this.uid})}},t.prototype._showComponentItemTooltip=function(e,n,i){var a=this._renderMode==="html",o=st(n),s=o.tooltipConfig,l=s.option||{},u=l.encodeHTMLContent;if(W(l)){var f=l;l={content:f,formatter:f},u=!0}u&&a&&l.content&&(l=tt(l),l.content=re(l.content));var h=[l],c=this._ecModel.getComponent(o.componentMainType,o.componentIndex);c&&h.push(c),h.push({formatter:l.content});var v=e.positionDefault,d=aa(h,this._tooltipModel,v?{position:v}:null),p=d.get("content"),g=Math.random()+"",y=new pu;this._showOrMove(d,function(){var m=tt(d.get("formatterParams")||{});this._showTooltipContent(d,p,m,g,e.offsetX,e.offsetY,e.position,n,y)}),i({type:"showTip",from:this.uid})},t.prototype._showTooltipContent=function(e,n,i,a,o,s,l,u,f){if(this._ticket="",!(!e.get("showContent")||!e.get("show"))){var h=this._tooltipContent;h.setEnterable(e.get("enterable"));var c=e.get("formatter");l=l||e.get("position");var v=n,d=this._getNearestPoint([o,s],i,e.get("trigger"),e.get("borderColor")),p=d.color;if(c)if(W(c)){var g=e.ecModel.get("useUTC"),y=V(i)?i[0]:i,m=y&&y.axisType&&y.axisType.indexOf("time")>=0;v=c,m&&(v=al(y.axisValue,v,g)),v=o0(v,i,!0)}else if(q(c)){var _=dt(function(S,w){S===this._ticket&&(h.setContent(w,f,e,p,l),this._updatePosition(e,l,o,s,h,i,u))},this);this._ticket=a,v=c(i,a,_)}else v=c;h.setContent(v,f,e,p,l),h.show(e,p),this._updatePosition(e,l,o,s,h,i,u)}},t.prototype._getNearestPoint=function(e,n,i,a){if(i==="axis"||V(n))return{color:a||(this._renderMode==="html"?"#fff":"none")};if(!V(n))return{color:a||n.color||n.borderColor}},t.prototype._updatePosition=function(e,n,i,a,o,s,l){var u=this._api.getWidth(),f=this._api.getHeight();n=n||e.get("position");var h=o.getSize(),c=e.get("align"),v=e.get("verticalAlign"),d=l&&l.getBoundingRect().clone();if(l&&d.applyTransform(l.transform),q(n)&&(n=n([i,a],s,o.el,d,{viewSize:[u,f],contentSize:h.slice()})),V(n))i=Z(n[0],u),a=Z(n[1],f);else if(Y(n)){var p=n;p.width=h[0],p.height=h[1];var g=Ur(p,{width:u,height:f});i=g.x,a=g.y,c=null,v=null}else if(W(n)&&l){var y=DR(n,d,h,e.get("borderWidth"));i=y[0],a=y[1]}else{var y=TR(i,a,o,u,f,c?null:20,v?null:20);i=y[0],a=y[1]}if(c&&(i-=Hg(c)?h[0]/2:c==="right"?h[0]:0),v&&(a-=Hg(v)?h[1]/2:v==="bottom"?h[1]:0),aS(e)){var y=CR(i,a,o,u,f);i=y[0],a=y[1]}o.moveTo(i,a)},t.prototype._updateContentNotChangedOnAxis=function(e,n){var i=this._lastDataByCoordSys,a=this._cbParamsList,o=!!i&&i.length===e.length;return o&&M(i,function(s,l){var u=s.dataByAxis||[],f=e[l]||{},h=f.dataByAxis||[];o=o&&u.length===h.length,o&&M(u,function(c,v){var d=h[v]||{},p=c.seriesDataIndices||[],g=d.seriesDataIndices||[];o=o&&c.value===d.value&&c.axisType===d.axisType&&c.axisId===d.axisId&&p.length===g.length,o&&M(p,function(y,m){var _=g[m];o=o&&y.seriesIndex===_.seriesIndex&&y.dataIndex===_.dataIndex}),a&&M(c.seriesDataIndices,function(y){var m=y.seriesIndex,_=n[m],S=a[m];_&&S&&S.data!==_.data&&(o=!1)})})}),this._lastDataByCoordSys=e,this._cbParamsList=n,!!o},t.prototype._hide=function(e){this._lastDataByCoordSys=null,e({type:"hideTip",from:this.uid})},t.prototype.dispose=function(e,n){J.node||!n.getDom()||(zf(this,"_updatePosition"),this._tooltipContent.dispose(),sh("itemTooltip",n))},t.type="tooltip",t}(Jt);function aa(r,t,e){var n=t.ecModel,i;e?(i=new wt(e,n,n),i=new wt(t.option,i,n)):i=t;for(var a=r.length-1;a>=0;a--){var o=r[a];o&&(o instanceof wt&&(o=o.get("tooltip",!0)),W(o)&&(o={formatter:o}),o&&(i=new wt(o,i,n)))}return i}function Gg(r,t){return r.dispatchAction||dt(t.dispatchAction,t)}function TR(r,t,e,n,i,a,o){var s=e.getSize(),l=s[0],u=s[1];return a!=null&&(r+l+a+2>n?r-=l+a:r+=a),o!=null&&(t+u+o>i?t-=u+o:t+=o),[r,t]}function CR(r,t,e,n,i){var a=e.getSize(),o=a[0],s=a[1];return r=Math.min(r+o,n)-o,t=Math.min(t+s,i)-s,r=Math.max(r,0),t=Math.max(t,0),[r,t]}function DR(r,t,e,n){var i=e[0],a=e[1],o=Math.ceil(Math.SQRT2*n)+8,s=0,l=0,u=t.width,f=t.height;switch(r){case"inside":s=t.x+u/2-i/2,l=t.y+f/2-a/2;break;case"top":s=t.x+u/2-i/2,l=t.y-a-o;break;case"bottom":s=t.x+u/2-i/2,l=t.y+f+o;break;case"left":s=t.x-i-o,l=t.y+f/2-a/2;break;case"right":s=t.x+u+o,l=t.y+f/2-a/2}return[s,l]}function Hg(r){return r==="center"||r==="middle"}function AR(r,t,e){var n=Ph(r).queryOptionMap,i=n.keys()[0];if(!(!i||i==="series")){var a=Ja(t,i,n.get(i),{useDefault:!1,enableAll:!1,enableNone:!1}),o=a.models[0];if(o){var s=e.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var f=st(u).tooltipConfig;if(f&&f.name===r.name)return l=u,!0}),l)return{componentMainType:i,componentIndex:o.componentIndex,el:l}}}}function MR(r){ke(J1),r.registerComponentModel(fR),r.registerComponentView(bR),r.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},qt),r.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},qt)}var IR=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode={type:"box",ignoreSize:!0},e}return t.type="title",t.defaultOption={z:6,show:!0,text:"",target:"blank",subtext:"",subtarget:"blank",left:0,top:0,backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderWidth:0,padding:5,itemGap:10,textStyle:{fontSize:18,fontWeight:"bold",color:"#464646"},subtextStyle:{fontSize:12,color:"#6E7079"}},t}(ht),LR=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,n,i){if(this.group.removeAll(),!!e.get("show")){var a=this.group,o=e.getModel("textStyle"),s=e.getModel("subtextStyle"),l=e.get("textAlign"),u=rt(e.get("textBaseline"),e.get("textVerticalAlign")),f=new Ct({style:ye(o,{text:e.get("text"),fill:o.getTextColor()},{disableBox:!0}),z2:10}),h=f.getBoundingRect(),c=e.get("subtext"),v=new Ct({style:ye(s,{text:c,fill:s.getTextColor(),y:h.height+e.get("itemGap"),verticalAlign:"top"},{disableBox:!0}),z2:10}),d=e.get("link"),p=e.get("sublink"),g=e.get("triggerEvent",!0);f.silent=!d&&!g,v.silent=!p&&!g,d&&f.on("click",function(){od(d,"_"+e.get("target"))}),p&&v.on("click",function(){od(p,"_"+e.get("subtarget"))}),st(f).eventData=st(v).eventData=g?{componentType:"title",componentIndex:e.componentIndex}:null,a.add(f),c&&a.add(v);var y=a.getBoundingRect(),m=e.getBoxLayoutParams();m.width=y.width,m.height=y.height;var _=Ur(m,{width:i.getWidth(),height:i.getHeight()},e.get("padding"));l||(l=e.get("left")||e.get("right"),l==="middle"&&(l="center"),l==="right"?_.x+=_.width:l==="center"&&(_.x+=_.width/2)),u||(u=e.get("top")||e.get("bottom"),u==="center"&&(u="middle"),u==="bottom"?_.y+=_.height:u==="middle"&&(_.y+=_.height/2),u=u||"top"),a.x=_.x,a.y=_.y,a.markRedraw();var S={align:l,verticalAlign:u};f.setStyle(S),v.setStyle(S),y=a.getBoundingRect();var w=_.margin,x=e.getItemStyle(["color","opacity"]);x.fill=e.get("backgroundColor");var b=new St({shape:{x:y.x-w[3],y:y.y-w[0],width:y.width+w[1]+w[3],height:y.height+w[0]+w[2],r:e.get("borderRadius")},style:x,subPixelOptimize:!0,silent:!0});a.add(b)}},t.type="title",t}(Jt);function PR(r){r.registerComponentModel(IR),r.registerComponentView(LR)}var RR=function(r,t){if(t==="all")return{type:"all",title:r.getLocaleModel().get(["legend","selector","all"])};if(t==="inverse")return{type:"inverse",title:r.getLocaleModel().get(["legend","selector","inverse"])}},hh=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode={type:"box",ignoreSize:!0},e}return t.prototype.init=function(e,n,i){this.mergeDefaultAndTheme(e,i),e.selected=e.selected||{},this._updateSelector(e)},t.prototype.mergeOption=function(e,n){r.prototype.mergeOption.call(this,e,n),this._updateSelector(e)},t.prototype._updateSelector=function(e){var n=e.selector,i=this.ecModel;n===!0&&(n=e.selector=["all","inverse"]),V(n)&&M(n,function(a,o){W(a)&&(a={type:a}),n[o]=nt(a,RR(i,a.type))})},t.prototype.optionUpdated=function(){this._updateData(this.ecModel);var e=this._data;if(e[0]&&this.get("selectedMode")==="single"){for(var n=!1,i=0;i<e.length;i++){var a=e[i].get("name");if(this.isSelected(a)){this.select(a),n=!0;break}}!n&&this.select(e[0].get("name"))}},t.prototype._updateData=function(e){var n=[],i=[];e.eachRawSeries(function(l){var u=l.name;i.push(u);var f;if(l.legendVisualProvider){var h=l.legendVisualProvider,c=h.getAllNames();e.isSeriesFiltered(l)||(i=i.concat(c)),c.length?n=n.concat(c):f=!0}else f=!0;f&&Lh(l)&&n.push(l.name)}),this._availableNames=i;var a=this.get("data")||n,o=$(),s=H(a,function(l){return(W(l)||ct(l))&&(l={name:l}),o.get(l.name)?null:(o.set(l.name,!0),new wt(l,this,this.ecModel))},this);this._data=Tt(s,function(l){return!!l})},t.prototype.getData=function(){return this._data},t.prototype.select=function(e){var n=this.option.selected,i=this.get("selectedMode");if(i==="single"){var a=this._data;M(a,function(o){n[o.get("name")]=!1})}n[e]=!0},t.prototype.unSelect=function(e){this.get("selectedMode")!=="single"&&(this.option.selected[e]=!1)},t.prototype.toggleSelected=function(e){var n=this.option.selected;n.hasOwnProperty(e)||(n[e]=!0),this[n[e]?"unSelect":"select"](e)},t.prototype.allSelect=function(){var e=this._data,n=this.option.selected;M(e,function(i){n[i.get("name",!0)]=!0})},t.prototype.inverseSelect=function(){var e=this._data,n=this.option.selected;M(e,function(i){var a=i.get("name",!0);n.hasOwnProperty(a)||(n[a]=!0),n[a]=!n[a]})},t.prototype.isSelected=function(e){var n=this.option.selected;return!(n.hasOwnProperty(e)&&!n[e])&&lt(this._availableNames,e)>=0},t.prototype.getOrient=function(){return this.get("orient")==="vertical"?{index:1,name:"vertical"}:{index:0,name:"horizontal"}},t.type="legend.plain",t.dependencies=["series"],t.defaultOption={z:4,show:!0,orient:"horizontal",left:"center",top:0,align:"auto",backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemGap:10,itemWidth:25,itemHeight:14,symbolRotate:"inherit",symbolKeepAspect:!0,inactiveColor:"#ccc",inactiveBorderColor:"#ccc",inactiveBorderWidth:"auto",itemStyle:{color:"inherit",opacity:"inherit",borderColor:"inherit",borderWidth:"auto",borderCap:"inherit",borderJoin:"inherit",borderDashOffset:"inherit",borderMiterLimit:"inherit"},lineStyle:{width:"auto",color:"inherit",inactiveColor:"#ccc",inactiveWidth:2,opacity:"inherit",type:"inherit",cap:"inherit",join:"inherit",dashOffset:"inherit",miterLimit:"inherit"},textStyle:{color:"#333"},selectedMode:!0,selector:!1,selectorLabel:{show:!0,borderRadius:10,padding:[3,5,3,5],fontSize:12,fontFamily:"sans-serif",color:"#666",borderWidth:1,borderColor:"#666"},emphasis:{selectorLabel:{show:!0,color:"#eee",backgroundColor:"#666"}},selectorPosition:"auto",selectorItemGap:7,selectorButtonGap:10,tooltip:{show:!1}},t}(ht),Qn=vt,vh=M,Uo=yt,uS=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.newlineDisabled=!1,e}return t.prototype.init=function(){this.group.add(this._contentGroup=new Uo),this.group.add(this._selectorGroup=new Uo),this._isFirstRender=!0},t.prototype.getContentGroup=function(){return this._contentGroup},t.prototype.getSelectorGroup=function(){return this._selectorGroup},t.prototype.render=function(e,n,i){var a=this._isFirstRender;if(this._isFirstRender=!1,this.resetInner(),!!e.get("show",!0)){var o=e.get("align"),s=e.get("orient");(!o||o==="auto")&&(o=e.get("left")==="right"&&s==="vertical"?"right":"left");var l=e.get("selector",!0),u=e.get("selectorPosition",!0);l&&(!u||u==="auto")&&(u=s==="horizontal"?"end":"start"),this.renderInner(o,e,n,i,l,s,u);var f=e.getBoxLayoutParams(),h={width:i.getWidth(),height:i.getHeight()},c=e.get("padding"),v=Ur(f,h,c),d=this.layoutInner(e,o,v,a,l,u),p=Ur(Q({width:d.width,height:d.height},f),h,c);this.group.x=p.x-d.x,this.group.y=p.y-d.y,this.group.markRedraw(),this.group.add(this._backgroundEl=eS(d,e))}},t.prototype.resetInner=function(){this.getContentGroup().removeAll(),this._backgroundEl&&this.group.remove(this._backgroundEl),this.getSelectorGroup().removeAll()},t.prototype.renderInner=function(e,n,i,a,o,s,l){var u=this.getContentGroup(),f=$(),h=n.get("selectedMode"),c=[];i.eachRawSeries(function(v){!v.get("legendHoverLink")&&c.push(v.id)}),vh(n.getData(),function(v,d){var p=v.get("name");if(!this.newlineDisabled&&(p===""||p===`
`)){var g=new Uo;g.newline=!0,u.add(g);return}var y=i.getSeriesByName(p)[0];if(!f.get(p))if(y){var m=y.getData(),_=m.getVisual("legendLineStyle")||{},S=m.getVisual("legendIcon"),w=m.getVisual("style"),x=this._createItem(y,p,d,v,n,e,_,w,S,h,a);x.on("click",Qn(Wg,p,null,a,c)).on("mouseover",Qn(ch,y.name,null,a,c)).on("mouseout",Qn(dh,y.name,null,a,c)),i.ssr&&x.eachChild(function(b){var T=st(b);T.seriesIndex=y.seriesIndex,T.dataIndex=d,T.ssrType="legend"}),f.set(p,!0)}else i.eachRawSeries(function(b){if(!f.get(p)&&b.legendVisualProvider){var T=b.legendVisualProvider;if(!T.containName(p))return;var C=T.indexOfName(p),D=T.getItemVisual(C,"style"),A=T.getItemVisual(C,"legendIcon"),I=dr(D.fill);I&&I[3]===0&&(I[3]=.2,D=F(F({},D),{fill:Ws(I,"rgba")}));var L=this._createItem(b,p,d,v,n,e,{},D,A,h,a);L.on("click",Qn(Wg,null,p,a,c)).on("mouseover",Qn(ch,null,p,a,c)).on("mouseout",Qn(dh,null,p,a,c)),i.ssr&&L.eachChild(function(P){var R=st(P);R.seriesIndex=b.seriesIndex,R.dataIndex=d,R.ssrType="legend"}),f.set(p,!0)}},this)},this),o&&this._createSelector(o,n,a,s,l)},t.prototype._createSelector=function(e,n,i,a,o){var s=this.getSelectorGroup();vh(e,function(u){var f=u.type,h=new Ct({style:{x:0,y:0,align:"center",verticalAlign:"middle"},onclick:function(){i.dispatchAction({type:f==="all"?"legendAllSelect":"legendInverseSelect",legendId:n.id})}});s.add(h);var c=n.getModel("selectorLabel"),v=n.getModel(["emphasis","selectorLabel"]);Rn(h,{normal:c,emphasis:v},{defaultText:u.title}),Cf(h)})},t.prototype._createItem=function(e,n,i,a,o,s,l,u,f,h,c){var v=e.visualDrawType,d=o.get("itemWidth"),p=o.get("itemHeight"),g=o.isSelected(n),y=a.get("symbolRotate"),m=a.get("symbolKeepAspect"),_=a.get("icon");f=_||f||"roundRect";var S=ER(f,a,l,u,v,g,c),w=new Uo,x=a.getModel("textStyle");if(q(e.getLegendIcon)&&(!_||_==="inherit"))w.add(e.getLegendIcon({itemWidth:d,itemHeight:p,icon:f,iconRotate:y,itemStyle:S.itemStyle,lineStyle:S.lineStyle,symbolKeepAspect:m}));else{var b=_==="inherit"&&e.getData().getVisual("symbol")?y==="inherit"?e.getData().getVisual("symbolRotate"):y:0;w.add(kR({itemWidth:d,itemHeight:p,icon:f,iconRotate:b,itemStyle:S.itemStyle,symbolKeepAspect:m}))}var T=s==="left"?d+5:-5,C=s,D=o.get("formatter"),A=n;W(D)&&D?A=D.replace("{name}",n??""):q(D)&&(A=D(n));var I=g?x.getTextColor():a.get("inactiveColor");w.add(new Ct({style:ye(x,{text:A,x:T,y:p/2,fill:I,align:C,verticalAlign:"middle"},{inheritColor:I})}));var L=new St({shape:w.getBoundingRect(),style:{fill:"transparent"}}),P=a.getModel("tooltip");return P.get("show")&&ja({el:L,componentModel:o,itemName:n,itemTooltipOption:P.option}),w.add(L),w.eachChild(function(R){R.silent=!0}),L.silent=!h,this.getContentGroup().add(w),Cf(w),w.__legendDataIndex=i,w},t.prototype.layoutInner=function(e,n,i,a,o,s){var l=this.getContentGroup(),u=this.getSelectorGroup();yi(e.get("orient"),l,e.get("itemGap"),i.width,i.height);var f=l.getBoundingRect(),h=[-f.x,-f.y];if(u.markRedraw(),l.markRedraw(),o){yi("horizontal",u,e.get("selectorItemGap",!0));var c=u.getBoundingRect(),v=[-c.x,-c.y],d=e.get("selectorButtonGap",!0),p=e.getOrient().index,g=p===0?"width":"height",y=p===0?"height":"width",m=p===0?"y":"x";s==="end"?v[p]+=f[g]+d:h[p]+=c[g]+d,v[1-p]+=f[y]/2-c[y]/2,u.x=v[0],u.y=v[1],l.x=h[0],l.y=h[1];var _={x:0,y:0};return _[g]=f[g]+d+c[g],_[y]=Math.max(f[y],c[y]),_[m]=Math.min(0,c[m]+v[1-p]),_}else return l.x=h[0],l.y=h[1],this.group.getBoundingRect()},t.prototype.remove=function(){this.getContentGroup().removeAll(),this._isFirstRender=!0},t.type="legend.plain",t}(Jt);function ER(r,t,e,n,i,a,o){function s(g,y){g.lineWidth==="auto"&&(g.lineWidth=y.lineWidth>0?2:0),vh(g,function(m,_){g[_]==="inherit"&&(g[_]=y[_])})}var l=t.getModel("itemStyle"),u=l.getItemStyle(),f=r.lastIndexOf("empty",0)===0?"fill":"stroke",h=l.getShallow("decal");u.decal=!h||h==="inherit"?n.decal:Uf(h,o),u.fill==="inherit"&&(u.fill=n[i]),u.stroke==="inherit"&&(u.stroke=n[f]),u.opacity==="inherit"&&(u.opacity=(i==="fill"?n:e).opacity),s(u,n);var c=t.getModel("lineStyle"),v=c.getLineStyle();if(s(v,e),u.fill==="auto"&&(u.fill=n.fill),u.stroke==="auto"&&(u.stroke=n.fill),v.stroke==="auto"&&(v.stroke=n.fill),!a){var d=t.get("inactiveBorderWidth"),p=u[f];u.lineWidth=d==="auto"?n.lineWidth>0&&p?2:0:u.lineWidth,u.fill=t.get("inactiveColor"),u.stroke=t.get("inactiveBorderColor"),v.stroke=c.get("inactiveColor"),v.lineWidth=c.get("inactiveWidth")}return{itemStyle:u,lineStyle:v}}function kR(r){var t=r.icon||"roundRect",e=Ee(t,0,0,r.itemWidth,r.itemHeight,r.itemStyle.fill,r.symbolKeepAspect);return e.setStyle(r.itemStyle),e.rotation=(r.iconRotate||0)*Math.PI/180,e.setOrigin([r.itemWidth/2,r.itemHeight/2]),t.indexOf("empty")>-1&&(e.style.stroke=e.style.fill,e.style.fill="#fff",e.style.lineWidth=2),e}function Wg(r,t,e,n){dh(r,t,e,n),e.dispatchAction({type:"legendToggleSelect",name:r??t}),ch(r,t,e,n)}function fS(r){for(var t=r.getZr().storage.getDisplayList(),e,n=0,i=t.length;n<i&&!(e=t[n].states.emphasis);)n++;return e&&e.hoverLayer}function ch(r,t,e,n){fS(e)||e.dispatchAction({type:"highlight",seriesName:r,name:t,excludeSeriesId:n})}function dh(r,t,e,n){fS(e)||e.dispatchAction({type:"downplay",seriesName:r,name:t,excludeSeriesId:n})}function OR(r){var t=r.findComponents({mainType:"legend"});t&&t.length&&r.filterSeries(function(e){for(var n=0;n<t.length;n++)if(!t[n].isSelected(e.name))return!1;return!0})}function oa(r,t,e){var n=r==="allSelect"||r==="inverseSelect",i={},a=[];e.eachComponent({mainType:"legend",query:t},function(s){n?s[r]():s[r](t.name),Ug(s,i),a.push(s.componentIndex)});var o={};return e.eachComponent("legend",function(s){M(i,function(l,u){s[l?"select":"unSelect"](u)}),Ug(s,o)}),n?{selected:o,legendIndex:a}:{name:t.name,selected:o}}function Ug(r,t){var e=t||{};return M(r.getData(),function(n){var i=n.get("name");if(!(i===`
`||i==="")){var a=r.isSelected(i);tr(e,i)?e[i]=e[i]&&a:e[i]=a}}),e}function BR(r){r.registerAction("legendToggleSelect","legendselectchanged",vt(oa,"toggleSelected")),r.registerAction("legendAllSelect","legendselectall",vt(oa,"allSelect")),r.registerAction("legendInverseSelect","legendinverseselect",vt(oa,"inverseSelect")),r.registerAction("legendSelect","legendselected",vt(oa,"select")),r.registerAction("legendUnSelect","legendunselected",vt(oa,"unSelect"))}function hS(r){r.registerComponentModel(hh),r.registerComponentView(uS),r.registerProcessor(r.PRIORITY.PROCESSOR.SERIES_FILTER,OR),r.registerSubTypeDefaulter("legend",function(){return"plain"}),BR(r)}var NR=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.setScrollDataIndex=function(e){this.option.scrollDataIndex=e},t.prototype.init=function(e,n,i){var a=hl(e);r.prototype.init.call(this,e,n,i),Yg(this,e,a)},t.prototype.mergeOption=function(e,n){r.prototype.mergeOption.call(this,e,n),Yg(this,this.option,e)},t.type="legend.scroll",t.defaultOption=Yh(hh.defaultOption,{scrollDataIndex:0,pageButtonItemGap:5,pageButtonGap:null,pageButtonPosition:"end",pageFormatter:"{current}/{total}",pageIcons:{horizontal:["M0,0L12,-10L12,10z","M0,0L-12,-10L-12,10z"],vertical:["M0,0L20,0L10,-20z","M0,0L20,0L10,20z"]},pageIconColor:"#2f4554",pageIconInactiveColor:"#aaa",pageIconSize:15,pageTextStyle:{color:"#333"},animationDurationUpdate:800}),t}(hh);function Yg(r,t,e){var n=r.getOrient(),i=[1,1];i[n.index]=0,bi(t,e,{type:"box",ignoreSize:!!i})}var Xg=yt,Xu=["width","height"],Zu=["x","y"],FR=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.newlineDisabled=!0,e._currentIndex=0,e}return t.prototype.init=function(){r.prototype.init.call(this),this.group.add(this._containerGroup=new Xg),this._containerGroup.add(this.getContentGroup()),this.group.add(this._controllerGroup=new Xg)},t.prototype.resetInner=function(){r.prototype.resetInner.call(this),this._controllerGroup.removeAll(),this._containerGroup.removeClipPath(),this._containerGroup.__rectSize=null},t.prototype.renderInner=function(e,n,i,a,o,s,l){var u=this;r.prototype.renderInner.call(this,e,n,i,a,o,s,l);var f=this._controllerGroup,h=n.get("pageIconSize",!0),c=V(h)?h:[h,h];d("pagePrev",0);var v=n.getModel("pageTextStyle");f.add(new Ct({name:"pageText",style:{text:"xx/xx",fill:v.getTextColor(),font:v.getFont(),verticalAlign:"middle",align:"center"},silent:!0})),d("pageNext",1);function d(p,g){var y=p+"DataIndex",m=el(n.get("pageIcons",!0)[n.getOrient().name][g],{onclick:dt(u._pageGo,u,y,n,a)},{x:-c[0]/2,y:-c[1]/2,width:c[0],height:c[1]});m.name=p,f.add(m)}},t.prototype.layoutInner=function(e,n,i,a,o,s){var l=this.getSelectorGroup(),u=e.getOrient().index,f=Xu[u],h=Zu[u],c=Xu[1-u],v=Zu[1-u];o&&yi("horizontal",l,e.get("selectorItemGap",!0));var d=e.get("selectorButtonGap",!0),p=l.getBoundingRect(),g=[-p.x,-p.y],y=tt(i);o&&(y[f]=i[f]-p[f]-d);var m=this._layoutContentAndController(e,a,y,u,f,c,v,h);if(o){if(s==="end")g[u]+=m[f]+d;else{var _=p[f]+d;g[u]-=_,m[h]-=_}m[f]+=p[f]+d,g[1-u]+=m[v]+m[c]/2-p[c]/2,m[c]=Math.max(m[c],p[c]),m[v]=Math.min(m[v],p[v]+g[1-u]),l.x=g[0],l.y=g[1],l.markRedraw()}return m},t.prototype._layoutContentAndController=function(e,n,i,a,o,s,l,u){var f=this.getContentGroup(),h=this._containerGroup,c=this._controllerGroup;yi(e.get("orient"),f,e.get("itemGap"),a?i.width:null,a?null:i.height),yi("horizontal",c,e.get("pageButtonItemGap",!0));var v=f.getBoundingRect(),d=c.getBoundingRect(),p=this._showController=v[o]>i[o],g=[-v.x,-v.y];n||(g[a]=f[u]);var y=[0,0],m=[-d.x,-d.y],_=rt(e.get("pageButtonGap",!0),e.get("itemGap",!0));if(p){var S=e.get("pageButtonPosition",!0);S==="end"?m[a]+=i[o]-d[o]:y[a]+=d[o]+_}m[1-a]+=v[s]/2-d[s]/2,f.setPosition(g),h.setPosition(y),c.setPosition(m);var w={x:0,y:0};if(w[o]=p?i[o]:v[o],w[s]=Math.max(v[s],d[s]),w[l]=Math.min(0,d[l]+m[1-a]),h.__rectSize=i[o],p){var x={x:0,y:0};x[o]=Math.max(i[o]-d[o]-_,0),x[s]=w[s],h.setClipPath(new St({shape:x})),h.__rectSize=x[o]}else c.eachChild(function(T){T.attr({invisible:!0,silent:!0})});var b=this._getPageInfo(e);return b.pageIndex!=null&&bt(f,{x:b.contentPosition[0],y:b.contentPosition[1]},p?e:null),this._updatePageInfoView(e,b),w},t.prototype._pageGo=function(e,n,i){var a=this._getPageInfo(n)[e];a!=null&&i.dispatchAction({type:"legendScroll",scrollDataIndex:a,legendId:n.id})},t.prototype._updatePageInfoView=function(e,n){var i=this._controllerGroup;M(["pagePrev","pageNext"],function(f){var h=f+"DataIndex",c=n[h]!=null,v=i.childOfName(f);v&&(v.setStyle("fill",c?e.get("pageIconColor",!0):e.get("pageIconInactiveColor",!0)),v.cursor=c?"pointer":"default")});var a=i.childOfName("pageText"),o=e.get("pageFormatter"),s=n.pageIndex,l=s!=null?s+1:0,u=n.pageCount;a&&o&&a.setStyle("text",W(o)?o.replace("{current}",l==null?"":l+"").replace("{total}",u==null?"":u+""):o({current:l,total:u}))},t.prototype._getPageInfo=function(e){var n=e.get("scrollDataIndex",!0),i=this.getContentGroup(),a=this._containerGroup.__rectSize,o=e.getOrient().index,s=Xu[o],l=Zu[o],u=this._findTargetItemIndex(n),f=i.children(),h=f[u],c=f.length,v=c?1:0,d={contentPosition:[i.x,i.y],pageCount:v,pageIndex:v-1,pagePrevDataIndex:null,pageNextDataIndex:null};if(!h)return d;var p=S(h);d.contentPosition[o]=-p.s;for(var g=u+1,y=p,m=p,_=null;g<=c;++g)_=S(f[g]),(!_&&m.e>y.s+a||_&&!w(_,y.s))&&(m.i>y.i?y=m:y=_,y&&(d.pageNextDataIndex==null&&(d.pageNextDataIndex=y.i),++d.pageCount)),m=_;for(var g=u-1,y=p,m=p,_=null;g>=-1;--g)_=S(f[g]),(!_||!w(m,_.s))&&y.i<m.i&&(m=y,d.pagePrevDataIndex==null&&(d.pagePrevDataIndex=y.i),++d.pageCount,++d.pageIndex),y=_;return d;function S(x){if(x){var b=x.getBoundingRect(),T=b[l]+x[l];return{s:T,e:T+b[s],i:x.__legendDataIndex}}}function w(x,b){return x.e>=b&&x.s<=b+a}},t.prototype._findTargetItemIndex=function(e){if(!this._showController)return 0;var n,i=this.getContentGroup(),a;return i.eachChild(function(o,s){var l=o.__legendDataIndex;a==null&&l!=null&&(a=s),l===e&&(n=s)}),n??a},t.type="legend.scroll",t}(uS);function zR(r){r.registerAction("legendScroll","legendscroll",function(t,e){var n=t.scrollDataIndex;n!=null&&e.eachComponent({mainType:"legend",subType:"scroll",query:t},function(i){i.setScrollDataIndex(n)})})}function VR(r){ke(hS),r.registerComponentModel(NR),r.registerComponentView(FR),zR(r)}function GR(r){ke(hS),ke(VR)}var Zg={value:"eq","<":"lt","<=":"lte",">":"gt",">=":"gte","=":"eq","!=":"ne","<>":"ne"},HR=function(){function r(t){var e=this._condVal=W(t)?new RegExp(t):rx(t)?t:null;if(e==null){var n="";ft(n)}}return r.prototype.evaluate=function(t){var e=typeof t;return W(e)?this._condVal.test(t):ct(e)?this._condVal.test(t+""):!1},r}(),WR=function(){function r(){}return r.prototype.evaluate=function(){return this.value},r}(),UR=function(){function r(){}return r.prototype.evaluate=function(){for(var t=this.children,e=0;e<t.length;e++)if(!t[e].evaluate())return!1;return!0},r}(),YR=function(){function r(){}return r.prototype.evaluate=function(){for(var t=this.children,e=0;e<t.length;e++)if(t[e].evaluate())return!0;return!1},r}(),XR=function(){function r(){}return r.prototype.evaluate=function(){return!this.child.evaluate()},r}(),ZR=function(){function r(){}return r.prototype.evaluate=function(){for(var t=!!this.valueParser,e=this.getValue,n=e(this.valueGetterParam),i=t?this.valueParser(n):null,a=0;a<this.subCondList.length;a++)if(!this.subCondList[a].evaluate(t?i:n))return!1;return!0},r}();function kv(r,t){if(r===!0||r===!1){var e=new WR;return e.value=r,e}var n="";return vS(r)||ft(n),r.and?$g("and",r,t):r.or?$g("or",r,t):r.not?$R(r,t):qR(r,t)}function $g(r,t,e){var n=t[r],i="";V(n)||ft(i),n.length||ft(i);var a=r==="and"?new UR:new YR;return a.children=H(n,function(o){return kv(o,e)}),a.children.length||ft(i),a}function $R(r,t){var e=r.not,n="";vS(e)||ft(n);var i=new XR;return i.child=kv(e,t),i.child||ft(n),i}function qR(r,t){for(var e="",n=t.prepareGetValue(r),i=[],a=mt(r),o=r.parser,s=o?b0(o):null,l=0;l<a.length;l++){var u=a[l];if(!(u==="parser"||t.valueGetterAttrMap.get(u))){var f=tr(Zg,u)?Zg[u]:u,h=r[u],c=s?s(h):h,v=nD(f,c)||f==="reg"&&new HR(c);v||ft(e),i.push(v)}}i.length||ft(e);var d=new ZR;return d.valueGetterParam=n,d.valueParser=s,d.getValue=t.getValue,d.subCondList=i,d}function vS(r){return Y(r)&&!Kt(r)}var KR=function(){function r(t,e){this._cond=kv(t,e)}return r.prototype.evaluate=function(){return this._cond.evaluate()},r}();function QR(r,t){return new KR(r,t)}var JR={type:"echarts:filter",transform:function(r){for(var t=r.upstream,e,n=QR(r.config,{valueGetterAttrMap:$({dimension:!0}),prepareGetValue:function(s){var l="",u=s.dimension;tr(s,"dimension")||ft(l);var f=t.getDimensionInfo(u);return f||ft(l),{dimIdx:f.index}},getValue:function(s){return t.retrieveValueFromItem(e,s.dimIdx)}}),i=[],a=0,o=t.count();a<o;a++)e=t.getRawDataItem(a),n.evaluate()&&i.push(e);return{data:i}}},jR={type:"echarts:sort",transform:function(r){var t=r.upstream,e=r.config,n="",i=It(e);i.length||ft(n);var a=[];M(i,function(f){var h=f.dimension,c=f.order,v=f.parser,d=f.incomparable;if(h==null&&ft(n),c!=="asc"&&c!=="desc"&&ft(n),d&&d!=="min"&&d!=="max"){var p="";ft(p)}if(c!=="asc"&&c!=="desc"){var g="";ft(g)}var y=t.getDimensionInfo(h);y||ft(n);var m=v?b0(v):null;v&&!m&&ft(n),a.push({dimIdx:y.index,parser:m,comparator:new C0(c,d)})});var o=t.sourceFormat;o!==Qt&&o!==we&&ft(n);for(var s=[],l=0,u=t.count();l<u;l++)s.push(t.getRawDataItem(l));return s.sort(function(f,h){for(var c=0;c<a.length;c++){var v=a[c],d=t.retrieveValueFromItem(f,v.dimIdx),p=t.retrieveValueFromItem(h,v.dimIdx);v.parser&&(d=v.parser(d),p=v.parser(p));var g=v.comparator.evaluate(d,p);if(g!==0)return g}return 0}),{data:s}}};function tE(r){r.registerTransform(JR),r.registerTransform(jR)}var eE=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataset",e}return t.prototype.init=function(e,n,i){r.prototype.init.call(this,e,n,i),this._sourceManager=new I0(this),Md(this)},t.prototype.mergeOption=function(e,n){r.prototype.mergeOption.call(this,e,n),Md(this)},t.prototype.optionUpdated=function(){this._sourceManager.dirty()},t.prototype.getSourceManager=function(){return this._sourceManager},t.type="dataset",t.defaultOption={seriesLayoutBy:Je},t}(ht),rE=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataset",e}return t.type="dataset",t}(Jt);function nE(r){r.registerComponentModel(eE),r.registerComponentView(rE)}var Ue=yr.CMD;function si(r,t){return Math.abs(r-t)<1e-5}function ph(r){var t=r.data,e=r.len(),n=[],i,a=0,o=0,s=0,l=0;function u(L,P){i&&i.length>2&&n.push(i),i=[L,P]}function f(L,P,R,E){si(L,R)&&si(P,E)||i.push(L,P,R,E,R,E)}function h(L,P,R,E,O,k){var B=Math.abs(P-L),z=Math.tan(B/4)*4/3,G=P<L?-1:1,U=Math.cos(L),j=Math.sin(L),et=Math.cos(P),at=Math.sin(P),Rt=U*O+R,jt=j*k+E,Nt=et*O+R,Lt=at*k+E,xt=O*z*G,K=k*z*G;i.push(Rt-xt*j,jt+K*U,Nt+xt*at,Lt-K*et,Nt,Lt)}for(var c,v,d,p,g=0;g<e;){var y=t[g++],m=g===1;switch(m&&(a=t[g],o=t[g+1],s=a,l=o,(y===Ue.L||y===Ue.C||y===Ue.Q)&&(i=[s,l])),y){case Ue.M:a=s=t[g++],o=l=t[g++],u(s,l);break;case Ue.L:c=t[g++],v=t[g++],f(a,o,c,v),a=c,o=v;break;case Ue.C:i.push(t[g++],t[g++],t[g++],t[g++],a=t[g++],o=t[g++]);break;case Ue.Q:c=t[g++],v=t[g++],d=t[g++],p=t[g++],i.push(a+2/3*(c-a),o+2/3*(v-o),d+2/3*(c-d),p+2/3*(v-p),d,p),a=d,o=p;break;case Ue.A:var _=t[g++],S=t[g++],w=t[g++],x=t[g++],b=t[g++],T=t[g++]+b;g+=1;var C=!t[g++];c=Math.cos(b)*w+_,v=Math.sin(b)*x+S,m?(s=c,l=v,u(s,l)):f(a,o,c,v),a=Math.cos(T)*w+_,o=Math.sin(T)*x+S;for(var D=(C?-1:1)*Math.PI/2,A=b;C?A>T:A<T;A+=D){var I=C?Math.max(A+D,T):Math.min(A+D,T);h(A,I,_,S,w,x)}break;case Ue.R:s=a=t[g++],l=o=t[g++],c=s+t[g++],v=l+t[g++],u(c,l),f(c,l,c,v),f(c,v,s,v),f(s,v,s,l),f(s,l,c,l);break;case Ue.Z:i&&f(a,o,s,l),a=s,o=l;break}}return i&&i.length>2&&n.push(i),n}function gh(r,t,e,n,i,a,o,s,l,u){if(si(r,e)&&si(t,n)&&si(i,o)&&si(a,s)){l.push(o,s);return}var f=2/u,h=f*f,c=o-r,v=s-t,d=Math.sqrt(c*c+v*v);c/=d,v/=d;var p=e-r,g=n-t,y=i-o,m=a-s,_=p*p+g*g,S=y*y+m*m;if(_<h&&S<h){l.push(o,s);return}var w=c*p+v*g,x=-c*y-v*m,b=_-w*w,T=S-x*x;if(b<h&&w>=0&&T<h&&x>=0){l.push(o,s);return}var C=[],D=[];Vr(r,e,i,o,.5,C),Vr(t,n,a,s,.5,D),gh(C[0],D[0],C[1],D[1],C[2],D[2],C[3],D[3],l,u),gh(C[4],D[4],C[5],D[5],C[6],D[6],C[7],D[7],l,u)}function iE(r,t){var e=ph(r),n=[];t=t||1;for(var i=0;i<e.length;i++){var a=e[i],o=[],s=a[0],l=a[1];o.push(s,l);for(var u=2;u<a.length;){var f=a[u++],h=a[u++],c=a[u++],v=a[u++],d=a[u++],p=a[u++];gh(s,l,f,h,c,v,d,p,o,t),s=d,l=p}n.push(o)}return n}function cS(r,t,e){var n=r[t],i=r[1-t],a=Math.abs(n/i),o=Math.ceil(Math.sqrt(a*e)),s=Math.floor(e/o);s===0&&(s=1,o=e);for(var l=[],u=0;u<o;u++)l.push(s);var f=o*s,h=e-f;if(h>0)for(var u=0;u<h;u++)l[u%o]+=1;return l}function qg(r,t,e){for(var n=r.r0,i=r.r,a=r.startAngle,o=r.endAngle,s=Math.abs(o-a),l=s*i,u=i-n,f=l>Math.abs(u),h=cS([l,u],f?0:1,t),c=(f?s:u)/h.length,v=0;v<h.length;v++)for(var d=(f?u:s)/h[v],p=0;p<h[v];p++){var g={};f?(g.startAngle=a+c*v,g.endAngle=a+c*(v+1),g.r0=n+d*p,g.r=n+d*(p+1)):(g.startAngle=a+d*p,g.endAngle=a+d*(p+1),g.r0=n+c*v,g.r=n+c*(v+1)),g.clockwise=r.clockwise,g.cx=r.cx,g.cy=r.cy,e.push(g)}}function aE(r,t,e){for(var n=r.width,i=r.height,a=n>i,o=cS([n,i],a?0:1,t),s=a?"width":"height",l=a?"height":"width",u=a?"x":"y",f=a?"y":"x",h=r[s]/o.length,c=0;c<o.length;c++)for(var v=r[l]/o[c],d=0;d<o[c];d++){var p={};p[u]=c*h,p[f]=d*v,p[s]=h,p[l]=v,p.x+=r.x,p.y+=r.y,e.push(p)}}function Kg(r,t,e,n){return r*n-e*t}function oE(r,t,e,n,i,a,o,s){var l=e-r,u=n-t,f=o-i,h=s-a,c=Kg(f,h,l,u);if(Math.abs(c)<1e-6)return null;var v=r-i,d=t-a,p=Kg(v,d,f,h)/c;return p<0||p>1?null:new X(p*l+r,p*u+t)}function sE(r,t,e){var n=new X;X.sub(n,e,t),n.normalize();var i=new X;X.sub(i,r,t);var a=i.dot(n);return a}function Jn(r,t){var e=r[r.length-1];e&&e[0]===t[0]&&e[1]===t[1]||r.push(t)}function lE(r,t,e){for(var n=r.length,i=[],a=0;a<n;a++){var o=r[a],s=r[(a+1)%n],l=oE(o[0],o[1],s[0],s[1],t.x,t.y,e.x,e.y);l&&i.push({projPt:sE(l,t,e),pt:l,idx:a})}if(i.length<2)return[{points:r},{points:r}];i.sort(function(g,y){return g.projPt-y.projPt});var u=i[0],f=i[i.length-1];if(f.idx<u.idx){var h=u;u=f,f=h}for(var c=[u.pt.x,u.pt.y],v=[f.pt.x,f.pt.y],d=[c],p=[v],a=u.idx+1;a<=f.idx;a++)Jn(d,r[a].slice());Jn(d,v),Jn(d,c);for(var a=f.idx+1;a<=u.idx+n;a++)Jn(p,r[a%n].slice());return Jn(p,c),Jn(p,v),[{points:d},{points:p}]}function Qg(r){var t=r.points,e=[],n=[];hm(t,e,n);var i=new ut(e[0],e[1],n[0]-e[0],n[1]-e[1]),a=i.width,o=i.height,s=i.x,l=i.y,u=new X,f=new X;return a>o?(u.x=f.x=s+a/2,u.y=l,f.y=l+o):(u.y=f.y=l+o/2,u.x=s,f.x=s+a),lE(t,u,f)}function Os(r,t,e,n){if(e===1)n.push(t);else{var i=Math.floor(e/2),a=r(t);Os(r,a[0],i,n),Os(r,a[1],e-i,n)}return n}function uE(r,t){for(var e=[],n=0;n<t;n++)e.push(Fh(r));return e}function fE(r,t){t.setStyle(r.style),t.z=r.z,t.z2=r.z2,t.zlevel=r.zlevel}function hE(r){for(var t=[],e=0;e<r.length;)t.push([r[e++],r[e++]]);return t}function vE(r,t){var e=[],n=r.shape,i;switch(r.type){case"rect":aE(n,t,e),i=St;break;case"sector":qg(n,t,e),i=Se;break;case"circle":qg({r0:0,r:n.r,startAngle:0,endAngle:Math.PI*2,cx:n.cx,cy:n.cy},t,e),i=Se;break;default:var a=r.getComputedTransform(),o=a?Math.sqrt(Math.max(a[0]*a[0]+a[1]*a[1],a[2]*a[2]+a[3]*a[3])):1,s=H(iE(r.getUpdatedPathProxy(),o),function(y){return hE(y)}),l=s.length;if(l===0)Os(Qg,{points:s[0]},t,e);else if(l===t)for(var u=0;u<l;u++)e.push({points:s[u]});else{var f=0,h=H(s,function(y){var m=[],_=[];hm(y,m,_);var S=(_[1]-m[1])*(_[0]-m[0]);return f+=S,{poly:y,area:S}});h.sort(function(y,m){return m.area-y.area});for(var c=t,u=0;u<l;u++){var v=h[u];if(c<=0)break;var d=u===l-1?c:Math.ceil(v.area/f*t);d<0||(Os(Qg,{points:v.poly},d,e),c-=d)}}i=Pn;break}if(!i)return uE(r,t);for(var p=[],u=0;u<e.length;u++){var g=new i;g.setShape(e[u]),fE(r,g),p.push(g)}return p}function cE(r,t){var e=r.length,n=t.length;if(e===n)return[r,t];for(var i=[],a=[],o=e<n?r:t,s=Math.min(e,n),l=Math.abs(n-e)/6,u=(s-2)/6,f=Math.ceil(l/u)+1,h=[o[0],o[1]],c=l,v=2;v<s;){var d=o[v-2],p=o[v-1],g=o[v++],y=o[v++],m=o[v++],_=o[v++],S=o[v++],w=o[v++];if(c<=0){h.push(g,y,m,_,S,w);continue}for(var x=Math.min(c,f-1)+1,b=1;b<=x;b++){var T=b/x;Vr(d,g,m,S,T,i),Vr(p,y,_,w,T,a),d=i[3],p=a[3],h.push(i[1],a[1],i[2],a[2],d,p),g=i[5],y=a[5],m=i[6],_=a[6]}c-=x-1}return o===r?[h,t]:[r,h]}function Jg(r,t){for(var e=r.length,n=r[e-2],i=r[e-1],a=[],o=0;o<t.length;)a[o++]=n,a[o++]=i;return a}function dE(r,t){for(var e,n,i,a=[],o=[],s=0;s<Math.max(r.length,t.length);s++){var l=r[s],u=t[s],f=void 0,h=void 0;l?u?(e=cE(l,u),f=e[0],h=e[1],n=f,i=h):(h=Jg(i||l,l),f=l):(f=Jg(n||u,u),h=u),a.push(f),o.push(h)}return[a,o]}function jg(r){for(var t=0,e=0,n=0,i=r.length,a=0,o=i-2;a<i;o=a,a+=2){var s=r[o],l=r[o+1],u=r[a],f=r[a+1],h=s*f-u*l;t+=h,e+=(s+u)*h,n+=(l+f)*h}return t===0?[r[0]||0,r[1]||0]:[e/t/3,n/t/3,t]}function pE(r,t,e,n){for(var i=(r.length-2)/6,a=1/0,o=0,s=r.length,l=s-2,u=0;u<i;u++){for(var f=u*6,h=0,c=0;c<s;c+=2){var v=c===0?f:(f+c-2)%l+2,d=r[v]-e[0],p=r[v+1]-e[1],g=t[c]-n[0],y=t[c+1]-n[1],m=g-d,_=y-p;h+=m*m+_*_}h<a&&(a=h,o=u)}return o}function gE(r){for(var t=[],e=r.length,n=0;n<e;n+=2)t[n]=r[e-n-2],t[n+1]=r[e-n-1];return t}function yE(r,t,e,n){for(var i=[],a,o=0;o<r.length;o++){var s=r[o],l=t[o],u=jg(s),f=jg(l);a==null&&(a=u[2]<0!=f[2]<0);var h=[],c=[],v=0,d=1/0,p=[],g=s.length;a&&(s=gE(s));for(var y=pE(s,l,u,f)*6,m=g-2,_=0;_<m;_+=2){var S=(y+_)%m+2;h[_+2]=s[S]-u[0],h[_+3]=s[S+1]-u[1]}h[0]=s[y]-u[0],h[1]=s[y+1]-u[1];for(var w=n/e,x=-n/2;x<=n/2;x+=w){for(var b=Math.sin(x),T=Math.cos(x),C=0,_=0;_<s.length;_+=2){var D=h[_],A=h[_+1],I=l[_]-f[0],L=l[_+1]-f[1],P=I*T-L*b,R=I*b+L*T;p[_]=P,p[_+1]=R;var E=P-D,O=R-A;C+=E*E+O*O}if(C<d){d=C,v=x;for(var k=0;k<p.length;k++)c[k]=p[k]}}i.push({from:h,to:c,fromCp:u,toCp:f,rotation:-v})}return i}function Bs(r){return r.__isCombineMorphing}var dS="__mOriginal_";function Ns(r,t,e){var n=dS+t,i=r[n]||r[t];r[n]||(r[n]=r[t]);var a=e.replace,o=e.after,s=e.before;r[t]=function(){var l=arguments,u;return s&&s.apply(this,l),a?u=a.apply(this,l):u=i.apply(this,l),o&&o.apply(this,l),u}}function La(r,t){var e=dS+t;r[e]&&(r[t]=r[e],r[e]=null)}function ty(r,t){for(var e=0;e<r.length;e++)for(var n=r[e],i=0;i<n.length;){var a=n[i],o=n[i+1];n[i++]=t[0]*a+t[2]*o+t[4],n[i++]=t[1]*a+t[3]*o+t[5]}}function pS(r,t){var e=r.getUpdatedPathProxy(),n=t.getUpdatedPathProxy(),i=dE(ph(e),ph(n)),a=i[0],o=i[1],s=r.getComputedTransform(),l=t.getComputedTransform();function u(){this.transform=null}s&&ty(a,s),l&&ty(o,l),Ns(t,"updateTransform",{replace:u}),t.transform=null;var f=yE(a,o,10,Math.PI),h=[];Ns(t,"buildPath",{replace:function(c){for(var v=t.__morphT,d=1-v,p=[],g=0;g<f.length;g++){var y=f[g],m=y.from,_=y.to,S=y.rotation*v,w=y.fromCp,x=y.toCp,b=Math.sin(S),T=Math.cos(S);Xo(p,w,x,v);for(var C=0;C<m.length;C+=2){var D=m[C],A=m[C+1],I=_[C],L=_[C+1],P=D*d+I*v,R=A*d+L*v;h[C]=P*T-R*b+p[0],h[C+1]=P*b+R*T+p[1]}var E=h[0],O=h[1];c.moveTo(E,O);for(var C=2;C<m.length;){var I=h[C++],L=h[C++],k=h[C++],B=h[C++],z=h[C++],G=h[C++];E===I&&O===L&&k===z&&B===G?c.lineTo(z,G):c.bezierCurveTo(I,L,k,B,z,G),E=z,O=G}}}})}function Ov(r,t,e){if(!r||!t)return t;var n=e.done,i=e.during;pS(r,t),t.__morphT=0;function a(){La(t,"buildPath"),La(t,"updateTransform"),t.__morphT=-1,t.createPathProxy(),t.dirtyShape()}return t.animateTo({__morphT:1},Q({during:function(o){t.dirtyShape(),i&&i(o)},done:function(){a(),n&&n()}},e)),t}function mE(r,t,e,n,i,a){var o=16;r=i===e?0:Math.round(32767*(r-e)/(i-e)),t=a===n?0:Math.round(32767*(t-n)/(a-n));for(var s=0,l,u=(1<<o)/2;u>0;u/=2){var f=0,h=0;(r&u)>0&&(f=1),(t&u)>0&&(h=1),s+=u*u*(3*f^h),h===0&&(f===1&&(r=u-1-r,t=u-1-t),l=r,r=t,t=l)}return s}function Fs(r){var t=1/0,e=1/0,n=-1/0,i=-1/0,a=H(r,function(s){var l=s.getBoundingRect(),u=s.getComputedTransform(),f=l.x+l.width/2+(u?u[4]:0),h=l.y+l.height/2+(u?u[5]:0);return t=Math.min(f,t),e=Math.min(h,e),n=Math.max(f,n),i=Math.max(h,i),[f,h]}),o=H(a,function(s,l){return{cp:s,z:mE(s[0],s[1],t,e,n,i),path:r[l]}});return o.sort(function(s,l){return s.z-l.z}).map(function(s){return s.path})}function gS(r){return vE(r.path,r.count)}function yh(){return{fromIndividuals:[],toIndividuals:[],count:0}}function _E(r,t,e){var n=[];function i(w){for(var x=0;x<w.length;x++){var b=w[x];Bs(b)?i(b.childrenRef()):b instanceof it&&n.push(b)}}i(r);var a=n.length;if(!a)return yh();var o=e.dividePath||gS,s=o({path:t,count:a});if(s.length!==a)return console.error("Invalid morphing: unmatched splitted path"),yh();n=Fs(n),s=Fs(s);for(var l=e.done,u=e.during,f=e.individualDelay,h=new Ka,c=0;c<a;c++){var v=n[c],d=s[c];d.parent=t,d.copyTransform(h),f||pS(v,d)}t.__isCombineMorphing=!0,t.childrenRef=function(){return s};function p(w){for(var x=0;x<s.length;x++)s[x].addSelfToZr(w)}Ns(t,"addSelfToZr",{after:function(w){p(w)}}),Ns(t,"removeSelfFromZr",{after:function(w){for(var x=0;x<s.length;x++)s[x].removeSelfFromZr(w)}});function g(){t.__isCombineMorphing=!1,t.__morphT=-1,t.childrenRef=null,La(t,"addSelfToZr"),La(t,"removeSelfFromZr")}var y=s.length;if(f)for(var m=y,_=function(){m--,m===0&&(g(),l&&l())},c=0;c<y;c++){var S=f?Q({delay:(e.delay||0)+f(c,y,n[c],s[c]),done:_},e):e;Ov(n[c],s[c],S)}else t.__morphT=0,t.animateTo({__morphT:1},Q({during:function(w){for(var x=0;x<y;x++){var b=s[x];b.__morphT=t.__morphT,b.dirtyShape()}u&&u(w)},done:function(){g();for(var w=0;w<r.length;w++)La(r[w],"updateTransform");l&&l()}},e));return t.__zr&&p(t.__zr),{fromIndividuals:n,toIndividuals:s,count:y}}function SE(r,t,e){var n=t.length,i=[],a=e.dividePath||gS;function o(v){for(var d=0;d<v.length;d++){var p=v[d];Bs(p)?o(p.childrenRef()):p instanceof it&&i.push(p)}}if(Bs(r)){o(r.childrenRef());var s=i.length;if(s<n)for(var l=0,u=s;u<n;u++)i.push(Fh(i[l++%s]));i.length=n}else{i=a({path:r,count:n});for(var f=r.getComputedTransform(),u=0;u<i.length;u++)i[u].setLocalTransform(f);if(i.length!==n)return console.error("Invalid morphing: unmatched splitted path"),yh()}i=Fs(i),t=Fs(t);for(var h=e.individualDelay,u=0;u<n;u++){var c=h?Q({delay:(e.delay||0)+h(u,n,i[u],t[u])},e):e;Ov(i[u],t[u],c)}return{fromIndividuals:i,toIndividuals:t,count:t.length}}function ey(r){return V(r[0])}function ry(r,t){for(var e=[],n=r.length,i=0;i<n;i++)e.push({one:r[i],many:[]});for(var i=0;i<t.length;i++){var a=t[i].length,o=void 0;for(o=0;o<a;o++)e[o%n].many.push(t[i][o])}for(var s=0,i=n-1;i>=0;i--)if(!e[i].many.length){var l=e[s].many;if(l.length<=1)if(s)s=0;else return e;var a=l.length,u=Math.ceil(a/2);e[i].many=l.slice(u,a),e[s].many=l.slice(0,u),s++}return e}var xE={clone:function(r){for(var t=[],e=1-Math.pow(1-r.path.style.opacity,1/r.count),n=0;n<r.count;n++){var i=Fh(r.path);i.setStyle("opacity",e),t.push(i)}return t},split:null};function $u(r,t,e,n,i,a){if(!r.length||!t.length)return;var o=tl("update",n,i);if(!(o&&o.duration>0))return;var s=n.getModel("universalTransition").get("delay"),l=Object.assign({setToFinal:!0},o),u,f;ey(r)&&(u=r,f=t),ey(t)&&(u=t,f=r);function h(y,m,_,S,w){var x=y.many,b=y.one;if(x.length===1&&!w){var T=m?x[0]:b,C=m?b:x[0];if(Bs(T))h({many:[T],one:C},!0,_,S,!0);else{var D=s?Q({delay:s(_,S)},l):l;Ov(T,C,D),a(T,C,T,C,D)}}else for(var A=Q({dividePath:xE[e],individualDelay:s&&function(O,k,B,z){return s(O+_,S)}},l),I=m?_E(x,b,A):SE(b,x,A),L=I.fromIndividuals,P=I.toIndividuals,R=L.length,E=0;E<R;E++){var D=s?Q({delay:s(E,R)},l):l;a(L[E],P[E],m?x[E]:y.one,m?y.one:x[E],D)}}for(var c=u?u===r:r.length>t.length,v=u?ry(f,u):ry(c?t:r,[c?r:t]),d=0,p=0;p<v.length;p++)d+=v[p].many.length;for(var g=0,p=0;p<v.length;p++)h(v[p],c,g,d),g+=v[p].many.length}function yn(r){if(!r)return[];if(V(r)){for(var t=[],e=0;e<r.length;e++)t.push(yn(r[e]));return t}var n=[];return r.traverse(function(i){i instanceof it&&!i.disableMorphing&&!i.invisible&&!i.ignore&&n.push(i)}),n}var yS=1e4,wE=0,ny=1,iy=2,bE=_t();function TE(r,t){for(var e=r.dimensions,n=0;n<e.length;n++){var i=r.getDimensionInfo(e[n]);if(i&&i.otherDims[t]===0)return e[n]}}function CE(r,t,e){var n=r.getDimensionInfo(e),i=n&&n.ordinalMeta;if(n){var a=r.get(n.name,t);return i&&i.categories[a]||a+""}}function ay(r,t,e,n){var i=n?"itemChildGroupId":"itemGroupId",a=TE(r,i);if(a){var o=CE(r,t,a);return o}var s=r.getRawDataItem(t),l=n?"childGroupId":"groupId";if(s&&s[l])return s[l]+"";if(!n)return e||r.getId(t)}function oy(r){var t=[];return M(r,function(e){var n=e.data,i=e.dataGroupId;if(!(n.count()>yS))for(var a=n.getIndices(),o=0;o<a.length;o++)t.push({data:n,groupId:ay(n,o,i,!1),childGroupId:ay(n,o,i,!0),divide:e.divide,dataIndex:o})}),t}function qu(r,t,e){r.traverse(function(n){n instanceof it&&Pt(n,{style:{opacity:0}},t,{dataIndex:e,isFrom:!0})})}function Ku(r){if(r.parent){var t=r.getComputedTransform();r.setLocalTransform(t),r.parent.remove(r)}}function jn(r){r.stopAnimation(),r.isGroup&&r.traverse(function(t){t.stopAnimation()})}function DE(r,t,e){var n=tl("update",e,t);n&&r.traverse(function(i){if(i instanceof Pi){var a=ET(i);a&&i.animateFrom({style:a},n)}})}function AE(r,t){var e=r.length;if(e!==t.length)return!1;for(var n=0;n<e;n++){var i=r[n],a=t[n];if(i.data.getId(i.dataIndex)!==a.data.getId(a.dataIndex))return!1}return!0}function mS(r,t,e){var n=oy(r),i=oy(t);function a(_,S,w,x,b){(w||_)&&S.animateFrom({style:w&&w!==_?F(F({},w.style),_.style):_.style},b)}var o=!1,s=wE,l=$(),u=$();n.forEach(function(_){_.groupId&&l.set(_.groupId,!0),_.childGroupId&&u.set(_.childGroupId,!0)});for(var f=0;f<i.length;f++){var h=i[f].groupId;if(u.get(h)){s=ny;break}var c=i[f].childGroupId;if(c&&l.get(c)){s=iy;break}}function v(_,S){return function(w){var x=w.data,b=w.dataIndex;return S?x.getId(b):_?s===ny?w.childGroupId:w.groupId:s===iy?w.childGroupId:w.groupId}}var d=AE(n,i),p={};if(!d)for(var f=0;f<i.length;f++){var g=i[f],y=g.data.getItemGraphicEl(g.dataIndex);y&&(p[y.id]=!0)}function m(_,S){var w=n[S],x=i[_],b=x.data.hostModel,T=w.data.getItemGraphicEl(w.dataIndex),C=x.data.getItemGraphicEl(x.dataIndex);if(T===C){C&&DE(C,x.dataIndex,b);return}T&&p[T.id]||C&&(jn(C),T?(jn(T),Ku(T),o=!0,$u(yn(T),yn(C),x.divide,b,_,a)):qu(C,b,_))}new Wa(n,i,v(!0,d),v(!1,d),null,"multiple").update(m).updateManyToOne(function(_,S){var w=i[_],x=w.data,b=x.hostModel,T=x.getItemGraphicEl(w.dataIndex),C=Tt(H(S,function(D){return n[D].data.getItemGraphicEl(n[D].dataIndex)}),function(D){return D&&D!==T&&!p[D.id]});T&&(jn(T),C.length?(M(C,function(D){jn(D),Ku(D)}),o=!0,$u(yn(C),yn(T),w.divide,b,_,a)):qu(T,b,w.dataIndex))}).updateOneToMany(function(_,S){var w=n[S],x=w.data.getItemGraphicEl(w.dataIndex);if(!(x&&p[x.id])){var b=Tt(H(_,function(C){return i[C].data.getItemGraphicEl(i[C].dataIndex)}),function(C){return C&&C!==x}),T=i[_[0]].data.hostModel;b.length&&(M(b,function(C){return jn(C)}),x?(jn(x),Ku(x),o=!0,$u(yn(x),yn(b),w.divide,T,_[0],a)):M(b,function(C){return qu(C,T,_[0])}))}}).updateManyToMany(function(_,S){new Wa(S,_,function(w){return n[w].data.getId(n[w].dataIndex)},function(w){return i[w].data.getId(i[w].dataIndex)}).update(function(w,x){m(_[w],S[x])}).execute()}).execute(),o&&M(t,function(_){var S=_.data,w=S.hostModel,x=w&&e.getViewOfSeriesModel(w),b=tl("update",w,0);x&&w.isAnimationEnabled()&&b&&b.duration>0&&x.group.traverse(function(T){T instanceof it&&!T.animators.length&&T.animateFrom({style:{opacity:0}},b)})})}function sy(r){var t=r.getModel("universalTransition").get("seriesKey");return t||r.id}function ly(r){return V(r)?r.sort().join(","):r}function Rr(r){if(r.hostModel)return r.hostModel.getModel("universalTransition").get("divideShape")}function ME(r,t){var e=$(),n=$(),i=$();return M(r.oldSeries,function(a,o){var s=r.oldDataGroupIds[o],l=r.oldData[o],u=sy(a),f=ly(u);n.set(f,{dataGroupId:s,data:l}),V(u)&&M(u,function(h){i.set(h,{key:f,dataGroupId:s,data:l})})}),M(t.updatedSeries,function(a){if(a.isUniversalTransitionEnabled()&&a.isAnimationEnabled()){var o=a.get("dataGroupId"),s=a.getData(),l=sy(a),u=ly(l),f=n.get(u);if(f)e.set(u,{oldSeries:[{dataGroupId:f.dataGroupId,divide:Rr(f.data),data:f.data}],newSeries:[{dataGroupId:o,divide:Rr(s),data:s}]});else if(V(l)){var h=[];M(l,function(d){var p=n.get(d);p.data&&h.push({dataGroupId:p.dataGroupId,divide:Rr(p.data),data:p.data})}),h.length&&e.set(u,{oldSeries:h,newSeries:[{dataGroupId:o,data:s,divide:Rr(s)}]})}else{var c=i.get(l);if(c){var v=e.get(c.key);v||(v={oldSeries:[{dataGroupId:c.dataGroupId,data:c.data,divide:Rr(c.data)}],newSeries:[]},e.set(c.key,v)),v.newSeries.push({dataGroupId:o,data:s,divide:Rr(s)})}}}}),e}function uy(r,t){for(var e=0;e<r.length;e++){var n=t.seriesIndex!=null&&t.seriesIndex===r[e].seriesIndex||t.seriesId!=null&&t.seriesId===r[e].id;if(n)return e}}function IE(r,t,e,n){var i=[],a=[];M(It(r.from),function(o){var s=uy(t.oldSeries,o);s>=0&&i.push({dataGroupId:t.oldDataGroupIds[s],data:t.oldData[s],divide:Rr(t.oldData[s]),groupIdDim:o.dimension})}),M(It(r.to),function(o){var s=uy(e.updatedSeries,o);if(s>=0){var l=e.updatedSeries[s].getData();a.push({dataGroupId:t.oldDataGroupIds[s],data:l,divide:Rr(l),groupIdDim:o.dimension})}}),i.length>0&&a.length>0&&mS(i,a,n)}function LE(r){r.registerUpdateLifecycle("series:beforeupdate",function(t,e,n){M(It(n.seriesTransition),function(i){M(It(i.to),function(a){for(var o=n.updatedSeries,s=0;s<o.length;s++)(a.seriesIndex!=null&&a.seriesIndex===o[s].seriesIndex||a.seriesId!=null&&a.seriesId===o[s].id)&&(o[s][as]=!0)})})}),r.registerUpdateLifecycle("series:transition",function(t,e,n){var i=bE(e);if(i.oldSeries&&n.updatedSeries&&n.optionChanged){var a=n.seriesTransition;if(a)M(It(a),function(v){IE(v,i,n,e)});else{var o=ME(i,n);M(o.keys(),function(v){var d=o.get(v);mS(d.oldSeries,d.newSeries,e)})}M(n.updatedSeries,function(v){v[as]&&(v[as]=!1)})}for(var s=t.getSeries(),l=i.oldSeries=[],u=i.oldDataGroupIds=[],f=i.oldData=[],h=0;h<s.length;h++){var c=s[h].getData();c.count()<yS&&(l.push(s[h]),u.push(s[h].get("dataGroupId")),f.push(c))}})}function fy(r,t,e){var n=Mi.createCanvas(),i=t.getWidth(),a=t.getHeight(),o=n.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=i+"px",o.height=a+"px",n.setAttribute("data-zr-dom-id",r)),n.width=i*e,n.height=a*e,n}var Qu=function(r){N(t,r);function t(e,n,i){var a=r.call(this)||this;a.motionBlur=!1,a.lastFrameAlpha=.7,a.dpr=1,a.virtual=!1,a.config={},a.incremental=!1,a.zlevel=0,a.maxRepaintRectCount=5,a.__dirty=!0,a.__firstTimePaint=!0,a.__used=!1,a.__drawIndex=0,a.__startIndex=0,a.__endIndex=0,a.__prevStartIndex=null,a.__prevEndIndex=null;var o;i=i||ps,typeof e=="string"?o=fy(e,n,i):Y(e)&&(o=e,e=o.id),a.id=e,a.dom=o;var s=o.style;return s&&(Cy(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),a.painter=n,a.dpr=i,a}return t.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},t.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},t.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},t.prototype.setUnpainted=function(){this.__firstTimePaint=!0},t.prototype.createBackBuffer=function(){var e=this.dpr;this.domBack=fy("back-"+this.id,this.painter,e),this.ctxBack=this.domBack.getContext("2d"),e!==1&&this.ctxBack.scale(e,e)},t.prototype.createRepaintRects=function(e,n,i,a){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new ut(0,0,0,0);function f(m){if(!(!m.isFinite()||m.isZero()))if(o.length===0){var _=new ut(0,0,0,0);_.copy(m),o.push(_)}else{for(var S=!1,w=1/0,x=0,b=0;b<o.length;++b){var T=o[b];if(T.intersect(m)){var C=new ut(0,0,0,0);C.copy(T),C.union(m),o[b]=C,S=!0;break}else if(l){u.copy(m),u.union(T);var D=m.width*m.height,A=T.width*T.height,I=u.width*u.height,L=I-D-A;L<w&&(w=L,x=b)}}if(l&&(o[x].union(m),S=!0),!S){var _=new ut(0,0,0,0);_.copy(m),o.push(_)}l||(l=o.length>=s)}}for(var h=this.__startIndex;h<this.__endIndex;++h){var c=e[h];if(c){var v=c.shouldBePainted(i,a,!0,!0),d=c.__isRendered&&(c.__dirty&Ke||!v)?c.getPrevPaintRect():null;d&&f(d);var p=v&&(c.__dirty&Ke||!c.__isRendered)?c.getPaintRect():null;p&&f(p)}}for(var h=this.__prevStartIndex;h<this.__prevEndIndex;++h){var c=n[h],v=c&&c.shouldBePainted(i,a,!0,!0);if(c&&(!v||!c.__zr)&&c.__isRendered){var d=c.getPrevPaintRect();d&&f(d)}}var g;do{g=!1;for(var h=0;h<o.length;){if(o[h].isZero()){o.splice(h,1);continue}for(var y=h+1;y<o.length;)o[h].intersect(o[y])?(g=!0,o[h].union(o[y]),o.splice(y,1)):y++;h++}}while(g);return this._paintRects=o,o},t.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},t.prototype.resize=function(e,n){var i=this.dpr,a=this.dom,o=a.style,s=this.domBack;o&&(o.width=e+"px",o.height=n+"px"),a.width=e*i,a.height=n*i,s&&(s.width=e*i,s.height=n*i,i!==1&&this.ctxBack.scale(i,i))},t.prototype.clear=function(e,n,i){var a=this.dom,o=this.ctx,s=a.width,l=a.height;n=n||this.clearColor;var u=this.motionBlur&&!e,f=this.lastFrameAlpha,h=this.dpr,c=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(a,0,0,s/h,l/h));var v=this.domBack;function d(p,g,y,m){if(o.clearRect(p,g,y,m),n&&n!=="transparent"){var _=void 0;if(Vs(n)){var S=n.global||n.__width===y&&n.__height===m;_=S&&n.__canvasGradient||Hf(o,n,{x:0,y:0,width:y,height:m}),n.__canvasGradient=_,n.__width=y,n.__height=m}else ex(n)&&(n.scaleX=n.scaleX||h,n.scaleY=n.scaleY||h,_=Wf(o,n,{dirty:function(){c.setUnpainted(),c.painter.refresh()}}));o.save(),o.fillStyle=_||n,o.fillRect(p,g,y,m),o.restore()}u&&(o.save(),o.globalAlpha=f,o.drawImage(v,p,g,y,m),o.restore())}!i||u?d(0,0,s,l):i.length&&M(i,function(p){d(p.x*h,p.y*h,p.width*h,p.height*h)})},t}(Be),hy=1e5,gn=314159,Yo=.01,PE=.001;function RE(r){return r?r.__builtin__?!0:!(typeof r.resize!="function"||typeof r.refresh!="function"):!1}function EE(r,t){var e=document.createElement("div");return e.style.cssText=["position:relative","width:"+r+"px","height:"+t+"px","padding:0","margin:0","border-width:0"].join(";")+";",e}var kE=function(){function r(t,e,n,i){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var a=!t.nodeName||t.nodeName.toUpperCase()==="CANVAS";this._opts=n=F({},n||{}),this.dpr=n.devicePixelRatio||ps,this._singleCanvas=a,this.root=t;var o=t.style;o&&(Cy(t),t.innerHTML=""),this.storage=e;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(a){var f=t,h=f.width,c=f.height;n.width!=null&&(h=n.width),n.height!=null&&(c=n.height),this.dpr=n.devicePixelRatio||1,f.width=h*this.dpr,f.height=c*this.dpr,this._width=h,this._height=c;var v=new Qu(f,this,this.dpr);v.__builtin__=!0,v.initContext(),l[gn]=v,v.zlevel=gn,s.push(gn),this._domRoot=t}else{this._width=Mo(t,0,n),this._height=Mo(t,1,n);var u=this._domRoot=EE(this._width,this._height);t.appendChild(u)}}return r.prototype.getType=function(){return"canvas"},r.prototype.isSingleCanvas=function(){return this._singleCanvas},r.prototype.getViewportRoot=function(){return this._domRoot},r.prototype.getViewportRootOffset=function(){var t=this.getViewportRoot();if(t)return{offsetLeft:t.offsetLeft||0,offsetTop:t.offsetTop||0}},r.prototype.refresh=function(t){var e=this.storage.getDisplayList(!0),n=this._prevDisplayList,i=this._zlevelList;this._redrawId=Math.random(),this._paintList(e,n,t,this._redrawId);for(var a=0;a<i.length;a++){var o=i[a],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=a===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=e.slice()),this},r.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},r.prototype._paintHoverList=function(t){var e=t.length,n=this._hoverlayer;if(n&&n.clear(),!!e){for(var i={inHover:!0,viewWidth:this._width,viewHeight:this._height},a,o=0;o<e;o++){var s=t[o];s.__inHover&&(n||(n=this._hoverlayer=this.getLayer(hy)),a||(a=n.ctx,a.save()),xn(a,s,i,o===e-1))}a&&a.restore()}},r.prototype.getHoverLayer=function(){return this.getLayer(hy)},r.prototype.paintOne=function(t,e){K0(t,e)},r.prototype._paintList=function(t,e,n,i){if(this._redrawId===i){n=n||!1,this._updateLayerStatus(t);var a=this._doPaintList(t,e,n),o=a.finished,s=a.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(t),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;hs(function(){l._paintList(t,e,n,i)})}}},r.prototype._compositeManually=function(){var t=this.getLayer(gn).ctx,e=this._domRoot.width,n=this._domRoot.height;t.clearRect(0,0,e,n),this.eachBuiltinLayer(function(i){i.virtual&&t.drawImage(i.dom,0,0,e,n)})},r.prototype._doPaintList=function(t,e,n){for(var i=this,a=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||n)&&a.push(u)}for(var f=!0,h=!1,c=function(p){var g=a[p],y=g.ctx,m=o&&g.createRepaintRects(t,e,v._width,v._height),_=n?g.__startIndex:g.__drawIndex,S=!n&&g.incremental&&Date.now,w=S&&Date.now(),x=g.zlevel===v._zlevelList[0]?v._backgroundColor:null;if(g.__startIndex===g.__endIndex)g.clear(!1,x,m);else if(_===g.__startIndex){var b=t[_];(!b.incremental||!b.notClear||n)&&g.clear(!1,x,m)}_===-1&&(console.error("For some unknown reason. drawIndex is -1"),_=g.__startIndex);var T,C=function(L){var P={inHover:!1,allClipped:!1,prevEl:null,viewWidth:i._width,viewHeight:i._height};for(T=_;T<g.__endIndex;T++){var R=t[T];if(R.__inHover&&(h=!0),i._doPaintEl(R,g,o,L,P,T===g.__endIndex-1),S){var E=Date.now()-w;if(E>15)break}}P.prevElClipPaths&&y.restore()};if(m)if(m.length===0)T=g.__endIndex;else for(var D=v.dpr,A=0;A<m.length;++A){var I=m[A];y.save(),y.beginPath(),y.rect(I.x*D,I.y*D,I.width*D,I.height*D),y.clip(),C(I),y.restore()}else y.save(),C(),y.restore();g.__drawIndex=T,g.__drawIndex<g.__endIndex&&(f=!1)},v=this,d=0;d<a.length;d++)c(d);return J.wxa&&M(this._layers,function(p){p&&p.ctx&&p.ctx.draw&&p.ctx.draw()}),{finished:f,needsRefreshHover:h}},r.prototype._doPaintEl=function(t,e,n,i,a,o){var s=e.ctx;if(n){var l=t.getPaintRect();(!i||l&&l.intersect(i))&&(xn(s,t,a,o),t.setPrevPaintRect(l))}else xn(s,t,a,o)},r.prototype.getLayer=function(t,e){this._singleCanvas&&!this._needsManuallyCompositing&&(t=gn);var n=this._layers[t];return n||(n=new Qu("zr_"+t,this,this.dpr),n.zlevel=t,n.__builtin__=!0,this._layerConfig[t]?nt(n,this._layerConfig[t],!0):this._layerConfig[t-Yo]&&nt(n,this._layerConfig[t-Yo],!0),e&&(n.virtual=e),this.insertLayer(t,n),n.initContext()),n},r.prototype.insertLayer=function(t,e){var n=this._layers,i=this._zlevelList,a=i.length,o=this._domRoot,s=null,l=-1;if(!n[t]&&RE(e)){if(a>0&&t>i[0]){for(l=0;l<a-1&&!(i[l]<t&&i[l+1]>t);l++);s=n[i[l]]}if(i.splice(l+1,0,t),n[t]=e,!e.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(e.dom,u.nextSibling):o.appendChild(e.dom)}else o.firstChild?o.insertBefore(e.dom,o.firstChild):o.appendChild(e.dom);e.painter||(e.painter=this)}},r.prototype.eachLayer=function(t,e){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i];t.call(e,this._layers[a],a)}},r.prototype.eachBuiltinLayer=function(t,e){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i],o=this._layers[a];o.__builtin__&&t.call(e,o,a)}},r.prototype.eachOtherLayer=function(t,e){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i],o=this._layers[a];o.__builtin__||t.call(e,o,a)}},r.prototype.getLayers=function(){return this._layers},r.prototype._updateLayerStatus=function(t){this.eachBuiltinLayer(function(h,c){h.__dirty=h.__used=!1});function e(h){a&&(a.__endIndex!==h&&(a.__dirty=!0),a.__endIndex=h)}if(this._singleCanvas)for(var n=1;n<t.length;n++){var i=t[n];if(i.zlevel!==t[n-1].zlevel||i.incremental){this._needsManuallyCompositing=!0;break}}var a=null,o=0,s,l;for(l=0;l<t.length;l++){var i=t[l],u=i.zlevel,f=void 0;s!==u&&(s=u,o=0),i.incremental?(f=this.getLayer(u+PE,this._needsManuallyCompositing),f.incremental=!0,o=1):f=this.getLayer(u+(o>0?Yo:0),this._needsManuallyCompositing),f.__builtin__||wh("ZLevel "+u+" has been used by unkown layer "+f.id),f!==a&&(f.__used=!0,f.__startIndex!==l&&(f.__dirty=!0),f.__startIndex=l,f.incremental?f.__drawIndex=-1:f.__drawIndex=l,e(l),a=f),i.__dirty&Ke&&!i.__inHover&&(f.__dirty=!0,f.incremental&&f.__drawIndex<0&&(f.__drawIndex=l))}e(l),this.eachBuiltinLayer(function(h,c){!h.__used&&h.getElementCount()>0&&(h.__dirty=!0,h.__startIndex=h.__endIndex=h.__drawIndex=0),h.__dirty&&h.__drawIndex<0&&(h.__drawIndex=h.__startIndex)})},r.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},r.prototype._clearLayer=function(t){t.clear()},r.prototype.setBackgroundColor=function(t){this._backgroundColor=t,M(this._layers,function(e){e.setUnpainted()})},r.prototype.configLayer=function(t,e){if(e){var n=this._layerConfig;n[t]?nt(n[t],e,!0):n[t]=e;for(var i=0;i<this._zlevelList.length;i++){var a=this._zlevelList[i];if(a===t||a===t+Yo){var o=this._layers[a];nt(o,n[t],!0)}}}},r.prototype.delLayer=function(t){var e=this._layers,n=this._zlevelList,i=e[t];i&&(i.dom.parentNode.removeChild(i.dom),delete e[t],n.splice(lt(n,t),1))},r.prototype.resize=function(t,e){if(this._domRoot.style){var n=this._domRoot;n.style.display="none";var i=this._opts,a=this.root;if(t!=null&&(i.width=t),e!=null&&(i.height=e),t=Mo(a,0,i),e=Mo(a,1,i),n.style.display="",this._width!==t||e!==this._height){n.style.width=t+"px",n.style.height=e+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(t,e);this.refresh(!0)}this._width=t,this._height=e}else{if(t==null||e==null)return;this._width=t,this._height=e,this.getLayer(gn).resize(t,e)}return this},r.prototype.clearLayer=function(t){var e=this._layers[t];e&&e.clear()},r.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},r.prototype.getRenderedCanvas=function(t){if(t=t||{},this._singleCanvas&&!this._compositeManually)return this._layers[gn].dom;var e=new Qu("image",this,t.pixelRatio||this.dpr);e.initContext(),e.clear(!1,t.backgroundColor||this._backgroundColor);var n=e.ctx;if(t.pixelRatio<=this.dpr){this.refresh();var i=e.dom.width,a=e.dom.height;this.eachLayer(function(h){h.__builtin__?n.drawImage(h.dom,0,0,i,a):h.renderToCanvas&&(n.save(),h.renderToCanvas(n),n.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var f=s[l];xn(n,f,o,l===u-1)}return e.dom},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r}();function OE(r){r.registerPainter("canvas",kE)}ke([PR,GR,MR,_P,nE,tE,uR,oI,Y2,gI,QI,$L,lL,mL,T2,LE,OE]);function _S(r,t={}){const e=LS(),n=PS(),i=ls(()=>n.darkMode),a=vy(null),o={width:0,height:0},{width:s,height:l}=RS(a,o);let u=null;const f=r(),{onRender:h=b=>{const T=i.value?"rgb(224, 224, 224)":"rgb(31, 31, 31)",C=i.value?"rgba(0, 0, 0, 0.4)":"rgba(255, 255, 255, 0.8)";b.showLoading({color:n.themeColor,textColor:T,fontSize:14,maskColor:C})},onUpdated:c=b=>{b.hideLoading()},onDestroy:v}=t;function d(){return a.value&&o.width>0&&o.height>0}function p(){return!!(a.value&&u)}async function g(b=()=>f){if(!p())return;const T=b(f,r);Object.assign(f,T),p()&&(u==null||u.clear()),u==null||u.setOption({...T,backgroundColor:"transparent"}),await(c==null?void 0:c(u))}function y(b){u==null||u.setOption(b)}async function m(){if(!p()){const b=i.value?"dark":"light";await py(),u=qA(a.value,b),u.setOption({...f,backgroundColor:"transparent"}),await(h==null?void 0:h(u))}}function _(){u==null||u.resize()}async function S(){u&&(await(v==null?void 0:v(u)),u==null||u.dispose(),u=null)}async function w(){await S(),await m(),await(c==null?void 0:c(u))}async function x(b,T){if(o.width=b,o.height=T,!d()){await S();return}p()&&_(),await m()}return e.run(()=>{Pa([s,l],([b,T])=>{x(b,T)}),Pa(i,()=>{w()})}),ES(()=>{S(),e.stop()}),{domRef:a,updateOptions:g,setOptions:y}}const BE=$a({name:"LineChart",__name:"line-chart",setup(r){const t=gy(),{domRef:e,updateOptions:n}=_S(()=>({tooltip:{trigger:"axis",axisPointer:{type:"cross",label:{backgroundColor:"#6a7985"}}},legend:{data:[Bt("page.home.downloadCount"),Bt("page.home.registerCount")]},grid:{left:"3%",right:"4%",bottom:"3%",containLabel:!0},xAxis:{type:"category",boundaryGap:!1,data:[]},yAxis:{type:"value"},series:[{color:"#8e9dff",name:Bt("page.home.downloadCount"),type:"line",smooth:!0,stack:"Total",areaStyle:{color:{type:"linear",x:0,y:0,x2:0,y2:1,colorStops:[{offset:.25,color:"#8e9dff"},{offset:1,color:"#fff"}]}},emphasis:{focus:"series"},data:[]},{color:"#26deca",name:Bt("page.home.registerCount"),type:"line",smooth:!0,stack:"Total",areaStyle:{color:{type:"linear",x:0,y:0,x2:0,y2:1,colorStops:[{offset:.25,color:"#26deca"},{offset:1,color:"#fff"}]}},emphasis:{focus:"series"},data:[]}]}));async function i(){await new Promise(s=>{setTimeout(s,1e3)}),n(s=>(s.xAxis.data=["06:00","08:00","10:00","12:00","14:00","16:00","18:00","20:00","22:00","24:00"],s.series[0].data=[4623,6145,6268,6411,1890,4251,2978,3880,3606,4311],s.series[1].data=[2208,2016,2916,4512,8281,2008,1963,2367,2956,678],s))}function a(){n((s,l)=>{const u=l();return s.legend.data=u.legend.data,s.series[0].name=u.series[0].name,s.series[1].name=u.series[1].name,s})}async function o(){i()}return Pa(()=>t.locale,()=>{a()}),o(),(s,l)=>{const u=mh;return Er(),li(u,{bordered:!1,class:"card-wrapper"},{default:Pe(()=>[pa("div",{ref_key:"domRef",ref:e,class:"h-360px overflow-hidden"},null,512)]),_:1})}}}),NE=$a({name:"PieChart",__name:"pie-chart",setup(r){const t=gy(),{domRef:e,updateOptions:n}=_S(()=>({tooltip:{trigger:"item"},legend:{bottom:"1%",left:"center",itemStyle:{borderWidth:0}},series:[{color:["#5da8ff","#8e9dff","#fedc69","#26deca"],name:Bt("page.home.schedule"),type:"pie",radius:["45%","75%"],avoidLabelOverlap:!1,itemStyle:{borderRadius:10,borderColor:"#fff",borderWidth:1},label:{show:!1,position:"center"},emphasis:{label:{show:!0,fontSize:"12"}},labelLine:{show:!1},data:[]}]}));async function i(){await new Promise(s=>{setTimeout(s,1e3)}),n(s=>(s.series[0].data=[{name:Bt("page.home.study"),value:20},{name:Bt("page.home.entertainment"),value:10},{name:Bt("page.home.work"),value:40},{name:Bt("page.home.rest"),value:30}],s))}function a(){n((s,l)=>{const u=l();return s.series[0].name=u.series[0].name,s.series[0].data=[{name:Bt("page.home.study"),value:20},{name:Bt("page.home.entertainment"),value:10},{name:Bt("page.home.work"),value:40},{name:Bt("page.home.rest"),value:30}],s})}async function o(){i()}return Pa(()=>t.locale,()=>{a()}),o(),(s,l)=>{const u=mh;return Er(),li(u,{bordered:!1,class:"card-wrapper"},{default:Pe(()=>[pa("div",{ref_key:"domRef",ref:e,class:"h-360px overflow-hidden"},null,512)]),_:1})}}}),VE=$a({name:"home",__name:"index",setup(r){return(t,e)=>{const n=my,i=yy,a=kS;return Er(),li(a,{direction:"vertical",size:16},{default:Pe(()=>[Ie(FS),Ie(i,{gutter:[16,16]},{default:Pe(()=>[Ie(n,{span:24,lg:14},{default:Pe(()=>[Ie(BE)]),_:1}),Ie(n,{span:24,lg:10},{default:Pe(()=>[Ie(NE)]),_:1})]),_:1})]),_:1})}}});export{VE as default};
